-- Adminer 4.8.4 MySQL 8.2.0 dump

SET NAMES utf8;
SET time_zone = '+00:00';
SET foreign_key_checks = 0;
SET sql_mode = 'NO_AUTO_VALUE_ON_ZERO';

SET NAMES utf8mb4;

DROP TABLE IF EXISTS `batch`;
CREATE TABLE `batch` (
  `bid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique batch ID.',
  `token` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'A string token generated against the current user''s session id and the batch id, used to ensure that only the user who submitted the batch can effectively access it.',
  `timestamp` int NOT NULL COMMENT 'A Unix timestamp indicating when this batch was submitted for processing. Stale batches are purged at cron time.',
  `batch` longblob COMMENT 'A serialized array containing the processing data for the batch.',
  PRIMARY KEY (`bid`),
  KEY `token` (`token`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores details about batches (processes that run in…';


DROP TABLE IF EXISTS `block_content`;
CREATE TABLE `block_content` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `block_content_field__uuid__value` (`uuid`),
  UNIQUE KEY `block_content__revision_id` (`revision_id`),
  KEY `block_content_field__type__target_id` (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for block_content entities.';


DROP TABLE IF EXISTS `block_content__body`;
CREATE TABLE `block_content__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field body.';


DROP TABLE IF EXISTS `block_content__field_ebt_accordion`;
CREATE TABLE `block_content__field_ebt_accordion` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_accordion_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_accordion_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_accordion_target_id` (`field_ebt_accordion_target_id`),
  KEY `field_ebt_accordion_target_revision_id` (`field_ebt_accordion_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_accordion.';


DROP TABLE IF EXISTS `block_content__field_ebt_basic_button_link`;
CREATE TABLE `block_content__field_ebt_basic_button_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_basic_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_basic_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_basic_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_basic_button_link_uri` (`field_ebt_basic_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_basic_button…';


DROP TABLE IF EXISTS `block_content__field_ebt_block_block`;
CREATE TABLE `block_content__field_ebt_block_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_block_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ebt_block_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_block_block_plugin_id` (`field_ebt_block_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_block_block.';


DROP TABLE IF EXISTS `block_content__field_ebt_bootstrap_button_link`;
CREATE TABLE `block_content__field_ebt_bootstrap_button_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_bootstrap_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_bootstrap_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_bootstrap_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_bootstrap_button_link_uri` (`field_ebt_bootstrap_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_bootstrap…';


DROP TABLE IF EXISTS `block_content__field_ebt_carousel`;
CREATE TABLE `block_content__field_ebt_carousel` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_carousel_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_carousel_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_carousel_target_id` (`field_ebt_carousel_target_id`),
  KEY `field_ebt_carousel_target_revision_id` (`field_ebt_carousel_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_carousel.';


DROP TABLE IF EXISTS `block_content__field_ebt_columns_blocks`;
CREATE TABLE `block_content__field_ebt_columns_blocks` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_columns_blocks_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ebt_columns_blocks_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_columns_blocks_plugin_id` (`field_ebt_columns_blocks_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_columns…';


DROP TABLE IF EXISTS `block_content__field_ebt_countdown_date`;
CREATE TABLE `block_content__field_ebt_countdown_date` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_countdown_date_value` varchar(20) NOT NULL COMMENT 'The date value.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_countdown_date_value` (`field_ebt_countdown_date_value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_countdown…';


DROP TABLE IF EXISTS `block_content__field_ebt_counter_icon`;
CREATE TABLE `block_content__field_ebt_counter_icon` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_icon_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_counter_icon_target_id` (`field_ebt_counter_icon_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_counter_icon.';


DROP TABLE IF EXISTS `block_content__field_ebt_counter_items`;
CREATE TABLE `block_content__field_ebt_counter_items` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_items_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_counter_items_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_counter_items_target_id` (`field_ebt_counter_items_target_id`),
  KEY `field_ebt_counter_items_target_revision_id` (`field_ebt_counter_items_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_counter…';


DROP TABLE IF EXISTS `block_content__field_ebt_counter_number`;
CREATE TABLE `block_content__field_ebt_counter_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_number_value` int NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_counter…';


DROP TABLE IF EXISTS `block_content__field_ebt_cta_column_image`;
CREATE TABLE `block_content__field_ebt_cta_column_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_cta_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_cta_column_image_target_id` (`field_ebt_cta_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_cta_column…';


DROP TABLE IF EXISTS `block_content__field_ebt_cta_link`;
CREATE TABLE `block_content__field_ebt_cta_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_cta_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_cta_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_cta_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_cta_link_uri` (`field_ebt_cta_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_cta_link.';


DROP TABLE IF EXISTS `block_content__field_ebt_cta_second_link`;
CREATE TABLE `block_content__field_ebt_cta_second_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_cta_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_cta_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_cta_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_cta_second_link_uri` (`field_ebt_cta_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_cta_second…';


DROP TABLE IF EXISTS `block_content__field_ebt_cta_title`;
CREATE TABLE `block_content__field_ebt_cta_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_cta_title_value` longtext NOT NULL,
  `field_ebt_cta_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_cta_title_format` (`field_ebt_cta_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_cta_title.';


DROP TABLE IF EXISTS `block_content__field_ebt_hero_column_image`;
CREATE TABLE `block_content__field_ebt_hero_column_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_hero_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_hero_column_image_target_id` (`field_ebt_hero_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_hero_column…';


DROP TABLE IF EXISTS `block_content__field_ebt_hero_link`;
CREATE TABLE `block_content__field_ebt_hero_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_hero_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_hero_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_hero_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_hero_link_uri` (`field_ebt_hero_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_hero_link.';


DROP TABLE IF EXISTS `block_content__field_ebt_hero_second_link`;
CREATE TABLE `block_content__field_ebt_hero_second_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_hero_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_hero_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_hero_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_hero_second_link_uri` (`field_ebt_hero_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_hero_second…';


DROP TABLE IF EXISTS `block_content__field_ebt_hero_title`;
CREATE TABLE `block_content__field_ebt_hero_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_hero_title_value` longtext NOT NULL,
  `field_ebt_hero_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_hero_title_format` (`field_ebt_hero_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_hero_title.';


DROP TABLE IF EXISTS `block_content__field_ebt_hero_title_prefix`;
CREATE TABLE `block_content__field_ebt_hero_title_prefix` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_hero_title_prefix_value` longtext NOT NULL,
  `field_ebt_hero_title_prefix_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_hero_title_prefix_format` (`field_ebt_hero_title_prefix_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_hero_title…';


DROP TABLE IF EXISTS `block_content__field_ebt_image`;
CREATE TABLE `block_content__field_ebt_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_image_target_id` (`field_ebt_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_image.';


DROP TABLE IF EXISTS `block_content__field_ebt_image_caption`;
CREATE TABLE `block_content__field_ebt_image_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_image_caption_value` longtext NOT NULL,
  `field_ebt_image_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_image_caption_format` (`field_ebt_image_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_image…';


DROP TABLE IF EXISTS `block_content__field_ebt_image_gallery`;
CREATE TABLE `block_content__field_ebt_image_gallery` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_image_gallery_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_image_gallery_target_id` (`field_ebt_image_gallery_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_image…';


DROP TABLE IF EXISTS `block_content__field_ebt_image_link`;
CREATE TABLE `block_content__field_ebt_image_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_image_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_image_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_image_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_image_link_uri` (`field_ebt_image_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_image_link.';


DROP TABLE IF EXISTS `block_content__field_ebt_micromodal_title`;
CREATE TABLE `block_content__field_ebt_micromodal_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_micromodal_title_value` longtext NOT NULL,
  `field_ebt_micromodal_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_micromodal_title_format` (`field_ebt_micromodal_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_micromodal…';


DROP TABLE IF EXISTS `block_content__field_ebt_quote_author`;
CREATE TABLE `block_content__field_ebt_quote_author` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_quote_author_value` longtext NOT NULL,
  `field_ebt_quote_author_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_quote_author_format` (`field_ebt_quote_author_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_quote_author.';


DROP TABLE IF EXISTS `block_content__field_ebt_quote_image`;
CREATE TABLE `block_content__field_ebt_quote_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_quote_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_quote_image_target_id` (`field_ebt_quote_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_quote_image.';


DROP TABLE IF EXISTS `block_content__field_ebt_settings`;
CREATE TABLE `block_content__field_ebt_settings` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_settings_ebt_settings` longblob COMMENT 'Serialized block settings data',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_settings.';


DROP TABLE IF EXISTS `block_content__field_ebt_slick_slider`;
CREATE TABLE `block_content__field_ebt_slick_slider` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slick_slider_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_slick_slider_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slick_slider_target_id` (`field_ebt_slick_slider_target_id`),
  KEY `field_ebt_slick_slider_target_revision_id` (`field_ebt_slick_slider_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_slick_slider.';


DROP TABLE IF EXISTS `block_content__field_ebt_slideshow`;
CREATE TABLE `block_content__field_ebt_slideshow` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slideshow_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_slideshow_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slideshow_target_id` (`field_ebt_slideshow_target_id`),
  KEY `field_ebt_slideshow_target_revision_id` (`field_ebt_slideshow_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_slideshow.';


DROP TABLE IF EXISTS `block_content__field_ebt_stats`;
CREATE TABLE `block_content__field_ebt_stats` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_stats_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_stats_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_stats_target_id` (`field_ebt_stats_target_id`),
  KEY `field_ebt_stats_target_revision_id` (`field_ebt_stats_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_stats.';


DROP TABLE IF EXISTS `block_content__field_ebt_tabs`;
CREATE TABLE `block_content__field_ebt_tabs` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tabs_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_tabs_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tabs_target_id` (`field_ebt_tabs_target_id`),
  KEY `field_ebt_tabs_target_revision_id` (`field_ebt_tabs_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_tabs.';


DROP TABLE IF EXISTS `block_content__field_ebt_tiles`;
CREATE TABLE `block_content__field_ebt_tiles` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tiles_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_tiles_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tiles_target_id` (`field_ebt_tiles_target_id`),
  KEY `field_ebt_tiles_target_revision_id` (`field_ebt_tiles_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_tiles.';


DROP TABLE IF EXISTS `block_content__field_ebt_timeline`;
CREATE TABLE `block_content__field_ebt_timeline` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_timeline_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_timeline_target_id` (`field_ebt_timeline_target_id`),
  KEY `field_ebt_timeline_target_revision_id` (`field_ebt_timeline_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_timeline.';


DROP TABLE IF EXISTS `block_content__field_ebt_video`;
CREATE TABLE `block_content__field_ebt_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_video_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_video_target_id` (`field_ebt_video_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_video.';


DROP TABLE IF EXISTS `block_content__field_ebt_videos_and_images`;
CREATE TABLE `block_content__field_ebt_videos_and_images` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_videos_and_images_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_videos_and_images_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_videos_and_images_target_id` (`field_ebt_videos_and_images_target_id`),
  KEY `field_ebt_videos_and_images_target_revision_id` (`field_ebt_videos_and_images_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_videos_and…';


DROP TABLE IF EXISTS `block_content__field_ebt_views_views`;
CREATE TABLE `block_content__field_ebt_views_views` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_views_views_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_views_views_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ebt_views_views_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_views_views_target_id` (`field_ebt_views_views_target_id`),
  KEY `field_ebt_views_views_display_id` (`field_ebt_views_views_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_views_views.';


DROP TABLE IF EXISTS `block_content__field_ebt_webform_form`;
CREATE TABLE `block_content__field_ebt_webform_form` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_webform_form_target_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the webform entity.',
  `field_ebt_webform_form_default_data` text COMMENT 'Default submission data.',
  `field_ebt_webform_form_status` varchar(20) DEFAULT NULL COMMENT 'Flag to control whether this webform should be open, closed, or scheduled for new submissions.',
  `field_ebt_webform_form_open` varchar(20) DEFAULT NULL COMMENT 'The open date/time.',
  `field_ebt_webform_form_close` varchar(20) DEFAULT NULL COMMENT 'The close date/time.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_webform_form_target_id` (`field_ebt_webform_form_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_webform_form.';


DROP TABLE IF EXISTS `block_content__field_ebt_webform_popup_form`;
CREATE TABLE `block_content__field_ebt_webform_popup_form` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_webform_popup_form_target_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the webform entity.',
  `field_ebt_webform_popup_form_default_data` text COMMENT 'Default submission data.',
  `field_ebt_webform_popup_form_status` varchar(20) DEFAULT NULL COMMENT 'Flag to control whether this webform should be open, closed, or scheduled for new submissions.',
  `field_ebt_webform_popup_form_open` varchar(20) DEFAULT NULL COMMENT 'The open date/time.',
  `field_ebt_webform_popup_form_close` varchar(20) DEFAULT NULL COMMENT 'The close date/time.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_webform_popup_form_target_id` (`field_ebt_webform_popup_form_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for block_content field field_ebt_webform…';


DROP TABLE IF EXISTS `block_content_field_data`;
CREATE TABLE `block_content_field_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `info` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `reusable` tinyint DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `block_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `block_content__revision_id` (`revision_id`),
  KEY `block_content_field__type__target_id` (`type`),
  KEY `block_content_field__reusable` (`reusable`),
  KEY `block_content__status_type` (`status`,`type`,`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for block_content entities.';


DROP TABLE IF EXISTS `block_content_field_revision`;
CREATE TABLE `block_content_field_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `info` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `block_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for block_content entities.';


DROP TABLE IF EXISTS `block_content_r__1d98dd7393`;
CREATE TABLE `block_content_r__1d98dd7393` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_hero_title_prefix_value` longtext NOT NULL,
  `field_ebt_hero_title_prefix_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_hero_title_prefix_format` (`field_ebt_hero_title_prefix_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_r__2d12375ee7`;
CREATE TABLE `block_content_r__2d12375ee7` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_bootstrap_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_bootstrap_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_bootstrap_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_bootstrap_button_link_uri` (`field_ebt_bootstrap_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_r__340d64eab4`;
CREATE TABLE `block_content_r__340d64eab4` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_videos_and_images_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_videos_and_images_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_videos_and_images_target_id` (`field_ebt_videos_and_images_target_id`),
  KEY `field_ebt_videos_and_images_target_revision_id` (`field_ebt_videos_and_images_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_r__5ab1225ba6`;
CREATE TABLE `block_content_r__5ab1225ba6` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_hero_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_hero_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_hero_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_hero_second_link_uri` (`field_ebt_hero_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_r__6145a3a301`;
CREATE TABLE `block_content_r__6145a3a301` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_basic_button_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_basic_button_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_basic_button_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_basic_button_link_uri` (`field_ebt_basic_button_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_r__6a87f4fdb7`;
CREATE TABLE `block_content_r__6a87f4fdb7` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_cta_second_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_cta_second_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_cta_second_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_cta_second_link_uri` (`field_ebt_cta_second_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_r__abebd0b113`;
CREATE TABLE `block_content_r__abebd0b113` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_micromodal_title_value` longtext NOT NULL,
  `field_ebt_micromodal_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_micromodal_title_format` (`field_ebt_micromodal_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_r__b1f6f83596`;
CREATE TABLE `block_content_r__b1f6f83596` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_webform_popup_form_target_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the webform entity.',
  `field_ebt_webform_popup_form_default_data` text COMMENT 'Default submission data.',
  `field_ebt_webform_popup_form_status` varchar(20) DEFAULT NULL COMMENT 'Flag to control whether this webform should be open, closed, or scheduled for new submissions.',
  `field_ebt_webform_popup_form_open` varchar(20) DEFAULT NULL COMMENT 'The open date/time.',
  `field_ebt_webform_popup_form_close` varchar(20) DEFAULT NULL COMMENT 'The close date/time.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_webform_popup_form_target_id` (`field_ebt_webform_popup_form_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_r__b5f82fb056`;
CREATE TABLE `block_content_r__b5f82fb056` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_cta_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_cta_column_image_target_id` (`field_ebt_cta_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_r__c4c7d0dccb`;
CREATE TABLE `block_content_r__c4c7d0dccb` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_hero_column_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_hero_column_image_target_id` (`field_ebt_hero_column_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision`;
CREATE TABLE `block_content_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `block_content__id` (`id`),
  KEY `block_content_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for block_content entities.';


DROP TABLE IF EXISTS `block_content_revision__body`;
CREATE TABLE `block_content_revision__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field body.';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_accordion`;
CREATE TABLE `block_content_revision__field_ebt_accordion` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_accordion_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_accordion_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_accordion_target_id` (`field_ebt_accordion_target_id`),
  KEY `field_ebt_accordion_target_revision_id` (`field_ebt_accordion_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_block_block`;
CREATE TABLE `block_content_revision__field_ebt_block_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_block_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ebt_block_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_block_block_plugin_id` (`field_ebt_block_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_carousel`;
CREATE TABLE `block_content_revision__field_ebt_carousel` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_carousel_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_carousel_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_carousel_target_id` (`field_ebt_carousel_target_id`),
  KEY `field_ebt_carousel_target_revision_id` (`field_ebt_carousel_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_columns_blocks`;
CREATE TABLE `block_content_revision__field_ebt_columns_blocks` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_columns_blocks_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ebt_columns_blocks_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_columns_blocks_plugin_id` (`field_ebt_columns_blocks_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_countdown_date`;
CREATE TABLE `block_content_revision__field_ebt_countdown_date` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_countdown_date_value` varchar(20) NOT NULL COMMENT 'The date value.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_countdown_date_value` (`field_ebt_countdown_date_value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_counter_icon`;
CREATE TABLE `block_content_revision__field_ebt_counter_icon` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_icon_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_counter_icon_target_id` (`field_ebt_counter_icon_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_counter_items`;
CREATE TABLE `block_content_revision__field_ebt_counter_items` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_items_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_counter_items_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_counter_items_target_id` (`field_ebt_counter_items_target_id`),
  KEY `field_ebt_counter_items_target_revision_id` (`field_ebt_counter_items_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_counter_number`;
CREATE TABLE `block_content_revision__field_ebt_counter_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_number_value` int NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_cta_link`;
CREATE TABLE `block_content_revision__field_ebt_cta_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_cta_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_cta_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_cta_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_cta_link_uri` (`field_ebt_cta_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_cta_title`;
CREATE TABLE `block_content_revision__field_ebt_cta_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_cta_title_value` longtext NOT NULL,
  `field_ebt_cta_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_cta_title_format` (`field_ebt_cta_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_hero_link`;
CREATE TABLE `block_content_revision__field_ebt_hero_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_hero_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_hero_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_hero_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_hero_link_uri` (`field_ebt_hero_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_hero_title`;
CREATE TABLE `block_content_revision__field_ebt_hero_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_hero_title_value` longtext NOT NULL,
  `field_ebt_hero_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_hero_title_format` (`field_ebt_hero_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_image`;
CREATE TABLE `block_content_revision__field_ebt_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_image_target_id` (`field_ebt_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_image_caption`;
CREATE TABLE `block_content_revision__field_ebt_image_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_image_caption_value` longtext NOT NULL,
  `field_ebt_image_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_image_caption_format` (`field_ebt_image_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_image_gallery`;
CREATE TABLE `block_content_revision__field_ebt_image_gallery` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_image_gallery_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_image_gallery_target_id` (`field_ebt_image_gallery_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_image_link`;
CREATE TABLE `block_content_revision__field_ebt_image_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_image_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_image_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_image_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_image_link_uri` (`field_ebt_image_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_quote_author`;
CREATE TABLE `block_content_revision__field_ebt_quote_author` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_quote_author_value` longtext NOT NULL,
  `field_ebt_quote_author_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_quote_author_format` (`field_ebt_quote_author_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_quote_image`;
CREATE TABLE `block_content_revision__field_ebt_quote_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_quote_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_quote_image_target_id` (`field_ebt_quote_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_settings`;
CREATE TABLE `block_content_revision__field_ebt_settings` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_settings_ebt_settings` longblob COMMENT 'Serialized block settings data',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_slick_slider`;
CREATE TABLE `block_content_revision__field_ebt_slick_slider` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slick_slider_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_slick_slider_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slick_slider_target_id` (`field_ebt_slick_slider_target_id`),
  KEY `field_ebt_slick_slider_target_revision_id` (`field_ebt_slick_slider_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_slideshow`;
CREATE TABLE `block_content_revision__field_ebt_slideshow` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slideshow_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_slideshow_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slideshow_target_id` (`field_ebt_slideshow_target_id`),
  KEY `field_ebt_slideshow_target_revision_id` (`field_ebt_slideshow_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_stats`;
CREATE TABLE `block_content_revision__field_ebt_stats` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_stats_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_stats_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_stats_target_id` (`field_ebt_stats_target_id`),
  KEY `field_ebt_stats_target_revision_id` (`field_ebt_stats_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_tabs`;
CREATE TABLE `block_content_revision__field_ebt_tabs` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tabs_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_tabs_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tabs_target_id` (`field_ebt_tabs_target_id`),
  KEY `field_ebt_tabs_target_revision_id` (`field_ebt_tabs_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_tiles`;
CREATE TABLE `block_content_revision__field_ebt_tiles` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tiles_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_tiles_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tiles_target_id` (`field_ebt_tiles_target_id`),
  KEY `field_ebt_tiles_target_revision_id` (`field_ebt_tiles_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_timeline`;
CREATE TABLE `block_content_revision__field_ebt_timeline` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_timeline_target_revision_id` int unsigned NOT NULL COMMENT 'The revision ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_timeline_target_id` (`field_ebt_timeline_target_id`),
  KEY `field_ebt_timeline_target_revision_id` (`field_ebt_timeline_target_revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_video`;
CREATE TABLE `block_content_revision__field_ebt_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_video_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_video_target_id` (`field_ebt_video_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_views_views`;
CREATE TABLE `block_content_revision__field_ebt_views_views` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_views_views_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_views_views_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ebt_views_views_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_views_views_target_id` (`field_ebt_views_views_target_id`),
  KEY `field_ebt_views_views_display_id` (`field_ebt_views_views_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `block_content_revision__field_ebt_webform_form`;
CREATE TABLE `block_content_revision__field_ebt_webform_form` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_webform_form_target_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the webform entity.',
  `field_ebt_webform_form_default_data` text COMMENT 'Default submission data.',
  `field_ebt_webform_form_status` varchar(20) DEFAULT NULL COMMENT 'Flag to control whether this webform should be open, closed, or scheduled for new submissions.',
  `field_ebt_webform_form_open` varchar(20) DEFAULT NULL COMMENT 'The open date/time.',
  `field_ebt_webform_form_close` varchar(20) DEFAULT NULL COMMENT 'The close date/time.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_webform_form_target_id` (`field_ebt_webform_form_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for block_content field field_ebt…';


DROP TABLE IF EXISTS `cache_access_policy`;
CREATE TABLE `cache_access_policy` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_bootstrap`;
CREATE TABLE `cache_bootstrap` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_config`;
CREATE TABLE `cache_config` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_container`;
CREATE TABLE `cache_container` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_data`;
CREATE TABLE `cache_data` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_default`;
CREATE TABLE `cache_default` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_discovery`;
CREATE TABLE `cache_discovery` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_dynamic_page_cache`;
CREATE TABLE `cache_dynamic_page_cache` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_entity`;
CREATE TABLE `cache_entity` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_menu`;
CREATE TABLE `cache_menu` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_page`;
CREATE TABLE `cache_page` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_render`;
CREATE TABLE `cache_render` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cache_toolbar`;
CREATE TABLE `cache_toolbar` (
  `cid` varchar(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique cache ID.',
  `data` longblob COMMENT 'A collection of data to cache.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'A Unix timestamp indicating when the cache entry should expire, or -1 for never.',
  `created` decimal(14,3) NOT NULL DEFAULT '0.000' COMMENT 'A timestamp with millisecond precision indicating when the cache entry was created.',
  `serialized` smallint NOT NULL DEFAULT '0' COMMENT 'A flag to indicate whether content is serialized (1) or not (0).',
  `tags` longtext COMMENT 'Space-separated list of cache tags for this entry.',
  `checksum` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The tag invalidation checksum when this entry was saved.',
  PRIMARY KEY (`cid`),
  KEY `expire` (`expire`),
  KEY `created` (`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Storage for the cache API.';


DROP TABLE IF EXISTS `cachetags`;
CREATE TABLE `cachetags` (
  `tag` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Namespace-prefixed tag string.',
  `invalidations` int NOT NULL DEFAULT '0' COMMENT 'Number incremented when the tag is invalidated.',
  PRIMARY KEY (`tag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Cache table for tracking cache tag invalidations.';

INSERT INTO `cachetags` (`tag`, `invalidations`) VALUES
('4xx-response',	37),
('block_content_view',	26),
('breakpoints',	70),
('comment_view',	1),
('config:action_list',	5),
('config:block_content_type_list',	26),
('config:comment.settings',	1),
('config:comment.type.comment',	1),
('config:comment_type_list',	1),
('config:core.entity_form_display.comment.comment.default',	1),
('config:core.entity_form_display.node.article.default',	3),
('config:core.entity_form_display.node.page.default',	2),
('config:core.entity_view_display.comment.comment.default',	1),
('config:core.entity_view_display.node.article.default',	3),
('config:core.entity_view_display.node.article.rss',	3),
('config:core.entity_view_display.node.article.teaser',	3),
('config:core.entity_view_display.node.page.default',	3),
('config:core.entity_view_display.node.page.teaser',	2),
('config:core.entity_view_mode.comment.full',	1),
('config:core.entity_view_mode.comment.token',	1),
('config:core.extension',	70),
('config:editor.editor.webform_default',	1),
('config:editor_list',	1),
('config:entity_form_display_list',	34),
('config:entity_form_mode_list',	1),
('config:entity_view_display_list',	35),
('config:entity_view_mode_list',	8),
('config:field.field.comment.comment.comment_body',	1),
('config:field.field.media.image.field_media_image',	1),
('config:field.field.node.article.comment',	1),
('config:field.field.node.article.field_image',	1),
('config:field.field.node.page.field_metatags',	1),
('config:field.storage.comment.comment_body',	1),
('config:field.storage.media.field_media_image',	1),
('config:field.storage.node.comment',	1),
('config:field.storage.node.field_image',	1),
('config:field.storage.node.field_metatags',	1),
('config:file.settings',	3),
('config:filter_format_list',	1),
('config:image_style_list',	6),
('config:linkit_profile_list',	1),
('config:media_type_list',	1),
('config:metatag_defaults_list',	1),
('config:paragraphs_type_list',	10),
('config:system.action.comment_delete_action',	1),
('config:system.action.comment_publish_action',	1),
('config:system.action.comment_save_action',	1),
('config:system.action.comment_unpublish_action',	1),
('config:system.action.user_add_role_action.content_editor',	1),
('config:system.action.user_remove_role_action.content_editor',	1),
('config:system.file',	3),
('config:system.mail',	1),
('config:system.menu.account',	36),
('config:system.menu.admin',	36),
('config:system.menu.footer',	36),
('config:system.menu.main',	36),
('config:system.menu.tools',	36),
('config:user.role.administrator',	1),
('config:user.role.anonymous',	3),
('config:user.role.authenticated',	4),
('config:user.role.content_editor',	2),
('config:user_role_list',	4),
('config:views.view.comment',	1),
('config:views.view.comments_recent',	1),
('config:views.view.media',	1),
('config:views.view.media_library',	1),
('config:views.view.redirect',	1),
('config:views.view.webform_submissions',	1),
('config:view_list',	5),
('config:webform_list',	1),
('config:webform_options_list',	1),
('entity_bundles',	45),
('entity_field_info',	272),
('entity_types',	95),
('http_response',	35),
('local_task',	103),
('media_view',	6),
('node:1',	1),
('node_list',	2),
('node_list:page',	2),
('node_view',	8),
('paragraph_view',	10),
('rendered',	2),
('routes',	35),
('route_match',	35),
('search_index:help_search',	3),
('search_index:node_search',	1),
('token_info',	35),
('views_data',	36),
('webform_submission_list',	3);

DROP TABLE IF EXISTS `config`;
CREATE TABLE `config` (
  `collection` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object collection.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object name.',
  `data` longblob COMMENT 'A serialized configuration object data.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for configuration data.';

INSERT INTO `config` (`collection`, `name`, `data`) VALUES
('',	'admin_toolbar.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvTSppzcgH5wnzBhX5xnAExcp2I1CzkQ_aky65XNfYI\";}s:10:\"menu_depth\";i:4;}'),
('',	'admin_toolbar_tools.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WgdZsrd_5w9jlmcHV4R9dD2tG9OZEkYo4I_O8h7Gq8Q\";}s:17:\"max_bundle_number\";i:20;s:25:\"hoverintent_functionality\";b:1;s:16:\"show_local_tasks\";b:0;}'),
('',	'announcements_feed.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0G5pZBcxbg8ONYzNLd1RJIsvuFFewm9htnS4I-ABKJ8\";}s:7:\"max_age\";i:86400;s:13:\"cron_interval\";i:21600;s:5:\"limit\";i:10;}'),
('',	'automated_cron.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fUksROt4FfkAU9BV4hV2XvhTBSS2nTNrZS4U7S-tKrs\";}s:8:\"interval\";i:10800;}'),
('',	'block.block.claro_breadcrumbs',	'a:13:{s:4:\"uuid\";s:36:\"d1a331f5-0df6-469b-9594-7d62381385aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NjcxOBrPOiK5-38t56DwFBDVY4yer7YSlbRWXFuHe7A\";}s:2:\"id\";s:17:\"claro_breadcrumbs\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_content',	'a:13:{s:4:\"uuid\";s:36:\"40baaa9b-4ebb-41cb-a0f8-9438fc1633e2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a0Yyx1GeyKarZ4T_yXQBR_ZFKnXiFLtxAb6gWLd8nr0\";}s:2:\"id\";s:13:\"claro_content\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_help',	'a:13:{s:4:\"uuid\";s:36:\"e609269b-1f74-4c6d-8adc-b242386187c9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jccFSSVqV0WCDb6NtML1VWAWTtDbZ-zn5YgTRMgMrIM\";}s:2:\"id\";s:10:\"claro_help\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_help_search',	'a:13:{s:4:\"uuid\";s:36:\"642a14ba-b7f3-4788-b6d7-7ec847635558\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"module\";a:2:{i:0;s:6:\"search\";i:1;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}s:8:\"enforced\";a:1:{s:6:\"config\";a:1:{i:0;s:23:\"search.page.help_search\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2ToeZLvlHKTeFY74gpgu1PejLoFyCECLO_gw6rAZwqw\";}s:2:\"id\";s:17:\"claro_help_search\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:11:\"Search help\";s:13:\"label_display\";s:7:\"visible\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:11:\"help_search\";}s:10:\"visibility\";a:1:{s:12:\"request_path\";a:4:{s:2:\"id\";s:12:\"request_path\";s:6:\"negate\";b:0;s:15:\"context_mapping\";a:0:{}s:5:\"pages\";s:11:\"/admin/help\";}}}'),
('',	'block.block.claro_local_actions',	'a:13:{s:4:\"uuid\";s:36:\"b9fe9f3b-f277-4a5a-a681-c952b93cbf81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdXfDmRgAvms7EQovxxWPdYi0GitxeRbVtScYK16ZH0\";}s:2:\"id\";s:19:\"claro_local_actions\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_messages',	'a:13:{s:4:\"uuid\";s:36:\"58d2b9f3-0bea-4a38-88ec-fdb62db9ccb4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-Ac3ISpIT0PQ-whzD7_dw0SdKi6dAbRFNWdSjOiVDqg\";}s:2:\"id\";s:14:\"claro_messages\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_page_title',	'a:13:{s:4:\"uuid\";s:36:\"ecc6ef43-9d4c-491e-a458-7b4ac180124d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNwDdW063tk_ktzSWzZVeQS9wzvLooVO280BQ9WrsIs\";}s:2:\"id\";s:16:\"claro_page_title\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_primary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"d47ee844-8c65-44d3-85c0-510835e982ac\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ACjBZI5shAMiiUpsz-inLYVXDqNNXRnSzAWV3kV_8Hw\";}s:2:\"id\";s:25:\"claro_primary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_secondary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"f080d7bf-33c8-49e4-a29b-4f78db0f7c2c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2L0geP-ixCbCkEpW6BVF6H7vDUZN4ea07_Y9CociQm4\";}s:2:\"id\";s:27:\"claro_secondary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_account_menu',	'a:13:{s:4:\"uuid\";s:36:\"217ad55d-fd7d-4ae4-8bda-6030889a03b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:20:\"olivero_account_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_breadcrumbs',	'a:13:{s:4:\"uuid\";s:36:\"064ecc20-9718-4137-8404-bb79862b5dbe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:19:\"olivero_breadcrumbs\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_content',	'a:13:{s:4:\"uuid\";s:36:\"b76437ff-efaf-4c97-84ca-ae001d11fa96\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:15:\"olivero_content\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_help',	'a:13:{s:4:\"uuid\";s:36:\"53d20db2-085f-49cb-b889-bfcda4fdc4f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:12:\"olivero_help\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_main_menu',	'a:13:{s:4:\"uuid\";s:36:\"0cd82e10-9f40-455e-9bc5-67bba0594412\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:17:\"olivero_main_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_messages',	'a:13:{s:4:\"uuid\";s:36:\"f259c98a-a416-406b-8df1-73b20ade139d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:16:\"olivero_messages\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_page_title',	'a:13:{s:4:\"uuid\";s:36:\"592b2a14-a8fb-40ab-af13-fad4757b447c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:18:\"olivero_page_title\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_powered',	'a:13:{s:4:\"uuid\";s:36:\"3aa71fac-64b6-42f2-8b3d-0feb4a6f805e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYL19CLDyinGTWYQfBD1DswWzglEotE_kHnHx3AxTXM\";}s:2:\"id\";s:15:\"olivero_powered\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"footer_bottom\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_powered_by_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_powered_by_block\";s:5:\"label\";s:17:\"Powered by Drupal\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_primary_admin_actions',	'a:13:{s:4:\"uuid\";s:36:\"f3ae5ab3-e08f-4d92-8238-c0346ead125d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:29:\"olivero_primary_admin_actions\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_primary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"869275af-a038-43a0-aec0-55d644632865\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:27:\"olivero_primary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_search_form_narrow',	'a:13:{s:4:\"uuid\";s:36:\"1895f221-afd5-4f39-946d-175efff616ba\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yEBET0cqDbk8dkWzaJw-8CKft0961VBflsISoSR6Lj8\";}s:2:\"id\";s:26:\"olivero_search_form_narrow\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:20:\"Search form (narrow)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_search_form_wide',	'a:13:{s:4:\"uuid\";s:36:\"10f91465-91e8-4b68-9b23-c26342c32145\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"imMyHD6LYci0gtXq56qr9ZKGHzbEG9uFydrN5EhKtSU\";}s:2:\"id\";s:24:\"olivero_search_form_wide\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:18:\"Search form (wide)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_secondary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"a425651d-4bbc-4735-b403-60eedd891c6d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:29:\"olivero_secondary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-2;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_site_branding',	'a:13:{s:4:\"uuid\";s:36:\"9826d68e-9bcc-4b43-9656-f3d5f0c60619\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:21:\"olivero_site_branding\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_syndicate',	'a:13:{s:4:\"uuid\";s:36:\"d4871bcb-88ea-4b21-8c89-7e1c3151ed0b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0gq3VPg-_UM69FCCWurLFIrrnIjC2HLKhwo9iQNtcUo\";}s:2:\"id\";s:17:\"olivero_syndicate\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"social\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:20:\"node_syndicate_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:20:\"node_syndicate_block\";s:5:\"label\";s:8:\"RSS feed\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"node\";s:11:\"block_count\";i:10;}s:10:\"visibility\";a:0:{}}'),
('',	'block_content.type.basic',	'a:9:{s:4:\"uuid\";s:36:\"8d0c7ff5-11fa-497e-b1cb-232bad118b10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQP5iQy4SdhAMVcjDUncCfkJmTofnHVtXrsMzx4k6Yk\";}s:2:\"id\";s:5:\"basic\";s:5:\"label\";s:11:\"Basic block\";s:8:\"revision\";b:0;s:11:\"description\";s:42:\"A basic block contains a title and a body.\";}'),
('',	'block_content.type.ebt_accordion',	'a:9:{s:4:\"uuid\";s:36:\"532936a4-d4ec-4684-97d3-ea06263ffdfe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dB47Zxr808aSXzelLxShTOImxLGvz9ibkaPpIHw2XL8\";}s:2:\"id\";s:13:\"ebt_accordion\";s:5:\"label\";s:17:\"EBT Accordion/FAQ\";s:8:\"revision\";i:1;s:11:\"description\";s:37:\"Extra Block Type (EBT): Accordion/FAQ\";}'),
('',	'block_content.type.ebt_basic_button',	'a:9:{s:4:\"uuid\";s:36:\"5f0bd962-43f3-4e4c-9dad-bd8ad9ad83bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eTgR86D-XlSSjL0DOkUgyDx9iqTLZCeiiE1Wz1CNl8o\";}s:2:\"id\";s:16:\"ebt_basic_button\";s:5:\"label\";s:16:\"EBT Basic Button\";s:8:\"revision\";i:0;s:11:\"description\";s:36:\"Extra Block Type (EBT): Basic Button\";}'),
('',	'block_content.type.ebt_block',	'a:9:{s:4:\"uuid\";s:36:\"a5b41dbb-434a-4f8f-aa0f-413c4cc768db\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nKr_tXmEQ2IE6yATLpR_w5SQeEqQCm6SSKpCMIx2hKo\";}s:2:\"id\";s:9:\"ebt_block\";s:5:\"label\";s:9:\"EBT Block\";s:8:\"revision\";i:0;s:11:\"description\";s:33:\"Extra Block Type (EBT): EBT Block\";}'),
('',	'block_content.type.ebt_bootstrap_button',	'a:9:{s:4:\"uuid\";s:36:\"9575961f-7777-487f-988c-3898cad5f5b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EPwbWyfVd_vUMqmDcQcJd9ww6p2h7kUQTny9S5dPxXQ\";}s:2:\"id\";s:20:\"ebt_bootstrap_button\";s:5:\"label\";s:20:\"EBT Bootstrap Button\";s:8:\"revision\";i:0;s:11:\"description\";s:40:\"Extra Block Type (EBT): Bootstrap Button\";}'),
('',	'block_content.type.ebt_carousel',	'a:9:{s:4:\"uuid\";s:36:\"a8e8c97d-abf8-4a95-a638-a6a54e403d91\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DXQisXm71ScIY9qHGkk7imRMnjI_dBDSZfzT-uFCzwQ\";}s:2:\"id\";s:12:\"ebt_carousel\";s:5:\"label\";s:12:\"EBT Carousel\";s:8:\"revision\";i:1;s:11:\"description\";s:32:\"Extra Block Type (EBT): Carousel\";}'),
('',	'block_content.type.ebt_columns',	'a:9:{s:4:\"uuid\";s:36:\"31aff369-3823-4bb0-93db-1bca2acd3aa3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CQSPoVI2zOeWs7Xgd9ALoKdgcYScRjwZQK17EBkHKX4\";}s:2:\"id\";s:11:\"ebt_columns\";s:5:\"label\";s:23:\"EBT Columns / Container\";s:8:\"revision\";i:0;s:11:\"description\";s:47:\"Extra Block Type (EBT): EBT Columns / Container\";}'),
('',	'block_content.type.ebt_countdown',	'a:9:{s:4:\"uuid\";s:36:\"17c62d51-6c7f-493f-85b4-fce54035fcf7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"b04bwlmhn4qM9mk46Hq1ekInijGgB9DI7WydX2K6RJg\";}s:2:\"id\";s:13:\"ebt_countdown\";s:5:\"label\";s:13:\"EBT Countdown\";s:8:\"revision\";i:0;s:11:\"description\";s:37:\"Extra Block Type (EBT): EBT Countdown\";}'),
('',	'block_content.type.ebt_counter',	'a:9:{s:4:\"uuid\";s:36:\"f84bf2c7-0d7f-45e5-9e44-618e1cb84f84\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BAdc_syLOJWN_IuQiwJb7kdzLXXokTLaEplzy8ajUBs\";}s:2:\"id\";s:11:\"ebt_counter\";s:5:\"label\";s:11:\"EBT Counter\";s:8:\"revision\";i:0;s:11:\"description\";s:100:\"Extra Block Type (EBT): Counter - Adds Counter with coffee cups, projects, case studies number, etc.\";}'),
('',	'block_content.type.ebt_cta',	'a:9:{s:4:\"uuid\";s:36:\"1a560148-0ddc-4fe6-a137-e201e64082d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k9yRFHPv-0cHC5GXpNilObPbaFf1SBRHn-asOPpDpPA\";}s:2:\"id\";s:7:\"ebt_cta\";s:5:\"label\";s:24:\"EBT Call to Action (CTA)\";s:8:\"revision\";i:1;s:11:\"description\";s:44:\"Extra Block Type (EBT): Call to Action (CTA)\";}'),
('',	'block_content.type.ebt_hero',	'a:9:{s:4:\"uuid\";s:36:\"19fbd216-4f28-4209-a30c-bddd372736ae\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UndgTjioHDq7754rxxFxg1qIXgj6xzvZ2292BZOTduY\";}s:2:\"id\";s:8:\"ebt_hero\";s:5:\"label\";s:8:\"EBT Hero\";s:8:\"revision\";i:1;s:11:\"description\";s:28:\"Extra Block Type (EBT): Hero\";}'),
('',	'block_content.type.ebt_image',	'a:9:{s:4:\"uuid\";s:36:\"9fd85032-8853-4ccb-8f84-451d84cc570c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XzIeU-QRNHX9yTHUrG3pAtW39sABFIN32xzM5Roe_Zs\";}s:2:\"id\";s:9:\"ebt_image\";s:5:\"label\";s:9:\"EBT Image\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Image\";}'),
('',	'block_content.type.ebt_image_gallery',	'a:9:{s:4:\"uuid\";s:36:\"61358808-828f-49a0-a1fc-850ba4856b25\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hyvESyE2V701OB-pYMNV1fcs9afHHvGMwmKvID2dSys\";}s:2:\"id\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:17:\"EBT Image Gallery\";s:8:\"revision\";i:0;s:11:\"description\";s:37:\"Extra Block Type (EBT): Image Gallery\";}'),
('',	'block_content.type.ebt_micromodal',	'a:9:{s:4:\"uuid\";s:36:\"49a7d1d2-299c-43f7-8353-442f7c80126a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yHkIKUcC5OaWnPM6t0NLrROJ_Qie3lZd1nYZCnncyxQ\";}s:2:\"id\";s:14:\"ebt_micromodal\";s:5:\"label\";s:14:\"EBT Micromodal\";s:8:\"revision\";i:0;s:11:\"description\";s:34:\"Extra Block Type (EBT): Micromodal\";}'),
('',	'block_content.type.ebt_quote',	'a:9:{s:4:\"uuid\";s:36:\"6c094884-55e1-4ce3-9782-8302e193358e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"R3qZ2pP9HUZZOVzX7J5oHroNb9W2pfSWulgYrgRbm4g\";}s:2:\"id\";s:9:\"ebt_quote\";s:5:\"label\";s:9:\"EBT Quote\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Quote\";}'),
('',	'block_content.type.ebt_slick_slider',	'a:9:{s:4:\"uuid\";s:36:\"fe1604e8-b328-4b89-bd85-fc64bd553f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dHxKwXfScnz1cdiQPDzE2uUuw62lhpTtSqV5b2YZbrE\";}s:2:\"id\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:16:\"EBT Slick Slider\";s:8:\"revision\";i:0;s:11:\"description\";s:36:\"Extra Block Type (EBT): Slick Slider\";}'),
('',	'block_content.type.ebt_slideshow',	'a:9:{s:4:\"uuid\";s:36:\"7d164bb3-5e33-440f-b644-b566e1827e32\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W-lXlcGHuv4qnJqSIhwhzbs7aE2_VKhpa9-wZzfr-1A\";}s:2:\"id\";s:13:\"ebt_slideshow\";s:5:\"label\";s:13:\"EBT Slideshow\";s:8:\"revision\";i:0;s:11:\"description\";s:33:\"Extra Block Type (EBT): Slideshow\";}'),
('',	'block_content.type.ebt_stats',	'a:9:{s:4:\"uuid\";s:36:\"3e06d945-9c14-4d86-add4-87ce46604987\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MYrjSAxOpL7yIgF7efseTPdxreHwdIytokEU8AsyKOc\";}s:2:\"id\";s:9:\"ebt_stats\";s:5:\"label\";s:9:\"EBT Stats\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Stats\";}'),
('',	'block_content.type.ebt_tabs',	'a:9:{s:4:\"uuid\";s:36:\"a548c9cd-2123-460d-ac7a-3776cbd6628d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2Zf0IzYoN8bXlbuz0O0K2EFPtAJ-8Zgijs9KDbMjPbU\";}s:2:\"id\";s:8:\"ebt_tabs\";s:5:\"label\";s:8:\"EBT Tabs\";s:8:\"revision\";i:1;s:11:\"description\";s:28:\"Extra Block Type (EBT): Tabs\";}'),
('',	'block_content.type.ebt_text',	'a:9:{s:4:\"uuid\";s:36:\"4d70b021-1215-4212-93ff-3a65cfe166f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EfDKjvl4An381lwiUletrxyYGHVSXr0ylsIz7wG4FkM\";}s:2:\"id\";s:8:\"ebt_text\";s:5:\"label\";s:8:\"EBT Text\";s:8:\"revision\";i:1;s:11:\"description\";s:40:\"Adds Text block type with WYSIWYG editor\";}'),
('',	'block_content.type.ebt_tiles',	'a:9:{s:4:\"uuid\";s:36:\"a4695763-bb05-45b7-877a-2988bc9c0c68\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7NM6NtKtRJqDl2LKF2ttqtshhXn4nV3DIIr56XEhBGw\";}s:2:\"id\";s:9:\"ebt_tiles\";s:5:\"label\";s:9:\"EBT Tiles\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Tiles\";}'),
('',	'block_content.type.ebt_timeline',	'a:9:{s:4:\"uuid\";s:36:\"8299bf83-c3a5-401f-a1b8-bf9bb009af40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bjr_DHRSS1dmovJ9hu9PkQkEIHfJ9wcHbVFuexiFC7I\";}s:2:\"id\";s:12:\"ebt_timeline\";s:5:\"label\";s:12:\"EBT Timeline\";s:8:\"revision\";i:0;s:11:\"description\";s:32:\"Extra Block Type (EBT): Timeline\";}'),
('',	'block_content.type.ebt_video',	'a:9:{s:4:\"uuid\";s:36:\"f30a12fb-b405-4036-a46f-fc82d5b577e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Pv_CZ1UneLNgz_a4bh6MvN5tmAbmgeaL-sIZl2WyaP0\";}s:2:\"id\";s:9:\"ebt_video\";s:5:\"label\";s:9:\"EBT Video\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Video\";}'),
('',	'block_content.type.ebt_video_and_image_gallery',	'a:9:{s:4:\"uuid\";s:36:\"c8e02878-ad67-4c1d-8022-1bcae43b1e10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t5QqFRQehMUNqFlizm8etvw0z1ASVYieiYTD5A-AMwM\";}s:2:\"id\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:27:\"EBT Video and Image Gallery\";s:8:\"revision\";i:0;s:11:\"description\";s:47:\"Extra Block Type (EBT): Video and Image Gallery\";}'),
('',	'block_content.type.ebt_views',	'a:9:{s:4:\"uuid\";s:36:\"6eb11d1d-b72a-4d76-a761-9c91bacf5654\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kKtLeF4r10QhfrqB_NLR_pg7hmb7wKFxIx53f6SPZPM\";}s:2:\"id\";s:9:\"ebt_views\";s:5:\"label\";s:9:\"EBT Views\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Views\";}'),
('',	'block_content.type.ebt_webform',	'a:9:{s:4:\"uuid\";s:36:\"656280fa-6df7-4fb1-97e2-0fba6d8acda7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N2h4kIizWCZkC89K2_Xf6_WGzjG-9XpMDds_jEJjsGs\";}s:2:\"id\";s:11:\"ebt_webform\";s:5:\"label\";s:11:\"EBT Webform\";s:8:\"revision\";i:0;s:11:\"description\";s:35:\"Extra Paragraph Type (EPT): Webform\";}'),
('',	'block_content.type.ebt_webform_popup',	'a:9:{s:4:\"uuid\";s:36:\"3f1d7aa5-63b0-4cf5-8b1e-c69f240e9a70\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2PyweimMCiXZdcfL7o3WT6DPFw8x8O1FPQfufWOKf5A\";}s:2:\"id\";s:17:\"ebt_webform_popup\";s:5:\"label\";s:17:\"EBT Webform Popup\";s:8:\"revision\";i:0;s:11:\"description\";s:37:\"Extra Block Type (EBT): Webform Popup\";}'),
('',	'claro.settings',	'a:1:{s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}}'),
('',	'config_ignore.settings',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IgOVnECx6lbVt6JVFnadoEEugneDf3UblPZnOzov43Q\";}s:4:\"mode\";s:6:\"simple\";s:23:\"ignored_config_entities\";a:0:{}}'),
('',	'contact.form.feedback',	'a:12:{s:4:\"uuid\";s:36:\"816a1630-e792-4f5c-a26b-35e17703bb04\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vymHlgJy26BuI5GGj9-IXjwR3dRC5C0tij4BpWJnoqw\";}s:2:\"id\";s:8:\"feedback\";s:5:\"label\";s:16:\"Website feedback\";s:10:\"recipients\";a:1:{i:0;s:17:\"admin@example.com\";}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),
('',	'contact.form.personal',	'a:12:{s:4:\"uuid\";s:36:\"6c8348fa-3a53-48ce-ac8f-7aa4d1c5c9cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jonvgt3CkUM2eMLTFwWfHileWWDC4YtXCuIlCahTk_I\";}s:2:\"id\";s:8:\"personal\";s:5:\"label\";s:21:\"Personal contact form\";s:10:\"recipients\";a:0:{}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),
('',	'contact.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U69DBeuvXuNVOC15rVNaBjDPK2fWFbo9v4takdYSSO8\";}s:12:\"default_form\";s:8:\"feedback\";s:5:\"flood\";a:2:{s:5:\"limit\";i:5;s:8:\"interval\";i:3600;}s:20:\"user_default_enabled\";b:1;}'),
('',	'core.base_field_override.node.page.promote',	'a:17:{s:4:\"uuid\";s:36:\"708a5000-dcce-43d4-8735-a04f3c0ae480\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:14:\"node.type.page\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fPUEnm4T5zfZRr3ttDUqq7yCDd2uW3clWD-pvos4tlQ\";}s:2:\"id\";s:17:\"node.page.promote\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:22:\"Promoted to front page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),
('',	'core.date_format.fallback',	'a:9:{s:4:\"uuid\";s:36:\"7066953f-600d-4fc2-84b8-58826b84da0a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7klS5IWXrwzVaPpYZFAs6wcx8U2FF1X73OfrtTsvuvE\";}s:2:\"id\";s:8:\"fallback\";s:5:\"label\";s:20:\"Fallback date format\";s:6:\"locked\";b:1;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),
('',	'core.date_format.html_date',	'a:9:{s:4:\"uuid\";s:36:\"c8f2ea5d-ee32-44b5-b2a4-73b29881a91d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EOQltUQPmgc6UQ2rcJ4Xi_leCEJj5ui0TR-12duS-Tk\";}s:2:\"id\";s:9:\"html_date\";s:5:\"label\";s:9:\"HTML Date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-m-d\";}'),
('',	'core.date_format.html_datetime',	'a:9:{s:4:\"uuid\";s:36:\"1b677438-94c3-4570-af48-166d068688f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxfClwZIRXIdcvMrE--WkcZxDGUVoOIE3Sm2NRZlFuE\";}s:2:\"id\";s:13:\"html_datetime\";s:5:\"label\";s:13:\"HTML Datetime\";s:6:\"locked\";b:1;s:7:\"pattern\";s:13:\"Y-m-d\\TH:i:sO\";}'),
('',	'core.date_format.html_month',	'a:9:{s:4:\"uuid\";s:36:\"b6631c90-a449-4cb7-93dc-33564909142a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Z7KuCUwM_WdTNvLcoltuX3_8d-s-8FZkTN6KgNwF0eM\";}s:2:\"id\";s:10:\"html_month\";s:5:\"label\";s:10:\"HTML Month\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"Y-m\";}'),
('',	'core.date_format.html_time',	'a:9:{s:4:\"uuid\";s:36:\"387b27db-0cbb-49c6-bce9-e2ae838a4eb4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M7yqicYkU36hRy5p9drAaGBBihhUD1OyujFrAaQ93ZE\";}s:2:\"id\";s:9:\"html_time\";s:5:\"label\";s:9:\"HTML Time\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"H:i:s\";}'),
('',	'core.date_format.html_week',	'a:9:{s:4:\"uuid\";s:36:\"aab47b59-a6c1-4205-a1bf-a0a7164b9f8d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKD4WsoV_wFgv2vgI4mcAAFSIzrye17ykzdwrnApkfY\";}s:2:\"id\";s:9:\"html_week\";s:5:\"label\";s:9:\"HTML Week\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-\\WW\";}'),
('',	'core.date_format.html_year',	'a:9:{s:4:\"uuid\";s:36:\"58dd1255-3bf1-465a-af62-74c3770e7861\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjekiQuX9RbVQ2_8jOHBL94RgYLePqX7wpfNGgcQzrk\";}s:2:\"id\";s:9:\"html_year\";s:5:\"label\";s:9:\"HTML Year\";s:6:\"locked\";b:1;s:7:\"pattern\";s:1:\"Y\";}'),
('',	'core.date_format.html_yearless_date',	'a:9:{s:4:\"uuid\";s:36:\"1bea5c34-af20-4053-9459-595e10032d04\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VpawMrKPEPCkoO4YpPa0TDFO2dgiIHfTziJtwlmUxc\";}s:2:\"id\";s:18:\"html_yearless_date\";s:5:\"label\";s:18:\"HTML Yearless date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"m-d\";}'),
('',	'core.date_format.long',	'a:9:{s:4:\"uuid\";s:36:\"3228fcaa-0dfe-4342-b299-d12cfba43674\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"og8sWXhBuHbLMw3CoiBEZjgqSyhFBFmcbUW_wLcfNbo\";}s:2:\"id\";s:4:\"long\";s:5:\"label\";s:17:\"Default long date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:15:\"l, F j, Y - H:i\";}'),
('',	'core.date_format.medium',	'a:9:{s:4:\"uuid\";s:36:\"2ae289c3-6325-45f0-9ec2-99609e297832\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nzL5d024NjXIX_8TlT6uFAu973lmfkmHklJC-2i9rAE\";}s:2:\"id\";s:6:\"medium\";s:5:\"label\";s:19:\"Default medium date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),
('',	'core.date_format.olivero_medium',	'a:9:{s:4:\"uuid\";s:36:\"9f0d1e0f-c3b1-477d-8825-2a12a34e41f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mt6cmxUbDZ9XxD6p25WQ8tj3_JcX8ylfcddwZc8gcAE\";}s:2:\"id\";s:14:\"olivero_medium\";s:5:\"label\";s:14:\"Olivero Medium\";s:6:\"locked\";b:0;s:7:\"pattern\";s:8:\"j  F,  Y\";}'),
('',	'core.date_format.short',	'a:9:{s:4:\"uuid\";s:36:\"ced168ae-c45d-4704-b1d4-c36fb84b47f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AlzeyytA8InBgxIG9H2UDJYs3CG98Zj6yRsDKmlbZwA\";}s:2:\"id\";s:5:\"short\";s:5:\"label\";s:18:\"Default short date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:11:\"m/d/Y - H:i\";}'),
('',	'core.entity_form_display.block_content.basic.default',	'a:11:{s:4:\"uuid\";s:36:\"2fb7a522-cf93-4f57-be42-0cb4c4d31165\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jAps3FCxvKecABS_tgExbhCZrBLQB3bNPWw18WjE3ss\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_accordion.default',	'a:12:{s:4:\"uuid\";s:36:\"7f7f76e5-ece6-4e93-9154-f7a914b883b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:44:\"field.field.block_content.ebt_accordion.body\";i:2;s:59:\"field.field.block_content.ebt_accordion.field_ebt_accordion\";i:3;s:58:\"field.field.block_content.ebt_accordion.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:13:\"ebt_accordion\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:19:\"field_ebt_accordion\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PzCFAyJrF1CHyonIY9UYHLYTUaTzxXhcv5uiJWU41DQ\";}s:2:\"id\";s:35:\"block_content.ebt_accordion.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ebt_accordion\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:22:\"ebt_settings_accordion\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_basic_button.default',	'a:11:{s:4:\"uuid\";s:36:\"37393abe-e80e-4438-a211-2b6937d2a850\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:70:\"field.field.block_content.ebt_basic_button.field_ebt_basic_button_link\";i:2;s:61:\"field.field.block_content.ebt_basic_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:16:\"ebt_basic_button\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TL36cBmV77cMjPzUpkHgNG3I6F4EZY_Iyr9A67xICRc\";}s:2:\"id\";s:38:\"block_content.ebt_basic_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:27:\"field_ebt_basic_button_link\";a:5:{s:6:\"weight\";i:27;s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"link_default\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:25:\"ebt_settings_basic_button\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_block.default',	'a:12:{s:4:\"uuid\";s:36:\"db7027b5-0083-4c23-932e-b8140582e848\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:40:\"field.field.block_content.ebt_block.body\";i:2;s:57:\"field.field.block_content.ebt_block.field_ebt_block_block\";i:3;s:54:\"field.field.block_content.ebt_block.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:11:\"block_field\";i:1;s:8:\"ebt_core\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:21:\"field_ebt_block_block\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kmx4yzKEAL5_us-5XrISqRaGX28ieDECPBvSA4I53eM\";}s:2:\"id\";s:31:\"block_content.ebt_block.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_block_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_bootstrap_button.default',	'a:11:{s:4:\"uuid\";s:36:\"3fd59f0a-2725-4fa8-85fd-69b00e41a16c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:78:\"field.field.block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link\";i:2;s:65:\"field.field.block_content.ebt_bootstrap_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:20:\"ebt_bootstrap_button\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JwJzpFM95dLE-G20D_3HgaKN8MiWZGW-4JEwf0rWVeA\";}s:2:\"id\";s:42:\"block_content.ebt_bootstrap_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:31:\"field_ebt_bootstrap_button_link\";a:5:{s:6:\"weight\";i:27;s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"link_default\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:29:\"ebt_settings_bootstrap_button\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_carousel.default',	'a:12:{s:4:\"uuid\";s:36:\"d9501a4e-79d4-4429-a572-1bc3f75caa0e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:57:\"field.field.block_content.ebt_carousel.field_ebt_carousel\";i:2;s:57:\"field.field.block_content.ebt_carousel.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:12:\"ebt_carousel\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_carousel\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QXlNXkmdvt1D3vvq3Xts_hS6xZcsvaZ_VMIpv7HSlJ4\";}s:2:\"id\";s:34:\"block_content.ebt_carousel.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_carousel\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:21:\"ebt_settings_carousel\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_columns.default',	'a:12:{s:4:\"uuid\";s:36:\"913c0375-72d6-4813-b10b-3696ff0b8a73\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:42:\"field.field.block_content.ebt_columns.body\";i:2;s:62:\"field.field.block_content.ebt_columns.field_ebt_columns_blocks\";i:3;s:56:\"field.field.block_content.ebt_columns.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:11:\"block_field\";i:1;s:11:\"ebt_columns\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:24:\"field_ebt_columns_blocks\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"F_pGWF26Foj_C1Hq_KcX77H7LkKnWLFPV7iyltEH6CM\";}s:2:\"id\";s:33:\"block_content.ebt_columns.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_columns_blocks\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_columns\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_countdown.default',	'a:12:{s:4:\"uuid\";s:36:\"b9105cc0-df88-453b-a92d-90b5e523a386\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:44:\"field.field.block_content.ebt_countdown.body\";i:2;s:64:\"field.field.block_content.ebt_countdown.field_ebt_countdown_date\";i:3;s:58:\"field.field.block_content.ebt_countdown.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"datetime\";i:1;s:13:\"ebt_countdown\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:24:\"field_ebt_countdown_date\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GsQnmOfbEL4H_QrRxe1J3YG8Iq7SEHUP16XkMeLPtac\";}s:2:\"id\";s:35:\"block_content.ebt_countdown.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:21;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_countdown_date\";a:5:{s:4:\"type\";s:16:\"datetime_default\";s:6:\"weight\";i:22;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:22:\"ebt_settings_countdown\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_counter.default',	'a:12:{s:4:\"uuid\";s:36:\"289e89e1-cc7d-4e50-8100-bb16ed9875c1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:42:\"field.field.block_content.ebt_counter.body\";i:2;s:60:\"field.field.block_content.ebt_counter.field_ebt_counter_icon\";i:3;s:61:\"field.field.block_content.ebt_counter.field_ebt_counter_items\";i:4;s:62:\"field.field.block_content.ebt_counter.field_ebt_counter_number\";i:5;s:56:\"field.field.block_content.ebt_counter.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:11:\"ebt_counter\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:5;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:23:\"field_ebt_counter_items\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k07TlMoweT9Yz6bjpmLGKe6YvkshSJkTRnz6uGMQHkI\";}s:2:\"id\";s:33:\"block_content.ebt_counter.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_counter_items\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_counter\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:22:\"field_ebt_counter_icon\";b:1;s:24:\"field_ebt_counter_number\";b:1;}}'),
('',	'core.entity_form_display.block_content.ebt_cta.default',	'a:12:{s:4:\"uuid\";s:36:\"8a7d1838-30dd-4dc0-a2ae-b9e053ede2c9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:38:\"field.field.block_content.ebt_cta.body\";i:2;s:60:\"field.field.block_content.ebt_cta.field_ebt_cta_column_image\";i:3;s:52:\"field.field.block_content.ebt_cta.field_ebt_cta_link\";i:4;s:59:\"field.field.block_content.ebt_cta.field_ebt_cta_second_link\";i:5;s:53:\"field.field.block_content.ebt_cta.field_ebt_cta_title\";i:6;s:52:\"field.field.block_content.ebt_cta.field_ebt_settings\";}s:6:\"module\";a:5:{i:0;s:7:\"ebt_cta\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:5:{i:0;s:19:\"field_ebt_cta_title\";i:1;s:4:\"body\";i:2;s:26:\"field_ebt_cta_column_image\";i:3;s:18:\"field_ebt_cta_link\";i:4;s:25:\"field_ebt_cta_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vYgl9r_zBmBwCVILYRfEwPU5CbS9sLUc-A0mmAR2nq4\";}s:2:\"id\";s:29:\"block_content.ebt_cta.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ebt_cta_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_cta_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ebt_cta_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ebt_cta_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:16:\"ebt_settings_cta\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_hero.default',	'a:12:{s:4:\"uuid\";s:36:\"d6f88c18-d8de-40c5-9c43-c1c4d94583bd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:39:\"field.field.block_content.ebt_hero.body\";i:2;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_column_image\";i:3;s:54:\"field.field.block_content.ebt_hero.field_ebt_hero_link\";i:4;s:61:\"field.field.block_content.ebt_hero.field_ebt_hero_second_link\";i:5;s:55:\"field.field.block_content.ebt_hero.field_ebt_hero_title\";i:6;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_title_prefix\";i:7;s:53:\"field.field.block_content.ebt_hero.field_ebt_settings\";}s:6:\"module\";a:5:{i:0;s:8:\"ebt_hero\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:6:{i:0;s:20:\"field_ebt_hero_title\";i:1;s:27:\"field_ebt_hero_title_prefix\";i:2;s:4:\"body\";i:3;s:27:\"field_ebt_hero_column_image\";i:4;s:19:\"field_ebt_hero_link\";i:5;s:26:\"field_ebt_hero_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GQBJ-wowpRaxqn3ERit4j93oiUyIBZaIJDtySINgXhM\";}s:2:\"id\";s:30:\"block_content.ebt_hero.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:8:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_hero_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ebt_hero_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ebt_hero_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_hero_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_hero_title_prefix\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:17:\"ebt_settings_hero\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_image.default',	'a:12:{s:4:\"uuid\";s:36:\"d00c707c-3248-4967-a6d8-4410bbfeb58f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:51:\"field.field.block_content.ebt_image.field_ebt_image\";i:2;s:59:\"field.field.block_content.ebt_image.field_ebt_image_caption\";i:3;s:56:\"field.field.block_content.ebt_image.field_ebt_image_link\";i:4;s:54:\"field.field.block_content.ebt_image.field_ebt_settings\";}s:6:\"module\";a:5:{i:0;s:9:\"ebt_image\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ebt_image\";i:1;s:23:\"field_ebt_image_caption\";i:2;s:20:\"field_ebt_image_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DD35mMXZ3KVmfiicbnARcLgWKRQLT1HYVk6OHxJ-iBk\";}s:2:\"id\";s:31:\"block_content.ebt_image.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:15:\"field_ebt_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:26;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_image_caption\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:27;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_image_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:28;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_image\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_image_gallery.default',	'a:12:{s:4:\"uuid\";s:36:\"90302297-9a10-4688-91b6-c1672cf0a17e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:48:\"field.field.block_content.ebt_image_gallery.body\";i:2;s:67:\"field.field.block_content.ebt_image_gallery.field_ebt_image_gallery\";i:3;s:62:\"field.field.block_content.ebt_image_gallery.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:17:\"ebt_image_gallery\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:4:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:23:\"field_ebt_image_gallery\";i:3;s:8:\"langcode\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0PSdTVGfXs7VaqV30tsbYPvmzGKHhU4hZYgKxHIHVcU\";}s:2:\"id\";s:39:\"block_content.ebt_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_image_gallery\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:26:\"ebt_settings_image_gallery\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_micromodal.default',	'a:12:{s:4:\"uuid\";s:36:\"50e0e4ff-bae9-4a5d-a915-ec8cdc49ff77\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:45:\"field.field.block_content.ebt_micromodal.body\";i:2;s:67:\"field.field.block_content.ebt_micromodal.field_ebt_micromodal_title\";i:3;s:59:\"field.field.block_content.ebt_micromodal.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:14:\"ebt_micromodal\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:26:\"field_ebt_micromodal_title\";i:1;s:4:\"body\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZNJcRUtL7EWaVB-UgRyHYVB4-th0NpBsk6t-AcQiZc0\";}s:2:\"id\";s:36:\"block_content.ebt_micromodal.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ebt_micromodal_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:23:\"ebt_settings_micromodal\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_quote.default',	'a:12:{s:4:\"uuid\";s:36:\"3ac9c5a0-b4a9-4360-8947-feabad5e7f71\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:40:\"field.field.block_content.ebt_quote.body\";i:2;s:58:\"field.field.block_content.ebt_quote.field_ebt_quote_author\";i:3;s:57:\"field.field.block_content.ebt_quote.field_ebt_quote_image\";i:4;s:54:\"field.field.block_content.ebt_quote.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_quote\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:4:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:22:\"field_ebt_quote_author\";i:3;s:21:\"field_ebt_quote_image\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N-LtYp4PCPoTpwSFmV_pxSB5hcbey07dO7biDALNdbg\";}s:2:\"id\";s:31:\"block_content.ebt_quote.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ebt_quote_author\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_quote_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_quote\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_slick_slider.default',	'a:12:{s:4:\"uuid\";s:36:\"92792509-019c-4727-be95-79a35850d3e8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:47:\"field.field.block_content.ebt_slick_slider.body\";i:2;s:61:\"field.field.block_content.ebt_slick_slider.field_ebt_settings\";i:3;s:65:\"field.field.block_content.ebt_slick_slider.field_ebt_slick_slider\";}s:6:\"module\";a:4:{i:0;s:16:\"ebt_slick_slider\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:22:\"field_ebt_slick_slider\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bpVaLzDSRRw2IoN4B7lX2DmpEtGagQ_kHdtfu2QnBWk\";}s:2:\"id\";s:38:\"block_content.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:4;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:25:\"ebt_settings_slick_slider\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ebt_slick_slider\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_slideshow.default',	'a:12:{s:4:\"uuid\";s:36:\"1e354f38-03e4-4eb3-83d9-64e23ea8e653\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:58:\"field.field.block_content.ebt_slideshow.field_ebt_settings\";i:2;s:59:\"field.field.block_content.ebt_slideshow.field_ebt_slideshow\";}s:6:\"module\";a:3:{i:0;s:13:\"ebt_slideshow\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:19:\"field_ebt_slideshow\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6DA12pCUzWErNlrzV5uI2gCLocIzFk1R4r6_m3BD42A\";}s:2:\"id\";s:35:\"block_content.ebt_slideshow.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:22;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:22:\"ebt_settings_slideshow\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_slideshow\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:21;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_stats.default',	'a:12:{s:4:\"uuid\";s:36:\"52b22b0d-85e9-4340-9aa7-8f4febf9050e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:40:\"field.field.block_content.ebt_stats.body\";i:2;s:54:\"field.field.block_content.ebt_stats.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_stats.field_ebt_stats\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_stats\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:15:\"field_ebt_stats\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_L5lmPQyOe6uFAwlop2yf-ekQRX87-T_CXqJ-IIRg7Y\";}s:2:\"id\";s:31:\"block_content.ebt_stats.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:27;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_stats\";s:6:\"weight\";i:22;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ebt_stats\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:28;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_tabs.default',	'a:12:{s:4:\"uuid\";s:36:\"a7d39dc1-5b23-4427-87b3-0bbc28e7b99b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:53:\"field.field.block_content.ebt_tabs.field_ebt_settings\";i:2;s:49:\"field.field.block_content.ebt_tabs.field_ebt_tabs\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_tabs\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:14:\"field_ebt_tabs\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiD2k00iSxydyLNXRexQsZwtt3kdC7yWjKnIE2TPsds\";}s:2:\"id\";s:30:\"block_content.ebt_tabs.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:17:\"ebt_settings_tabs\";s:6:\"region\";s:7:\"content\";}s:14:\"field_ebt_tabs\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_text.default',	'a:12:{s:4:\"uuid\";s:36:\"a186725f-445b-4043-83f2-c3bc2d5b1b87\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:39:\"field.field.block_content.ebt_text.body\";i:2;s:53:\"field.field.block_content.ebt_text.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"info\";i:1;s:4:\"body\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qr5FWoE0Z8wFG-omC1KS3oG2wlcQ86J_zl7wsCOUCto\";}s:2:\"id\";s:30:\"block_content.ebt_text.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:1;s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_tiles.default',	'a:12:{s:4:\"uuid\";s:36:\"8876d1b6-9d39-4029-abb6-793bf6be88df\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:40:\"field.field.block_content.ebt_tiles.body\";i:2;s:54:\"field.field.block_content.ebt_tiles.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_tiles.field_ebt_tiles\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_tiles\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:240;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:15:\"field_ebt_tiles\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"B8B292gqxvNzedSxDhs7Ss9nrmX75yMSBzLtMUBusxw\";}s:2:\"id\";s:31:\"block_content.ebt_tiles.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_tiles\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ebt_tiles\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_timeline.default',	'a:12:{s:4:\"uuid\";s:36:\"2d00d268-fcaf-44e1-a5d2-99bf5b954cee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:57:\"field.field.block_content.ebt_timeline.field_ebt_settings\";i:2;s:57:\"field.field.block_content.ebt_timeline.field_ebt_timeline\";}s:6:\"module\";a:3:{i:0;s:12:\"ebt_timeline\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_timeline\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lnh43KY0voHRBULlVHJ5n0V8Twh6dwTa482WpJEf7nU\";}s:2:\"id\";s:34:\"block_content.ebt_timeline.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:21:\"ebt_settings_timeline\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_timeline\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_video.default',	'a:12:{s:4:\"uuid\";s:36:\"adebe1bd-2c8a-4e24-8830-be649450bd8e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:40:\"field.field.block_content.ebt_video.body\";i:2;s:54:\"field.field.block_content.ebt_video.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_video.field_ebt_video\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_video\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:15:\"field_ebt_video\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tS6jBKcl-OCTitIjmc0ugKz08ENt8SoAs6NCnjOy-ek\";}s:2:\"id\";s:31:\"block_content.ebt_video.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_video\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ebt_video\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_video_and_image_gallery.default',	'a:12:{s:4:\"uuid\";s:36:\"4de506fd-736b-43b4-b4e9-87a88229b117\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:58:\"field.field.block_content.ebt_video_and_image_gallery.body\";i:2;s:72:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_settings\";i:3;s:81:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images\";}s:6:\"module\";a:4:{i:0;s:27:\"ebt_video_and_image_gallery\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:27:\"field_ebt_videos_and_images\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QGg-MV2IynMGDSKSb1vqdwAQyQ8p83BjC_W3v8O_1lg\";}s:2:\"id\";s:49:\"block_content.ebt_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:36:\"ebt_settings_video_and_image_gallery\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_videos_and_images\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_views.default',	'a:12:{s:4:\"uuid\";s:36:\"9166e36b-940f-481e-9cf3-5aacb1ef1208\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:40:\"field.field.block_content.ebt_views.body\";i:2;s:54:\"field.field.block_content.ebt_views.field_ebt_settings\";i:3;s:57:\"field.field.block_content.ebt_views.field_ebt_views_views\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";i:3;s:14:\"viewsreference\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:21:\"field_ebt_views_views\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E47G4jhOaCiwauUu7Cp8eOG0n1xF0TbNyp6_qUkGMcI\";}s:2:\"id\";s:31:\"block_content.ebt_views.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_views_views\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_webform.default',	'a:11:{s:4:\"uuid\";s:36:\"e6638a9a-dd30-4dab-b46a-9c913eb531bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:42:\"field.field.block_content.ebt_webform.body\";i:2;s:56:\"field.field.block_content.ebt_webform.field_ebt_settings\";i:3;s:60:\"field.field.block_content.ebt_webform.field_ebt_webform_form\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rtuRBm-Z8ZrdOhT7mc0JrMlWONwesUqNR-IwTM6axEY\";}s:2:\"id\";s:33:\"block_content.ebt_webform.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:26;s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:29;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_webform_form\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:2:{s:12:\"default_data\";b:1;s:8:\"webforms\";a:0:{}}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_webform_popup.default',	'a:11:{s:4:\"uuid\";s:36:\"76422ca6-6b1c-4ebd-b6e5-d362e8bc423d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:62:\"field.field.block_content.ebt_webform_popup.field_ebt_settings\";i:2;s:72:\"field.field.block_content.ebt_webform_popup.field_ebt_webform_popup_form\";}s:6:\"module\";a:2:{i:0;s:17:\"ebt_webform_popup\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-EvEMaGTSq7rxJjzGuhqBIybUTNrM39BXJjRKhFkDos\";}s:2:\"id\";s:39:\"block_content.ebt_webform_popup.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:26:\"ebt_settings_webform_popup\";s:6:\"region\";s:7:\"content\";}s:28:\"field_ebt_webform_popup_form\";a:5:{s:6:\"weight\";i:27;s:8:\"settings\";a:2:{s:12:\"default_data\";b:1;s:8:\"webforms\";a:0:{}}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.media.audio.default',	'a:11:{s:4:\"uuid\";s:36:\"9efccee6-8cc4-4ff4-92bb-0553278490ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"G2_SKH3jmI9FQeXSUxo3KgQqiyF1hPDEkc7-3-rCSbc\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_audio_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.audio.media_library',	'a:11:{s:4:\"uuid\";s:36:\"70924fc9-698f-43ce-8125-c9f66ca37236\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:16:\"media.type.audio\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"28vwMIYtvyjPcD4RyciZXIztxtZgmuWRCNgYemr_SZE\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.document.default',	'a:11:{s:4:\"uuid\";s:36:\"c99f3040-4f5d-4326-9040-193db1713a88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aewrRkePgJzdD5kPOq8JeMcKHs6yat49nE7ZeCQzQZg\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_media_document\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.document.media_library',	'a:11:{s:4:\"uuid\";s:36:\"8df854a8-6d93-49a7-803e-4334857e73fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:19:\"media.type.document\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dcpfpqyLXOSGpulacMAJW3H-G34_LeNsjdfxd1_oCfY\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.image.default',	'a:11:{s:4:\"uuid\";s:36:\"7b876128-538a-4826-a5a4-52747a729203\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:21:\"image.style.thumbnail\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JSY4-JPyNZBiYYo6imdRYF6_SdtWQexPndrLvn3-vw4\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.image.media_library',	'a:11:{s:4:\"uuid\";s:36:\"3d16f00d-32eb-4ac9-a711-00689691832b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BMLrK4zKp8-FFnMseBdT_6h6YipUsKRfbDf_3WUB5HA\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:5:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.remote_video.default',	'a:11:{s:4:\"uuid\";s:36:\"d145d9a4-1eb4-4ece-a5e9-4e77dd7a4b2a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pM8mGlwfpvfG_y5tZn0lGAXFLXz2_yKkL7MvWZsRqdA\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_media_oembed_video\";a:5:{s:4:\"type\";s:16:\"oembed_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.remote_video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"996b87ca-42a9-4803-afcc-24ebfbdf7849\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBgPW-uaXRaICBwLaVc16rXpRiLSknDIdF9q0XL7qso\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.video.default',	'a:11:{s:4:\"uuid\";s:36:\"432d0cdf-b7f6-4927-af19-9a26a2f71c65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0kIIaDTt6dixXy8TZkat2MNGZJ6vkRG8TaBWTy3E1bM\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_video_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"eed6f1c2-957f-4ca5-9d11-57d9fb6c9564\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:16:\"media.type.video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kGv8YsopqHvzTzb7QTINWcv0fnNa5ZDQyZxpOQR2vro\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.node.article.default',	'a:11:{s:4:\"uuid\";s:36:\"c224932f-6de0-4883-88df-0c2ae5186624\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:39:\"field.field.node.article.field_metatags\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:47:\"field.field.node.article.layout_builder__layout\";i:5;s:21:\"image.style.thumbnail\";i:6;s:17:\"node.type.article\";}s:6:\"module\";a:4:{i:0;s:7:\"metatag\";i:1;s:4:\"path\";i:2;s:9:\"svg_image\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ewbd6G2uX456-bgwseM2Q-KQG3RkASoyHmTh-XR3oLU\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:12:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:11:\"field_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_metatags\";a:5:{s:4:\"type\";s:16:\"metatag_firehose\";s:6:\"weight\";i:121;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:7:\"sidebar\";b:1;s:11:\"use_details\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:10:\"field_tags\";a:5:{s:4:\"type\";s:34:\"entity_reference_autocomplete_tags\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:13:\"url_redirects\";a:4:{s:6:\"weight\";i:50;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_form_display.node.page.default',	'a:11:{s:4:\"uuid\";s:36:\"095e0e3b-5060-4869-9c69-f8044cadf927\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:26:\"field.field.node.page.body\";i:1;s:36:\"field.field.node.page.field_metatags\";i:2;s:44:\"field.field.node.page.layout_builder__layout\";i:3;s:14:\"node.type.page\";}s:6:\"module\";a:3:{i:0;s:7:\"metatag\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:10:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:31;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_metatags\";a:5:{s:4:\"type\";s:16:\"metatag_firehose\";s:6:\"weight\";i:121;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:7:\"sidebar\";b:1;s:11:\"use_details\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:13:\"url_redirects\";a:4:{s:6:\"weight\";i:50;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_accordion.default',	'a:11:{s:4:\"uuid\";s:36:\"ee2f8f98-b9f7-4254-9737-68dc2197b2fd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:60:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_text\";i:1;s:61:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_title\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VV4WvHQlFMN4Xl5jLocxzCyuI7nCn1nGWGmJZbXlG2Q\";}s:2:\"id\";s:31:\"paragraph.ebt_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ebt_accordion_text\";a:5:{s:6:\"weight\";i:1;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_accordion_title\";a:5:{s:6:\"weight\";i:0;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_carousel.default',	'a:11:{s:4:\"uuid\";s:36:\"d1b4eb72-c64f-476b-bb62-88226cb19793\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:61:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_caption\";i:1;s:59:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yERJpwaJ1QC8Q1Gr8Tezl9O_q0ufoiR8gwonaEjSspw\";}s:2:\"id\";s:30:\"paragraph.ebt_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ebt_carousel_caption\";a:5:{s:6:\"weight\";i:1;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_carousel_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_counter_item.default',	'a:11:{s:4:\"uuid\";s:36:\"4579f4f8-31b0-4cd5-b9fe-f87cd45f5fb6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_description\";i:1;s:61:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_icon\";i:2;s:63:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_number\";i:3;s:62:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"snzZLNDA9DFF0msO0Up9bLDhB8kgJR3OFtnbryzGVms\";}s:2:\"id\";s:34:\"paragraph.ebt_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ebt_counter_description\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ebt_counter_icon\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_counter_number\";a:5:{s:4:\"type\";s:6:\"number\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_counter_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_slick_slider.default',	'a:11:{s:4:\"uuid\";s:36:\"49d083c6-462d-45e8-b2da-c158f1f21e4d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:67:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_image\";i:1;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_link\";i:2;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_text\";i:3;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SrB8f_Znsaiqtv7a46b7z53joZ5A1SCIFKCJUjFizQk\";}s:2:\"id\";s:34:\"paragraph.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ebt_slick_slider_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_slick_slider_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_slick_slider_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_slideshow.default',	'a:11:{s:4:\"uuid\";s:36:\"4d6b8979-02dc-432e-a1ee-1e39bf6d0736\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_link\";i:1;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_slide\";i:2;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_text\";i:3;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_title\";i:4;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1kjXAT0qkIlX0WEGDAcnGaQHa1XeILgCDnWcPfDVJ0\";}s:2:\"id\";s:31:\"paragraph.ebt_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ebt_slideshow_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ebt_slideshow_slide\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_slideshow_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ebt_slideshow_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_stats_item.default',	'a:11:{s:4:\"uuid\";s:36:\"a7152796-e586-430a-a770-6b093d09cb7c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:59:\"field.field.paragraph.ebt_stats_item.field_stats_item_image\";i:1;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_link\";i:2;s:60:\"field.field.paragraph.ebt_stats_item.field_stats_item_number\";i:3;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_LZlRyxzZkfNDaWmAIuAHQXMASYeRLzj_Tu9HB2QGnw\";}s:2:\"id\";s:32:\"paragraph.ebt_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:22:\"field_stats_item_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_stats_item_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_stats_item_number\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_stats_item_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_tab.default',	'a:11:{s:4:\"uuid\";s:36:\"99244a65-d42c-43a2-baae-958073fef48f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_block\";i:1;s:51:\"field.field.paragraph.ebt_tab.field_ebt_tab_content\";i:2;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_page\";i:3;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_text\";i:4;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_title\";i:5;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_views\";i:6;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3tkvVlJEyrGPBNqg-NmBgDBe7aW-ckCLKwsrbQPd28E\";}s:2:\"id\";s:25:\"paragraph.ebt_tab.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:19:\"field_ebt_tab_block\";a:5:{s:6:\"weight\";i:7;s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:19:\"block_field_default\";s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_tab_content\";a:5:{s:6:\"weight\";i:1;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:14:\"options_select\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_page\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_text\";a:5:{s:6:\"weight\";i:3;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_title\";a:5:{s:6:\"weight\";i:0;s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:14:\"text_textfield\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_views\";a:5:{s:6:\"weight\";i:6;s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_tiles_item.default',	'a:11:{s:4:\"uuid\";s:36:\"fbaff897-1222-45d2-bdee-f1c92ecc517d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_tiles_item.field_ebt_clickable_tile\";i:1;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_image\";i:2;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_link\";i:3;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_text\";i:4;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aO9CEu-AEXoDrOUyi0zQ-BFKnOQQ4j-7EZboHKs25Ao\";}s:2:\"id\";s:32:\"paragraph.ebt_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ebt_clickable_tile\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_tiles_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_tiles_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_tiles_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_tiles_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_timeline.default',	'a:11:{s:4:\"uuid\";s:36:\"9ade0a26-a08a-49b3-8f21-5cc52e0a9d4a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_current\";i:1;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_date\";i:2;s:65:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_media_image\";i:3;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_text\";i:4;s:59:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_title\";i:5;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"roudiPcEWEQePvvKVTvyQOha3roMsIYNfxuZ8yhsA7o\";}s:2:\"id\";s:30:\"paragraph.ebt_timeline.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:26:\"field_ebt_timeline_current\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_timeline_date\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:30:\"field_ebt_timeline_media_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_timeline_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_timeline_title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_video_and_image_gallery_item.default',	'a:11:{s:4:\"uuid\";s:36:\"af68c1f1-a952-4c8a-ad1c-06f3eaa33777\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:85:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description\";i:1;s:79:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item\";i:2;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ajt8RnSI29uPiHiC5kZcmSORcHZviDbPeC4fnIM2VWo\";}s:2:\"id\";s:50:\"paragraph.ebt_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:30:\"field_gallery_item_description\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_video_gallery_item\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.user.user.default',	'a:11:{s:4:\"uuid\";s:36:\"2e78043c-ec7e-40d3-9893-74a39341e80d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FaQ9Ptcpxpg30AtiqRDtl_8zbJArHP1LPfug_s59TOA\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"account\";a:2:{s:6:\"weight\";i:-10;s:6:\"region\";s:7:\"content\";}s:7:\"contact\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:8:\"language\";a:2:{s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:8:\"timezone\";a:2:{s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_mode.media.media_library',	'a:10:{s:4:\"uuid\";s:36:\"4f486238-f30d-4022-ac1d-42675ab0f17a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_form_mode.user.register',	'a:10:{s:4:\"uuid\";s:36:\"2a875655-65fd-42f4-bd80-8b41714fa393\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5pE_4hurqtIlZN3XDi7eTo5RG13BMG0Rh9HYlRI3h8U\";}s:2:\"id\";s:13:\"user.register\";s:5:\"label\";s:8:\"Register\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_display.block_content.basic.default',	'a:11:{s:4:\"uuid\";s:36:\"d5902a81-52d9-49dd-b8db-4665dbc4368c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBNNDTFwakREOTa6GGMqN899Iyrii0hInwSJtQ7Kj30\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_accordion.default',	'a:11:{s:4:\"uuid\";s:36:\"4043bfd5-1d8c-40be-b5b7-7566608c0a10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:44:\"field.field.block_content.ebt_accordion.body\";i:2;s:59:\"field.field.block_content.ebt_accordion.field_ebt_accordion\";i:3;s:58:\"field.field.block_content.ebt_accordion.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WJqWWf2uiJH8b576_UiYa5phDxIJKwgJiQjqG9e3TNI\";}s:2:\"id\";s:35:\"block_content.ebt_accordion.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_accordion\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_basic_button.default',	'a:11:{s:4:\"uuid\";s:36:\"e002007d-e402-414c-a43e-0e11a4ff059c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:70:\"field.field.block_content.ebt_basic_button.field_ebt_basic_button_link\";i:2;s:61:\"field.field.block_content.ebt_basic_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"D0bWnt-1a4nvpSyJNmrOwKtHeZ4joh72qib-yadGXdo\";}s:2:\"id\";s:38:\"block_content.ebt_basic_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:27:\"field_ebt_basic_button_link\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:4:\"link\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_block.default',	'a:11:{s:4:\"uuid\";s:36:\"7dac4777-4a33-402e-a4fb-d2ec54e7bdbf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:40:\"field.field.block_content.ebt_block.body\";i:2;s:57:\"field.field.block_content.ebt_block.field_ebt_block_block\";i:3;s:54:\"field.field.block_content.ebt_block.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:8:\"ebt_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fbnp4SbjbUUixWLq5rrWDtCZ10d3rhYWoqZRmYFJPfo\";}s:2:\"id\";s:31:\"block_content.ebt_block.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_block_block\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_bootstrap_button.default',	'a:11:{s:4:\"uuid\";s:36:\"8a03d29e-a687-49e7-9a56-0dfe88836e7a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:78:\"field.field.block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link\";i:2;s:65:\"field.field.block_content.ebt_bootstrap_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"B0SuU0apEENhv8h4tMjfQJZqaMhqfIqzm2aj6K7pj8g\";}s:2:\"id\";s:42:\"block_content.ebt_bootstrap_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:31:\"field_ebt_bootstrap_button_link\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:4:\"link\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_carousel.default',	'a:11:{s:4:\"uuid\";s:36:\"5595a634-71e4-4b9c-840c-c1fcb074609f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:57:\"field.field.block_content.ebt_carousel.field_ebt_carousel\";i:2;s:57:\"field.field.block_content.ebt_carousel.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XxudurKwt1BsJ27WvP-j9wjYhEJwJoXWpngR6KCPXG8\";}s:2:\"id\";s:34:\"block_content.ebt_carousel.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_carousel\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_columns.default',	'a:11:{s:4:\"uuid\";s:36:\"86bcc126-14bc-40cd-a04a-95794d3f1e10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:42:\"field.field.block_content.ebt_columns.body\";i:2;s:62:\"field.field.block_content.ebt_columns.field_ebt_columns_blocks\";i:3;s:56:\"field.field.block_content.ebt_columns.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:8:\"ebt_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a-6glPDfvKWglLxQBv5i50OSaExRNK8Y9fdSycITPPg\";}s:2:\"id\";s:33:\"block_content.ebt_columns.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_columns_blocks\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_countdown.default',	'a:11:{s:4:\"uuid\";s:36:\"814b296d-272d-49bd-b543-8a896015c80d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:44:\"field.field.block_content.ebt_countdown.body\";i:2;s:64:\"field.field.block_content.ebt_countdown.field_ebt_countdown_date\";i:3;s:58:\"field.field.block_content.ebt_countdown.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"datetime\";i:1;s:8:\"ebt_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SD9uKkLwTaGxA9CLhoLDWa7OVamzALkQ381JeZFM12Q\";}s:2:\"id\";s:35:\"block_content.ebt_countdown.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_countdown_date\";a:6:{s:4:\"type\";s:16:\"datetime_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:2:{s:17:\"timezone_override\";s:0:\"\";s:11:\"format_type\";s:6:\"medium\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_counter.default',	'a:11:{s:4:\"uuid\";s:36:\"4117f5ae-b100-40a0-82be-376d1b9cdd5c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:42:\"field.field.block_content.ebt_counter.body\";i:2;s:60:\"field.field.block_content.ebt_counter.field_ebt_counter_icon\";i:3;s:61:\"field.field.block_content.ebt_counter.field_ebt_counter_items\";i:4;s:62:\"field.field.block_content.ebt_counter.field_ebt_counter_number\";i:5;s:56:\"field.field.block_content.ebt_counter.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U0J7ekcnrzJlts3b7XRAuCz6M0oc4laODI1JQpfnSWU\";}s:2:\"id\";s:33:\"block_content.ebt_counter.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_counter_items\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:22:\"field_ebt_counter_icon\";b:1;s:24:\"field_ebt_counter_number\";b:1;}}'),
('',	'core.entity_view_display.block_content.ebt_cta.default',	'a:11:{s:4:\"uuid\";s:36:\"0ad5cd1c-3a95-492c-a42a-3a33aad2fc81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:38:\"field.field.block_content.ebt_cta.body\";i:2;s:60:\"field.field.block_content.ebt_cta.field_ebt_cta_column_image\";i:3;s:52:\"field.field.block_content.ebt_cta.field_ebt_cta_link\";i:4;s:59:\"field.field.block_content.ebt_cta.field_ebt_cta_second_link\";i:5;s:53:\"field.field.block_content.ebt_cta.field_ebt_cta_title\";i:6;s:52:\"field.field.block_content.ebt_cta.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rJRx3IkJfHu6PnEX98fydtBu7xtB6TBPxbD0H22l5MY\";}s:2:\"id\";s:29:\"block_content.ebt_cta.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:26:\"field_ebt_cta_column_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_cta_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_cta_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_cta_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_hero.default',	'a:11:{s:4:\"uuid\";s:36:\"ef3f9c37-ba74-4569-9402-eb895497b1ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:39:\"field.field.block_content.ebt_hero.body\";i:2;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_column_image\";i:3;s:54:\"field.field.block_content.ebt_hero.field_ebt_hero_link\";i:4;s:61:\"field.field.block_content.ebt_hero.field_ebt_hero_second_link\";i:5;s:55:\"field.field.block_content.ebt_hero.field_ebt_hero_title\";i:6;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_title_prefix\";i:7;s:53:\"field.field.block_content.ebt_hero.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XtJum4t5ZIxuZCmM5WqHm32Q5cPXTBC1K_4FK0DKBak\";}s:2:\"id\";s:30:\"block_content.ebt_hero.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_hero_column_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_hero_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:26:\"field_ebt_hero_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_hero_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_hero_title_prefix\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_image.default',	'a:11:{s:4:\"uuid\";s:36:\"2b267e2d-1fdb-48ce-9cb4-9e8ab433ed76\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:51:\"field.field.block_content.ebt_image.field_ebt_image\";i:2;s:59:\"field.field.block_content.ebt_image.field_ebt_image_caption\";i:3;s:56:\"field.field.block_content.ebt_image.field_ebt_image_link\";i:4;s:54:\"field.field.block_content.ebt_image.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"D3uYbuXeXgRMCscOC7MzthncsxVzm02BUnKoPT6DgNI\";}s:2:\"id\";s:31:\"block_content.ebt_image.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:15:\"field_ebt_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_image_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_image_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_image_gallery.default',	'a:11:{s:4:\"uuid\";s:36:\"4b5d6bc4-4cc6-4319-a6bf-ffb11737fa1d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:48:\"field.field.block_content.ebt_image_gallery.body\";i:2;s:67:\"field.field.block_content.ebt_image_gallery.field_ebt_image_gallery\";i:3;s:62:\"field.field.block_content.ebt_image_gallery.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vR-7_1M__12ELdq1IjHW5dYHXbjNbXTl83IbuAVADFo\";}s:2:\"id\";s:39:\"block_content.ebt_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_image_gallery\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_micromodal.default',	'a:11:{s:4:\"uuid\";s:36:\"f5514d94-f0a7-4adb-af94-b565702bcb87\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:45:\"field.field.block_content.ebt_micromodal.body\";i:2;s:67:\"field.field.block_content.ebt_micromodal.field_ebt_micromodal_title\";i:3;s:59:\"field.field.block_content.ebt_micromodal.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UuFtw5Q8hlkws7oxPOMwDUQdLg1VvFThNrchcXpdFdc\";}s:2:\"id\";s:36:\"block_content.ebt_micromodal.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:26:\"field_ebt_micromodal_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_quote.default',	'a:11:{s:4:\"uuid\";s:36:\"7606605a-9eff-4f52-aff9-3a7d785bb2a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:40:\"field.field.block_content.ebt_quote.body\";i:2;s:58:\"field.field.block_content.ebt_quote.field_ebt_quote_author\";i:3;s:57:\"field.field.block_content.ebt_quote.field_ebt_quote_image\";i:4;s:54:\"field.field.block_content.ebt_quote.field_ebt_settings\";i:5;s:23:\"image.style.quote_image\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xpCHQRrtCqVeeuVSJ231HGw2oStHov2UFyb3zRr3Oik\";}s:2:\"id\";s:31:\"block_content.ebt_quote.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_quote_author\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_quote_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:11:\"quote_image\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_slick_slider.default',	'a:11:{s:4:\"uuid\";s:36:\"8feddd3f-45a8-46bf-a16f-2be6634a45ea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:47:\"field.field.block_content.ebt_slick_slider.body\";i:2;s:61:\"field.field.block_content.ebt_slick_slider.field_ebt_settings\";i:3;s:65:\"field.field.block_content.ebt_slick_slider.field_ebt_slick_slider\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hPQzjkILUgWxfntdmuZ6HzJR7VFbSsJzCXcSrlrzRdY\";}s:2:\"id\";s:38:\"block_content.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_slick_slider\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_slideshow.default',	'a:11:{s:4:\"uuid\";s:36:\"764e5ba9-f7cd-4885-88bb-ab706b279f69\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:58:\"field.field.block_content.ebt_slideshow.field_ebt_settings\";i:2;s:59:\"field.field.block_content.ebt_slideshow.field_ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mtWCnFfgKEeW85VC8B0w6c1438S-bOGUJEppAIJAakE\";}s:2:\"id\";s:35:\"block_content.ebt_slideshow.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:19:\"field_ebt_slideshow\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:18:\"field_ebt_settings\";b:1;}}'),
('',	'core.entity_view_display.block_content.ebt_stats.default',	'a:11:{s:4:\"uuid\";s:36:\"8c54cc11-1b16-48f3-a610-44727c203a3d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:40:\"field.field.block_content.ebt_stats.body\";i:2;s:54:\"field.field.block_content.ebt_stats.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_stats.field_ebt_stats\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M6fW5L7z_DmzcpI5BCl95NixIxJEv1cpCEL2n4x9zpo\";}s:2:\"id\";s:31:\"block_content.ebt_stats.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ebt_stats\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_tabs.default',	'a:11:{s:4:\"uuid\";s:36:\"62183f0d-0b60-47ba-bb16-40798a4776ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:53:\"field.field.block_content.ebt_tabs.field_ebt_settings\";i:2;s:49:\"field.field.block_content.ebt_tabs.field_ebt_tabs\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I2VT_ayFTNxciojtahrIwigBhAXkhZMO4_sAejsopW0\";}s:2:\"id\";s:30:\"block_content.ebt_tabs.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:14:\"field_ebt_tabs\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_text.default',	'a:11:{s:4:\"uuid\";s:36:\"b33df2ac-91d5-4257-bfa4-bb4911c6a960\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:39:\"field.field.block_content.ebt_text.body\";i:2;s:53:\"field.field.block_content.ebt_text.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l_0JH2bJx47kWrf-7eYOBgwIV1dRWjVeLv68ugJKxso\";}s:2:\"id\";s:30:\"block_content.ebt_text.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_tiles.default',	'a:11:{s:4:\"uuid\";s:36:\"fb6bfaa3-7636-41c1-a411-dff1def2fef0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:40:\"field.field.block_content.ebt_tiles.body\";i:2;s:54:\"field.field.block_content.ebt_tiles.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_tiles.field_ebt_tiles\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rX3FVFGQ9cD5O0wbYbIxbj872CHdsK9aIut1PNuAeVI\";}s:2:\"id\";s:31:\"block_content.ebt_tiles.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:15:\"field_ebt_tiles\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_timeline.default',	'a:11:{s:4:\"uuid\";s:36:\"1395e5da-67f6-420f-a32d-094a7d218bd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:57:\"field.field.block_content.ebt_timeline.field_ebt_settings\";i:2;s:57:\"field.field.block_content.ebt_timeline.field_ebt_timeline\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bfJtQm_JGhXjpffKuejK_QMbyA4fxEqMrVt-N98sqZo\";}s:2:\"id\";s:34:\"block_content.ebt_timeline.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_timeline\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_video.default',	'a:11:{s:4:\"uuid\";s:36:\"96a65454-d2c6-4d47-8247-42a53fffe403\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:40:\"field.field.block_content.ebt_video.body\";i:2;s:54:\"field.field.block_content.ebt_video.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_video.field_ebt_video\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2csH7beKeLrgGpTLBYSVXXoJzKb7u0PjD1AUlW6AzbU\";}s:2:\"id\";s:31:\"block_content.ebt_video.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:15:\"field_ebt_video\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:9:\"ebt_video\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_video_and_image_gallery.default',	'a:11:{s:4:\"uuid\";s:36:\"b7590d64-18fe-489a-8317-2999e71355e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:58:\"field.field.block_content.ebt_video_and_image_gallery.body\";i:2;s:72:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_settings\";i:3;s:81:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GRVAFs0nqUHdsiSZnjDv7msUFBQh_m8jr87a-UZhMEs\";}s:2:\"id\";s:49:\"block_content.ebt_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_videos_and_images\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_views.default',	'a:11:{s:4:\"uuid\";s:36:\"65ebcab1-d240-4884-855d-df0c65f731df\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:40:\"field.field.block_content.ebt_views.body\";i:2;s:54:\"field.field.block_content.ebt_views.field_ebt_settings\";i:3;s:57:\"field.field.block_content.ebt_views.field_ebt_views_views\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P_rfCoJ0TGHiNoFYHjaR-ngK4cjbqANziLUpxF5UBZM\";}s:2:\"id\";s:31:\"block_content.ebt_views.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_views_views\";a:6:{s:4:\"type\";s:24:\"viewsreference_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:5:{s:4:\"page\";s:4:\"page\";s:5:\"block\";s:5:\"block\";s:7:\"default\";s:1:\"0\";s:4:\"feed\";s:1:\"0\";s:5:\"embed\";s:1:\"0\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_webform.default',	'a:11:{s:4:\"uuid\";s:36:\"dc06c30d-3cfa-4f39-809f-8390cd056466\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:42:\"field.field.block_content.ebt_webform.body\";i:2;s:56:\"field.field.block_content.ebt_webform.field_ebt_settings\";i:3;s:60:\"field.field.block_content.ebt_webform.field_ebt_webform_form\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gpru4Rd0T0JY8wkKLrvgy_u9NIovpL4X5IKCjcykrUE\";}s:2:\"id\";s:33:\"block_content.ebt_webform.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:3;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_webform_form\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:13:\"source_entity\";b:1;}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_webform_popup.default',	'a:11:{s:4:\"uuid\";s:36:\"8d599765-5bbf-4aff-b2cb-bd108e6c5046\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:62:\"field.field.block_content.ebt_webform_popup.field_ebt_settings\";i:2;s:72:\"field.field.block_content.ebt_webform_popup.field_ebt_webform_popup_form\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AkhheynCt4FPPMFnHY7nwaoh-xmCWBAFHkUSVVu-DN8\";}s:2:\"id\";s:39:\"block_content.ebt_webform_popup.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:28:\"field_ebt_webform_popup_form\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:13:\"source_entity\";b:1;}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.media.audio.default',	'a:11:{s:4:\"uuid\";s:36:\"38a6ca87-814c-4d4a-b346-9326e4c72021\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AS765MdDfNpK6K5eE7WVnBvpynClz_havy1R3bO3gVo\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_audio_file\";a:6:{s:4:\"type\";s:10:\"file_audio\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:4:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.audio.media_library',	'a:11:{s:4:\"uuid\";s:36:\"ede5e29a-aefb-40b5-9859-1ac8ed22e499\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tcAUW1Xzq5Tjw5jomR6XKGSgfiXO7QiRAHJBF-n0akg\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.document.default',	'a:11:{s:4:\"uuid\";s:36:\"beb45182-e505-48ae-a153-5d34274d8013\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XxUyhaTuM0OUUZpr8G6jdrFBEh5eag7auWxBKhm6cvY\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:20:\"field_media_document\";a:6:{s:4:\"type\";s:12:\"file_default\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.document.media_library',	'a:11:{s:4:\"uuid\";s:36:\"b0e61493-d3f5-4a7d-8ead-492300acdf21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:21:\"image.style.thumbnail\";i:3;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YcWqjhIlo-2RZUM5ogvRsrKB7M3voF2XB3lVLwgOlLU\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.default',	'a:11:{s:4:\"uuid\";s:36:\"c80bfe30-db84-4270-a319-1c27729f2edf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:17:\"image.style.large\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"73xaTNkI5J6sfFcBmNYeuk070X3mQS_iwwWaPYyfG2M\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:5:\"large\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.ebt_image_gallery',	'a:11:{s:4:\"uuid\";s:36:\"a35ebe6b-2715-41f7-a570-96ae3af68c78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:45:\"core.entity_view_mode.media.ebt_image_gallery\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:29:\"image.style.ebt_gallery_image\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9KEafftKnenx_jl3tACupmwb0WA-eaq31pCE89gmGaY\";}s:2:\"id\";s:29:\"media.image.ebt_image_gallery\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:17:\"ebt_image_gallery\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:17:\"ebt_gallery_image\";s:26:\"glightbox_node_style_first\";s:17:\"ebt_gallery_image\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:6:\"parent\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.media_library',	'a:11:{s:4:\"uuid\";s:36:\"f69a9286-8f3b-42cf-a15a-5f569ca96e99\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:18:\"image.style.medium\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ILLWu5KFvbsX6J7sh2Itd4w8-lBBRhR_H8ZrmQiN2yo\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:17:\"field_media_image\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.video_and_image_gallery_item',	'a:11:{s:4:\"uuid\";s:36:\"513a5e40-b967-4358-8200-0c9cd79302cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:56:\"core.entity_view_mode.media.video_and_image_gallery_item\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:39:\"image.style.ebt_video_and_image_gallery\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"71w4ybrqWdKueRDFJwcgki2l30Gpyrl7WRkhoMS7C6M\";}s:2:\"id\";s:40:\"media.image.video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:28:\"video_and_image_gallery_item\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:27:\"ebt_video_and_image_gallery\";s:26:\"glightbox_node_style_first\";s:0:\"\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.default',	'a:11:{s:4:\"uuid\";s:36:\"7b9a2dff-1714-4265-92f5-b08cb9237f6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZdPcl2hPxl5pgv3pI-07R7h51OjeUeKJTy-ab1NfM34\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:6:\"oembed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:9:\"max_width\";i:0;s:10:\"max_height\";i:0;s:7:\"loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.ebt_video',	'a:11:{s:4:\"uuid\";s:36:\"1e1b792b-f71b-470f-9810-bc2e2d11f17f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:37:\"core.entity_view_mode.media.ebt_video\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NHnPc8vxx5bXjFmHokLtYvI3ebeo_FybRqjMNEhIVOg\";}s:2:\"id\";s:28:\"media.remote_video.ebt_video\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:9:\"ebt_video\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:4:\"post\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"e91b1f8e-5ba5-485e-9c6e-04afe2948e85\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:18:\"image.style.medium\";i:3;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PGGoP-hVkXe_S-GiJRAub4PHDu0KhMExylclrqjdJb4\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.video_and_image_gallery_item',	'a:11:{s:4:\"uuid\";s:36:\"9672ae47-7a64-49d5-904a-cba847d9377d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:56:\"core.entity_view_mode.media.video_and_image_gallery_item\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0gtodl3N0wRFdXaP60sG0h05qbgCOF8wy6ggVWOa8UY\";}s:2:\"id\";s:47:\"media.remote_video.video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:28:\"video_and_image_gallery_item\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:27:\"ebt_video_and_image_gallery\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.video.default',	'a:11:{s:4:\"uuid\";s:36:\"863188fb-17da-49e4-8e79-ddeb23903eef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SxvbuGh-6cQMxl9bBV27-hGI46u7ZvwlMm5ObaJMNnw\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_video_file\";a:6:{s:4:\"type\";s:10:\"file_video\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";s:5:\"muted\";b:0;s:5:\"width\";i:640;s:6:\"height\";i:480;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.video.ebt_video',	'a:11:{s:4:\"uuid\";s:36:\"7bab1942-d337-4497-a621-f6cc29536967\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:37:\"core.entity_view_mode.media.ebt_video\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PhLS2RcsgmXaRpOr6Z569J0KXiE9KNW5OMTC9dvUTkg\";}s:2:\"id\";s:21:\"media.video.ebt_video\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:9:\"ebt_video\";s:7:\"content\";a:1:{s:22:\"field_media_video_file\";a:6:{s:4:\"type\";s:10:\"file_video\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";s:5:\"muted\";b:0;s:5:\"width\";i:640;s:6:\"height\";i:480;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"d00b3c78-35a0-460e-a063-a98a387591cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_fnkUKwQYHkXO1Ngmq9nE6FqWUNAmkddOxAH1h5aiKg\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.node.article.default',	'a:12:{s:4:\"uuid\";s:36:\"97d9050c-f2b4-4b7e-9f3f-10de564e06a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:39:\"field.field.node.article.field_metatags\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:16:\"image.style.wide\";i:5;s:17:\"node.type.article\";}s:6:\"module\";a:5:{i:0;s:14:\"layout_builder\";i:1;s:7:\"metatag\";i:2;s:9:\"svg_image\";i:3;s:4:\"text\";i:4;s:4:\"user\";}}s:20:\"third_party_settings\";a:1:{s:14:\"layout_builder\";a:3:{s:7:\"enabled\";b:1;s:12:\"allow_custom\";b:1;s:8:\"sections\";a:1:{i:0;a:4:{s:9:\"layout_id\";s:13:\"layout_onecol\";s:15:\"layout_settings\";a:1:{s:5:\"label\";s:0:\"\";}s:10:\"components\";a:5:{s:36:\"3120cf62-1cc1-4e2b-96e0-0996d5d6928a\";a:5:{s:4:\"uuid\";s:36:\"3120cf62-1cc1-4e2b-96e0-0996d5d6928a\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:36:\"field_block:node:article:field_image\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:14:\"svg_attributes\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}s:19:\"svg_render_as_image\";b:1;}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:0;s:10:\"additional\";a:0:{}}s:36:\"7f5f46b4-472b-4e74-9a01-8a03e0321444\";a:5:{s:4:\"uuid\";s:36:\"7f5f46b4-472b-4e74-9a01-8a03e0321444\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:29:\"field_block:node:article:body\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:1;s:10:\"additional\";a:0:{}}s:36:\"b902a34b-a3ce-4efc-a85b-86bb824651b9\";a:5:{s:4:\"uuid\";s:36:\"b902a34b-a3ce-4efc-a85b-86bb824651b9\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:35:\"field_block:node:article:field_tags\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:2;s:10:\"additional\";a:0:{}}s:36:\"25d5958c-bea2-4027-8bae-b924b89dce41\";a:5:{s:4:\"uuid\";s:36:\"25d5958c-bea2-4027-8bae-b924b89dce41\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:3:{s:2:\"id\";s:36:\"extra_field_block:node:article:links\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}}s:6:\"weight\";i:3;s:10:\"additional\";a:0:{}}s:36:\"667348d3-3500-418a-b027-8b25f62317df\";a:5:{s:4:\"uuid\";s:36:\"667348d3-3500-418a-b027-8b25f62317df\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:39:\"field_block:node:article:field_metatags\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:4;s:10:\"additional\";a:0:{}}}s:20:\"third_party_settings\";a:0:{}}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"br6izr-iGEu--JvNbCJNtOBpRnxpFLXfoV5y61U9Nqc\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:14:\"svg_attributes\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}s:19:\"svg_render_as_image\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:14:\"field_metatags\";a:6:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.node.article.rss',	'a:11:{s:4:\"uuid\";s:36:\"2e2f92c3-c50a-4139-9c95-4e46ce1f757d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:39:\"field.field.node.article.field_metatags\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:47:\"field.field.node.article.layout_builder__layout\";i:6;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2rIr6K5Q0UQ9khg0zE_CK-PtJH76UL-BDDZcZnZzwCc\";}s:2:\"id\";s:16:\"node.article.rss\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:3:\"rss\";s:7:\"content\";a:1:{s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:5:{s:4:\"body\";b:1;s:11:\"field_image\";b:1;s:14:\"field_metatags\";b:1;s:10:\"field_tags\";b:1;s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_view_display.node.article.teaser',	'a:11:{s:4:\"uuid\";s:36:\"08318816-b086-4cdd-b48c-c020f5a6f328\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:39:\"field.field.node.article.field_metatags\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:47:\"field.field.node.article.layout_builder__layout\";i:6;s:18:\"image.style.medium\";i:7;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:9:\"svg_image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"O8PxzfG8DOHHRu6M23kwR6TDPq_MNfYQ10Mp367ICUQ\";}s:2:\"id\";s:19:\"node.article.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:14:\"field_metatags\";b:1;s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_view_display.node.page.default',	'a:12:{s:4:\"uuid\";s:36:\"5aaa71f3-3511-4b50-8003-331c936478f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:36:\"field.field.node.page.field_metatags\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:4:{i:0;s:14:\"layout_builder\";i:1;s:7:\"metatag\";i:2;s:4:\"text\";i:3;s:4:\"user\";}}s:20:\"third_party_settings\";a:1:{s:14:\"layout_builder\";a:3:{s:7:\"enabled\";b:1;s:12:\"allow_custom\";b:1;s:8:\"sections\";a:1:{i:0;a:4:{s:9:\"layout_id\";s:13:\"layout_onecol\";s:15:\"layout_settings\";a:1:{s:5:\"label\";s:0:\"\";}s:10:\"components\";a:3:{s:36:\"38a9abee-f957-4c37-bf25-26572a864786\";a:5:{s:4:\"uuid\";s:36:\"38a9abee-f957-4c37-bf25-26572a864786\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:26:\"field_block:node:page:body\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:0;s:10:\"additional\";a:0:{}}s:36:\"49025aed-c7ef-4f99-bdb3-01a066d936cf\";a:5:{s:4:\"uuid\";s:36:\"49025aed-c7ef-4f99-bdb3-01a066d936cf\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:3:{s:2:\"id\";s:33:\"extra_field_block:node:page:links\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}}s:6:\"weight\";i:1;s:10:\"additional\";a:0:{}}s:36:\"022c3459-1bc8-481c-aea0-dc1a493c5abb\";a:5:{s:4:\"uuid\";s:36:\"022c3459-1bc8-481c-aea0-dc1a493c5abb\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:36:\"field_block:node:page:field_metatags\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:2;s:10:\"additional\";a:0:{}}}s:20:\"third_party_settings\";a:0:{}}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Y8L5tfmhx7DR143E05YyZSpvgil6VFvqcfBWykalg\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:14:\"field_metatags\";a:6:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:102;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.node.page.teaser',	'a:11:{s:4:\"uuid\";s:36:\"0cdde055-9011-4c16-b82c-494a58ce39ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:26:\"field.field.node.page.body\";i:2;s:36:\"field.field.node.page.field_metatags\";i:3;s:44:\"field.field.node.page.layout_builder__layout\";i:4;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8BgdRtLbtQ0F__o0FHSH0Mx5fvXOra9tfT1GmNKbRYw\";}s:2:\"id\";s:16:\"node.page.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:14:\"field_metatags\";b:1;s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_view_display.paragraph.ebt_accordion.default',	'a:11:{s:4:\"uuid\";s:36:\"d7bca4fc-d99f-4966-929d-15f5247c8564\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:60:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_text\";i:1;s:61:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_title\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yn5RBnnmFE_Y5sCchtXzAOZg0joBlJrWIBEaYAnP9Ps\";}s:2:\"id\";s:31:\"paragraph.ebt_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ebt_accordion_text\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_accordion_title\";a:6:{s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_carousel.default',	'a:11:{s:4:\"uuid\";s:36:\"2e2b2311-9c14-4e94-aecd-97a3f060f45a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:61:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_caption\";i:1;s:59:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o21VkkuJdszAqDOznTVc61VIxPQJc6ocyXSW3qSQFHc\";}s:2:\"id\";s:30:\"paragraph.ebt_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ebt_carousel_caption\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_carousel_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:11:\"image_style\";s:0:\"\";s:10:\"image_link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_counter_item.default',	'a:11:{s:4:\"uuid\";s:36:\"9cd9785e-414b-4ccf-a6f4-9b5039218fd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_description\";i:1;s:61:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_icon\";i:2;s:63:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_number\";i:3;s:62:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EjbsMNoEaP6Z3U6dn1mNEir0yNE1gFyyIzkKiYVPO_4\";}s:2:\"id\";s:34:\"paragraph.ebt_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ebt_counter_description\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_counter_icon\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_counter_number\";a:6:{s:4:\"type\";s:14:\"number_integer\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_counter_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_slick_slider.default',	'a:11:{s:4:\"uuid\";s:36:\"152c6a3e-8703-40b0-ad21-283b4ae6cc5b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:67:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_image\";i:1;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_link\";i:2;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_text\";i:3;s:29:\"image.style.slick_slider_card\";i:4;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VVV9wfo5l1gK1weU695gzyXqp5on_oNav7jAwjjWowQ\";}s:2:\"id\";s:34:\"paragraph.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ebt_slick_slider_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:17:\"slick_slider_card\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_slick_slider_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_slick_slider_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_slideshow.default',	'a:11:{s:4:\"uuid\";s:36:\"5003e24e-550b-4a07-a87f-66e0dbab0e83\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_link\";i:1;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_slide\";i:2;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_text\";i:3;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_title\";i:4;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-TV7U97Wd40UA7J_3-aQjPyYv360Wi3Te0PPvYviuxU\";}s:2:\"id\";s:31:\"paragraph.ebt_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ebt_slideshow_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1023;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_slideshow_slide\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_slideshow_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_slideshow_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_stats_item.default',	'a:11:{s:4:\"uuid\";s:36:\"77949beb-f2e0-46a7-bbe3-3ede2ef7f061\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:59:\"field.field.paragraph.ebt_stats_item.field_stats_item_image\";i:1;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_link\";i:2;s:60:\"field.field.paragraph.ebt_stats_item.field_stats_item_number\";i:3;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5RDw3deJvwfKptyvRWt0uMj5O3zRyWKrJCZ_MFWk7Po\";}s:2:\"id\";s:32:\"paragraph.ebt_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:22:\"field_stats_item_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:21:\"field_stats_item_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:23:\"field_stats_item_number\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:21:\"field_stats_item_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_tab.default',	'a:11:{s:4:\"uuid\";s:36:\"4b41c82a-77c1-47f0-a052-9b87649b8136\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_block\";i:1;s:51:\"field.field.paragraph.ebt_tab.field_ebt_tab_content\";i:2;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_page\";i:3;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_text\";i:4;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_title\";i:5;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_views\";i:6;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"slUTwjnod77jaefmi2b5OQYl4vYxpAodJPHvoHGvQUA\";}s:2:\"id\";s:25:\"paragraph.ebt_tab.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:19:\"field_ebt_tab_block\";a:6:{s:6:\"weight\";i:6;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:11:\"block_field\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_page\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:4:\"link\";b:1;s:9:\"view_mode\";s:7:\"default\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:28:\"entity_reference_entity_view\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_text\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_title\";a:6:{s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_views\";a:6:{s:6:\"weight\";i:5;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:1:{i:0;s:5:\"block\";}}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:24:\"viewsreference_formatter\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:21:\"field_ebt_tab_content\";b:1;}}'),
('',	'core.entity_view_display.paragraph.ebt_tiles_item.default',	'a:11:{s:4:\"uuid\";s:36:\"4ccbb938-c11d-49a7-ba57-753328efb08b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_tiles_item.field_ebt_clickable_tile\";i:1;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_image\";i:2;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_link\";i:3;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_text\";i:4;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZHOP2C6K3eAHsBjc_FJwNsbIKZ-XL88CGUz5EexQ8nE\";}s:2:\"id\";s:32:\"paragraph.ebt_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ebt_clickable_tile\";a:6:{s:4:\"type\";s:7:\"boolean\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:3:{s:6:\"format\";s:7:\"default\";s:19:\"format_custom_false\";s:0:\"\";s:18:\"format_custom_true\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_tiles_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_tiles_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_tiles_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_tiles_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_timeline.default',	'a:11:{s:4:\"uuid\";s:36:\"553c2833-822a-4508-a2f9-99f9ffc89f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_current\";i:1;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_date\";i:2;s:65:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_media_image\";i:3;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_text\";i:4;s:59:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_title\";i:5;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kScbPfdPZDsoEdHqJtQ9QjqdBXgkz2VT-TEA4uO4yQU\";}s:2:\"id\";s:30:\"paragraph.ebt_timeline.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:26:\"field_ebt_timeline_current\";a:6:{s:4:\"type\";s:7:\"boolean\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:6:\"format\";s:7:\"default\";s:19:\"format_custom_false\";s:0:\"\";s:18:\"format_custom_true\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_timeline_date\";a:6:{s:4:\"type\";s:6:\"string\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:30:\"field_ebt_timeline_media_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_timeline_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_timeline_title\";a:6:{s:4:\"type\";s:6:\"string\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_video_and_image_gallery_item.default',	'a:11:{s:4:\"uuid\";s:36:\"0a70dbed-c211-4ec2-a7e5-7d9b701046db\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:85:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description\";i:1;s:79:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item\";i:2;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ATQKQ04wbZpenyUY_sMfDM08puKPXNvoGB5tSxGxwG0\";}s:2:\"id\";s:50:\"paragraph.ebt_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:30:\"field_gallery_item_description\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:24:\"field_video_gallery_item\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:28:\"video_and_image_gallery_item\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.user.user.compact',	'a:11:{s:4:\"uuid\";s:36:\"73223d5a-b425-4fba-9090-7b112d030f92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:34:\"core.entity_view_mode.user.compact\";i:1;s:34:\"field.field.user.user.user_picture\";i:2;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"00zr_RBdTjPjBGITD3h4c1ESQZimjdVCcHGt1trLqIY\";}s:2:\"id\";s:17:\"user.user.compact\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"compact\";s:7:\"content\";a:1:{s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:10:\"member_for\";b:1;}}'),
('',	'core.entity_view_display.user.user.default',	'a:11:{s:4:\"uuid\";s:36:\"1c220693-f471-4184-9453-cd90fc0030d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mZLyuWM9CQx2ZJVqFGSbzgFnHzudVbHBYmdU256A5Wk\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:10:\"member_for\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_mode.block.token',	'a:9:{s:4:\"uuid\";s:36:\"c298243a-fc61-46e8-8878-5de88a9bcb0b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"block\";}}s:2:\"id\";s:11:\"block.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"block\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.block_content.full',	'a:10:{s:4:\"uuid\";s:36:\"9268fa23-36f9-4a94-a9ef-799f2d1c5eb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q7yUUYeRLByl-MCGveKKF_KhAtNICLCMJuKWfugCvso\";}s:2:\"id\";s:18:\"block_content.full\";s:5:\"label\";s:4:\"Full\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.block_content.token',	'a:9:{s:4:\"uuid\";s:36:\"004ad1d4-03ad-4317-af82-4bb9f039c686\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:2:\"id\";s:19:\"block_content.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.contact_message.token',	'a:9:{s:4:\"uuid\";s:36:\"b51e5b3c-1a2e-49cf-acff-bfc2dea5ad40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"contact\";}}s:2:\"id\";s:21:\"contact_message.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:15:\"contact_message\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.file.token',	'a:9:{s:4:\"uuid\";s:36:\"99749d8d-98ee-49e8-b272-054f53d7c97f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:2:\"id\";s:10:\"file.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"file\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.ebt_image_gallery',	'a:10:{s:4:\"uuid\";s:36:\"d8772b40-e75a-46fe-a0eb-48e3c2f13441\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gx3dAzTlzUoOPV6nrqIxtsHu6AWtMEd6M4HRihgOIdc\";}s:2:\"id\";s:23:\"media.ebt_image_gallery\";s:5:\"label\";s:17:\"EBT Image Gallery\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.ebt_video',	'a:10:{s:4:\"uuid\";s:36:\"9ff59caf-8ee9-4fca-bffa-89132c94c813\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IXsnV3TXq49eaMlltbjpSWIiseAysJRe042Revn8t1s\";}s:2:\"id\";s:15:\"media.ebt_video\";s:5:\"label\";s:9:\"EBT Video\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.full',	'a:10:{s:4:\"uuid\";s:36:\"fb758fd6-28cd-4155-8eda-49912e1da3f8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dTfAUHooYV0uOVPO3saGpgv-c5PppJXDwxvwRTJOycM\";}s:2:\"id\";s:10:\"media.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.media_library',	'a:10:{s:4:\"uuid\";s:36:\"1a098749-bd7d-429f-9d91-d4e7913c8c3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.token',	'a:9:{s:4:\"uuid\";s:36:\"aa6556df-5384-471d-96b4-a6d264801693\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:2:\"id\";s:11:\"media.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.video_and_image_gallery_item',	'a:10:{s:4:\"uuid\";s:36:\"6f5a787d-85f5-4bea-aab2-4094c6f7772f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u0M3Ybb0-9QE3E30c77uKo8PW64Vexg-TwC2IHerOgs\";}s:2:\"id\";s:34:\"media.video_and_image_gallery_item\";s:5:\"label\";s:28:\"Video and Image gallery item\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.menu_link_content.token',	'a:9:{s:4:\"uuid\";s:36:\"33a56e28-1d42-4a4f-b42a-88eb552104a7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:17:\"menu_link_content\";}}s:2:\"id\";s:23:\"menu_link_content.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:17:\"menu_link_content\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.full',	'a:10:{s:4:\"uuid\";s:36:\"5aefb664-7e3c-4ebe-86a2-07194cada9f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QJ2aZ1xfVf59aq6Pz5X7fyUOa2HxuCoTwQ_RQjoulAU\";}s:2:\"id\";s:9:\"node.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.rss',	'a:10:{s:4:\"uuid\";s:36:\"6b3209c3-0ae1-46f6-8e2c-44d4391f2434\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l8fiAFE3Kng_6bhLlUDnVTkTDzXWxzYFrCWTrngVXEA\";}s:2:\"id\";s:8:\"node.rss\";s:5:\"label\";s:3:\"RSS\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.search_index',	'a:10:{s:4:\"uuid\";s:36:\"416e3f7c-ab1b-4bb4-b428-aabf9906eecf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_A0T3aTqGDwLyvoH7wLps-0PM--RHlS8UsiJe_Ac64\";}s:2:\"id\";s:17:\"node.search_index\";s:5:\"label\";s:12:\"Search index\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.search_result',	'a:10:{s:4:\"uuid\";s:36:\"c196759a-15b6-47d3-b672-f853645cc638\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d8wBEm7XvJ6H3S0IneDD9PfTBklPIH7GMpxElVemPf8\";}s:2:\"id\";s:18:\"node.search_result\";s:5:\"label\";s:32:\"Search result highlighting input\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.teaser',	'a:10:{s:4:\"uuid\";s:36:\"aa910ffb-3a87-4512-af06-273b721bc12f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KgGJDZFpMaz_8bTv6fN1bXS3Qi5LWmRJI9R53kEGsNQ\";}s:2:\"id\";s:11:\"node.teaser\";s:5:\"label\";s:6:\"Teaser\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.token',	'a:9:{s:4:\"uuid\";s:36:\"3ec23f24-50ef-434e-a7b6-3d8cb9a2a4f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:2:\"id\";s:10:\"node.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.paragraph.preview',	'a:10:{s:4:\"uuid\";s:36:\"f30f214f-6163-41a8-a996-f703e5fd92cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"h3BeHVei4Lnyqbkao3YiF4KqoY-DhRvUNfEgKG8Rgjg\";}s:2:\"id\";s:17:\"paragraph.preview\";s:5:\"label\";s:7:\"Preview\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.path_alias.token',	'a:9:{s:4:\"uuid\";s:36:\"b47111c9-dcb8-4762-af5c-3f7acca095d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"path_alias\";}}s:2:\"id\";s:16:\"path_alias.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:10:\"path_alias\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.shortcut.token',	'a:9:{s:4:\"uuid\";s:36:\"550ba8ad-246f-433e-8c0d-f2c76255df0e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"shortcut\";}}s:2:\"id\";s:14:\"shortcut.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:8:\"shortcut\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.taxonomy_term.full',	'a:10:{s:4:\"uuid\";s:36:\"e72ba8d8-dba4-4920-91d6-5e916b81a6fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iukUENpf8CFvjZbGGacKX_Ges0-lU9z6zvsd32P6kbo\";}s:2:\"id\";s:18:\"taxonomy_term.full\";s:5:\"label\";s:18:\"Taxonomy term page\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.taxonomy_term.token',	'a:9:{s:4:\"uuid\";s:36:\"ea887f34-9e29-4000-aef4-21112004577d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:2:\"id\";s:19:\"taxonomy_term.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.user.compact',	'a:10:{s:4:\"uuid\";s:36:\"06ded9f9-3e1a-44f0-a5e0-224efcca6431\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TtD7OuGskOsQfoGyxXkrdtllBpR37J19d5BMQDZWJgA\";}s:2:\"id\";s:12:\"user.compact\";s:5:\"label\";s:7:\"Compact\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.user.full',	'a:10:{s:4:\"uuid\";s:36:\"ad69e028-e0a2-4eab-9d8b-d18e904da6bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZbXunWS_xAvMZXFfinyvClDAb_RCVLt7gAzE3v16E-Q\";}s:2:\"id\";s:9:\"user.full\";s:5:\"label\";s:12:\"User account\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.user.token',	'a:9:{s:4:\"uuid\";s:36:\"676a8206-d9d0-4094-bf54-66a60c6bad53\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:10:\"user.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.webform.token',	'a:9:{s:4:\"uuid\";s:36:\"5f8faafa-6ec3-4704-a06c-08d5391b12d7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:2:\"id\";s:13:\"webform.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:7:\"webform\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.webform_submission.token',	'a:9:{s:4:\"uuid\";s:36:\"92d0137a-b4c4-4c19-b07b-84c8b8844019\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:2:\"id\";s:24:\"webform_submission.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:18:\"webform_submission\";s:5:\"cache\";b:1;}'),
('',	'core.extension',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GIX5Esnc_umpXUBj4IIocRX7Mt5fPhm4AgXfE3E56E\";}s:6:\"module\";a:107:{s:13:\"admin_toolbar\";i:0;s:19:\"admin_toolbar_tools\";i:0;s:18:\"announcements_feed\";i:0;s:14:\"automated_cron\";i:0;s:8:\"big_pipe\";i:0;s:5:\"block\";i:0;s:13:\"block_content\";i:0;s:11:\"block_field\";i:0;s:10:\"breakpoint\";i:0;s:9:\"ckeditor5\";i:0;s:21:\"ckeditor5_plugin_pack\";i:0;s:32:\"ckeditor5_plugin_pack_auto_image\";i:0;s:38:\"ckeditor5_plugin_pack_find_and_replace\";i:0;s:26:\"ckeditor5_plugin_pack_font\";i:0;s:31:\"ckeditor5_plugin_pack_highlight\";i:0;s:34:\"ckeditor5_plugin_pack_indent_block\";i:0;s:32:\"ckeditor5_plugin_pack_page_break\";i:0;s:32:\"ckeditor5_plugin_pack_select_all\";i:0;s:31:\"ckeditor5_plugin_pack_templates\";i:0;s:41:\"ckeditor5_plugin_pack_text_transformation\";i:0;s:40:\"ckeditor5_plugin_pack_todo_document_list\";i:0;s:32:\"ckeditor5_plugin_pack_word_count\";i:0;s:37:\"ckeditor5_premium_features_fullscreen\";i:0;s:6:\"config\";i:0;s:13:\"config_ignore\";i:0;s:7:\"contact\";i:0;s:10:\"contextual\";i:0;s:8:\"datetime\";i:0;s:5:\"dblog\";i:0;s:18:\"dynamic_page_cache\";i:0;s:13:\"ebt_accordion\";i:0;s:16:\"ebt_basic_button\";i:0;s:9:\"ebt_block\";i:0;s:20:\"ebt_bootstrap_button\";i:0;s:12:\"ebt_carousel\";i:0;s:11:\"ebt_columns\";i:0;s:8:\"ebt_core\";i:0;s:13:\"ebt_countdown\";i:0;s:11:\"ebt_counter\";i:0;s:7:\"ebt_cta\";i:0;s:8:\"ebt_hero\";i:0;s:9:\"ebt_image\";i:0;s:17:\"ebt_image_gallery\";i:0;s:14:\"ebt_micromodal\";i:0;s:9:\"ebt_quote\";i:0;s:16:\"ebt_slick_slider\";i:0;s:13:\"ebt_slideshow\";i:0;s:9:\"ebt_stats\";i:0;s:8:\"ebt_tabs\";i:0;s:8:\"ebt_text\";i:0;s:9:\"ebt_tiles\";i:0;s:12:\"ebt_timeline\";i:0;s:9:\"ebt_video\";i:0;s:27:\"ebt_video_and_image_gallery\";i:0;s:9:\"ebt_views\";i:0;s:11:\"ebt_webform\";i:0;s:17:\"ebt_webform_popup\";i:0;s:6:\"editor\";i:0;s:26:\"entity_reference_revisions\";i:0;s:5:\"field\";i:0;s:11:\"field_group\";i:0;s:8:\"field_ui\";i:0;s:4:\"file\";i:0;s:6:\"filter\";i:0;s:9:\"glightbox\";i:0;s:21:\"glightbox_media_video\";i:0;s:16:\"google_analytics\";i:0;s:4:\"help\";i:0;s:7:\"history\";i:0;s:5:\"image\";i:0;s:9:\"jquery_ui\";i:0;s:19:\"jquery_ui_accordion\";i:0;s:14:\"jquery_ui_tabs\";i:0;s:14:\"layout_builder\";i:0;s:16:\"layout_discovery\";i:0;s:4:\"link\";i:0;s:6:\"linkit\";i:0;s:5:\"media\";i:0;s:13:\"media_library\";i:0;s:26:\"media_library_form_element\";i:0;s:17:\"menu_link_content\";i:0;s:7:\"menu_ui\";i:0;s:7:\"metatag\";i:0;s:4:\"node\";i:0;s:7:\"options\";i:0;s:10:\"page_cache\";i:0;s:4:\"path\";i:0;s:10:\"path_alias\";i:0;s:16:\"profile_switcher\";i:0;s:8:\"redirect\";i:0;s:6:\"search\";i:0;s:8:\"shortcut\";i:0;s:9:\"svg_image\";i:0;s:6:\"system\";i:0;s:8:\"taxonomy\";i:0;s:4:\"text\";i:0;s:5:\"token\";i:0;s:7:\"toolbar\";i:0;s:6:\"update\";i:0;s:4:\"user\";i:0;s:8:\"views_ui\";i:0;s:14:\"viewsreference\";i:0;s:7:\"webform\";i:0;s:8:\"pathauto\";i:1;s:5:\"views\";i:10;s:10:\"paragraphs\";i:11;s:4:\"fast\";i:1000;}s:5:\"theme\";a:2:{s:7:\"olivero\";i:0;s:5:\"claro\";i:0;}s:7:\"profile\";s:4:\"fast\";}'),
('',	'core.menu.static_menu_link_overrides',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CXhei_vpaZk-3f_Mj2cH0YmpK-ZpKHoSzVA3yZrDq0g\";}s:11:\"definitions\";a:1:{s:18:\"contact__site_page\";a:5:{s:9:\"menu_name\";s:6:\"footer\";s:6:\"parent\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:7:\"enabled\";b:1;}}}'),
('',	'dblog.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e883aGsrt1wFrsydlYU584PZONCSfRy0DtkZ9KzHb58\";}s:9:\"row_limit\";i:1000;}'),
('',	'ebt_core.settings',	'a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VBIZ2klsa-wrUk3pFOgIi3avMLFro6A0nFNYc35MvNQ\";}s:26:\"ebt_core_mobile_breakpoint\";s:3:\"640\";s:26:\"ebt_core_tablet_breakpoint\";s:4:\"1020\";s:27:\"ebt_core_desktop_breakpoint\";s:4:\"1320\";s:22:\"ebt_core_xxsmall_width\";s:3:\"480\";s:21:\"ebt_core_xsmall_width\";s:3:\"640\";s:20:\"ebt_core_small_width\";s:3:\"768\";s:22:\"ebt_core_default_width\";s:3:\"960\";s:20:\"ebt_core_large_width\";s:4:\"1100\";s:21:\"ebt_core_xlarge_width\";s:4:\"1320\";s:22:\"ebt_core_xxlarge_width\";s:4:\"1600\";s:25:\"ebt_core_background_color\";s:7:\"#0d77b5\";}'),
('',	'editor.editor.basic_html',	'a:9:{s:4:\"uuid\";s:36:\"65aded18-2f8d-4ec3-8d69-0a602798f4dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"filter.format.basic_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qi2tIe-L97EutlMmhEvhsNxZOpOoA-RH82c4BQb5n4A\";}s:6:\"format\";s:10:\"basic_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:15:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:1:\"|\";i:3;s:4:\"link\";i:4;s:1:\"|\";i:5;s:12:\"bulletedList\";i:6;s:12:\"numberedList\";i:7;s:1:\"|\";i:8;s:10:\"blockQuote\";i:9;s:17:\"drupalInsertImage\";i:10;s:1:\"|\";i:11;s:7:\"heading\";i:12;s:4:\"code\";i:13;s:1:\"|\";i:14;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:4:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:0;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:13:{i:0;s:6:\"<cite>\";i:1;s:4:\"<dl>\";i:2;s:4:\"<dt>\";i:3;s:4:\"<dd>\";i:4;s:12:\"<a hreflang>\";i:5;s:17:\"<blockquote cite>\";i:6;s:9:\"<ul type>\";i:7;s:9:\"<ol type>\";i:8;s:7:\"<h2 id>\";i:9;s:7:\"<h3 id>\";i:10;s:7:\"<h4 id>\";i:11;s:7:\"<h5 id>\";i:12;s:7:\"<h6 id>\";}}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),
('',	'editor.editor.full_html',	'a:9:{s:4:\"uuid\";s:36:\"1926258e-dc0e-4aaa-95d1-5abf3be483cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"filter.format.full_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lurcn8yf33g3Dkzdc55cTfJa9salGp9ytSYyG1s7QMI\";}s:6:\"format\";s:9:\"full_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:21:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:13:\"strikethrough\";i:3;s:11:\"superscript\";i:4;s:9:\"subscript\";i:5;s:12:\"removeFormat\";i:6;s:1:\"|\";i:7;s:4:\"link\";i:8;s:1:\"|\";i:9;s:12:\"bulletedList\";i:10;s:12:\"numberedList\";i:11;s:1:\"|\";i:12;s:10:\"blockQuote\";i:13;s:17:\"drupalInsertImage\";i:14;s:11:\"insertTable\";i:15;s:14:\"horizontalLine\";i:16;s:1:\"|\";i:17;s:7:\"heading\";i:18;s:9:\"codeBlock\";i:19;s:1:\"|\";i:20;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:5:{s:19:\"ckeditor5_codeBlock\";a:1:{s:9:\"languages\";a:14:{i:0;a:2:{s:5:\"label\";s:10:\"Plain text\";s:8:\"language\";s:9:\"plaintext\";}i:1;a:2:{s:5:\"label\";s:1:\"C\";s:8:\"language\";s:1:\"c\";}i:2;a:2:{s:5:\"label\";s:2:\"C#\";s:8:\"language\";s:2:\"cs\";}i:3;a:2:{s:5:\"label\";s:3:\"C++\";s:8:\"language\";s:3:\"cpp\";}i:4;a:2:{s:5:\"label\";s:3:\"CSS\";s:8:\"language\";s:3:\"css\";}i:5;a:2:{s:5:\"label\";s:4:\"Diff\";s:8:\"language\";s:4:\"diff\";}i:6;a:2:{s:5:\"label\";s:4:\"HTML\";s:8:\"language\";s:4:\"html\";}i:7;a:2:{s:5:\"label\";s:4:\"Java\";s:8:\"language\";s:4:\"java\";}i:8;a:2:{s:5:\"label\";s:10:\"JavaScript\";s:8:\"language\";s:10:\"javascript\";}i:9;a:2:{s:5:\"label\";s:3:\"PHP\";s:8:\"language\";s:3:\"php\";}i:10;a:2:{s:5:\"label\";s:6:\"Python\";s:8:\"language\";s:6:\"python\";}i:11;a:2:{s:5:\"label\";s:4:\"Ruby\";s:8:\"language\";s:4:\"ruby\";}i:12;a:2:{s:5:\"label\";s:10:\"TypeScript\";s:8:\"language\";s:10:\"typescript\";}i:13;a:2:{s:5:\"label\";s:3:\"XML\";s:8:\"language\";s:3:\"xml\";}}}s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),
('',	'editor.editor.webform_default',	'a:8:{s:4:\"uuid\";s:36:\"4c6d924f-2c8d-4499-9713-799828c76079\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:6:\"format\";s:15:\"webform_default\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:20:{i:0;s:7:\"heading\";i:1;s:1:\"|\";i:2;s:4:\"bold\";i:3;s:6:\"italic\";i:4;s:9:\"subscript\";i:5;s:11:\"superscript\";i:6;s:1:\"|\";i:7;s:17:\"specialCharacters\";i:8;s:1:\"|\";i:9;s:12:\"numberedList\";i:10;s:12:\"bulletedList\";i:11;s:1:\"|\";i:12;s:4:\"link\";i:13;s:1:\"|\";i:14;s:6:\"indent\";i:15;s:7:\"outdent\";i:16;s:1:\"|\";i:17;s:10:\"blockQuote\";i:18;s:1:\"|\";i:19;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:3:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}}}s:12:\"image_upload\";a:1:{s:6:\"status\";b:0;}}'),
('',	'field.field.block_content.basic.body',	'a:17:{s:4:\"uuid\";s:36:\"22004f3b-acef-4ec7-a26a-84514e3b0755\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j00Gfs9AFqwK4x9RIsISLbPO7vA12psPR4s60wOIwQo\";}s:2:\"id\";s:24:\"block_content.basic.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_accordion.body',	'a:17:{s:4:\"uuid\";s:36:\"28cf0280-0877-4dba-9961-a719b378e9f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EcoPer3Ti0HE0G0vbR_XTjvl4J4xhtcfJlZiIpT2-ic\";}s:2:\"id\";s:32:\"block_content.ebt_accordion.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_accordion.field_ebt_accordion',	'a:17:{s:4:\"uuid\";s:36:\"da20cc91-36e0-4116-8c1e-1b5e33ccbd6e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:47:\"field.storage.block_content.field_ebt_accordion\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KleL2jMUTWlOv_XwXvSfbaLHvZFC4TO3ZGrHClNa8Jk\";}s:2:\"id\";s:47:\"block_content.ebt_accordion.field_ebt_accordion\";s:10:\"field_name\";s:19:\"field_ebt_accordion\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:9:\"Accordion\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:13:\"ebt_accordion\";s:13:\"ebt_accordion\";}s:24:\"target_bundles_drag_drop\";a:1:{s:13:\"ebt_accordion\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:3;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_accordion.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"082df8d4-f424-4ec5-9be7-fa79dca0bc70\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4JvhH84_ab4oNGRe99S5bOvjSJdmPzs1XF2s5a0tlPc\";}s:2:\"id\";s:46:\"block_content.ebt_accordion.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_basic_button.field_ebt_basic_button_link',	'a:17:{s:4:\"uuid\";s:36:\"c0f9b024-755c-40ce-9a70-2d7135b9b02d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:55:\"field.storage.block_content.field_ebt_basic_button_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sHxTdakkm0n2AWPN2_ygOqsVXsuySIH10GpOOAEbzYE\";}s:2:\"id\";s:58:\"block_content.ebt_basic_button.field_ebt_basic_button_link\";s:10:\"field_name\";s:27:\"field_ebt_basic_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:5:\"label\";s:11:\"Button LInk\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"link_type\";i:17;s:5:\"title\";i:2;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_basic_button.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"28dce901-3d51-4486-b431-ddbf214523f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TljYP0E4TAaKsPdVXhWVNLXzzFG9oPBu7BUROGtWlPY\";}s:2:\"id\";s:49:\"block_content.ebt_basic_button.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_block.body',	'a:17:{s:4:\"uuid\";s:36:\"c82da539-0efe-4f63-b7ed-cfb0c65f3022\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ze4f8wKV-sjDw10PzW5_0VDQpHaV7fUywYLVyynLOXQ\";}s:2:\"id\";s:28:\"block_content.ebt_block.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_block.field_ebt_block_block',	'a:17:{s:4:\"uuid\";s:36:\"02b3090f-c1e2-41ef-961f-8f9dbe3677b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:49:\"field.storage.block_content.field_ebt_block_block\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ODt400wjC0-0TFAwPcqdOKmEH1RCrno2RlHZAO9jMDY\";}s:2:\"id\";s:45:\"block_content.ebt_block.field_ebt_block_block\";s:10:\"field_name\";s:21:\"field_ebt_block_block\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:5:\"label\";s:5:\"Block\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:10:\"categories\";s:18:\"selection_settings\";a:1:{s:10:\"categories\";a:24:{s:5:\"Block\";s:5:\"Block\";s:14:\"Comment fields\";s:14:\"Comment fields\";s:22:\"Contact message fields\";s:22:\"Contact message fields\";s:13:\"Content block\";s:13:\"Content block\";s:20:\"Content block fields\";s:20:\"Content block fields\";s:14:\"Content fields\";s:14:\"Content fields\";s:4:\"core\";s:4:\"core\";s:23:\"Custom menu link fields\";s:23:\"Custom menu link fields\";s:11:\"File fields\";s:11:\"File fields\";s:5:\"Forms\";s:5:\"Forms\";s:4:\"Help\";s:4:\"Help\";s:13:\"Inline blocks\";s:13:\"Inline blocks\";s:13:\"Lists (Views)\";s:13:\"Lists (Views)\";s:12:\"Media fields\";s:12:\"Media fields\";s:5:\"Menus\";s:5:\"Menus\";s:16:\"Paragraph fields\";s:16:\"Paragraph fields\";s:20:\"Shortcut link fields\";s:20:\"Shortcut link fields\";s:6:\"System\";s:6:\"System\";s:20:\"Taxonomy term fields\";s:20:\"Taxonomy term fields\";s:16:\"URL alias fields\";s:16:\"URL alias fields\";s:4:\"User\";s:4:\"User\";s:11:\"User fields\";s:11:\"User fields\";s:7:\"Webform\";s:7:\"Webform\";s:25:\"Webform submission fields\";s:25:\"Webform submission fields\";}}}s:10:\"field_type\";s:11:\"block_field\";}'),
('',	'field.field.block_content.ebt_block.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"4cf8e43c-52cf-40e7-8fab-03ba24e5671d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HsmfX01jgclZMXztEvPXS8YoUBvYO2AzDJY7Olj0G5A\";}s:2:\"id\";s:42:\"block_content.ebt_block.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link',	'a:17:{s:4:\"uuid\";s:36:\"308dba68-d030-422d-b8e9-72568d1fd20a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:59:\"field.storage.block_content.field_ebt_bootstrap_button_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LHj34VkFYZYI5N_541KsHaqlWyuH7Cw_KxfjHm23woU\";}s:2:\"id\";s:66:\"block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ebt_bootstrap_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"link_type\";i:17;s:5:\"title\";i:2;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_bootstrap_button.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"b6ea63fb-dfef-42aa-bda8-892c68583ffc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-6S_O_kYEPD4uAw2AnjYuYGHz_CMhBBvkkO5sJA1DYg\";}s:2:\"id\";s:53:\"block_content.ebt_bootstrap_button.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_carousel.field_ebt_carousel',	'a:17:{s:4:\"uuid\";s:36:\"2bc22340-9888-4636-9768-5a9bc9ffd66c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:46:\"field.storage.block_content.field_ebt_carousel\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NZhceEWb8sFj-vaeEbM_eFgHPVULnofUVtBb6FO526E\";}s:2:\"id\";s:45:\"block_content.ebt_carousel.field_ebt_carousel\";s:10:\"field_name\";s:18:\"field_ebt_carousel\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:8:\"Carousel\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:12:\"ebt_carousel\";s:12:\"ebt_carousel\";}s:24:\"target_bundles_drag_drop\";a:1:{s:12:\"ebt_carousel\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:6;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_carousel.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"82540ccc-a725-412b-b6ba-bc89d09e03fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U2Ky-DS_Wo_f9KN2f-PSJN975w1XnGxWcaly7VF6-tU\";}s:2:\"id\";s:45:\"block_content.ebt_carousel.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_columns.body',	'a:17:{s:4:\"uuid\";s:36:\"b6c8e80f-807f-4acf-b36e-55ea98dc4fb3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WqbyqczhS3unr9KEuC6FRXfpi9rVW3mCtF8P2TGxkQI\";}s:2:\"id\";s:30:\"block_content.ebt_columns.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_columns.field_ebt_columns_blocks',	'a:17:{s:4:\"uuid\";s:36:\"eca7b2b8-8806-49f1-ae15-756018a6c67f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:52:\"field.storage.block_content.field_ebt_columns_blocks\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DlzRJb8gJARkGrf3IjWcpsIQfTvSJt9DmGRT1aBailQ\";}s:2:\"id\";s:50:\"block_content.ebt_columns.field_ebt_columns_blocks\";s:10:\"field_name\";s:24:\"field_ebt_columns_blocks\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:5:\"label\";s:6:\"Blocks\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:10:\"categories\";s:18:\"selection_settings\";a:1:{s:10:\"categories\";a:24:{s:5:\"Block\";s:5:\"Block\";s:14:\"Comment fields\";s:14:\"Comment fields\";s:22:\"Contact message fields\";s:22:\"Contact message fields\";s:13:\"Content block\";s:13:\"Content block\";s:20:\"Content block fields\";s:20:\"Content block fields\";s:14:\"Content fields\";s:14:\"Content fields\";s:4:\"core\";s:4:\"core\";s:23:\"Custom menu link fields\";s:23:\"Custom menu link fields\";s:11:\"File fields\";s:11:\"File fields\";s:5:\"Forms\";s:5:\"Forms\";s:4:\"Help\";s:4:\"Help\";s:13:\"Inline blocks\";s:13:\"Inline blocks\";s:13:\"Lists (Views)\";s:13:\"Lists (Views)\";s:12:\"Media fields\";s:12:\"Media fields\";s:5:\"Menus\";s:5:\"Menus\";s:16:\"Paragraph fields\";s:16:\"Paragraph fields\";s:20:\"Shortcut link fields\";s:20:\"Shortcut link fields\";s:6:\"System\";s:6:\"System\";s:20:\"Taxonomy term fields\";s:20:\"Taxonomy term fields\";s:16:\"URL alias fields\";s:16:\"URL alias fields\";s:4:\"User\";s:4:\"User\";s:11:\"User fields\";s:11:\"User fields\";s:7:\"Webform\";s:7:\"Webform\";s:25:\"Webform submission fields\";s:25:\"Webform submission fields\";}}}s:10:\"field_type\";s:11:\"block_field\";}'),
('',	'field.field.block_content.ebt_columns.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"9cc6560f-9a4a-4969-9e4b-0d667ef4817c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"97Zeg-Y42bu_WIG-So7eo7DK0hKpS1XqwrJ1kGdYY8E\";}s:2:\"id\";s:44:\"block_content.ebt_columns.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_countdown.body',	'a:17:{s:4:\"uuid\";s:36:\"7266abd1-c799-4ff0-96ef-b464471e6583\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7Eup8vFqqabcEdya_X4KmbnCSstllEkrmXRpfxOCdmU\";}s:2:\"id\";s:32:\"block_content.ebt_countdown.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_countdown.field_ebt_countdown_date',	'a:17:{s:4:\"uuid\";s:36:\"daee2d15-8abc-4764-8789-2fcf13604386\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:52:\"field.storage.block_content.field_ebt_countdown_date\";}s:6:\"module\";a:1:{i:0;s:8:\"datetime\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rS3ZCjiH3ZhM6LLmDYfxfr1x4lVA0pMJeUjgvHYJwJU\";}s:2:\"id\";s:52:\"block_content.ebt_countdown.field_ebt_countdown_date\";s:10:\"field_name\";s:24:\"field_ebt_countdown_date\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:5:\"label\";s:14:\"Countdown date\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:8:\"datetime\";}'),
('',	'field.field.block_content.ebt_countdown.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"56e05cdb-f253-4954-9c39-5253face9482\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2Z_UQh0ye99krkSwmrnf32Lbdr_bJwll60WqPfcn3WQ\";}s:2:\"id\";s:46:\"block_content.ebt_countdown.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_counter.body',	'a:17:{s:4:\"uuid\";s:36:\"c23a3476-69db-400e-a938-54992d1cfa18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aNXxUnwWYqtaYNggYYhPjJH0IhNPU6aWjGZmWwC2Ock\";}s:2:\"id\";s:30:\"block_content.ebt_counter.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"9ba660a3-d550-47fe-aaa5-4325e7ffe30d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:50:\"field.storage.block_content.field_ebt_counter_icon\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AqwI810Vi6u8gzBeecbZAAUxasqqVBWGSG3usxdzT8Y\";}s:2:\"id\";s:48:\"block_content.ebt_counter.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:4:\"Icon\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_counter_items',	'a:17:{s:4:\"uuid\";s:36:\"0776e496-c917-49a5-a502-a77f73b79b69\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:51:\"field.storage.block_content.field_ebt_counter_items\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l82_oxjYqdf0vGlc2vOu3y3PdJhm9-QYk3j9aKOI-eg\";}s:2:\"id\";s:49:\"block_content.ebt_counter.field_ebt_counter_items\";s:10:\"field_name\";s:23:\"field_ebt_counter_items\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:17:\"EBT Counter Items\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:16:\"ebt_counter_item\";s:16:\"ebt_counter_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:16:\"ebt_counter_item\";a:2:{s:6:\"weight\";i:12;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"b4ecb5ee-b852-4360-ab89-92327a624bdf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:52:\"field.storage.block_content.field_ebt_counter_number\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xYrvXZvhuSrLAZDblfVrQO8BT0HeZGJKPail-de9LYQ\";}s:2:\"id\";s:50:\"block_content.ebt_counter.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:6:\"Number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:4:{s:3:\"min\";N;s:3:\"max\";N;s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"field_type\";s:7:\"integer\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"1df891a3-3bde-4def-8c4e-79dd5182017a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-jefiww756YZOfPypjb0uMhOWdCkTYnChNabi-X7VTM\";}s:2:\"id\";s:44:\"block_content.ebt_counter.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_cta.body',	'a:17:{s:4:\"uuid\";s:36:\"55f4a1e8-6366-4c0b-aba3-0f05bdc8dccc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Xswlt75VBfRWb1lhRxDCEdmO2MWrGjyFMGZtNtNvvhs\";}s:2:\"id\";s:26:\"block_content.ebt_cta.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_column_image',	'a:17:{s:4:\"uuid\";s:36:\"13cbf6a5-260c-40e0-b225-a8dd66d72da5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:54:\"field.storage.block_content.field_ebt_cta_column_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BhJzD_e2sAj1RN0VJgS6aMUtzNeUEopdiFutXxsCBAk\";}s:2:\"id\";s:48:\"block_content.ebt_cta.field_ebt_cta_column_image\";s:10:\"field_name\";s:26:\"field_ebt_cta_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_link',	'a:17:{s:4:\"uuid\";s:36:\"b2ba6467-2022-4aa3-9527-2821ef8b3866\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:46:\"field.storage.block_content.field_ebt_cta_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kXVJG1nw4xsap-XsAKzJbpyAv6NK8jpGZ9eWXpGpewI\";}s:2:\"id\";s:40:\"block_content.ebt_cta.field_ebt_cta_link\";s:10:\"field_name\";s:18:\"field_ebt_cta_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_second_link',	'a:17:{s:4:\"uuid\";s:36:\"21e7fce1-906b-4e52-94b2-deaee971de2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:53:\"field.storage.block_content.field_ebt_cta_second_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HYewglTA2MKbS8dL349fn4qm9mA-S_FxSL-Suhi0H2k\";}s:2:\"id\";s:47:\"block_content.ebt_cta.field_ebt_cta_second_link\";s:10:\"field_name\";s:25:\"field_ebt_cta_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:11:\"Second Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_title',	'a:17:{s:4:\"uuid\";s:36:\"67606c2f-9b8c-41b7-80d6-aa24493fa0d3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:47:\"field.storage.block_content.field_ebt_cta_title\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AKUtn2Ht2dlGYr9Y8at4yVXu5P1ozFKBdcgzWq44560\";}s:2:\"id\";s:41:\"block_content.ebt_cta.field_ebt_cta_title\";s:10:\"field_name\";s:19:\"field_ebt_cta_title\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"b3a9c8ab-38aa-42a9-9c7a-8d9b4c4e0192\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o4qhawOFKN4zS8tfJKa0LamrN4V8y8cW4d55CAAP8EY\";}s:2:\"id\";s:40:\"block_content.ebt_cta.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_hero.body',	'a:17:{s:4:\"uuid\";s:36:\"b99d81f7-46a3-4dd4-8588-c20bf7f86b06\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qut8svTV-WRC6mB8zNNFw0jqqJp5gzYemzlgnt3AElM\";}s:2:\"id\";s:27:\"block_content.ebt_hero.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_column_image',	'a:17:{s:4:\"uuid\";s:36:\"47eab2ed-be4c-44cf-8125-61c4726d2170\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:55:\"field.storage.block_content.field_ebt_hero_column_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VbR985Mwa7blDm4IzjllHaKyIKieWmVaPhFiNTxALUg\";}s:2:\"id\";s:50:\"block_content.ebt_hero.field_ebt_hero_column_image\";s:10:\"field_name\";s:27:\"field_ebt_hero_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_link',	'a:17:{s:4:\"uuid\";s:36:\"8c50936f-d412-4429-a9af-fe0720478b0f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:47:\"field.storage.block_content.field_ebt_hero_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDbic2tmAxT3Nwj4frhpQJGnF8nX1JE_Q3hu02XZ10o\";}s:2:\"id\";s:42:\"block_content.ebt_hero.field_ebt_hero_link\";s:10:\"field_name\";s:19:\"field_ebt_hero_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_second_link',	'a:17:{s:4:\"uuid\";s:36:\"04371c34-46be-4086-ae87-cc361d2d3ced\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:54:\"field.storage.block_content.field_ebt_hero_second_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1RX5_6HKYaNcisy7DgpQuSjGICKop8azTX3B6B_p8xc\";}s:2:\"id\";s:49:\"block_content.ebt_hero.field_ebt_hero_second_link\";s:10:\"field_name\";s:26:\"field_ebt_hero_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:11:\"Second Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_title',	'a:17:{s:4:\"uuid\";s:36:\"11b83dfa-e605-4b74-8cab-d665ab3d12a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:48:\"field.storage.block_content.field_ebt_hero_title\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"86hFjrfGlcIjrIIrmgUrVPJ3_QyoV2KsiqXTYhCAeR8\";}s:2:\"id\";s:43:\"block_content.ebt_hero.field_ebt_hero_title\";s:10:\"field_name\";s:20:\"field_ebt_hero_title\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_title_prefix',	'a:17:{s:4:\"uuid\";s:36:\"f115e5b7-c8ee-4130-9311-4bc5ac45d6d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:55:\"field.storage.block_content.field_ebt_hero_title_prefix\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"135nCPN0Zyg7GtNdwrEY1joFOZdHSUqBoP1cfFmTlws\";}s:2:\"id\";s:50:\"block_content.ebt_hero.field_ebt_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ebt_hero_title_prefix\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:12:\"Title Prefix\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"9ab7be9d-f391-4845-abb9-9620046d2cea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T5k5YZCMxiQ-YbufcTAzxPfL6x68fxMB1znaMkjM1Ug\";}s:2:\"id\";s:41:\"block_content.ebt_hero.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_image',	'a:17:{s:4:\"uuid\";s:36:\"f07c72d3-6387-4d4d-a4eb-5a81420e247b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:43:\"field.storage.block_content.field_ebt_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W7kXKygcBjPcCe8gOrc11eBNXBHQWunB-xUjHS5ccZM\";}s:2:\"id\";s:39:\"block_content.ebt_image.field_ebt_image\";s:10:\"field_name\";s:15:\"field_ebt_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_image_caption',	'a:17:{s:4:\"uuid\";s:36:\"d7eb3cf3-fabf-4526-9e59-2559843a4b10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:51:\"field.storage.block_content.field_ebt_image_caption\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WZl4X3tBs3QDBckRJjPbxFlnn9RiKDJXSb32UI78b0Y\";}s:2:\"id\";s:47:\"block_content.ebt_image.field_ebt_image_caption\";s:10:\"field_name\";s:23:\"field_ebt_image_caption\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:13:\"Image caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_image_link',	'a:17:{s:4:\"uuid\";s:36:\"d64d6cf7-d342-4551-933f-875ccf757101\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:48:\"field.storage.block_content.field_ebt_image_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WDCm4s-2KzOBP2lD1x_6iuJ28RmYQLSfvdSJ4KTS8hc\";}s:2:\"id\";s:44:\"block_content.ebt_image.field_ebt_image_link\";s:10:\"field_name\";s:20:\"field_ebt_image_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:10:\"Image Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"4f2baecc-10aa-4164-b62a-d414a7a219b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Lo63F4kx4le3BFUXIP1j-nTj0TQ1wlVCW8T4eXa_Xu8\";}s:2:\"id\";s:42:\"block_content.ebt_image.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_image_gallery.body',	'a:17:{s:4:\"uuid\";s:36:\"20361483-5f67-45d3-a3cb-a44f2e7bbae3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RI-w_mHu5j0k1rnEr3l73w0KQBcCH3Q6ZImikN8AdBw\";}s:2:\"id\";s:36:\"block_content.ebt_image_gallery.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_image_gallery.field_ebt_image_gallery',	'a:17:{s:4:\"uuid\";s:36:\"f76e7399-746c-4735-a354-63cad22949ff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:51:\"field.storage.block_content.field_ebt_image_gallery\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FAizD6Kvuyrbl5yxVgCp1vn4NLB9d-nI3wWWaqOR-kQ\";}s:2:\"id\";s:55:\"block_content.ebt_image_gallery.field_ebt_image_gallery\";s:10:\"field_name\";s:23:\"field_ebt_image_gallery\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:13:\"Image Gallery\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_image_gallery.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"4c8c9d22-d8fd-4927-b62c-41815a17d1c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jJLv7Zyb3L4ZWqdYGWpZz_z81eZXwjYwQexwHk7WX2s\";}s:2:\"id\";s:50:\"block_content.ebt_image_gallery.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_micromodal.body',	'a:17:{s:4:\"uuid\";s:36:\"1dd47019-ce01-47d2-8520-e5625b17bd32\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfYtQCVLNmvze1_Qc3zTCMg2QFHln36_wjCm6y2MMWQ\";}s:2:\"id\";s:33:\"block_content.ebt_micromodal.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_micromodal.field_ebt_micromodal_title',	'a:17:{s:4:\"uuid\";s:36:\"59e52aef-8c74-4576-ae43-df723099b73d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:54:\"field.storage.block_content.field_ebt_micromodal_title\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lm4MPSDui0NEYaqvulzZIgmZumlIaUiE638_N0umXDI\";}s:2:\"id\";s:55:\"block_content.ebt_micromodal.field_ebt_micromodal_title\";s:10:\"field_name\";s:26:\"field_ebt_micromodal_title\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:5:\"label\";s:16:\"Micromodal Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_micromodal.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"157b9dd5-a769-42f1-9986-195e571255c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ed-JI-p3sJDcQ3-4guJZ89L_Smftc8LwJ3Z_7XCW5rE\";}s:2:\"id\";s:47:\"block_content.ebt_micromodal.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_quote.body',	'a:17:{s:4:\"uuid\";s:36:\"bcd054c1-c1e6-47a1-9c84-af43855b0dc7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RHJ2BeL7FRpMNmRALB5w7o8erlsGuBnb8MOaVvceiDo\";}s:2:\"id\";s:28:\"block_content.ebt_quote.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:5:\"Quote\";s:11:\"description\";s:20:\"Quote or Testimonial\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_quote.field_ebt_quote_author',	'a:17:{s:4:\"uuid\";s:36:\"5c41064f-97a8-4a0e-aea7-eab453f27eb0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:50:\"field.storage.block_content.field_ebt_quote_author\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bcr-ywW2dLY1kQTCKA6fqxCSgq_nrKEgCB1wj_G8rOs\";}s:2:\"id\";s:46:\"block_content.ebt_quote.field_ebt_quote_author\";s:10:\"field_name\";s:22:\"field_ebt_quote_author\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:12:\"Quote Author\";s:11:\"description\";s:44:\"Company name, Persona name and job position.\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_quote.field_ebt_quote_image',	'a:17:{s:4:\"uuid\";s:36:\"aa44dee9-e2fb-4a02-8f85-0ed2534a54e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:49:\"field.storage.block_content.field_ebt_quote_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_AaWTlSa1X6CaC-_c0qarZPGAD9IaSjpuJF_CUK9vk0\";}s:2:\"id\";s:45:\"block_content.ebt_quote.field_ebt_quote_image\";s:10:\"field_name\";s:21:\"field_ebt_quote_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:11:\"Quote Image\";s:11:\"description\";s:29:\"Persona photo or Company logo\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_quote.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"c5fb6c52-df83-49a6-982d-13cd459b5086\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gKtk0T_7VnCmUPgUgJX1z7v13az3bkGF3bazJXEwZ_o\";}s:2:\"id\";s:42:\"block_content.ebt_quote.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_slick_slider.body',	'a:17:{s:4:\"uuid\";s:36:\"ac203ba4-4731-48c0-a489-49772d98bbcc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1VYVNgk5Hp9ZSjh89NrWVzpkv3BfOpNJz3E_qlTqNkY\";}s:2:\"id\";s:35:\"block_content.ebt_slick_slider.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_slick_slider.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"35e70eb2-5981-4ca9-9540-a6263e5f01ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YIrMWNLT6TiXF-tmAzVOGQaDbDkIa_qy9_KBL0B4TxA\";}s:2:\"id\";s:49:\"block_content.ebt_slick_slider.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_slick_slider.field_ebt_slick_slider',	'a:17:{s:4:\"uuid\";s:36:\"237e10e6-95ca-4f5e-9d1b-2f1d8f7eef67\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:50:\"field.storage.block_content.field_ebt_slick_slider\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eH6HMdmAatyKEevKR8YXk2VH3AF_ntUZim5F7X5D3Cc\";}s:2:\"id\";s:53:\"block_content.ebt_slick_slider.field_ebt_slick_slider\";s:10:\"field_name\";s:22:\"field_ebt_slick_slider\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:12:\"Slick Slider\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:16:\"ebt_slick_slider\";s:16:\"ebt_slick_slider\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:16:\"ebt_slick_slider\";a:2:{s:6:\"weight\";i:9;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_slideshow.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"f6196b18-31e7-4003-842a-206131de10c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oveTq0gmp5_KAESCvT3DtytAnJElJGWzrHzr1lEb-x0\";}s:2:\"id\";s:46:\"block_content.ebt_slideshow.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_slideshow.field_ebt_slideshow',	'a:17:{s:4:\"uuid\";s:36:\"dfe1a625-168b-485c-9c9e-2e8296f0dec8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:47:\"field.storage.block_content.field_ebt_slideshow\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0sk3ViXko3tl_QC0x0GggU_08m7tEtKEoNDg9vwOE-Q\";}s:2:\"id\";s:47:\"block_content.ebt_slideshow.field_ebt_slideshow\";s:10:\"field_name\";s:19:\"field_ebt_slideshow\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:9:\"Slideshow\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:13:\"ebt_slideshow\";s:13:\"ebt_slideshow\";}s:24:\"target_bundles_drag_drop\";a:1:{s:13:\"ebt_slideshow\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:5;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_stats.body',	'a:17:{s:4:\"uuid\";s:36:\"33c69170-b2b4-49a9-9557-a9542eb08865\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qjLV8uviFQzoYVcltie2--7y-ZZpauda_owKbFf-IPA\";}s:2:\"id\";s:28:\"block_content.ebt_stats.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_stats.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"1e3aa7ba-222f-4f33-8628-7c5bf22f00fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Yhkjb0s5PYlfHuk2JdMtwch30e3IZCjz8R1KMJqE4JA\";}s:2:\"id\";s:42:\"block_content.ebt_stats.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_stats.field_ebt_stats',	'a:17:{s:4:\"uuid\";s:36:\"280d2344-5e0c-42f5-bd77-7b358f9b2c08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:43:\"field.storage.block_content.field_ebt_stats\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j6MsUG9RUUe4pToCAeVx7TIOtSMQyibl7ikftOLpXqA\";}s:2:\"id\";s:39:\"block_content.ebt_stats.field_ebt_stats\";s:10:\"field_name\";s:15:\"field_ebt_stats\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:5:\"label\";s:9:\"EBT Stats\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ebt_stats_item\";s:14:\"ebt_stats_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ebt_stats_item\";a:2:{s:6:\"weight\";i:12;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_tabs.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"1396353c-ec74-4693-9d16-7ffb5a6090cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_Gn1i1ea7T8MzoBSjiDcnQMYgfSAq2jN9g-ZJfv27PA\";}s:2:\"id\";s:41:\"block_content.ebt_tabs.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_tabs.field_ebt_tabs',	'a:17:{s:4:\"uuid\";s:36:\"b89072e5-91ec-40a1-aa9c-2a20808308cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:42:\"field.storage.block_content.field_ebt_tabs\";i:2;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4qzYKe-tuRQPHfXtyOyfFfwSfj-Onz88kqc6nsXX4ns\";}s:2:\"id\";s:37:\"block_content.ebt_tabs.field_ebt_tabs\";s:10:\"field_name\";s:14:\"field_ebt_tabs\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:5:\"label\";s:4:\"Tabs\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:7:\"ebt_tab\";s:7:\"ebt_tab\";}s:24:\"target_bundles_drag_drop\";a:1:{s:7:\"ebt_tab\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:2;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_text.body',	'a:17:{s:4:\"uuid\";s:36:\"c72f430e-7366-4a91-bce3-aa5dc0cf8726\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"htRzt66f_OSqHawgprrWKiHiaLoBZUKzc0aMsoIVRlI\";}s:2:\"id\";s:27:\"block_content.ebt_text.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_text.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"2a94aaad-3c54-4074-9d7a-fc204b0cc509\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"G1bcFZfGqQcn1FyernQez0LoRoXBRPKXAjI6-yZKMGw\";}s:2:\"id\";s:41:\"block_content.ebt_text.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_tiles.body',	'a:17:{s:4:\"uuid\";s:36:\"b13d5126-3f86-4bb5-8cdc-a9b72478ab6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hru15RrwqNoJ9o_uoGV1KT2wAkHwJsGaTj7KF0sIZxU\";}s:2:\"id\";s:28:\"block_content.ebt_tiles.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_tiles.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"34788ebc-a5ee-43a6-be6c-58bf07f8a47a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"J3ICag16O5nBkU9zwYLt76LvxEF78Qt-pDCJWA5n1Q4\";}s:2:\"id\";s:42:\"block_content.ebt_tiles.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_tiles.field_ebt_tiles',	'a:17:{s:4:\"uuid\";s:36:\"2e2ec692-0d82-4b56-9cfc-4e871f3a1882\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:43:\"field.storage.block_content.field_ebt_tiles\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"L9cDmlbMT83s3nbfD0cDfsf0BnRv1fpAyA4KTplqxJs\";}s:2:\"id\";s:39:\"block_content.ebt_tiles.field_ebt_tiles\";s:10:\"field_name\";s:15:\"field_ebt_tiles\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:5:\"label\";s:5:\"Tiles\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ebt_tiles_item\";s:14:\"ebt_tiles_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ebt_tiles_item\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_timeline.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"72a4ef65-870a-4488-8009-80269e968b1b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HN5G2K_JDpCXJ8t1Hf1GlS9QdBeEP63Bly-VhnBB6sc\";}s:2:\"id\";s:45:\"block_content.ebt_timeline.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_timeline.field_ebt_timeline',	'a:17:{s:4:\"uuid\";s:36:\"87a15adf-8be6-4080-925b-ebc76f101b32\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:46:\"field.storage.block_content.field_ebt_timeline\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OpOMqlp0m970YTcVsX9wdXHaI-hN6RW9eawnPmz3KtQ\";}s:2:\"id\";s:45:\"block_content.ebt_timeline.field_ebt_timeline\";s:10:\"field_name\";s:18:\"field_ebt_timeline\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:8:\"Timeline\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:12:\"ebt_timeline\";s:12:\"ebt_timeline\";}s:24:\"target_bundles_drag_drop\";a:1:{s:12:\"ebt_timeline\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:10;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_video.body',	'a:17:{s:4:\"uuid\";s:36:\"9b4acfb1-3d8e-4e3d-8901-6120a3b342b2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJmLT9YexVdfd-JSg5eErRWt3FrtaozSqR_v29xtRwU\";}s:2:\"id\";s:28:\"block_content.ebt_video.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_video.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"55445905-ca67-4040-b176-00e1fc2ebb3e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZSSE8vNHSVgLXEAdnpSbPDmk02qrlhm3jj3AJhOLGDs\";}s:2:\"id\";s:42:\"block_content.ebt_video.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_video.field_ebt_video',	'a:17:{s:4:\"uuid\";s:36:\"2e653244-7a00-41c7-a943-06eade5f15ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:43:\"field.storage.block_content.field_ebt_video\";i:2;s:23:\"media.type.remote_video\";i:3;s:16:\"media.type.video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HK8CWqddmUhsshgNl5XJCSCl0ZgJWByyd-uQp8gR9to\";}s:2:\"id\";s:39:\"block_content.ebt_video.field_ebt_video\";s:10:\"field_name\";s:15:\"field_ebt_video\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:2:{s:12:\"remote_video\";s:12:\"remote_video\";s:5:\"video\";s:5:\"video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:12:\"remote_video\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_video_and_image_gallery.body',	'a:17:{s:4:\"uuid\";s:36:\"161669c7-6a7e-4616-86d5-a2e3de9c8fe5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1OrJhHg5mGo5emzkaM2Z6ClqRPHEtI72w5kwSnSWOaI\";}s:2:\"id\";s:46:\"block_content.ebt_video_and_image_gallery.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_video_and_image_gallery.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"278f7615-4ab0-4e87-963f-33f2ae8f78ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5WWOgyldW7uBFXBGN623Yc_zkiry6HnXAn0L5CywrsI\";}s:2:\"id\";s:60:\"block_content.ebt_video_and_image_gallery.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images',	'a:17:{s:4:\"uuid\";s:36:\"efc991a5-26b8-4df3-977e-953a90c2f86c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:55:\"field.storage.block_content.field_ebt_videos_and_images\";i:2;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kZTsNALzCfl1z3gE4CQ1OVfS633RZUMyI5ZBPiMVnm0\";}s:2:\"id\";s:69:\"block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images\";s:10:\"field_name\";s:27:\"field_ebt_videos_and_images\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:17:\"Videos and Images\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:32:\"ebt_video_and_image_gallery_item\";s:32:\"ebt_video_and_image_gallery_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:32:\"ebt_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:16;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_views.body',	'a:17:{s:4:\"uuid\";s:36:\"f746c64f-5c49-4079-bb53-0a1a1dd1a7c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gYULmkk3OY2DQugmZyL9Fv_2Car9QCaQzCeihnGhfPI\";}s:2:\"id\";s:28:\"block_content.ebt_views.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_views.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"3a0e2513-d1ec-4966-9162-427a855b0977\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZrXPDXifY_gudYEr4cT9o_GDEspGqI6gFQgTyN_6RdM\";}s:2:\"id\";s:42:\"block_content.ebt_views.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_views.field_ebt_views_views',	'a:17:{s:4:\"uuid\";s:36:\"5f1f69e3-3f90-4442-95f1-5c1579c679ab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:49:\"field.storage.block_content.field_ebt_views_views\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MAlu-k2uullIwcqbzIvVPeeMm6-JiW5Ev0USbMEGejk\";}s:2:\"id\";s:45:\"block_content.ebt_views.field_ebt_views_views\";s:10:\"field_name\";s:21:\"field_ebt_views_views\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:5:\"label\";s:5:\"Views\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}s:12:\"plugin_types\";a:2:{s:4:\"page\";s:4:\"page\";s:5:\"block\";s:5:\"block\";}s:15:\"preselect_views\";a:0:{}s:16:\"enabled_settings\";a:0:{}}s:10:\"field_type\";s:14:\"viewsreference\";}'),
('',	'field.field.block_content.ebt_webform.body',	'a:17:{s:4:\"uuid\";s:36:\"8733818b-9c02-4e2c-91a6-045583f1e01d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Baa8yf9wUinT0D2-5V7tRKydSUOfQvZsUuTvSBeC-bQ\";}s:2:\"id\";s:30:\"block_content.ebt_webform.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_webform.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"a50fcf2c-9887-448e-a18c-78ac4e87b38c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VOgJYtNjHNsjml3J6mwuL3oMqXc4JPjPD8gGVHyGftg\";}s:2:\"id\";s:44:\"block_content.ebt_webform.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_webform.field_ebt_webform_form',	'a:17:{s:4:\"uuid\";s:36:\"9c984eac-a275-47d3-a7ac-029f8216fcb8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:50:\"field.storage.block_content.field_ebt_webform_form\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"S36GzWuHJCt3YstEnQsUPzQ1dwXpO2MKmqaAgoQ2eb4\";}s:2:\"id\";s:48:\"block_content.ebt_webform.field_ebt_webform_form\";s:10:\"field_name\";s:22:\"field_ebt_webform_form\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:5:\"label\";s:4:\"Form\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}}s:10:\"field_type\";s:7:\"webform\";}'),
('',	'field.field.block_content.ebt_webform_popup.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"7bd9f73f-8c64-46d8-9848-e86bcb5b491e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nY4Z9bxYtEWKQwTfEQV5y1aJi2T_PME930j0zdUd6e4\";}s:2:\"id\";s:50:\"block_content.ebt_webform_popup.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_webform_popup.field_ebt_webform_popup_form',	'a:17:{s:4:\"uuid\";s:36:\"ebbc4709-9eb2-4a48-bc09-0d83eaad805d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:56:\"field.storage.block_content.field_ebt_webform_popup_form\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XKxb-rFq0rOSgKq7mU1s79aoU0-O0IeICu_ZMzj9vG8\";}s:2:\"id\";s:60:\"block_content.ebt_webform_popup.field_ebt_webform_popup_form\";s:10:\"field_name\";s:28:\"field_ebt_webform_popup_form\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:5:\"label\";s:7:\"Webform\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}}s:10:\"field_type\";s:7:\"webform\";}'),
('',	'field.field.media.audio.field_media_audio_file',	'a:17:{s:4:\"uuid\";s:36:\"4fa57014-dbe5-4dc4-b5c9-e6cb3404ad5c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UlZPIbHcLyNqGY5bvydCTijGcKDmwn4Fo8oYZT85wlk\";}s:2:\"id\";s:34:\"media.audio.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:5:\"label\";s:10:\"Audio file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:11:\"mp3 wav aac\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),
('',	'field.field.media.document.field_media_document',	'a:17:{s:4:\"uuid\";s:36:\"1ebfa792-cf03-471d-9e5c-2dccd1fedd38\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:40:\"field.storage.media.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DY5HtJTxUjFRGU_PaY6ifo2nhR-nAZ0y0s6kLmUbv5g\";}s:2:\"id\";s:35:\"media.document.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:96:\"txt rtf doc docx ppt pptx xls xlsx pdf odf odg odp ods odt fodt fods fodp fodg key numbers pages\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),
('',	'field.field.media.image.field_media_image',	'a:17:{s:4:\"uuid\";s:36:\"e2b79a9d-deda-4076-bcbe-2c9ae00b616e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:37:\"field.storage.media.field_media_image\";i:1;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P7CkVOgjDXiN26Fm2hniNei-XPK3iuZTlcBGqreTbJ0\";}s:2:\"id\";s:29:\"media.image.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:25:\"png gif jpg jpeg webp svg\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),
('',	'field.field.media.remote_video.field_media_oembed_video',	'a:17:{s:4:\"uuid\";s:36:\"96b9388f-0779-4e2b-8429-6932b1a68ead\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.media.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Eo4HHenV5iZat_kEWgr_wydD3TgwURMCzwt-7qIEyoM\";}s:2:\"id\";s:43:\"media.remote_video.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:5:\"label\";s:9:\"Video URL\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),
('',	'field.field.media.video.field_media_video_file',	'a:17:{s:4:\"uuid\";s:36:\"af846c60-eb6c-4029-84b4-aa0ccf412591\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6kMMjmk2r_csGQ52qI9BUaO8r_oAzNLbxlclaj-JlDQ\";}s:2:\"id\";s:34:\"media.video.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:5:\"label\";s:10:\"Video file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:3:\"mp4\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),
('',	'field.field.node.article.body',	'a:17:{s:4:\"uuid\";s:36:\"7f75b85e-a8a9-4e63-8ba8-42cd18f1d713\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Wxs1LseZ8JsNwD9uJVIbzZqG35yQXN8Eo1Hub6NMuI\";}s:2:\"id\";s:17:\"node.article.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.node.article.field_image',	'a:17:{s:4:\"uuid\";s:36:\"ba97827c-59cc-4fb5-be06-7c44f9e98113\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"field.storage.node.field_image\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j0riO_-77ZFWNLtj0iJ31HnohiNjdn8HUL86RueCF-M\";}s:2:\"id\";s:24:\"node.article.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:12:\"Teaser Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),
('',	'field.field.node.article.field_metatags',	'a:16:{s:4:\"uuid\";s:36:\"06f91975-9ecb-430d-b7f8-3de8ae8601c8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"field.storage.node.field_metatags\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:7:\"metatag\";}}s:2:\"id\";s:27:\"node.article.field_metatags\";s:10:\"field_name\";s:14:\"field_metatags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:8:\"Metatags\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:7:\"metatag\";}'),
('',	'field.field.node.article.field_tags',	'a:17:{s:4:\"uuid\";s:36:\"61a810a4-e29c-4fbf-b132-9fe51b115626\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:29:\"field.storage.node.field_tags\";i:1;s:17:\"node.type.article\";i:2;s:24:\"taxonomy.vocabulary.tags\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QdUgf_beeoaPiyKorFv0q1fcJpWH_uZTqe_xoVJacrw\";}s:2:\"id\";s:23:\"node.article.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Tags\";s:11:\"description\";s:84:\"Enter a comma-separated list. For example: Amsterdam, Mexico City, \"Cleveland, Ohio\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:21:\"default:taxonomy_term\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.node.article.layout_builder__layout',	'a:16:{s:4:\"uuid\";s:36:\"97640446-27d5-4146-8b2a-a776d7a62ec7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:41:\"field.storage.node.layout_builder__layout\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:14:\"layout_builder\";}}s:2:\"id\";s:35:\"node.article.layout_builder__layout\";s:10:\"field_name\";s:22:\"layout_builder__layout\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:6:\"Layout\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:14:\"layout_section\";}'),
('',	'field.field.node.page.body',	'a:17:{s:4:\"uuid\";s:36:\"f2e704ba-2d4f-4bf0-976b-19d893472d4f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KHu9I-pR4FnP79crRJ5gVD_1mKGSZcJsdIm9bn64iFg\";}s:2:\"id\";s:14:\"node.page.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.node.page.field_metatags',	'a:16:{s:4:\"uuid\";s:36:\"e785ab1b-0edf-46aa-bbaf-56e645079434\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"field.storage.node.field_metatags\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:7:\"metatag\";}}s:2:\"id\";s:24:\"node.page.field_metatags\";s:10:\"field_name\";s:14:\"field_metatags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:8:\"Metatags\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:7:\"metatag\";}'),
('',	'field.field.node.page.layout_builder__layout',	'a:16:{s:4:\"uuid\";s:36:\"79c176b7-33a8-419d-b175-1853525a7e50\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:41:\"field.storage.node.layout_builder__layout\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:14:\"layout_builder\";}}s:2:\"id\";s:32:\"node.page.layout_builder__layout\";s:10:\"field_name\";s:22:\"layout_builder__layout\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:6:\"Layout\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:14:\"layout_section\";}'),
('',	'field.field.paragraph.ebt_accordion.field_ebt_accordion_text',	'a:17:{s:4:\"uuid\";s:36:\"f0b63cf1-7f17-4dea-a7e0-b54d5d7d823f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_accordion_text\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K83AQZ4cOGBmrJfAKHjN1BC5fNJE2slkMvsq-eOngms\";}s:2:\"id\";s:48:\"paragraph.ebt_accordion.field_ebt_accordion_text\";s:10:\"field_name\";s:24:\"field_ebt_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:13:\"Text / Answer\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_accordion.field_ebt_accordion_title',	'a:17:{s:4:\"uuid\";s:36:\"c7bb20d0-7c3a-4e1d-80bd-fc8145337db5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ebt_accordion_title\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4iRsnnRe66bYKBWRFqXd8sFfW3tTM7kGDHb5ZI6bRoI\";}s:2:\"id\";s:49:\"paragraph.ebt_accordion.field_ebt_accordion_title\";s:10:\"field_name\";s:25:\"field_ebt_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:16:\"Title / Question\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_carousel.field_ebt_carousel_caption',	'a:17:{s:4:\"uuid\";s:36:\"cdf69cb6-7607-44f2-8e15-66eff3ea978e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ebt_carousel_caption\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zJkgaoa5XS7hvJb5prthRdBt34u3Y3QPJJ_obTMfkfQ\";}s:2:\"id\";s:49:\"paragraph.ebt_carousel.field_ebt_carousel_caption\";s:10:\"field_name\";s:26:\"field_ebt_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:13:\"Slide caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_carousel.field_ebt_carousel_image',	'a:17:{s:4:\"uuid\";s:36:\"cf3345b8-8872-40ef-818f-2e94b33e8961\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:48:\"field.storage.paragraph.field_ebt_carousel_image\";i:1;s:16:\"media.type.image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"igPOF7Xbo0_CaEPXbAyrAz0x22az-ryGnj9S4zfXsZY\";}s:2:\"id\";s:47:\"paragraph.ebt_carousel.field_ebt_carousel_image\";s:10:\"field_name\";s:24:\"field_ebt_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:11:\"Slide image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_description',	'a:17:{s:4:\"uuid\";s:36:\"89d82ff4-da95-426e-b0c1-c9f18b4c7e6a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:53:\"field.storage.paragraph.field_ebt_counter_description\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SGPys8iAffvOl_W66tfDAlPixkXxxxidEUCONW9q7dI\";}s:2:\"id\";s:56:\"paragraph.ebt_counter_item.field_ebt_counter_description\";s:10:\"field_name\";s:29:\"field_ebt_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:11:\"Description\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"22d74b30-be52-4cee-91ea-a0aa04de5dff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_ebt_counter_icon\";i:1;s:16:\"media.type.image\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Vzl7VAXpLPJd2KXAxVHrOfGNPWB1y1s1Jr5foDGSdIg\";}s:2:\"id\";s:49:\"paragraph.ebt_counter_item.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:4:\"Icon\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"e3b02b26-e9be-46ee-be2a-9c0cdb537a47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_counter_number\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-5pDzCL0Ha9nbkySRCIjCME2yqGDQ9k92GT8A1xqWU\";}s:2:\"id\";s:51:\"paragraph.ebt_counter_item.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:6:\"Number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:4:{s:3:\"min\";N;s:3:\"max\";N;s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"field_type\";s:7:\"integer\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_title',	'a:17:{s:4:\"uuid\";s:36:\"62ea8aa7-eadf-46fe-8360-d5a565d6e339\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ebt_counter_title\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CvlljFbOKRTlxFz1hVYtYJkEdk3S-0I9UmjjS41E7_U\";}s:2:\"id\";s:50:\"paragraph.ebt_counter_item.field_ebt_counter_title\";s:10:\"field_name\";s:23:\"field_ebt_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_image',	'a:17:{s:4:\"uuid\";s:36:\"0ed191f1-4795-4501-9075-ad48a0ed7ef5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:52:\"field.storage.paragraph.field_ebt_slick_slider_image\";i:1;s:16:\"media.type.image\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pYWtlYxsR5uP9TrVPzdvPyRiMgr6Lp75dE9QtVEyu3Q\";}s:2:\"id\";s:55:\"paragraph.ebt_slick_slider.field_ebt_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ebt_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_link',	'a:17:{s:4:\"uuid\";s:36:\"ae270a12-20ca-4ebe-a2f1-69ea8b4fe6e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ebt_slick_slider_link\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jk5t1dH13MfYx1LmuLzIlSTGOi3qFvAHr8Zj5vlyM2I\";}s:2:\"id\";s:54:\"paragraph.ebt_slick_slider.field_ebt_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_text',	'a:17:{s:4:\"uuid\";s:36:\"087b3c83-4e91-4f68-b458-96330c343db8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ebt_slick_slider_text\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ob6mfPaJJwePb80FfSWg_M2reWUeqydWDbjtcshe-Bw\";}s:2:\"id\";s:54:\"paragraph.ebt_slick_slider.field_ebt_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_link',	'a:17:{s:4:\"uuid\";s:36:\"f3fdd942-959d-4943-993f-2d7c52030728\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_slideshow_link\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_fFBiyKlJ3i_w71vNv_KlKPhYmEARkECK_6O5gU5skA\";}s:2:\"id\";s:48:\"paragraph.ebt_slideshow.field_ebt_slideshow_link\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_slide',	'a:17:{s:4:\"uuid\";s:36:\"b8c36a1d-4e00-47c8-8d3b-5f5c824c1c41\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:49:\"field.storage.paragraph.field_ebt_slideshow_slide\";i:1;s:16:\"media.type.image\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZhjSOx4h5C-uQqS8wmCEX4R-expUAu-sQghZL7OK400\";}s:2:\"id\";s:49:\"paragraph.ebt_slideshow.field_ebt_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_text',	'a:17:{s:4:\"uuid\";s:36:\"db307a56-3f8e-4027-b5d1-28fe5edaa11e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_slideshow_text\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bZ0m2BBV-ldK-3Eh4BGp1MRAgA6rMqeGPulDsD9kdyg\";}s:2:\"id\";s:48:\"paragraph.ebt_slideshow.field_ebt_slideshow_text\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_title',	'a:17:{s:4:\"uuid\";s:36:\"cc62f49e-1354-4058-a151-c4c1e7e5994a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ebt_slideshow_title\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6qs_c-h6E-d-9pn4rWyP3VMtvPIx0dwfa_m8bl9Or4g\";}s:2:\"id\";s:49:\"paragraph.ebt_slideshow.field_ebt_slideshow_title\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:11:\"Slide Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_image',	'a:17:{s:4:\"uuid\";s:36:\"e7dc4733-12c7-4748-975b-b7d57accd4ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_stats_item_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1k1v70N6h-IQn541w0qMasOm8bEEp3XimOb7xSv8suk\";}s:2:\"id\";s:47:\"paragraph.ebt_stats_item.field_stats_item_image\";s:10:\"field_name\";s:22:\"field_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:16:\"Stats item image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_link',	'a:17:{s:4:\"uuid\";s:36:\"67b6c95b-30fa-471d-a031-e84ec26a1a54\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_stats_item_link\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uExk2SWTCDuqJRmvyPPMsGBSMj4ilG_32ADqZm_jKZY\";}s:2:\"id\";s:46:\"paragraph.ebt_stats_item.field_stats_item_link\";s:10:\"field_name\";s:21:\"field_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:15:\"Stats item link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_number',	'a:17:{s:4:\"uuid\";s:36:\"4ae0f11b-4c4f-43c8-a58e-9413b992ad4d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_stats_item_number\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5OFR72Rn-pvsZTbp7LEkgUVp0q21QilFZMegsC5ICbo\";}s:2:\"id\";s:48:\"paragraph.ebt_stats_item.field_stats_item_number\";s:10:\"field_name\";s:23:\"field_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:17:\"Stats item number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_text',	'a:17:{s:4:\"uuid\";s:36:\"2907b7cd-48be-4276-8c1a-ad20ca437cd4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_stats_item_text\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5YdkRFvRcJQuYp6xs1qhhjaUeyj1ysW93i6EPEh9dWU\";}s:2:\"id\";s:46:\"paragraph.ebt_stats_item.field_stats_item_text\";s:10:\"field_name\";s:21:\"field_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:15:\"Stats item text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_block',	'a:17:{s:4:\"uuid\";s:36:\"6821e0ef-8080-428a-ac78-f51249bb5e2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_block\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7dftnJ-QEc2wq727UtTNqtQGbbQis8Pwgykf0EPgU5U\";}s:2:\"id\";s:37:\"paragraph.ebt_tab.field_ebt_tab_block\";s:10:\"field_name\";s:19:\"field_ebt_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:9:\"Tab Block\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:6:\"blocks\";s:18:\"selection_settings\";a:1:{s:10:\"plugin_ids\";a:0:{}}}s:10:\"field_type\";s:11:\"block_field\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_content',	'a:17:{s:4:\"uuid\";s:36:\"9093a2e3-eafc-42f9-9d74-0c76cf2fa7e6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ebt_tab_content\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:7:\"options\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"as55Dml1Xd2yWFDU0vGxsQmoXaIr9fZ2lC4KG8TpvzA\";}s:2:\"id\";s:39:\"paragraph.ebt_tab.field_ebt_tab_content\";s:10:\"field_name\";s:21:\"field_ebt_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:11:\"Tab content\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:11:\"list_string\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_page',	'a:17:{s:4:\"uuid\";s:36:\"6b77acaf-9fab-4d2e-9843-cfe8180ce9fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:42:\"field.storage.paragraph.field_ebt_tab_page\";i:1;s:14:\"node.type.page\";i:2;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t9WpCMZrY0hReO2jvRG2Rte22ZW2y4Dq_5kF4YVAWqo\";}s:2:\"id\";s:36:\"paragraph.ebt_tab.field_ebt_tab_page\";s:10:\"field_name\";s:18:\"field_ebt_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:8:\"Tab page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:12:\"default:node\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:4:\"page\";s:4:\"page\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_text',	'a:17:{s:4:\"uuid\";s:36:\"0cb50bf8-21aa-4ea6-a7d0-90d454555f86\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ebt_tab_text\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qDqTeXYS1CTWbjbJQUSmVXGsWThhwp_YLObjCrj-4wo\";}s:2:\"id\";s:36:\"paragraph.ebt_tab.field_ebt_tab_text\";s:10:\"field_name\";s:18:\"field_ebt_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:8:\"Tab text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_title',	'a:17:{s:4:\"uuid\";s:36:\"217d9d46-984c-450c-b218-1d58121ced68\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_title\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"axHae-sP24gbeAgLnxqUi-W0N6tnY4ImUB_wdC1bCiM\";}s:2:\"id\";s:37:\"paragraph.ebt_tab.field_ebt_tab_title\";s:10:\"field_name\";s:19:\"field_ebt_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:9:\"Tab title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:4:\"text\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_views',	'a:17:{s:4:\"uuid\";s:36:\"5c306dcf-d85c-424e-b5d0-a819386f6ecc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_views\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Zc3r5Wx5CVuHBS5Fvv1jYRaHo4EnB7V2rhALuCxql_o\";}s:2:\"id\";s:37:\"paragraph.ebt_tab.field_ebt_tab_views\";s:10:\"field_name\";s:19:\"field_ebt_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:9:\"Tab views\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";i:0;}s:12:\"plugin_types\";a:5:{s:7:\"default\";s:7:\"default\";s:5:\"block\";s:5:\"block\";s:4:\"page\";i:0;s:4:\"feed\";i:0;s:5:\"embed\";i:0;}s:15:\"preselect_views\";a:14:{s:8:\"articles\";i:0;s:13:\"block_content\";i:0;s:7:\"comment\";i:0;s:15:\"comments_recent\";i:0;s:7:\"content\";i:0;s:14:\"content_recent\";i:0;s:5:\"files\";i:0;s:9:\"frontpage\";i:0;s:13:\"taxonomy_term\";i:0;s:17:\"user_admin_people\";i:0;s:8:\"watchdog\";i:0;s:19:\"webform_submissions\";i:0;s:9:\"who_s_new\";i:0;s:12:\"who_s_online\";i:0;}s:16:\"enabled_settings\";a:5:{s:5:\"pager\";i:0;s:5:\"limit\";i:0;s:6:\"offset\";i:0;s:5:\"title\";i:0;s:8:\"argument\";i:0;}}s:10:\"field_type\";s:14:\"viewsreference\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_clickable_tile',	'a:17:{s:4:\"uuid\";s:36:\"b6bcf941-67b4-43b7-9747-c95baf1b7bc4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_clickable_tile\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I8Bhnp9Mihk3DDEulISHIOOcN-avs5jkwzt9L0n-CcI\";}s:2:\"id\";s:49:\"paragraph.ebt_tiles_item.field_ebt_clickable_tile\";s:10:\"field_name\";s:24:\"field_ebt_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:14:\"Clickable Tile\";s:11:\"description\";s:66:\"Make entire tile clickable or display link separataly if unchecked\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_image',	'a:17:{s:4:\"uuid\";s:36:\"9d903341-553f-4311-8a83-c48130d410e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:45:\"field.storage.paragraph.field_ebt_tiles_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lPf_h3aKofBH6XHQRhBmyVb1lV4Z8_w0oD6vY9JLcjM\";}s:2:\"id\";s:46:\"paragraph.ebt_tiles_item.field_ebt_tiles_image\";s:10:\"field_name\";s:21:\"field_ebt_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_link',	'a:17:{s:4:\"uuid\";s:36:\"3c7cd9d7-a4c3-49a9-9bbc-1ced5ab70209\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ebt_tiles_link\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQ8lDL7PoSiLrK83cA8hSPIPNufbpw3j1qT4f1V9VUc\";}s:2:\"id\";s:45:\"paragraph.ebt_tiles_item.field_ebt_tiles_link\";s:10:\"field_name\";s:20:\"field_ebt_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_text',	'a:17:{s:4:\"uuid\";s:36:\"5201e488-c9af-4ec2-867e-3b3dbe8c8b16\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ebt_tiles_text\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yZYhpVfxBQEK7LOwoolFtOZY726XpjMHK5opPVJB4j4\";}s:2:\"id\";s:45:\"paragraph.ebt_tiles_item.field_ebt_tiles_text\";s:10:\"field_name\";s:20:\"field_ebt_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_title',	'a:17:{s:4:\"uuid\";s:36:\"1e88de7b-7c46-4562-a223-9ccf83779820\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ebt_tiles_title\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"V7UyIKTz-lufN2i-3921iDZVIjrM1K-GA3PPgZfgYTI\";}s:2:\"id\";s:46:\"paragraph.ebt_tiles_item.field_ebt_tiles_title\";s:10:\"field_name\";s:21:\"field_ebt_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_current',	'a:17:{s:4:\"uuid\";s:36:\"24fd2c38-f992-42ae-89ce-590dd574cb31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ebt_timeline_current\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Js3oBqyPFEjLEDUuAPzn29jLKcNg1wsB7M9uvAF8fwQ\";}s:2:\"id\";s:49:\"paragraph.ebt_timeline.field_ebt_timeline_current\";s:10:\"field_name\";s:26:\"field_ebt_timeline_current\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:7:\"Current\";s:11:\"description\";s:36:\"Highlight current stage in timeline.\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_date',	'a:17:{s:4:\"uuid\";s:36:\"d1569baf-9302-4e38-9ed4-987caeafa2e4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ebt_timeline_date\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ajUABeEHsfvEoCEA1JJywutAhjakBjNSR6yymicgJcQ\";}s:2:\"id\";s:46:\"paragraph.ebt_timeline.field_ebt_timeline_date\";s:10:\"field_name\";s:23:\"field_ebt_timeline_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:4:\"Date\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_media_image',	'a:17:{s:4:\"uuid\";s:36:\"a0651ff8-3cb5-478f-acbe-120dd869e921\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:54:\"field.storage.paragraph.field_ebt_timeline_media_image\";i:1;s:16:\"media.type.image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0WMqQDbMLHG-hJMnj9tohP4sS2B93Gy_jhhZoUJIA9I\";}s:2:\"id\";s:53:\"paragraph.ebt_timeline.field_ebt_timeline_media_image\";s:10:\"field_name\";s:30:\"field_ebt_timeline_media_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_text',	'a:17:{s:4:\"uuid\";s:36:\"265711bf-cab4-450f-83c7-f401aa255ff1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ebt_timeline_text\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5F87FeFRv4oMn7nyxCCJ3pjlpG-G5NBIfD-5o5No0t8\";}s:2:\"id\";s:46:\"paragraph.ebt_timeline.field_ebt_timeline_text\";s:10:\"field_name\";s:23:\"field_ebt_timeline_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_title',	'a:17:{s:4:\"uuid\";s:36:\"ae101647-2196-429e-ba3e-cbb55e4e92f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_timeline_title\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_pET64Z-ylj-Ic4NyQ0BmUF4zGO8dZ-uVWadrNKQvyo\";}s:2:\"id\";s:47:\"paragraph.ebt_timeline.field_ebt_timeline_title\";s:10:\"field_name\";s:24:\"field_ebt_timeline_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),
('',	'field.field.paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description',	'a:17:{s:4:\"uuid\";s:36:\"2c335583-7279-4b40-95b9-09d17b06fc4a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:54:\"field.storage.paragraph.field_gallery_item_description\";i:1;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lW3Ks0DIMaIjFKfbgrmmUXgP-Atqo_sKwWuBuvS3Rmg\";}s:2:\"id\";s:73:\"paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description\";s:10:\"field_name\";s:30:\"field_gallery_item_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:5:\"label\";s:24:\"Gallery item description\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item',	'a:17:{s:4:\"uuid\";s:36:\"2d4456ac-0c7c-4f72-8624-a25a5d933b9b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:4:{i:0;s:48:\"field.storage.paragraph.field_video_gallery_item\";i:1;s:16:\"media.type.image\";i:2;s:23:\"media.type.remote_video\";i:3;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JaxawDXWXvX-mf-HuaUiJYhh81uXGJm8rPPZGOoQze8\";}s:2:\"id\";s:67:\"paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item\";s:10:\"field_name\";s:24:\"field_video_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:5:\"label\";s:12:\"Gallery Item\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:2:{s:5:\"image\";s:5:\"image\";s:12:\"remote_video\";s:12:\"remote_video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:5:\"image\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.user.user.user_picture',	'a:17:{s:4:\"uuid\";s:36:\"a99bd180-01c5-4300-997c-47456c8ba004\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:31:\"field.storage.user.user_picture\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TE3gYVzd6g0deXqUl8SEu2azHwVG-SdXm3kwbrz0kHw\";}s:2:\"id\";s:22:\"user.user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:5:\"label\";s:7:\"Picture\";s:11:\"description\";s:29:\"Your virtual face or picture.\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:40:\"pictures/[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:0;s:18:\"alt_field_required\";b:0;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),
('',	'field.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJk0TAQBzlNo52ehiHI7bIEPLGi0BYqZvPdEn7Chfu0\";}s:16:\"purge_batch_size\";i:50;}'),
('',	'field.storage.block_content.body',	'a:17:{s:4:\"uuid\";s:36:\"3db51960-3062-400f-b922-f0a7373dacb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:2:\"id\";s:18:\"block_content.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_accordion',	'a:17:{s:4:\"uuid\";s:36:\"510be1fe-456a-4a0f-8638-40b7764bd46a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-9lmszSGOf8FvJqERXt4Y75SqfNFnjrUmffe3mvm63E\";}s:2:\"id\";s:33:\"block_content.field_ebt_accordion\";s:10:\"field_name\";s:19:\"field_ebt_accordion\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_basic_button_link',	'a:17:{s:4:\"uuid\";s:36:\"227cb366-5e8c-44f6-bcc0-a4197c0060f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BzBSGwNX6bKi7xiNAKiETrdJPbGYMNk27dC6VzdE2Z4\";}s:2:\"id\";s:41:\"block_content.field_ebt_basic_button_link\";s:10:\"field_name\";s:27:\"field_ebt_basic_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_block_block',	'a:17:{s:4:\"uuid\";s:36:\"93988320-9748-44ab-ac19-9ac1a6feaa9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qUmxIKbmrhd1TnlvNUsQ24_IqgsilgfToL8gamHgjPk\";}s:2:\"id\";s:35:\"block_content.field_ebt_block_block\";s:10:\"field_name\";s:21:\"field_ebt_block_block\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_bootstrap_button_link',	'a:17:{s:4:\"uuid\";s:36:\"6848e7e6-6bb4-4d7b-bfe3-64cb965c8d83\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Mn_2tFUWa7Mu6w06yP9iFQ7KLLKr83YOpxoaTd3IDo\";}s:2:\"id\";s:45:\"block_content.field_ebt_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ebt_bootstrap_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_carousel',	'a:17:{s:4:\"uuid\";s:36:\"c31eee89-5d35-4da4-a2f9-daca2ffd26b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5RyRgQO2iOVZE4gIaH8pGJ4s3UZCNOm5nqfkFXWwVvE\";}s:2:\"id\";s:32:\"block_content.field_ebt_carousel\";s:10:\"field_name\";s:18:\"field_ebt_carousel\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_columns_blocks',	'a:17:{s:4:\"uuid\";s:36:\"007c60bc-7d54-4666-8065-f77200cca762\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8ubMRbdfnR4zPhu3EFrCWZOc2hr9_Dum6gPo01gA7OE\";}s:2:\"id\";s:38:\"block_content.field_ebt_columns_blocks\";s:10:\"field_name\";s:24:\"field_ebt_columns_blocks\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_countdown_date',	'a:17:{s:4:\"uuid\";s:36:\"18c467c8-f5f7-4380-a5b7-5d8dd1bd6891\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:8:\"datetime\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tfVOPr7E66mYxIOwRxWNsSw4nFQnztb5FQbxuKg7_Dg\";}s:2:\"id\";s:38:\"block_content.field_ebt_countdown_date\";s:10:\"field_name\";s:24:\"field_ebt_countdown_date\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:8:\"datetime\";s:8:\"settings\";a:1:{s:13:\"datetime_type\";s:8:\"datetime\";}s:6:\"module\";s:8:\"datetime\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"90f3734d-9d21-4723-8027-039393a502ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bYFfyXow5e24VR-vUVn5lG3PHuSyRBkkEZ_qOShiuk\";}s:2:\"id\";s:36:\"block_content.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_counter_items',	'a:17:{s:4:\"uuid\";s:36:\"fcff8171-e2db-44a5-9585-8b9fb7992b79\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n1DI17J39aMu-YkFmfdRmeqTQflyy2-_xOR8jw99LkE\";}s:2:\"id\";s:37:\"block_content.field_ebt_counter_items\";s:10:\"field_name\";s:23:\"field_ebt_counter_items\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"62a1a67b-d505-4c27-8636-6a9c35a21cf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fzJ_kU3wKSQOA7gdcWs4erHYixRul2pFzixpKaUIEcs\";}s:2:\"id\";s:38:\"block_content.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:7:\"integer\";s:8:\"settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_column_image',	'a:17:{s:4:\"uuid\";s:36:\"1e11b0a4-9fbb-4f77-a027-2abe7c00a623\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cWseV862aJoW9_oVsbhZOp1F-1WgQGPaPWt4miaSdoM\";}s:2:\"id\";s:40:\"block_content.field_ebt_cta_column_image\";s:10:\"field_name\";s:26:\"field_ebt_cta_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_link',	'a:17:{s:4:\"uuid\";s:36:\"069a665c-1062-4320-b384-be548389f826\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rx7cMICk6v3oU3DQBozX_KkK6bXWe9gJNBM2H0aC6n4\";}s:2:\"id\";s:32:\"block_content.field_ebt_cta_link\";s:10:\"field_name\";s:18:\"field_ebt_cta_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_second_link',	'a:17:{s:4:\"uuid\";s:36:\"95a9a9f7-3de1-4e44-8f20-3d0f2dfe6baa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nldTu1l1Acs-EQQUI6pM7wxOCM_8L8QdevFiQDrvqdk\";}s:2:\"id\";s:39:\"block_content.field_ebt_cta_second_link\";s:10:\"field_name\";s:25:\"field_ebt_cta_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_title',	'a:17:{s:4:\"uuid\";s:36:\"28d853cc-13c3-4be6-9b85-37001544855b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QzI1KYIZiUFHadsdJPmZk_6XW4wCrROvPpgDNWpBa8M\";}s:2:\"id\";s:33:\"block_content.field_ebt_cta_title\";s:10:\"field_name\";s:19:\"field_ebt_cta_title\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_column_image',	'a:17:{s:4:\"uuid\";s:36:\"ef778f49-5062-47e4-bca2-1b340272972f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qRkbr3wurZNCdoGUXFQbfo3Q8o-iJ-GBBGGEAY2iPYg\";}s:2:\"id\";s:41:\"block_content.field_ebt_hero_column_image\";s:10:\"field_name\";s:27:\"field_ebt_hero_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_link',	'a:17:{s:4:\"uuid\";s:36:\"27029cab-99df-44cd-891e-de41f3558b7c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u6S6Tua-DwnyB3sGdBXHub-aGYa1PeUoR9SfeJOlpYE\";}s:2:\"id\";s:33:\"block_content.field_ebt_hero_link\";s:10:\"field_name\";s:19:\"field_ebt_hero_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_second_link',	'a:17:{s:4:\"uuid\";s:36:\"535ff977-be0f-4fa5-8d38-7803ae8b9094\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zmAY3AWa6AyFxiDtFl2a9fy666r6LZkvLTF540UTBdE\";}s:2:\"id\";s:40:\"block_content.field_ebt_hero_second_link\";s:10:\"field_name\";s:26:\"field_ebt_hero_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_title',	'a:17:{s:4:\"uuid\";s:36:\"2807bb2f-4aff-460c-9cf6-46dd6ddcf653\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tz0LPZeke3wFWFFnRzkakjNgB9UGwLj1eCtzzQv6XSA\";}s:2:\"id\";s:34:\"block_content.field_ebt_hero_title\";s:10:\"field_name\";s:20:\"field_ebt_hero_title\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_title_prefix',	'a:17:{s:4:\"uuid\";s:36:\"d972b731-9ab7-4ca0-8ee1-32320e00018b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yPT-fy4fwafnNJhdyQ0u1kFfPiRvtGiJ8-5FOUcKyaw\";}s:2:\"id\";s:41:\"block_content.field_ebt_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ebt_hero_title_prefix\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image',	'a:17:{s:4:\"uuid\";s:36:\"90e79693-e9f5-46f1-bb04-df225231b9a7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"glPjB_880Y127LFOondnNWS1FPhcaT_fJa11BR0P5BA\";}s:2:\"id\";s:29:\"block_content.field_ebt_image\";s:10:\"field_name\";s:15:\"field_ebt_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image_caption',	'a:17:{s:4:\"uuid\";s:36:\"d9f39667-4231-4f25-b5b5-7d6a627c0143\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LJgW5JIAhD9XCJuoflFRdy-F8SWYW2Cix0FvZz4SYiY\";}s:2:\"id\";s:37:\"block_content.field_ebt_image_caption\";s:10:\"field_name\";s:23:\"field_ebt_image_caption\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image_gallery',	'a:17:{s:4:\"uuid\";s:36:\"0ab015a1-cb97-4ec7-ad66-d236d2472cee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VTE6qLfHmQDITpk4f42HVWATR8Wgh7o2ygcj4yx3iNQ\";}s:2:\"id\";s:37:\"block_content.field_ebt_image_gallery\";s:10:\"field_name\";s:23:\"field_ebt_image_gallery\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image_link',	'a:17:{s:4:\"uuid\";s:36:\"d53112b6-fda3-4a60-9140-a4f4d8c03704\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wLzveDC1XvIz7oYfIvN4OjokbzzjPzDc9Ik730ZY254\";}s:2:\"id\";s:34:\"block_content.field_ebt_image_link\";s:10:\"field_name\";s:20:\"field_ebt_image_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_micromodal_title',	'a:17:{s:4:\"uuid\";s:36:\"8889dde4-ff00-4644-8af5-1d22a85992bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KxeGHZZZNOmgTH3mTuMpwjJqQoqqDIsVOiT05vaOjSQ\";}s:2:\"id\";s:40:\"block_content.field_ebt_micromodal_title\";s:10:\"field_name\";s:26:\"field_ebt_micromodal_title\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_quote_author',	'a:17:{s:4:\"uuid\";s:36:\"66105a0b-52fa-455d-9673-6bab401dd3d9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"un8UvEIKf-pPNdISDAwHz8cnHArBXUbFHb8rYis_-KU\";}s:2:\"id\";s:36:\"block_content.field_ebt_quote_author\";s:10:\"field_name\";s:22:\"field_ebt_quote_author\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_quote_image',	'a:17:{s:4:\"uuid\";s:36:\"c53a9a24-143b-4766-a552-e983659465b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"usPfnGqFjnh9WSQ4-5tqsU1G2FvbPHpJMyt4Omq2btU\";}s:2:\"id\";s:35:\"block_content.field_ebt_quote_image\";s:10:\"field_name\";s:21:\"field_ebt_quote_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"37d2f916-06b4-418e-91ad-84a23f9fe7aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ifyYbCOsv_c2p19zBnvPk39PxYWsMjVLhswFVxeoMEk\";}s:2:\"id\";s:32:\"block_content.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:12:\"ebt_settings\";s:8:\"settings\";a:0:{}s:6:\"module\";s:8:\"ebt_core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_slick_slider',	'a:17:{s:4:\"uuid\";s:36:\"4f31d892-e4c2-45d6-a14e-723ccc4c06f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvQGqiPKTXqRaJpknm7I-jiTH0_2U95OADILQZQt5zA\";}s:2:\"id\";s:36:\"block_content.field_ebt_slick_slider\";s:10:\"field_name\";s:22:\"field_ebt_slick_slider\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_slideshow',	'a:17:{s:4:\"uuid\";s:36:\"aec7f7b6-b7a3-414f-8026-620c99e80fee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pGo99IMeEAHZnIdMVP18pkNzYTjRT7opYqgiP2t4CzI\";}s:2:\"id\";s:33:\"block_content.field_ebt_slideshow\";s:10:\"field_name\";s:19:\"field_ebt_slideshow\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_stats',	'a:17:{s:4:\"uuid\";s:36:\"65f88f19-ba20-4a37-8258-22b4bbd0bed3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TCxq8NOVtHeT-j0H_fF1rrmP8AxlDhBMsOm8KSQlkrs\";}s:2:\"id\";s:29:\"block_content.field_ebt_stats\";s:10:\"field_name\";s:15:\"field_ebt_stats\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_tabs',	'a:17:{s:4:\"uuid\";s:36:\"8b001212-3460-4d07-af2d-efb8bed64599\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-l2aVtFab9PohqPfDUp_RU4Ji6kBJLDWSfB6L_rUZmo\";}s:2:\"id\";s:28:\"block_content.field_ebt_tabs\";s:10:\"field_name\";s:14:\"field_ebt_tabs\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_tiles',	'a:17:{s:4:\"uuid\";s:36:\"2fa60bf2-361b-4902-b836-53c11ea98d00\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xpk_uqKrbVXj3nCNx7pki4z-Cql8XOb4a0GLo-PxaDE\";}s:2:\"id\";s:29:\"block_content.field_ebt_tiles\";s:10:\"field_name\";s:15:\"field_ebt_tiles\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_timeline',	'a:17:{s:4:\"uuid\";s:36:\"34f357a7-4ec0-459d-9349-7c3b933ed9ca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"w5cvHJQa6dOxx4ke6vQ8dBNORP8_2BYC8XoDyNSh_ag\";}s:2:\"id\";s:32:\"block_content.field_ebt_timeline\";s:10:\"field_name\";s:18:\"field_ebt_timeline\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_video',	'a:17:{s:4:\"uuid\";s:36:\"cd7bca62-bdaa-494e-8d09-d0af7c881721\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yqpxggVM9qa9BsCQ0dK4C8x0wU_GrVyhYXeHKQe-IMI\";}s:2:\"id\";s:29:\"block_content.field_ebt_video\";s:10:\"field_name\";s:15:\"field_ebt_video\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_videos_and_images',	'a:17:{s:4:\"uuid\";s:36:\"51b55e7c-d254-49db-b70a-396cd9835bd2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gzA7OAqszgyne63vWHEzNQQzhp58wo4JD5jrt82tjk8\";}s:2:\"id\";s:41:\"block_content.field_ebt_videos_and_images\";s:10:\"field_name\";s:27:\"field_ebt_videos_and_images\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_views_views',	'a:17:{s:4:\"uuid\";s:36:\"f11fd5af-293c-41e7-91eb-52f5c2b14f5a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"crklekBdziPXiKGCBhoUfqwhWUXAuyDEQHEw0J7NdQI\";}s:2:\"id\";s:35:\"block_content.field_ebt_views_views\";s:10:\"field_name\";s:21:\"field_ebt_views_views\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_webform_form',	'a:17:{s:4:\"uuid\";s:36:\"08365941-eddc-446f-8fc9-72a7728df65c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K4nKI1yvxZ4s40vKrpuBiz09L15lK0ygK9etUTwYVRw\";}s:2:\"id\";s:36:\"block_content.field_ebt_webform_form\";s:10:\"field_name\";s:22:\"field_ebt_webform_form\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_webform_popup_form',	'a:17:{s:4:\"uuid\";s:36:\"fb27b8eb-ae9d-44ec-8d20-6aa1287b8b5f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GlZwbpK_4w1bHHs_IAnr12BJmD-fvq2QCviVBXnfiRA\";}s:2:\"id\";s:42:\"block_content.field_ebt_webform_popup_form\";s:10:\"field_name\";s:28:\"field_ebt_webform_popup_form\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_audio_file',	'a:17:{s:4:\"uuid\";s:36:\"75a1e1d5-184d-4541-96b7-8957dddb2453\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JCHoh95CpUeBx9ch24Tmi6ru0nwmNz8xWVH4Qs7RnTg\";}s:2:\"id\";s:28:\"media.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_document',	'a:17:{s:4:\"uuid\";s:36:\"2c293a08-a63a-47a3-8b49-8e7650f47903\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BdkTx7IL59MCw5a_fOZprPTOGM_wcjz-Fm8g7HV3vFk\";}s:2:\"id\";s:26:\"media.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_image',	'a:17:{s:4:\"uuid\";s:36:\"379994ed-ae76-4656-ab52-4f8661d6efc4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0N0KSFk57p6qsq3qM4lYVGSuROvzXK-tSsdwByqUh3g\";}s:2:\"id\";s:23:\"media.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_oembed_video',	'a:17:{s:4:\"uuid\";s:36:\"eca9af3a-0023-4307-a38b-526dac079818\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cNf_852Dq-fNnSaMI4LxL-J6N7bLkHuDbD9EUqOn4_U\";}s:2:\"id\";s:30:\"media.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;s:8:\"is_ascii\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_video_file',	'a:17:{s:4:\"uuid\";s:36:\"4f8a6296-0295-4cc5-8e6a-c61c708a78ba\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z5mgbn1PIVZ5TNMByBmivqo_u3Rdk58UIzpyN4ypTeM\";}s:2:\"id\";s:28:\"media.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.body',	'a:17:{s:4:\"uuid\";s:36:\"27acecd6-ddfe-41ab-ad13-d09a77410226\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:2:\"id\";s:9:\"node.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.field_image',	'a:17:{s:4:\"uuid\";s:36:\"0ce9563d-0108-4dd8-9768-e3f3f692efb8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:2:\"id\";s:16:\"node.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.field_metatags',	'a:16:{s:4:\"uuid\";s:36:\"3a56d56d-4fea-4e6d-abfd-6e9fd5799d1f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"metatag\";i:1;s:4:\"node\";}}s:2:\"id\";s:19:\"node.field_metatags\";s:10:\"field_name\";s:14:\"field_metatags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:7:\"metatag\";s:8:\"settings\";a:0:{}s:6:\"module\";s:7:\"metatag\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.field_tags',	'a:17:{s:4:\"uuid\";s:36:\"11256bc1-c4ef-404b-ae80-826c196dfc3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:2:\"id\";s:15:\"node.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.layout_builder__layout',	'a:16:{s:4:\"uuid\";s:36:\"01dcf303-887c-48ba-8de3-a183f2dc164d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:14:\"layout_builder\";i:1;s:4:\"node\";}}s:2:\"id\";s:27:\"node.layout_builder__layout\";s:10:\"field_name\";s:22:\"layout_builder__layout\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:14:\"layout_section\";s:8:\"settings\";a:0:{}s:6:\"module\";s:14:\"layout_builder\";s:6:\"locked\";b:1;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:0;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_accordion_text',	'a:17:{s:4:\"uuid\";s:36:\"c88354ca-8244-4d5a-8c63-2709d938c811\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dl3BMOx4hnrrl4qqLYkCtUssYQ_RkV9iIcbThUL8opE\";}s:2:\"id\";s:34:\"paragraph.field_ebt_accordion_text\";s:10:\"field_name\";s:24:\"field_ebt_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_accordion_title',	'a:17:{s:4:\"uuid\";s:36:\"7205b1e6-f387-4cb5-80f3-ea6e935096ea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xtdycMRMTk1-RbuIsXUkC8uoiTiAeIi8PtDCDuev5pM\";}s:2:\"id\";s:35:\"paragraph.field_ebt_accordion_title\";s:10:\"field_name\";s:25:\"field_ebt_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_carousel_caption',	'a:17:{s:4:\"uuid\";s:36:\"9950466c-7cf2-451c-a90c-6d94bc4223d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eH045cIw7DgTbyESpPO40c1yE4GkZSKAsRjv6wCv1cc\";}s:2:\"id\";s:36:\"paragraph.field_ebt_carousel_caption\";s:10:\"field_name\";s:26:\"field_ebt_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_carousel_image',	'a:17:{s:4:\"uuid\";s:36:\"c9955fe0-9e81-4347-b5c8-b3a2813ea422\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sBBtSihKznwfoZE4RCUfKLyFx5JPJOKThpsezNspQUg\";}s:2:\"id\";s:34:\"paragraph.field_ebt_carousel_image\";s:10:\"field_name\";s:24:\"field_ebt_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_clickable_tile',	'a:17:{s:4:\"uuid\";s:36:\"4a6ac85b-3418-4331-8d82-82c365e01b2a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sqyvMHG_MfFRoRtp9QsU69-Hqibbf7-n0L6nXXuy-RY\";}s:2:\"id\";s:34:\"paragraph.field_ebt_clickable_tile\";s:10:\"field_name\";s:24:\"field_ebt_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_description',	'a:17:{s:4:\"uuid\";s:36:\"474cb9c9-f18d-40c9-8bdc-2b263c5bf1bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T2aI_SC10fUAVAHAQ6YSjRx-RgZI16Y4DhBlcYV8xTY\";}s:2:\"id\";s:39:\"paragraph.field_ebt_counter_description\";s:10:\"field_name\";s:29:\"field_ebt_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"17ec174c-0286-4b9d-8d57-f5618c7d73b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A3xIcHA3Yh7nEExvOCO8fCJ2RKTLwO7PHRzSW91-6ag\";}s:2:\"id\";s:32:\"paragraph.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"fe9a8722-bb07-4268-815a-a4b9b20eb504\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"12yti1pJd8_55sJ_ipVJkKkOSBrqJNbIN1ScDohe8Ug\";}s:2:\"id\";s:34:\"paragraph.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"integer\";s:8:\"settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_title',	'a:17:{s:4:\"uuid\";s:36:\"646af88e-2cb1-4e61-9b5a-1720fbe00d94\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8SSZniajg5zo9MscuowyDAxLHlUJhnpGgVXmpef2Qfc\";}s:2:\"id\";s:33:\"paragraph.field_ebt_counter_title\";s:10:\"field_name\";s:23:\"field_ebt_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slick_slider_image',	'a:17:{s:4:\"uuid\";s:36:\"7b1e8d87-89a6-4d9c-b0ae-16292b52f88b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HwpmmxKvO4846yzGMxYlF27KAqxGN93LugyydI_mAQk\";}s:2:\"id\";s:38:\"paragraph.field_ebt_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ebt_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slick_slider_link',	'a:17:{s:4:\"uuid\";s:36:\"ce8c8911-2694-45d2-b941-6c8f08c9a8fd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2sX2ALM8UbHO085MTpnVsKr65w2_hTSuR1OGRh9yhnc\";}s:2:\"id\";s:37:\"paragraph.field_ebt_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slick_slider_text',	'a:17:{s:4:\"uuid\";s:36:\"fd3e2c50-dcff-4f84-bd3f-a28c9352ea81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bw5ktsaCO3NIoI8s4_-sX-8nheZucWVVtes3gNa3nAM\";}s:2:\"id\";s:37:\"paragraph.field_ebt_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_link',	'a:17:{s:4:\"uuid\";s:36:\"99143ce8-61ee-4652-a122-2b74cf0353a8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYqrMKPAVBTFXGukNiO0LmsHSZLTwSIqlH0B12cWoSc\";}s:2:\"id\";s:34:\"paragraph.field_ebt_slideshow_link\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_slide',	'a:17:{s:4:\"uuid\";s:36:\"20a2702c-d0d9-491e-bc0d-48bd8f4e5479\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yvMPSQ3opDpO2Y7W2gLC_lfyYsUerg7quMuaUIXTG6Y\";}s:2:\"id\";s:35:\"paragraph.field_ebt_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_text',	'a:17:{s:4:\"uuid\";s:36:\"5476f31f-53b6-41ea-919f-8ea57cf902fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l1sRS9qn9Xk0p6T25AqVsGWWAhp74-8ejyMC2cSICnA\";}s:2:\"id\";s:34:\"paragraph.field_ebt_slideshow_text\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_title',	'a:17:{s:4:\"uuid\";s:36:\"b514672e-03d7-4efa-81b8-0f04c6b94cd1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"56OfbIVnrkDV6Ei_ldSAYihwJbVyAJds03m4lf7fsqc\";}s:2:\"id\";s:35:\"paragraph.field_ebt_slideshow_title\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_block',	'a:17:{s:4:\"uuid\";s:36:\"0fc30373-baea-48fd-8769-4b6c582ae3d8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AwzF4qJWahe58UULrqET0cwFen2kxLMygeAFj96-4Kk\";}s:2:\"id\";s:29:\"paragraph.field_ebt_tab_block\";s:10:\"field_name\";s:19:\"field_ebt_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_content',	'a:17:{s:4:\"uuid\";s:36:\"d00f9fc0-b613-4eed-90b2-740af89205eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"options\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7FvDDnDFUS9rxHT4MbM9RwHPArBckbhp09KzHNMtD10\";}s:2:\"id\";s:31:\"paragraph.field_ebt_tab_content\";s:10:\"field_name\";s:21:\"field_ebt_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"list_string\";s:8:\"settings\";a:2:{s:14:\"allowed_values\";a:4:{i:0;a:2:{s:5:\"value\";s:4:\"text\";s:5:\"label\";s:4:\"Text\";}i:1;a:2:{s:5:\"value\";s:4:\"page\";s:5:\"label\";s:4:\"Page\";}i:2;a:2:{s:5:\"value\";s:5:\"block\";s:5:\"label\";s:5:\"Block\";}i:3;a:2:{s:5:\"value\";s:5:\"views\";s:5:\"label\";s:5:\"Views\";}}s:23:\"allowed_values_function\";s:0:\"\";}s:6:\"module\";s:7:\"options\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_page',	'a:17:{s:4:\"uuid\";s:36:\"527f69af-c7cb-450d-a95f-a0199f66a3fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Lx2SQWOPiXsxTotbjz7VPPAu-QERRb10_IFn-ApZRDo\";}s:2:\"id\";s:28:\"paragraph.field_ebt_tab_page\";s:10:\"field_name\";s:18:\"field_ebt_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"node\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_text',	'a:17:{s:4:\"uuid\";s:36:\"7492acc6-65ae-4f1f-b3c7-3e41a385e8cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvq8PSEOBXAVYlGbuM_TA0t_zulyHA_Bkjc6MrrkLWY\";}s:2:\"id\";s:28:\"paragraph.field_ebt_tab_text\";s:10:\"field_name\";s:18:\"field_ebt_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_title',	'a:17:{s:4:\"uuid\";s:36:\"0c03a11f-8242-48d7-ae98-2da2e80f3f2e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"chlF7z3GEcHoQnXo-49bdW3H_FSDPxAqWy0miEMc3AM\";}s:2:\"id\";s:29:\"paragraph.field_ebt_tab_title\";s:10:\"field_name\";s:19:\"field_ebt_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"text\";s:8:\"settings\";a:1:{s:10:\"max_length\";i:1023;}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_views',	'a:17:{s:4:\"uuid\";s:36:\"3dc81a0a-ea91-4e72-af8b-18c1abffc08d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QmZGd58IuoXxDcUvh8hfNHnRLR71GZA3qzfZpuVSjH4\";}s:2:\"id\";s:29:\"paragraph.field_ebt_tab_views\";s:10:\"field_name\";s:19:\"field_ebt_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_image',	'a:17:{s:4:\"uuid\";s:36:\"3988ff22-66ff-4325-be58-387a6451784f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3aeaxW3pHrK5yFagP66-FT7HXAGYacr2YhOcg-h70n0\";}s:2:\"id\";s:31:\"paragraph.field_ebt_tiles_image\";s:10:\"field_name\";s:21:\"field_ebt_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_link',	'a:17:{s:4:\"uuid\";s:36:\"f1992284-2903-4d4f-b4c2-4336abc56b45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mUN0Fv2hYJXOjWBr3fDMeZnblvk6m_qvnRncjAS5Jz0\";}s:2:\"id\";s:30:\"paragraph.field_ebt_tiles_link\";s:10:\"field_name\";s:20:\"field_ebt_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_text',	'a:17:{s:4:\"uuid\";s:36:\"6e677df8-5ee4-417d-be3a-d5036e605903\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SYBCp04_zUg3tqwrydEEBCSg6JWf7CR4f2Jym-jtu7Y\";}s:2:\"id\";s:30:\"paragraph.field_ebt_tiles_text\";s:10:\"field_name\";s:20:\"field_ebt_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_title',	'a:17:{s:4:\"uuid\";s:36:\"adfc8f4b-838d-40b5-956a-1f813f9dc592\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"__j2dIJmEb5SExuxv7f5bTbyHtFYlG0BqQD9owZgiFA\";}s:2:\"id\";s:31:\"paragraph.field_ebt_tiles_title\";s:10:\"field_name\";s:21:\"field_ebt_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_current',	'a:17:{s:4:\"uuid\";s:36:\"1043de86-9fe2-4436-8425-6f47521f1f00\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"io0Gxmv8qUwbnmMiTtgXlnMKWybAbO4f6d7W3yHn9vE\";}s:2:\"id\";s:36:\"paragraph.field_ebt_timeline_current\";s:10:\"field_name\";s:26:\"field_ebt_timeline_current\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_date',	'a:17:{s:4:\"uuid\";s:36:\"80c677f9-529e-499e-959c-dc9187ab7a49\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nmy2TG7m2qANlPD4kTWJk7016mawyxdzgYZ3omLSCVc\";}s:2:\"id\";s:33:\"paragraph.field_ebt_timeline_date\";s:10:\"field_name\";s:23:\"field_ebt_timeline_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_media_image',	'a:17:{s:4:\"uuid\";s:36:\"7089f45d-1e3c-4225-bba6-736084040e5b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yB2KT5oQDNzQfggkUQGHhoqlikRSVCE8a5MSV_5NvEo\";}s:2:\"id\";s:40:\"paragraph.field_ebt_timeline_media_image\";s:10:\"field_name\";s:30:\"field_ebt_timeline_media_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_text',	'a:17:{s:4:\"uuid\";s:36:\"fe035edd-b535-4ceb-bd54-a3c604fbae92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CFCHP9vAPguIB2d677v2iLm245zKg4MRxpfICMcUHo8\";}s:2:\"id\";s:33:\"paragraph.field_ebt_timeline_text\";s:10:\"field_name\";s:23:\"field_ebt_timeline_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_title',	'a:17:{s:4:\"uuid\";s:36:\"7b0677d8-0312-4994-b0a6-cd1c0852a050\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cM8ncQUeGNJamKPS5THMY_gIhCe_qsCwn4s-_6YPaq4\";}s:2:\"id\";s:34:\"paragraph.field_ebt_timeline_title\";s:10:\"field_name\";s:24:\"field_ebt_timeline_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:512;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_gallery_item_description',	'a:17:{s:4:\"uuid\";s:36:\"31c1cb14-3677-44d6-951e-3560a93c8f65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jf90xTmsti89Pjc4bIjB0aBV5QshhjB0mhGkqONmGjU\";}s:2:\"id\";s:40:\"paragraph.field_gallery_item_description\";s:10:\"field_name\";s:30:\"field_gallery_item_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_image',	'a:17:{s:4:\"uuid\";s:36:\"233843a3-22c1-4376-a920-f894f695b87c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ml8f47_-t_lza9fvHT7YnpccMFPtmO5CC_TKle1QMr8\";}s:2:\"id\";s:32:\"paragraph.field_stats_item_image\";s:10:\"field_name\";s:22:\"field_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_link',	'a:17:{s:4:\"uuid\";s:36:\"7003f50c-c76e-4efe-bfcc-67453daeb93c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6Xx4YNeE_zQDdDg8HySkyOGsBrl8RHNnsFsWYoC1GI4\";}s:2:\"id\";s:31:\"paragraph.field_stats_item_link\";s:10:\"field_name\";s:21:\"field_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_number',	'a:17:{s:4:\"uuid\";s:36:\"f6763f4c-c4a6-4d80-ab1d-f0e2aca44f60\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YWL60ZrNzy_L7BYYe7ipJCC3__awGcG9ewUwecK82J4\";}s:2:\"id\";s:33:\"paragraph.field_stats_item_number\";s:10:\"field_name\";s:23:\"field_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_text',	'a:17:{s:4:\"uuid\";s:36:\"0d6fd00f-5382-443f-ae8a-996e1552af22\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7R83PXXuAu39Em7tMg3vXyaerbWjilK3AuSi3IXVRYc\";}s:2:\"id\";s:31:\"paragraph.field_stats_item_text\";s:10:\"field_name\";s:21:\"field_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_video_gallery_item',	'a:17:{s:4:\"uuid\";s:36:\"5c6f70cc-17fc-4f18-bcfb-4c0d8a66500e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qNGEoWbTX-CnhncjUmfOTlH2eL2GnzBZckwY_yzsHfM\";}s:2:\"id\";s:34:\"paragraph.field_video_gallery_item\";s:10:\"field_name\";s:24:\"field_video_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.user.user_picture',	'a:17:{s:4:\"uuid\";s:36:\"13a3c6c5-6417-4477-8a58-0b066b2141c3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:2:\"id\";s:17:\"user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field_ui.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1nMi90W6YQxKzZAgJQw7Ag9U4JrsEUwkomF0lhvbIM\";}s:12:\"field_prefix\";s:6:\"field_\";}'),
('',	'file.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bwjZB1IjEYbppgZT3g7YW_5h_LDZYNa3DaDEfWX82U\";}s:11:\"description\";a:2:{s:4:\"type\";s:9:\"textfield\";s:6:\"length\";i:128;}s:4:\"icon\";a:1:{s:9:\"directory\";s:23:\"core/modules/file/icons\";}s:35:\"make_unused_managed_files_temporary\";b:0;s:21:\"filename_sanitization\";a:6:{s:13:\"transliterate\";b:1;s:18:\"replace_whitespace\";b:1;s:24:\"replace_non_alphanumeric\";b:1;s:22:\"deduplicate_separators\";b:1;s:9:\"lowercase\";b:1;s:21:\"replacement_character\";s:1:\"-\";}}'),
('',	'filter.format.basic_html',	'a:9:{s:4:\"uuid\";s:36:\"5d0c18fb-1e15-4eac-9e4b-1484b52ff943\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:6:\"editor\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mclCbTlJwWJORez4Y1eX2MqA0aGjSMAoJb3TaBABcK8\";}s:4:\"name\";s:10:\"Basic HTML\";s:6:\"format\";s:10:\"basic_html\";s:6:\"weight\";i:0;s:7:\"filters\";a:6:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:7;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:243:\"<br> <p> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id> <cite> <dl> <dt> <dd> <a hreflang href> <blockquote cite> <ul type> <ol start type> <strong> <em> <code> <li> <img src alt data-entity-uuid data-entity-type height width data-caption data-align>\";s:16:\"filter_html_help\";b:0;s:20:\"filter_html_nofollow\";b:0;}}s:24:\"filter_html_image_secure\";a:5:{s:2:\"id\";s:24:\"filter_html_image_secure\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}}}'),
('',	'filter.format.full_html',	'a:9:{s:4:\"uuid\";s:36:\"e00030fb-b30d-42df-a35b-b9dca992742e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:6:\"editor\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpZysv3RHJjhYzq7O_q5q8mVlHdrSzKELmXyiX6RtV0\";}s:4:\"name\";s:9:\"Full HTML\";s:6:\"format\";s:9:\"full_html\";s:6:\"weight\";i:2;s:7:\"filters\";a:5:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:20:\"filter_htmlcorrector\";a:5:{s:2:\"id\";s:20:\"filter_htmlcorrector\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}}}'),
('',	'filter.format.plain_text',	'a:9:{s:4:\"uuid\";s:36:\"98975409-6030-4f9b-8f64-18610166736a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JLMwODO0epnA_H-jFlH9ezVfa5YBJniRv3MmLqYNl_Q\";}s:4:\"name\";s:10:\"Plain text\";s:6:\"format\";s:10:\"plain_text\";s:6:\"weight\";i:10;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:18:\"filter_html_escape\";a:5:{s:2:\"id\";s:18:\"filter_html_escape\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:0:{}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),
('',	'filter.format.restricted_html',	'a:9:{s:4:\"uuid\";s:36:\"8ca43f73-d620-4c03-bbd7-8221d546124f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QiKqQS_YGAT3Qr4vaAgZICJknm-MGCzt_xBAMqg-tRM\";}s:4:\"name\";s:15:\"Restricted HTML\";s:6:\"format\";s:15:\"restricted_html\";s:6:\"weight\";i:1;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:149:\"<a href hreflang> <em> <strong> <cite> <blockquote cite> <code> <ul type> <ol start type> <li> <dl> <dt> <dd> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id>\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),
('',	'filter.format.webform_default',	'a:9:{s:4:\"uuid\";s:36:\"cf32d962-2f58-41c9-989d-a8f82367e8e1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EeKp_M4Oid3erARiAam9rsgBKR91uEnFkEP3aZS2ol8\";}s:4:\"name\";s:31:\"Webform (Default) - DO NOT EDIT\";s:6:\"format\";s:15:\"webform_default\";s:6:\"weight\";i:100;s:7:\"filters\";a:0:{}}'),
('',	'filter.settings',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiPjM3WdB__ruFA7B6TLwni_UcZbmek5G4b2dxQItxA\";}s:15:\"fallback_format\";s:10:\"plain_text\";s:27:\"always_show_fallback_choice\";b:0;}'),
('',	'glightbox.settings',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5G059LQS_7DV7oGUpxVTPM0aWtunW7bvDpRkgeb0KtE\";}s:6:\"custom\";a:17:{s:8:\"activate\";i:0;s:11:\"open_effect\";s:4:\"zoom\";s:12:\"close_effect\";s:4:\"zoom\";s:12:\"slide_effect\";s:5:\"slide\";s:5:\"width\";s:3:\"98%\";s:6:\"height\";s:3:\"98%\";s:11:\"videosWidth\";s:5:\"960px\";s:22:\"close_on_outside_click\";b:1;s:9:\"more_text\";s:8:\"See more\";s:11:\"more_length\";i:60;s:13:\"desc_position\";s:6:\"bottom\";s:4:\"loop\";b:0;s:8:\"zoomable\";b:1;s:9:\"draggable\";b:1;s:7:\"preload\";b:1;s:15:\"autoplay_videos\";b:1;s:16:\"autofocus_videos\";b:0;}s:8:\"advanced\";a:2:{s:12:\"unique_token\";i:0;s:16:\"compression_type\";s:8:\"minified\";}}'),
('',	'google_analytics.settings',	'a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dwMYPgAnj9KBO77SLEv9Z42NDJAbuxe0uU9eGC8qw3M\";}s:7:\"account\";s:0:\"\";s:11:\"domain_mode\";i:0;s:13:\"cross_domains\";s:0:\"\";s:10:\"visibility\";a:5:{s:17:\"request_path_mode\";i:0;s:18:\"request_path_pages\";s:53:\"/admin\n/admin/*\n/batch\n/node/add*\n/node/*/*\n/user/*/*\";s:14:\"user_role_mode\";i:0;s:15:\"user_role_roles\";a:0:{}s:17:\"user_account_mode\";i:1;}s:5:\"track\";a:13:{s:8:\"outbound\";b:1;s:6:\"mailto\";b:1;s:3:\"tel\";b:1;s:5:\"files\";b:1;s:16:\"files_extensions\";s:279:\"7z|aac|arc|arj|asf|asx|avi|bin|csv|doc(x|m)?|dot(x|m)?|exe|flv|gif|gz|gzip|hqx|jar|jpe?g|js|mp(2|3|4|e?g)|mov(ie)?|msi|msp|pdf|phps|png|ppt(x|m)?|pot(x|m)?|pps(x|m)?|ppam|sld(x|m)?|thmx|qtm?|ra(m|r)?|sea|sit|tar|tgz|torrent|txt|wav|wma|wmv|wpd|xls(x|m|b)?|xlt(x|m)|xlam|xml|z|zip\";s:8:\"colorbox\";b:1;s:6:\"linkid\";b:0;s:12:\"urlfragments\";b:0;s:6:\"userid\";b:0;s:8:\"messages\";a:0:{}s:11:\"site_search\";b:0;s:7:\"adsense\";b:0;s:15:\"displayfeatures\";b:1;}s:7:\"privacy\";a:1:{s:11:\"anonymizeip\";b:1;}s:6:\"custom\";a:1:{s:10:\"parameters\";a:0:{}}s:11:\"codesnippet\";a:3:{s:6:\"create\";a:0:{}s:6:\"before\";s:0:\"\";s:5:\"after\";s:0:\"\";}s:15:\"translation_set\";b:0;s:5:\"cache\";b:0;s:5:\"debug\";b:0;}'),
('',	'image.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-yDFHbqNfpe-Srg4sdCSqaosCl2D8uwyEY5esF8gEw\";}s:13:\"preview_image\";s:29:\"core/modules/image/sample.png\";s:26:\"allow_insecure_derivatives\";b:0;s:20:\"suppress_itok_output\";b:0;}'),
('',	'image.style.ebt_gallery_image',	'a:8:{s:4:\"uuid\";s:36:\"3387ae71-e231-4ddd-9e5f-664ca37b095b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Et29BhgBeTqvhgY2GYsCViL4QGjZRI0vsbEe5O1VON4\";}s:4:\"name\";s:17:\"ebt_gallery_image\";s:5:\"label\";s:17:\"EBT Gallery Image\";s:7:\"effects\";a:1:{s:36:\"6ab4544c-7611-414c-aaa8-4eed96b10c84\";a:4:{s:4:\"uuid\";s:36:\"6ab4544c-7611-414c-aaa8-4eed96b10c84\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:365;s:6:\"height\";i:265;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.ebt_video_and_image_gallery',	'a:8:{s:4:\"uuid\";s:36:\"c4e70146-66c8-4f81-9049-d4e41b4c5305\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9px7Sz4srt9t5bnyp1lHoLhxTyuSbHKBR0pbE7rMPJ4\";}s:4:\"name\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:27:\"EBT Video and Image gallery\";s:7:\"effects\";a:1:{s:36:\"de12b6ed-b5ac-4ec8-9cf1-0df6cb6c8d32\";a:4:{s:4:\"uuid\";s:36:\"de12b6ed-b5ac-4ec8-9cf1-0df6cb6c8d32\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:360;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.large',	'a:8:{s:4:\"uuid\";s:36:\"527e81f9-fafb-4f3e-aad6-f169b5885095\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDR2BOewa2UFH9yG4tVvrGxEVv8U7LQo-RLkJhFpERs\";}s:4:\"name\";s:5:\"large\";s:5:\"label\";s:16:\"Large (480×480)\";s:7:\"effects\";a:2:{s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";a:4:{s:4:\"uuid\";s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:480;s:7:\"upscale\";b:0;}}s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";a:4:{s:4:\"uuid\";s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.linkit_result_thumbnail',	'a:8:{s:4:\"uuid\";s:36:\"7751cf12-1253-4c81-bcd8-bc001066b67b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PY0kMp7KIxvU4kBi5mcnD_DHTKUc1OkYCfaPliXjpa8\";}s:4:\"name\";s:23:\"linkit_result_thumbnail\";s:5:\"label\";s:23:\"Linkit result thumbnail\";s:7:\"effects\";a:1:{s:36:\"2943df29-38ea-459c-ba1d-290489bb1807\";a:4:{s:4:\"uuid\";s:36:\"2943df29-38ea-459c-ba1d-290489bb1807\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:50;s:6:\"height\";i:50;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.media_library',	'a:8:{s:4:\"uuid\";s:36:\"9fcd2b87-5cd2-4214-90f8-d2a1c4229d26\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FxMdscEA4aDH0KPM73HIZtVn3zIAgC1kQ3CkBw26HYs\";}s:4:\"name\";s:13:\"media_library\";s:5:\"label\";s:34:\"Media Library thumbnail (220×220)\";s:7:\"effects\";a:2:{s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";a:4:{s:4:\"uuid\";s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";a:4:{s:4:\"uuid\";s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.medium',	'a:8:{s:4:\"uuid\";s:36:\"c8b8fa24-4235-4e63-abae-72f30beb637e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dlar76VBuGj5iMGTruB_uMZX8VbivXt9_QLemaG2q4E\";}s:4:\"name\";s:6:\"medium\";s:5:\"label\";s:17:\"Medium (220×220)\";s:7:\"effects\";a:2:{s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";a:4:{s:4:\"uuid\";s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";a:4:{s:4:\"uuid\";s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.quote_image',	'a:8:{s:4:\"uuid\";s:36:\"60fb949e-3206-43f8-8a85-d75fa8ec9bf5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xlTbw2rsxfnXJ7Hv3VCpxLp5Ekaa0jutCubC0YpGcbw\";}s:4:\"name\";s:11:\"quote_image\";s:5:\"label\";s:11:\"Quote Image\";s:7:\"effects\";a:1:{s:36:\"d8117768-053a-4efa-87bf-a1e49600d865\";a:4:{s:4:\"uuid\";s:36:\"d8117768-053a-4efa-87bf-a1e49600d865\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:2;s:4:\"data\";a:3:{s:5:\"width\";i:530;s:6:\"height\";N;s:7:\"upscale\";b:0;}}}}'),
('',	'image.style.slick_slider_card',	'a:8:{s:4:\"uuid\";s:36:\"a7519911-04cf-4e32-8dd4-55d8d342ddfc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2zkdfRMnFwX0N2JCd1N-mTn2NTGgTRwRkfqW4Uiit8c\";}s:4:\"name\";s:17:\"slick_slider_card\";s:5:\"label\";s:17:\"Slick Slider card\";s:7:\"effects\";a:1:{s:36:\"c770ae08-739c-4196-a069-6d5becc97113\";a:4:{s:4:\"uuid\";s:36:\"c770ae08-739c-4196-a069-6d5becc97113\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:2;s:4:\"data\";a:3:{s:5:\"width\";i:400;s:6:\"height\";i:300;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.thumbnail',	'a:8:{s:4:\"uuid\";s:36:\"7e8ff02c-5435-43f6-8dc3-916788ea8d9f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BgeBV-xOFINMsz-y2thm45EGesj6bRM6DTLZ6ce3V9I\";}s:4:\"name\";s:9:\"thumbnail\";s:5:\"label\";s:20:\"Thumbnail (100×100)\";s:7:\"effects\";a:2:{s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";a:4:{s:4:\"uuid\";s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:100;s:6:\"height\";i:100;s:7:\"upscale\";b:0;}}s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";a:4:{s:4:\"uuid\";s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.wide',	'a:8:{s:4:\"uuid\";s:36:\"cf4a237b-4886-4db6-90a2-e2f1348070b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XHh3ATMH7z4ljwmzdndM47qNMkgLnoYsP98rGxVgCOw\";}s:4:\"name\";s:4:\"wide\";s:5:\"label\";s:11:\"Wide (1090)\";s:7:\"effects\";a:2:{s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";a:4:{s:4:\"uuid\";s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:1090;s:6:\"height\";N;s:7:\"upscale\";b:0;}}s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";a:4:{s:4:\"uuid\";s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'linkit.linkit_profile.default',	'a:9:{s:4:\"uuid\";s:36:\"655a70f6-77d9-4568-ad74-866e455f296a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0Jw_BFJCCtWk187tIYvME58VFpYwPaAdrc4eRtAyHH0\";}s:5:\"label\";s:7:\"Default\";s:2:\"id\";s:7:\"default\";s:11:\"description\";s:24:\"A default Linkit profile\";s:8:\"matchers\";a:1:{s:36:\"556010a3-e317-48b3-b4ed-854c10f4b950\";a:4:{s:2:\"id\";s:11:\"entity:node\";s:4:\"uuid\";s:36:\"556010a3-e317-48b3-b4ed-854c10f4b950\";s:8:\"settings\";a:6:{s:8:\"metadata\";s:77:\"[node:content-type:name] #[node:nid] | [node:created:medium] by [node:author]\";s:7:\"bundles\";a:0:{}s:15:\"group_by_bundle\";b:0;s:19:\"include_unpublished\";b:0;s:17:\"substitution_type\";s:9:\"canonical\";s:5:\"limit\";i:100;}s:6:\"weight\";i:0;}}}'),
('',	'media.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WCFqLQAxMw1weToDJEhfnW1Z-iOF7cqMdL8X7YTFxBA\";}s:13:\"icon_base_uri\";s:28:\"public://media-icons/generic\";s:13:\"iframe_domain\";N;s:20:\"oembed_providers_url\";s:33:\"https://oembed.com/providers.json\";s:14:\"standalone_url\";b:0;}'),
('',	'media.type.audio',	'a:13:{s:4:\"uuid\";s:36:\"5b9f8640-5def-4f1f-8cbb-9a34ee0d322b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJw8n6Tk2tO3ZysuEeGR1gZa1yRffaZzR4t0Q7iNurs\";}s:2:\"id\";s:5:\"audio\";s:5:\"label\";s:5:\"Audio\";s:11:\"description\";s:28:\"A locally hosted audio file.\";s:6:\"source\";s:10:\"audio_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_audio_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media.type.document',	'a:13:{s:4:\"uuid\";s:36:\"474a8161-6e84-4c54-8d09-7cd6cf51ca6f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_D9q3XSnP6ik9we9UuoTvZsQKPuYNp_G9PfwVtWzgnQ\";}s:2:\"id\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:44:\"An uploaded file or document, such as a PDF.\";s:6:\"source\";s:4:\"file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:20:\"field_media_document\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media.type.image',	'a:13:{s:4:\"uuid\";s:36:\"d02792ed-7ab7-466f-94e2-1bc1eb7fc178\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6Qope5wG7HUpV0tPOBMtDI_GZkHFcF1Xj4hgD9Cu_hM\";}s:2:\"id\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:36:\"Use local images for reusable media.\";s:6:\"source\";s:5:\"image\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:17:\"field_media_image\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media.type.remote_video',	'a:13:{s:4:\"uuid\";s:36:\"59bb7b69-536f-47d7-b202-4c65a9b02036\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hIBTnDGgDKnCiP6HUZm1m7600DHUEpC6FN3LQ4sUgZ4\";}s:2:\"id\";s:12:\"remote_video\";s:5:\"label\";s:12:\"Remote video\";s:11:\"description\";s:46:\"A remotely hosted video from YouTube or Vimeo.\";s:6:\"source\";s:12:\"oembed:video\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:3:{s:12:\"source_field\";s:24:\"field_media_oembed_video\";s:20:\"thumbnails_directory\";s:44:\"public://oembed_thumbnails/[date:custom:Y-m]\";s:9:\"providers\";a:2:{i:0;s:7:\"YouTube\";i:1;s:5:\"Vimeo\";}}s:9:\"field_map\";a:1:{s:5:\"title\";s:4:\"name\";}}'),
('',	'media.type.video',	'a:13:{s:4:\"uuid\";s:36:\"47a446d2-2250-4e11-98eb-8a4c51117635\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzgvcRgZHltqWf8hBmttoWh95tCJoPL25lPq9YSIRsY\";}s:2:\"id\";s:5:\"video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:28:\"A locally hosted video file.\";s:6:\"source\";s:10:\"video_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_video_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media_library.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3gQsCnZELUjUUqHk8SSh8bXnx7TZwN95vctAeVJG60\";}s:11:\"advanced_ui\";b:0;}'),
('',	'menu_ui.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SqMarzIjxC3F8dZo9FEOxfqDKD_sdW1tbcFTV1BA2zU\";}s:24:\"override_parent_selector\";b:0;}'),
('',	'metatag.metatag_defaults.403',	'a:8:{s:4:\"uuid\";s:36:\"32de19c3-215d-4985-a7d7-d588a90d7f0d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RDCkFL0NDt75Gwioooxo1iuA1S50xTVsBOgX__c6wTw\";}s:2:\"id\";s:3:\"403\";s:5:\"label\";s:17:\"403 access denied\";s:4:\"tags\";a:3:{s:6:\"robots\";s:7:\"noindex\";s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),
('',	'metatag.metatag_defaults.404',	'a:8:{s:4:\"uuid\";s:36:\"1131c9da-259d-4688-af2b-8cd70c4d304f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"puBstSLDz8mbaWU357zaqQDBGMGsJzG0j-TQNQkjg20\";}s:2:\"id\";s:3:\"404\";s:5:\"label\";s:18:\"404 page not found\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),
('',	'metatag.metatag_defaults.front',	'a:8:{s:4:\"uuid\";s:36:\"14e6bd6a-5fd4-4abb-b304-231e944ee914\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1noCXlegCr5HFehQRF1ViXy1jhU1jZ_sNN99a8Sj5jo\";}s:2:\"id\";s:5:\"front\";s:5:\"label\";s:10:\"Front page\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),
('',	'metatag.metatag_defaults.global',	'a:8:{s:4:\"uuid\";s:36:\"c377ec68-aa9d-4ed0-8e17-b44da3051c14\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sL588ui1E_8-2c_UupwyYxcqX2OVyMFp3HTLbbFqvPc\";}s:2:\"id\";s:6:\"global\";s:5:\"label\";s:6:\"Global\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:18:\"[current-page:url]\";s:5:\"title\";s:34:\"[current-page:title] | [site:name]\";}}'),
('',	'metatag.metatag_defaults.node',	'a:8:{s:4:\"uuid\";s:36:\"3950fa9e-d155-4064-8913-f7928e563aa1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rpwvgyEURXLz_JjgMCrkS1rUv-0k3L79BpO-ReN7fDI\";}s:2:\"id\";s:4:\"node\";s:5:\"label\";s:7:\"Content\";s:4:\"tags\";a:3:{s:5:\"title\";s:26:\"[node:title] | [site:name]\";s:11:\"description\";s:14:\"[node:summary]\";s:13:\"canonical_url\";s:10:\"[node:url]\";}}'),
('',	'metatag.metatag_defaults.taxonomy_term',	'a:8:{s:4:\"uuid\";s:36:\"7175fa40-e959-4cb9-a9af-08b0acf53b23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"92bXZdyYJ5xqukdfmGRr_CYcwm1vfuS8b8aJ7X_G7E0\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:4:\"tags\";a:3:{s:13:\"canonical_url\";s:10:\"[term:url]\";s:11:\"description\";s:18:\"[term:description]\";s:5:\"title\";s:25:\"[term:name] | [site:name]\";}}'),
('',	'metatag.metatag_defaults.user',	'a:8:{s:4:\"uuid\";s:36:\"2ce7b5a6-e273-4808-988d-bd51796041d7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MvQPTbQx0Vxwy0ordSHyixdZmLCMpvMdLD69dlwkrKc\";}s:2:\"id\";s:4:\"user\";s:5:\"label\";s:4:\"User\";s:4:\"tags\";a:3:{s:13:\"canonical_url\";s:10:\"[user:url]\";s:11:\"description\";s:11:\"[site:name]\";s:5:\"title\";s:33:\"[user:display-name] | [site:name]\";}}'),
('',	'metatag.settings',	'a:7:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tKLBW2GXZVLFXqS9QgLyfTuxCLc1u_quKPQLtCia-Bw\";}s:18:\"entity_type_groups\";a:0:{}s:9:\"separator\";s:0:\"\";s:15:\"tag_trim_method\";s:11:\"beforeValue\";s:18:\"tag_trim_maxlength\";a:0:{}s:21:\"tag_scroll_max_height\";s:0:\"\";s:13:\"use_maxlength\";b:1;}'),
('',	'node.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W0cgFPhPJ3gAdqm06-az48BLf5MVcoZVS0HdByoofi0\";}s:15:\"use_admin_theme\";b:1;}'),
('',	'node.type.article',	'a:12:{s:4:\"uuid\";s:36:\"23740c9e-4bc8-422a-a456-7efd997502e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fe3N1uqaAyyKJbVkqT-btXy3t98puW8GCRD822xjl10\";}s:4:\"name\";s:7:\"Article\";s:4:\"type\";s:7:\"article\";s:11:\"description\";s:89:\"Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:1;}'),
('',	'node.type.page',	'a:12:{s:4:\"uuid\";s:36:\"1edca201-7650-4af0-af2a-47c5a971bfde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"i0snV8Wj--OkRW12UdachUiYiz3FbeMwHu_pZYfzKLc\";}s:4:\"name\";s:10:\"Basic page\";s:4:\"type\";s:4:\"page\";s:11:\"description\";s:77:\"Use <em>basic pages</em> for your static content, such as an \'About us\' page.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),
('',	'olivero.settings',	'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1TswGK46jyu77aIM7Z-0JVQs5bxHmo-gtgrvrQGMXxc\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:0;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:0;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:22:\"mobile_menu_all_widths\";i:0;s:22:\"site_branding_bg_color\";s:7:\"default\";s:18:\"base_primary_color\";s:7:\"#1b9ae4\";}'),
('',	'paragraphs.paragraphs_type.ebt_accordion',	'a:11:{s:4:\"uuid\";s:36:\"5071ad52-b6e8-4a13-88ad-a0e644e823f9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a7oBJmAAPescdOPyZ2zkmnxQR_-MkKei1Cs600-7sxM\";}s:2:\"id\";s:13:\"ebt_accordion\";s:5:\"label\";s:35:\"EBT Accordion section / FAQ section\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:46:\"Accordion or FAQ section for EBT Accordion/FAQ\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_carousel',	'a:11:{s:4:\"uuid\";s:36:\"eae57e5f-f332-4203-be4f-1ead1a6c1ebf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"F5G5bjObjmi_ofKoiKAxY1BXGoLKFMVsBTNd7Z39OuI\";}s:2:\"id\";s:12:\"ebt_carousel\";s:5:\"label\";s:17:\"EBT Carousel item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Carousel section for EBT Carousel\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_counter_item',	'a:11:{s:4:\"uuid\";s:36:\"8a0e0b99-a544-4c46-8cb3-534e418ac0e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ycgzZPt9EhNziX0konZumLTJ6y69olJaVnLJ2dtyKnI\";}s:2:\"id\";s:16:\"ebt_counter_item\";s:5:\"label\";s:16:\"EBT Counter Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:60:\"Counter Items to be used inside of Block Type: \"EBT Counter\"\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_slick_slider',	'a:11:{s:4:\"uuid\";s:36:\"70607742-51bf-4b77-8d46-c07397b718e6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7IpvZPMN9T939ox72-gNDYNrZIVrXQ7nlF-Pxkzq_7M\";}s:2:\"id\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:15:\"EBT Slick Slide\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:26:\"Slide for EBT Slick Slider\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_slideshow',	'a:11:{s:4:\"uuid\";s:36:\"68f7444a-b28e-4ac9-abc5-57a62d63fe7f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HQnVagG9vsLrOtO1nF5ggZaNQ0tRGZZhiOW1-8nLOMM\";}s:2:\"id\";s:13:\"ebt_slideshow\";s:5:\"label\";s:9:\"EBT Slide\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:35:\"Slideshow section for EBT Slideshow\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_stats_item',	'a:11:{s:4:\"uuid\";s:36:\"210023af-0ce2-4183-bbba-6adbe094a405\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mXP3gCAYTFLXux_oLacqKfa_b0MprpWFhqxO39VWGl8\";}s:2:\"id\";s:14:\"ebt_stats_item\";s:5:\"label\";s:14:\"EBT Stats Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:30:\"Stats Item for EBT Stats block\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_tab',	'a:11:{s:4:\"uuid\";s:36:\"d24c7342-50a5-4bba-a2ca-23838ec42c25\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nzTVRmvjb6HJiVMoRzf0HR02L3_n5N9VxatQ_IQQCmc\";}s:2:\"id\";s:7:\"ebt_tab\";s:5:\"label\";s:7:\"EBT Tab\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:32:\"Tab paragraph for EBT Tabs block\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_tiles_item',	'a:11:{s:4:\"uuid\";s:36:\"332e9a66-40d4-4d0f-a252-bacb76456f61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OXCYSO_8vGgFySd4voU9Be7Av6Oqe56G4XnMO_fX4EE\";}s:2:\"id\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:14:\"EBT Tiles Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:21:\"Section for EBT Tiles\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_timeline',	'a:11:{s:4:\"uuid\";s:36:\"0700c7f4-0990-4033-a96a-7eac220fe625\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"giGGVKGIGi_PVlgEPMjzx78I9q-gtwP8qRWwp4goOaE\";}s:2:\"id\";s:12:\"ebt_timeline\";s:5:\"label\";s:18:\"EBT Timeline Event\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Timeline section for EBT Timeline\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_video_and_image_gallery_item',	'a:11:{s:4:\"uuid\";s:36:\"69becd39-ca29-4229-a5e0-b50dda5e664e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ASm3yV1er7y-WJqAsPm4lUKhLJEK2A1QYjC-_eJJFIA\";}s:2:\"id\";s:32:\"ebt_video_and_image_gallery_item\";s:5:\"label\";s:32:\"EBT Video and Image gallery item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:58:\"Video and Image item for EBT Video and Image Gallery block\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7eR0sk71Eol86r_A7BMqn5_46wzenh5J1O5vZRCGKv8\";}s:16:\"show_unpublished\";b:1;}'),
('',	'pathauto.settings',	'a:13:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SwvLp8snyPEExF41CaJJYdPUVomofLqtXvwciHc4cPg\";}s:20:\"enabled_entity_types\";a:1:{i:0;s:4:\"user\";}s:11:\"punctuation\";a:1:{s:6:\"hyphen\";i:1;}s:7:\"verbose\";b:0;s:9:\"separator\";s:1:\"-\";s:10:\"max_length\";i:100;s:20:\"max_component_length\";i:100;s:13:\"transliterate\";b:1;s:12:\"reduce_ascii\";b:0;s:4:\"case\";b:1;s:12:\"ignore_words\";s:134:\"a, an, as, at, before, but, by, for, from, is, in, into, like, of, off, on, onto, per, since, than, the, this, that, to, up, via, with\";s:13:\"update_action\";i:2;s:11:\"safe_tokens\";a:6:{i:0;s:5:\"alias\";i:1;s:4:\"path\";i:2;s:9:\"join-path\";i:3;s:9:\"login-url\";i:4;s:3:\"url\";i:5;s:9:\"url-brief\";}}'),
('',	'redirect.settings',	'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FEwQLW1wXW7fiJdG1B2bxW1c_-k6w-r-3V3bSsW6PqM\";}s:13:\"auto_redirect\";b:1;s:19:\"default_status_code\";i:301;s:23:\"passthrough_querystring\";b:1;s:7:\"warning\";b:0;s:17:\"ignore_admin_path\";b:0;s:12:\"access_check\";b:0;s:24:\"route_normalizer_enabled\";b:1;}'),
('',	'search.page.help_search',	'a:11:{s:4:\"uuid\";s:36:\"fec10881-499f-4858-a42b-9b60cee45abe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RZ-bcSekNSsAbIPLW7Gmyd3uUjIOSrPvnb8RCCZYJm8\";}s:2:\"id\";s:11:\"help_search\";s:5:\"label\";s:4:\"Help\";s:4:\"path\";s:4:\"help\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"help_search\";s:13:\"configuration\";a:0:{}}'),
('',	'search.page.node_search',	'a:11:{s:4:\"uuid\";s:36:\"72642a28-df7e-4618-aa8c-3f52bf7d9f97\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"97tvtzGOa8_flb22CzSjgtm_YkiGMHvEBO-6q2K9V_U\";}s:2:\"id\";s:11:\"node_search\";s:5:\"label\";s:7:\"Content\";s:4:\"path\";s:4:\"node\";s:6:\"weight\";i:-10;s:6:\"plugin\";s:11:\"node_search\";s:13:\"configuration\";a:1:{s:8:\"rankings\";a:0:{}}}'),
('',	'search.page.user_search',	'a:11:{s:4:\"uuid\";s:36:\"294f8603-9cb9-4c47-91cb-def8653638f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k3aUaZXGDuhkek2TZIee0PApOPTvYZLadziekdyHA5A\";}s:2:\"id\";s:11:\"user_search\";s:5:\"label\";s:5:\"Users\";s:4:\"path\";s:4:\"user\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"user_search\";s:13:\"configuration\";a:0:{}}'),
('',	'search.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hvVxL1G-ZCxaq32IZws0YsfuhvaDiQE_np-0g35KjUk\";}s:12:\"and_or_limit\";i:7;s:12:\"default_page\";s:11:\"node_search\";s:5:\"index\";a:4:{s:10:\"cron_limit\";i:100;s:11:\"overlap_cjk\";b:1;s:17:\"minimum_word_size\";i:3;s:11:\"tag_weights\";a:12:{s:2:\"h1\";i:25;s:2:\"h2\";i:18;s:2:\"h3\";i:15;s:2:\"h4\";i:14;s:2:\"h5\";i:9;s:2:\"h6\";i:6;s:1:\"u\";i:3;s:1:\"b\";i:3;s:1:\"i\";i:3;s:6:\"strong\";i:3;s:2:\"em\";i:3;s:1:\"a\";i:10;}}s:7:\"logging\";b:0;}'),
('',	'shortcut.set.default',	'a:7:{s:4:\"uuid\";s:36:\"bc9830ea-c02f-4ef4-a17e-f3539c02304b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U5VlGjd_SfV0Qm_EfnaynOfc549cNscFAx48JfYoMRI\";}s:2:\"id\";s:7:\"default\";s:5:\"label\";s:7:\"Default\";}'),
('',	'system.action.media_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"62205804-910a-4719-bbcb-1c8ef9179e61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FrZy1tmuXJcOxhXlBoI1Hsnen5TT-9OCC1iolWH84go\";}s:2:\"id\";s:19:\"media_delete_action\";s:5:\"label\";s:12:\"Delete media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:26:\"entity:delete_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.media_publish_action',	'a:10:{s:4:\"uuid\";s:36:\"74ae1caf-547b-4f5b-b2c5-344fbdfc9454\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nh83qNNrmWE-CDdHz2MdFOAk60T9mzv3R-MaKfZR2jw\";}s:2:\"id\";s:20:\"media_publish_action\";s:5:\"label\";s:13:\"Publish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:27:\"entity:publish_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.media_save_action',	'a:10:{s:4:\"uuid\";s:36:\"15843e3d-3327-4414-a048-e956e137183d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VVyUA6PIaVeGtcIbgEWqJ6SYDiJdReBeojFswURFpKs\";}s:2:\"id\";s:17:\"media_save_action\";s:5:\"label\";s:10:\"Save media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:24:\"entity:save_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.media_unpublish_action',	'a:10:{s:4:\"uuid\";s:36:\"9d24595c-700e-4798-9d98-3f086528cbd9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CsK6TseQ2DatEbZgbd30swOlZ28_HHwAESU2LvEnWq0\";}s:2:\"id\";s:22:\"media_unpublish_action\";s:5:\"label\";s:15:\"Unpublish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:29:\"entity:unpublish_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"8ff0ec2c-b155-4314-9b5d-65aef57e6ed9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t43OqwzP3CTbcAagSsWKNy6KwMm_zShXo3c4-So6rQg\";}s:2:\"id\";s:18:\"node_delete_action\";s:5:\"label\";s:14:\"Delete content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"entity:delete_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_make_sticky_action',	'a:10:{s:4:\"uuid\";s:36:\"d5b780e9-4002-48fb-9961-4890d2e18a4e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sOb26JSy3fGpWkvR0WYN6_hMqj_6d1rvbvrkzp1yya0\";}s:2:\"id\";s:23:\"node_make_sticky_action\";s:5:\"label\";s:19:\"Make content sticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"node_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_make_unsticky_action',	'a:10:{s:4:\"uuid\";s:36:\"79cd458d-4e0f-42fc-8713-cf8324d4116c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lDM9mvIGAu8Sw8rt-uCO4Sr7yX5VPrDPxYcawkbKd6k\";}s:2:\"id\";s:25:\"node_make_unsticky_action\";s:5:\"label\";s:21:\"Make content unsticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"node_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_promote_action',	'a:10:{s:4:\"uuid\";s:36:\"80e483ef-5cef-449b-b6eb-338611cedfbf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N0RDBTqiK4dKoN4p4oW2j0SGWycdHyALUe9M-Ofp89U\";}s:2:\"id\";s:19:\"node_promote_action\";s:5:\"label\";s:29:\"Promote content to front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:19:\"node_promote_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_publish_action',	'a:10:{s:4:\"uuid\";s:36:\"638ab18d-e126-4bf0-934b-ca0f8e76d21a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2B9uF8NL5gutNKSdPRAhhAsDWFZZG1PJOBmx0aBGd_0\";}s:2:\"id\";s:19:\"node_publish_action\";s:5:\"label\";s:15:\"Publish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:26:\"entity:publish_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_save_action',	'a:10:{s:4:\"uuid\";s:36:\"e656d6be-7229-49e2-a65a-513fbe566776\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LhdsoZPL_pFas2fjaAWue4zvrQ_tEVofLYtcNec-JGM\";}s:2:\"id\";s:16:\"node_save_action\";s:5:\"label\";s:12:\"Save content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"entity:save_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_unpromote_action',	'a:10:{s:4:\"uuid\";s:36:\"1dc10e26-9e52-406f-aa64-78f6f7ff20b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JBptjnfuOMtsdKygklXxoOgeOCTMtQxlkymjnnj-cC0\";}s:2:\"id\";s:21:\"node_unpromote_action\";s:5:\"label\";s:30:\"Remove content from front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"node_unpromote_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_unpublish_action',	'a:10:{s:4:\"uuid\";s:36:\"12dedc3c-a189-49b8-bfa3-3925d1475a53\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C7X8h9FWlwkQ9y5mnU2JzgaZICAdc6HFbPVbhvjlAYE\";}s:2:\"id\";s:21:\"node_unpublish_action\";s:5:\"label\";s:17:\"Unpublish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:28:\"entity:unpublish_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.pathauto_update_alias_node',	'a:10:{s:4:\"uuid\";s:36:\"49be4fb0-6832-463d-8bbe-69dd46552e18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"pathauto\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lno8QThS348UX-kaUsagJtCnuPHKLXYnTQiF_9HSDWA\";}s:2:\"id\";s:26:\"pathauto_update_alias_node\";s:5:\"label\";s:16:\"Update URL alias\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"pathauto_update_alias\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.pathauto_update_alias_user',	'a:10:{s:4:\"uuid\";s:36:\"acf6f444-fa28-4103-ae56-96da6d7abcc5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"pathauto\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x_ok_ZsfA4Xk4B_hVW3O4-3PcNoK57nXLz_Dlletidg\";}s:2:\"id\";s:26:\"pathauto_update_alias_user\";s:5:\"label\";s:16:\"Update URL alias\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:21:\"pathauto_update_alias\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.redirect_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"8c900910-1bd8-48a7-abea-4493a2f89f45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vcnRZRvBqTbK3nZ2M4_lKPlEGc8GjPzgaqapYUfyX8M\";}s:2:\"id\";s:22:\"redirect_delete_action\";s:5:\"label\";s:15:\"Delete redirect\";s:4:\"type\";s:8:\"redirect\";s:6:\"plugin\";s:22:\"redirect_delete_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.taxonomy_term_publish_action',	'a:10:{s:4:\"uuid\";s:36:\"98441d8b-cb2a-44eb-863f-f500933dc072\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DoVt_VGgVLcDD4XmVbSFzr0K17SJy9imFiYusKkJBgY\";}s:2:\"id\";s:28:\"taxonomy_term_publish_action\";s:5:\"label\";s:21:\"Publish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:35:\"entity:publish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.taxonomy_term_unpublish_action',	'a:10:{s:4:\"uuid\";s:36:\"c50e2e3d-3fd4-474f-b4c3-6e9deb3aa4ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z2sNRM3ECa7FPCGnSNje_9SmZJQgwhD_6fG_L4Mr8zI\";}s:2:\"id\";s:30:\"taxonomy_term_unpublish_action\";s:5:\"label\";s:23:\"Unpublish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:37:\"entity:unpublish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.user_add_role_action.administrator',	'a:9:{s:4:\"uuid\";s:36:\"e9cdc7cd-560d-4c6e-b18d-4086edd12442\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:34:\"user_add_role_action.administrator\";s:5:\"label\";s:50:\"Add the Administrator role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),
('',	'system.action.user_block_user_action',	'a:10:{s:4:\"uuid\";s:36:\"e33d4c27-1cb5-4a82-a343-178013992c5b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DyypzTfThX10FFQw-399qPfEbLLyrhXgQrKPVsmAoJ4\";}s:2:\"id\";s:22:\"user_block_user_action\";s:5:\"label\";s:26:\"Block the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:22:\"user_block_user_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.user_cancel_user_action',	'a:10:{s:4:\"uuid\";s:36:\"47b35c2c-ef80-4dbb-9bc2-87e5467e802a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nvrL9bFilzBvm2bjO9rQnFDpBA7dBBUjShSSt6NS-DU\";}s:2:\"id\";s:23:\"user_cancel_user_action\";s:5:\"label\";s:35:\"Cancel the selected user account(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_cancel_user_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.user_remove_role_action.administrator',	'a:9:{s:4:\"uuid\";s:36:\"3a610953-8310-41e6-916e-67a38ded8605\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:37:\"user_remove_role_action.administrator\";s:5:\"label\";s:55:\"Remove the Administrator role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),
('',	'system.action.user_unblock_user_action',	'a:10:{s:4:\"uuid\";s:36:\"f372b8db-b95d-43f7-8c2b-b99a92076084\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SPsUXsR3Rc8d1y3gewzaAKWa1ncea_ywXX3f7LTn7k0\";}s:2:\"id\";s:24:\"user_unblock_user_action\";s:5:\"label\";s:28:\"Unblock the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:24:\"user_unblock_user_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_archive_action',	'a:10:{s:4:\"uuid\";s:36:\"6125548a-6827-4acb-a08b-eda4e1b25de1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OmnschvBLb9ZJn0iVyBd2odf8U8Nt0INjRbRMixZw9U\";}s:2:\"id\";s:22:\"webform_archive_action\";s:5:\"label\";s:15:\"Archive webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:22:\"webform_archive_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_close_action',	'a:10:{s:4:\"uuid\";s:36:\"9a449986-702c-4f26-a07f-3cbbae693dde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Dl-1T9PDkraB7MyMUjTJAioPEx6UNvIB9gqmnB1CRkk\";}s:2:\"id\";s:20:\"webform_close_action\";s:5:\"label\";s:13:\"Close webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:20:\"webform_close_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"d93c6987-507f-40ab-8f7a-1166f768bc12\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e1bCTp0ryXZZtnS9nlVAbtoWz3-8fmbNlqKY3GHzbsM\";}s:2:\"id\";s:21:\"webform_delete_action\";s:5:\"label\";s:14:\"Delete webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:21:\"webform_delete_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_open_action',	'a:10:{s:4:\"uuid\";s:36:\"b9252337-7eb0-41ce-b704-8142809ba069\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AK83C-dOZEPruvi6GbkuhihWLnO4VtrbesqSC6izf4o\";}s:2:\"id\";s:19:\"webform_open_action\";s:5:\"label\";s:12:\"Open webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:19:\"webform_open_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"9caf9021-aacc-4038-827b-c7fe7712e0ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBnl4vapW7sy5bRi7TcF-ueJnvz7aZNLif95ifvhfTQ\";}s:2:\"id\";s:32:\"webform_submission_delete_action\";s:5:\"label\";s:17:\"Delete submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:32:\"webform_submission_delete_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_lock_action',	'a:10:{s:4:\"uuid\";s:36:\"5e4d1084-e98f-408d-9529-89567e88b624\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MKmZlPRk3OJKNcYdYxSeZGQUh7LMah6MRShfkzch4bk\";}s:2:\"id\";s:35:\"webform_submission_make_lock_action\";s:5:\"label\";s:15:\"Lock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:35:\"webform_submission_make_lock_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_sticky_action',	'a:10:{s:4:\"uuid\";s:36:\"71eff68f-3ada-438a-93f8-5554a79cb737\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mPWBT52fKHyINRl9S3cCWFxY3rKbwkIRxaK6sIA26oo\";}s:2:\"id\";s:37:\"webform_submission_make_sticky_action\";s:5:\"label\";s:20:\"Star/flag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_unlock_action',	'a:10:{s:4:\"uuid\";s:36:\"f6b34ab3-4ded-41c8-8a32-ba4e032881fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"begZ0-RmTzO_zDAwEKA2lKvtGYw1vbFOzbQOJzUbZX0\";}s:2:\"id\";s:37:\"webform_submission_make_unlock_action\";s:5:\"label\";s:17:\"Unlock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_unlock_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_unsticky_action',	'a:10:{s:4:\"uuid\";s:36:\"326c9843-f7a5-4f11-a105-e093bfdaae75\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n4gTFiUsdp7gw6yWUlDbKFEasZLCgXWWCmm7eJejay0\";}s:2:\"id\";s:39:\"webform_submission_make_unsticky_action\";s:5:\"label\";s:24:\"Unstar/unflag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:39:\"webform_submission_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_unarchive_action',	'a:10:{s:4:\"uuid\";s:36:\"30b42137-73bc-48ad-bd3d-7b1492d2645a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aqi5Ftlnhe9KyOowpK7CanEvJMBBo8xAR1dA99bKOuc\";}s:2:\"id\";s:24:\"webform_unarchive_action\";s:5:\"label\";s:15:\"Restore webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:24:\"webform_unarchive_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.advisories',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x0FuQ_7Cg81mSDQwG028_Z0CjH3R9ib5IDlHeV2BbAo\";}s:7:\"enabled\";b:1;s:14:\"interval_hours\";i:6;}'),
('',	'system.cron',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f3yToH8v8EaBZU0NFFw2qR8ogSCuWVmQaN0hpYR1BD8\";}s:9:\"threshold\";a:2:{s:20:\"requirements_warning\";i:172800;s:18:\"requirements_error\";i:1209600;}s:7:\"logging\";b:1;}'),
('',	'system.date',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IVsFTD1mvR2NGBP_1myt9kFIFmGepH4PyaN5aQBYpno\";}s:9:\"first_day\";i:0;s:7:\"country\";a:1:{s:7:\"default\";N;}s:8:\"timezone\";a:2:{s:7:\"default\";s:15:\"Europe/Belgrade\";s:4:\"user\";a:3:{s:12:\"configurable\";b:1;s:7:\"default\";i:0;s:4:\"warn\";b:0;}}}'),
('',	'system.diff',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1WanmaEhxW_vM8_5Ktsdntj8MaO9UBHXg0lN603PsWM\";}s:7:\"context\";a:2:{s:13:\"lines_leading\";i:2;s:14:\"lines_trailing\";i:2;}}'),
('',	'system.feature_flags',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYyVj1FtPGV40Cf65YDVTUIc7YgLH6trXlotuevfs2I\";}s:16:\"linkset_endpoint\";b:0;}'),
('',	'system.file',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mguGHCYb9Dw5EcpfjwoShGV1Vjkbz3QuPRCLfxiye-g\";}s:22:\"allow_insecure_uploads\";b:0;s:14:\"default_scheme\";s:6:\"public\";s:21:\"temporary_maximum_age\";i:21600;}'),
('',	'system.image',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"durWHaKeBaq4d9Wpi4RqwADj1OufDepcnJuhVLmKN24\";}s:7:\"toolkit\";s:2:\"gd\";}'),
('',	'system.image.gd',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eNXaHfkJJUThHeF0nvkoXyPLRrKYGxgHRjORvT4F5rQ\";}s:12:\"jpeg_quality\";i:75;}'),
('',	'system.logging',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u3-njszl92FaxjrCMiq0yDcjAfcdx72w1zT1O9dx6aA\";}s:11:\"error_level\";s:4:\"hide\";}'),
('',	'system.mail',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5PvD9swkqWUeHkabdvbJ2SQqdhrzjkCT21wtD4BLfk4\";}s:9:\"interface\";a:2:{s:7:\"default\";s:8:\"php_mail\";s:7:\"webform\";s:16:\"webform_php_mail\";}s:10:\"mailer_dsn\";a:6:{s:6:\"scheme\";s:8:\"sendmail\";s:4:\"host\";s:7:\"default\";s:4:\"user\";N;s:8:\"password\";N;s:4:\"port\";N;s:7:\"options\";a:0:{}}}'),
('',	'system.maintenance',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1SNdA25INsV5YjlgAJtfC-6AM8VcWe_00xneMLb2yFg\";}s:8:\"langcode\";s:2:\"en\";s:7:\"message\";s:93:\"@site is currently under maintenance. We should be back shortly. Thank you for your patience.\";}'),
('',	'system.menu.account',	'a:9:{s:4:\"uuid\";s:36:\"c0346b12-c5cd-40d6-886c-cf0888f426ac\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Bh81osDyUQ4wV0GgU_NdBNqkzM87sLxjaCdFj9mnw\";}s:2:\"id\";s:7:\"account\";s:5:\"label\";s:17:\"User account menu\";s:11:\"description\";s:40:\"Links related to the active user account\";s:6:\"locked\";b:1;}'),
('',	'system.menu.admin',	'a:9:{s:4:\"uuid\";s:36:\"90616064-32be-41e1-baa8-be78784e75f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sapEi2YDGoI9yQIT_WgIV2vUdQ6DScH0V3fAyTadAL0\";}s:2:\"id\";s:5:\"admin\";s:5:\"label\";s:14:\"Administration\";s:11:\"description\";s:25:\"Administrative task links\";s:6:\"locked\";b:1;}'),
('',	'system.menu.footer',	'a:9:{s:4:\"uuid\";s:36:\"ba5622c9-4800-414f-8f65-c096cf34841d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7yrlW5z9zdg2eBucB2GPqXKSMQfH9lSRSO4DbWF7AFc\";}s:2:\"id\";s:6:\"footer\";s:5:\"label\";s:6:\"Footer\";s:11:\"description\";s:22:\"Site information links\";s:6:\"locked\";b:1;}'),
('',	'system.menu.main',	'a:9:{s:4:\"uuid\";s:36:\"7f6e64bf-0677-4eaf-82ae-a29df89f11b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q2Ra3jfoIVk0f3SjxJX61byRQFVBAbpzYDQOiY-kno8\";}s:2:\"id\";s:4:\"main\";s:5:\"label\";s:15:\"Main navigation\";s:11:\"description\";s:18:\"Site section links\";s:6:\"locked\";b:1;}'),
('',	'system.menu.tools',	'a:9:{s:4:\"uuid\";s:36:\"a2a145f9-0c16-431e-975e-9af61b72ef36\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCM-vV1zzRaLHN18dqAR_CuGOj8AFJvTx7BKl_8Gcxc\";}s:2:\"id\";s:5:\"tools\";s:5:\"label\";s:5:\"Tools\";s:11:\"description\";s:39:\"User tool links, often added by modules\";s:6:\"locked\";b:1;}'),
('',	'system.performance',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jtno5biznHZbrIgKwzq-ze-7XaQxLCGe6PeUOR7bRiQ\";}s:5:\"cache\";a:1:{s:4:\"page\";a:1:{s:7:\"max_age\";i:0;}}s:3:\"css\";a:2:{s:10:\"preprocess\";b:1;s:4:\"gzip\";b:1;}s:8:\"fast_404\";a:4:{s:7:\"enabled\";b:1;s:5:\"paths\";s:69:\"/\\.(?:txt|png|gif|jpe?g|css|js|ico|swf|flv|cgi|bat|pl|dll|exe|asp)$/i\";s:13:\"exclude_paths\";s:27:\"/\\/(?:styles|imagecache)\\//\";s:4:\"html\";s:162:\"<!DOCTYPE html><html><head><title>404 Not Found</title></head><body><h1>Not Found</h1><p>The requested URL \"@path\" was not found on this server.</p></body></html>\";}s:2:\"js\";a:2:{s:10:\"preprocess\";b:1;s:4:\"gzip\";b:1;}}'),
('',	'system.rss',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MIpNzlG4gPunfS7vTCwUPum6QH3GUsEBMj-qS631Jw0\";}s:5:\"items\";a:1:{s:9:\"view_mode\";s:3:\"rss\";}}'),
('',	'system.site',	'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ijfbzDTN4CbE7Sr-6ubWzy_t1vH4OtU1doNCLssVz-4\";}s:8:\"langcode\";s:2:\"en\";s:4:\"uuid\";s:36:\"81f69bca-c1ec-48e0-bfde-2d9c7e27ddda\";s:4:\"name\";s:18:\"EBT Builder Source\";s:4:\"mail\";s:17:\"admin@example.com\";s:6:\"slogan\";s:0:\"\";s:4:\"page\";a:3:{i:403;s:0:\"\";i:404;s:0:\"\";s:5:\"front\";s:5:\"/node\";}s:18:\"admin_compact_mode\";b:0;s:17:\"weight_select_max\";i:100;s:16:\"default_langcode\";s:2:\"en\";s:17:\"mail_notification\";N;}'),
('',	'system.theme',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJ529VM1gSIA_vgTy2PdiDvJuG0xhSxfQjCyl5WKlv4\";}s:5:\"admin\";s:5:\"claro\";s:7:\"default\";s:7:\"olivero\";}'),
('',	'system.theme.global',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KZiV2LB312xgJBphfq5BTjmp16xiR5KM8InBJ-pff7Y\";}s:7:\"favicon\";a:4:{s:8:\"mimetype\";s:24:\"image/vnd.microsoft.icon\";s:4:\"path\";s:0:\"\";s:3:\"url\";s:0:\"\";s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:3:{s:4:\"path\";s:0:\"\";s:3:\"url\";N;s:11:\"use_default\";b:1;}}'),
('',	'taxonomy.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zKpaWT6cJc1tVQQaTqatGELaCqU_oyRym6zTl27Yias\";}s:20:\"maintain_index_table\";b:1;s:17:\"override_selector\";b:0;s:20:\"terms_per_page_admin\";i:100;}'),
('',	'taxonomy.vocabulary.tags',	'a:10:{s:4:\"uuid\";s:36:\"bae62ed0-d39a-4ca0-a737-86bf6ae374a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iTEzwrEQ_4JIb-OYGiqzyF2TmMgWyWayresXcWgwGWM\";}s:4:\"name\";s:4:\"Tags\";s:3:\"vid\";s:4:\"tags\";s:11:\"description\";s:61:\"Use tags to group articles on similar topics into categories.\";s:6:\"weight\";i:0;s:12:\"new_revision\";b:0;}'),
('',	'text.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Bkewb77RBOK3_aXMPsp8p87gbc03NvmC5gBLzPl7hVA\";}s:22:\"default_summary_length\";i:600;}'),
('',	'update.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xbYr66-g0FjNgVBkGypCuN46vBI2XHntXN1URawq1s4\";}s:5:\"check\";a:2:{s:19:\"disabled_extensions\";b:0;s:13:\"interval_days\";i:1;}s:5:\"fetch\";a:3:{s:3:\"url\";N;s:12:\"max_attempts\";i:2;s:7:\"timeout\";i:30;}s:12:\"notification\";a:2:{s:6:\"emails\";a:1:{i:0;s:17:\"admin@example.com\";}s:9:\"threshold\";s:3:\"all\";}}'),
('',	'user.flood',	'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UYfMzeP1S8jKm9PSvxf7nQNe8DsNS-3bc2WSNNXBQWs\";}s:8:\"uid_only\";b:0;s:8:\"ip_limit\";i:50;s:9:\"ip_window\";i:3600;s:10:\"user_limit\";i:5;s:11:\"user_window\";i:21600;}'),
('',	'user.mail',	'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6CZIzFifRq3qbdq3n3nDpEOO4hWIQtKOAQNPvGNGKeM\";}s:8:\"langcode\";s:2:\"en\";s:14:\"cancel_confirm\";a:2:{s:7:\"subject\";s:67:\"Account cancellation request for [user:display-name] at [site:name]\";s:4:\"body\";s:376:\"[user:display-name]\n\nA request to cancel your account has been made at [site:name].\n\nYou may now cancel your account on [site:url-brief] by clicking this link or copying and pasting it into your browser:\n\n[user:cancel-url]\n\nNOTE: The cancellation of your account is not reversible.\n\nThis link expires in one day and nothing will happen if it is not used.\n\n--  [site:name] team\";}s:14:\"password_reset\";a:2:{s:7:\"subject\";s:68:\"Replacement login information for [user:display-name] at [site:name]\";s:4:\"body\";s:407:\"[user:display-name],\n\nA request to reset the password for your account has been made at [site:name].\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password. It expires after one day and nothing will happen if it\'s not used.\n\n--  [site:name] team\";}s:22:\"register_admin_created\";a:2:{s:7:\"subject\";s:58:\"An administrator created an account for you at [site:name]\";s:4:\"body\";s:473:\"[user:display-name],\n\nA site administrator at [site:name] has created an account for you. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:29:\"register_no_approval_required\";a:2:{s:7:\"subject\";s:54:\"Account details for [user:display-name] at [site:name]\";s:4:\"body\";s:447:\"[user:display-name],\n\nThank you for registering at [site:name]. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:25:\"register_pending_approval\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:288:\"[user:display-name],\n\nThank you for registering at [site:name]. Your application for an account is currently pending approval. Once it has been approved, you will receive another email containing information about how to log in, set your password, and other details.\n\n--  [site:name] team\";}s:31:\"register_pending_approval_admin\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:64:\"[user:display-name] has applied for an account.\n\n[user:edit-url]\";}s:16:\"status_activated\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (approved)\";s:4:\"body\";s:462:\"[user:display-name],\n\nYour account at [site:name] has been activated.\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:account-name]\npassword: Your password\n\n--  [site:name] team\";}s:14:\"status_blocked\";a:2:{s:7:\"subject\";s:64:\"Account details for [user:display-name] at [site:name] (blocked)\";s:4:\"body\";s:89:\"[user:display-name],\n\nYour account on [site:name] has been blocked.\n\n--  [site:name] team\";}s:15:\"status_canceled\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (canceled)\";s:4:\"body\";s:90:\"[user:display-name],\n\nYour account on [site:name] has been canceled.\n\n--  [site:name] team\";}}'),
('',	'user.role.administrator',	'a:10:{s:4:\"uuid\";s:36:\"55c650b9-b5a7-4ff4-bc0f-f89243b36175\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OeKGIkmZA_c-t6QLH81WNQx8gDCc1MRmxaTuQgxBByU\";}s:2:\"id\";s:13:\"administrator\";s:5:\"label\";s:13:\"Administrator\";s:6:\"weight\";i:3;s:8:\"is_admin\";b:1;s:11:\"permissions\";a:0:{}}'),
('',	'user.role.anonymous',	'a:10:{s:4:\"uuid\";s:36:\"8ae6303e-51a9-461e-9cd1-3548f02fd2f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.restricted_html\";}s:6:\"module\";a:5:{i:0;s:7:\"contact\";i:1;s:6:\"filter\";i:2;s:5:\"media\";i:3;s:6:\"search\";i:4;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6WavjUYXIegP9AAg2zXGx54MWIVoomC3SZhNiqe-Dyk\";}s:2:\"id\";s:9:\"anonymous\";s:5:\"label\";s:14:\"Anonymous user\";s:6:\"weight\";i:0;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:5:{i:0;s:14:\"access content\";i:1;s:29:\"access site-wide contact form\";i:2;s:14:\"search content\";i:3;s:31:\"use text format restricted_html\";i:4;s:10:\"view media\";}}'),
('',	'user.role.authenticated',	'a:10:{s:4:\"uuid\";s:36:\"a817234d-3eaa-4c9f-a2ec-0f6cada70063\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"filter.format.basic_html\";i:1;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:8:{i:0;s:7:\"contact\";i:1;s:4:\"file\";i:2;s:6:\"filter\";i:3;s:16:\"google_analytics\";i:4;s:5:\"media\";i:5;s:6:\"search\";i:6;s:8:\"shortcut\";i:7;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFrlqjtkTfvY3RGccjJkPf1SGIfJ942IrxTLWAO4mgA\";}s:2:\"id\";s:13:\"authenticated\";s:5:\"label\";s:18:\"Authenticated user\";s:6:\"weight\";i:1;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:9:{i:0;s:14:\"access content\";i:1;s:16:\"access shortcuts\";i:2;s:29:\"access site-wide contact form\";i:3;s:16:\"delete own files\";i:4;s:42:\"opt-in or out of google analytics tracking\";i:5;s:14:\"search content\";i:6;s:26:\"use text format basic_html\";i:7;s:31:\"use text format webform_default\";i:8;s:10:\"view media\";}}'),
('',	'user.role.content_editor',	'a:10:{s:4:\"uuid\";s:36:\"d6e980dc-d5d4-42cf-8308-888d9c255fa0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:17:\"node.type.article\";i:1;s:14:\"node.type.page\";i:2;s:24:\"taxonomy.vocabulary.tags\";}s:6:\"module\";a:7:{i:0;s:10:\"contextual\";i:1;s:4:\"file\";i:2;s:4:\"node\";i:3;s:4:\"path\";i:4;s:6:\"system\";i:5;s:8:\"taxonomy\";i:6;s:7:\"toolbar\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e_wG1u7SrGaJbY2-Szgbgl-c8T3kdirU3uTNq2c_QJQ\";}s:2:\"id\";s:14:\"content_editor\";s:5:\"label\";s:14:\"Content editor\";s:6:\"weight\";i:2;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:22:{i:0;s:27:\"access administration pages\";i:1;s:23:\"access content overview\";i:2;s:23:\"access contextual links\";i:3;s:21:\"access files overview\";i:4;s:14:\"access toolbar\";i:5;s:22:\"administer url aliases\";i:6;s:22:\"create article content\";i:7;s:19:\"create page content\";i:8;s:20:\"create terms in tags\";i:9;s:18:\"create url aliases\";i:10;s:24:\"delete article revisions\";i:11;s:26:\"delete own article content\";i:12;s:16:\"delete own files\";i:13;s:23:\"delete own page content\";i:14;s:21:\"delete page revisions\";i:15;s:24:\"edit own article content\";i:16;s:21:\"edit own page content\";i:17;s:18:\"edit terms in tags\";i:18;s:20:\"revert all revisions\";i:19;s:18:\"view all revisions\";i:20;s:28:\"view own unpublished content\";i:21;s:29:\"view the administration theme\";}}'),
('',	'user.settings',	'a:9:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-htDFWUv1S4OlJMzta2nhFl4QbhJvu0D9xsJ-clxo-M\";}s:8:\"langcode\";s:2:\"en\";s:9:\"anonymous\";s:9:\"Anonymous\";s:11:\"verify_mail\";b:1;s:6:\"notify\";a:8:{s:14:\"cancel_confirm\";b:1;s:14:\"password_reset\";b:1;s:16:\"status_activated\";b:1;s:14:\"status_blocked\";b:0;s:15:\"status_canceled\";b:0;s:22:\"register_admin_created\";b:1;s:29:\"register_no_approval_required\";b:1;s:25:\"register_pending_approval\";b:1;}s:8:\"register\";s:23:\"visitors_admin_approval\";s:13:\"cancel_method\";s:17:\"user_cancel_block\";s:22:\"password_reset_timeout\";i:86400;s:17:\"password_strength\";b:1;}'),
('',	'views.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8oDr9oPVb_ostrNnVV6V7VdphwoH_u-NqTS0u7SE7qc\";}s:17:\"display_extenders\";a:0:{}s:13:\"sql_signature\";b:0;s:2:\"ui\";a:3:{s:4:\"show\";a:7:{s:18:\"additional_queries\";b:0;s:15:\"advanced_column\";b:0;s:15:\"default_display\";b:0;s:22:\"performance_statistics\";b:0;s:19:\"preview_information\";b:1;s:9:\"sql_query\";a:2:{s:7:\"enabled\";b:0;s:5:\"where\";s:5:\"above\";}s:13:\"display_embed\";b:0;}s:19:\"always_live_preview\";b:1;s:24:\"exposed_filter_any_label\";s:7:\"old_any\";}s:22:\"field_rewrite_elements\";a:29:{s:3:\"div\";s:3:\"DIV\";s:4:\"span\";s:4:\"SPAN\";s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";s:2:\"h6\";s:2:\"H6\";s:1:\"p\";s:1:\"P\";s:6:\"header\";s:6:\"HEADER\";s:6:\"footer\";s:6:\"FOOTER\";s:7:\"article\";s:7:\"ARTICLE\";s:7:\"section\";s:7:\"SECTION\";s:5:\"aside\";s:5:\"ASIDE\";s:7:\"details\";s:7:\"DETAILS\";s:10:\"blockquote\";s:10:\"BLOCKQUOTE\";s:6:\"figure\";s:6:\"FIGURE\";s:7:\"address\";s:7:\"ADDRESS\";s:4:\"code\";s:4:\"CODE\";s:3:\"pre\";s:3:\"PRE\";s:3:\"var\";s:3:\"VAR\";s:4:\"samp\";s:4:\"SAMP\";s:3:\"kbd\";s:3:\"KBD\";s:6:\"strong\";s:6:\"STRONG\";s:2:\"em\";s:2:\"EM\";s:3:\"del\";s:3:\"DEL\";s:3:\"ins\";s:3:\"INS\";s:1:\"q\";s:1:\"Q\";s:1:\"s\";s:1:\"S\";}}'),
('',	'views.view.archive',	'a:13:{s:4:\"uuid\";s:36:\"869573d7-3210-47a6-a85b-2b4f70595558\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"exIF08PTvYSK6tJCsAzBqMEKUBKIptPorMn74SVhevc\";}s:2:\"id\";s:7:\"archive\";s:5:\"label\";s:7:\"Archive\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:22:\"All content, by month.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:15:\"Monthly archive\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:2:{s:8:\"override\";b:1;s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:2:{s:10:\"sort_order\";s:4:\"desc\";s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:0;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:1:{s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"archive\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.block_content',	'a:13:{s:4:\"uuid\";s:36:\"2b2425c7-ad13-4164-afc2-8d66592f2a30\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HfvTcWhiVuvxchoh4DjIkXhKkj9ow2TGgHkLHSvRLq8\";}s:2:\"id\";s:13:\"block_content\";s:5:\"label\";s:14:\"Content blocks\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:31:\"Find and manage content blocks.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:24:\"block_content_field_data\";s:10:\"base_field\";s:2:\"id\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:14:\"Content blocks\";s:6:\"fields\";a:4:{s:4:\"info\";a:37:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";N;s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:17:\"Block description\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Block type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access block library\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:2:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:38:\"There are no content blocks available.\";s:8:\"tokenize\";b:0;}s:27:\"block_content_listing_empty\";a:10:{s:2:\"id\";s:27:\"block_content_listing_empty\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:27:\"block_content_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:27:\"block_content_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:4:\"info\";a:16:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"info_op\";s:5:\"label\";s:17:\"Block description\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"info_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"info\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:10:\"Block type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"reusable\";a:16:{s:2:\"id\";s:8:\"reusable\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:8:\"reusable\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:8:\"reusable\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:4:\"info\";s:4:\"info\";s:4:\"type\";s:4:\"type\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:4:{s:4:\"info\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/block\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:6:\"Blocks\";s:11:\"description\";s:31:\"Create and edit content blocks.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:20:\"system.admin_content\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.content',	'a:13:{s:4:\"uuid\";s:36:\"53b483f4-38d1-4359-99b2-b24e9f23a505\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"whBYBAcXQuQblGEdvQ9QfGuuW3zC49F2-5vXSm1slFM\";}s:2:\"id\";s:7:\"content\";s:5:\"label\";s:7:\"Content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:24:\"Find and manage content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:7:\"Content\";s:6:\"fields\";a:8:{s:14:\"node_bulk_form\";a:14:{s:2:\"id\";s:14:\"node_bulk_form\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:14:\"node_bulk_form\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:14:\"node_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"title\";a:17:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Content type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:17:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:17:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}}s:7:\"changed\";a:17:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:8:\"langcode\";a:37:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Language\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:8:\"language\";s:8:\"settings\";a:2:{s:14:\"link_to_entity\";b:0;s:15:\"native_language\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:23:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:3:{s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:23:\"access content overview\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:5:\"title\";a:16:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:8:\"title_op\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:8:\"title_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:5:\"title\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:12:\"Content type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:12:\"status_extra\";a:9:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:6:\"expose\";a:2:{s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:10:{s:14:\"node_bulk_form\";s:14:\"node_bulk_form\";s:5:\"title\";s:5:\"title\";s:4:\"type\";s:4:\"type\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:7:\"changed\";s:7:\"changed\";s:9:\"edit_node\";s:9:\"edit_node\";s:11:\"delete_node\";s:11:\"delete_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";s:9:\"timestamp\";s:5:\"title\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:10:{s:14:\"node_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"title\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"delete_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:18:\"admin/content/node\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:23:\"Find and manage content\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.content_recent',	'a:13:{s:4:\"uuid\";s:36:\"0aadfe89-23e4-4ec3-a50a-3c76c79be76a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YqZN5rc7XDQcFcInc8wkzuaHJmC5YvirhTmDcrarT6M\";}s:2:\"id\";s:14:\"content_recent\";s:5:\"label\";s:14:\"Recent content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:15:\"Recent content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:22:{s:5:\"title\";s:14:\"Recent content\";s:6:\"fields\";a:2:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"More\";s:12:\"link_display\";s:1:\"0\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:1:{s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.files',	'a:13:{s:4:\"uuid\";s:36:\"534a8e69-2ee4-4c66-98d4-040cedf2dcd1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"blP1XdpU4RqVoA_8po7qnIokIbHB6DJt0lpilgY5ovM\";}s:2:\"id\";s:5:\"files\";s:5:\"label\";s:5:\"Files\";s:6:\"module\";s:4:\"file\";s:11:\"description\";s:22:\"Find and manage files.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:12:\"file_managed\";s:10:\"base_field\";s:3:\"fid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:5:\"Files\";s:6:\"fields\";a:9:{s:3:\"fid\";a:24:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:3:\"Fid\";s:7:\"exclude\";b:1;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"filename\";a:36:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"file_link\";s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:8:\"filemime\";a:25:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"MIME type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"file_filemime\";}s:8:\"filesize\";a:25:{s:2:\"id\";s:8:\"filesize\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filesize\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filesize\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Size\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"file_size\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:9:\"Temporary\";s:18:\"format_custom_true\";s:9:\"Permanent\";}}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Upload date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Changed date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:3:\"fid\";s:10:\"group_type\";s:3:\"sum\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:7:\"Used in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/content/files/usage/{{ fid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:1;s:20:\"format_plural_string\";s:21:\"1 place@count places\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access files overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No files available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:8:\"filename\";a:16:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:8:\"Filename\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filename_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filename\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"filemime\";a:16:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:9:\"MIME type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filemime_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filemime\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:11:\"file_status\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"status_op\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:3:\"fid\";s:3:\"fid\";s:8:\"filename\";s:8:\"filename\";s:8:\"filemime\";s:8:\"filemime\";s:8:\"filesize\";s:8:\"filesize\";s:6:\"status\";s:6:\"status\";s:7:\"created\";s:7:\"created\";s:7:\"changed\";s:7:\"changed\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:8:{s:3:\"fid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filename\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filemime\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:8:\"filesize\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:1;s:16:\"show_admin_links\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:14:\"Files overview\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:2:{s:5:\"pager\";b:1;s:13:\"relationships\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:0;}}s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/files\";s:4:\"menu\";a:6:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Files\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_2\";a:6:{s:2:\"id\";s:6:\"page_2\";s:13:\"display_title\";s:10:\"File usage\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:15:{s:5:\"title\";s:10:\"File usage\";s:6:\"fields\";a:4:{s:12:\"entity_label\";a:23:{s:2:\"id\";s:12:\"entity_label\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:12:\"entity_label\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"entity_label\";s:5:\"label\";s:6:\"Entity\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:14:\"link_to_entity\";b:1;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:11:\"Entity type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:6:\"module\";a:22:{s:2:\"id\";s:6:\"module\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:6:\"module\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:18:\"Registering module\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:9:\"Use count\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:0;s:20:\"format_plural_string\";s:8:\"1@count\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:5:\"empty\";a:0:{}s:9:\"arguments\";a:1:{s:3:\"fid\";a:22:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:8:\"file_fid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:46:\"File usage information for {{ arguments.fid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;}}s:7:\"filters\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:12:\"entity_label\";s:12:\"entity_label\";s:4:\"type\";s:4:\"type\";s:6:\"module\";s:6:\"module\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:12:\"entity_label\";s:4:\"info\";a:4:{s:12:\"entity_label\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:6:\"module\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:11:{s:5:\"empty\";b:0;s:5:\"title\";b:0;s:5:\"pager\";b:0;s:8:\"group_by\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:13:\"relationships\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:0;s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:27:\"admin/content/files/usage/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.frontpage',	'a:13:{s:4:\"uuid\";s:36:\"697fbe61-72f2-4f36-9ef0-93f40a5476d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OEEnRQIjfIaCFRsz8U3VqDrE82ltQKlo8wNbQJRZXu0\";}s:2:\"id\";s:9:\"frontpage\";s:5:\"label\";s:9:\"Frontpage\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:39:\"All content promoted to the front page.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:0:\"\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:3:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:181:\"No front page content has been created yet.<br/>Follow the <a target=\"_blank\" href=\"https://www.drupal.org/docs/user_guide/en/index.html\">User Guide</a> to start building your site.\";s:8:\"tokenize\";b:0;}s:18:\"node_listing_empty\";a:10:{s:2:\"id\";s:18:\"node_listing_empty\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:18:\"node_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:18:\"node_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}s:5:\"title\";a:10:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"title\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:5:\"title\";s:8:\"Welcome!\";}}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:12:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:7:\"promote\";a:16:{s:2:\"id\";s:7:\"promote\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"promote\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"promote\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:3:\"rss\";}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"rss.xml\";s:14:\"sitename_title\";b:1;s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:28:\"languages:language_interface\";i:1;s:21:\"user.node_grants:view\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:4:\"node\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.glossary',	'a:13:{s:4:\"uuid\";s:36:\"4b34ee05-e652-40b7-8ec4-c522b22c6013\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r-klgGeO4haVHqAwxW1HXZLzdzLSMUVC08OuTBrRh58\";}s:2:\"id\";s:8:\"glossary\";s:5:\"label\";s:8:\"Glossary\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:23:\"All content, by letter.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:6:\"fields\";a:3:{s:5:\"title\";a:24:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:36;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"default\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:0:{}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;s:7:\"columns\";a:3:{s:5:\"title\";s:5:\"title\";s:4:\"name\";s:4:\"name\";s:7:\"changed\";s:7:\"changed\";}s:7:\"default\";s:5:\"title\";s:4:\"info\";a:3:{s:5:\"title\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:4:\"name\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:7:\"changed\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:5:\"order\";s:3:\"asc\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"attachment_1\";a:6:{s:2:\"id\";s:12:\"attachment_1\";s:13:\"display_title\";s:10:\"Attachment\";s:14:\"display_plugin\";s:10:\"attachment\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:0;}}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:3:{s:14:\"items_per_page\";i:25;s:6:\"inline\";b:1;s:9:\"separator\";s:3:\" | \";}s:7:\"summary\";a:1:{s:6:\"format\";s:19:\"unformatted_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}s:8:\"displays\";a:2:{s:7:\"default\";s:7:\"default\";s:6:\"page_1\";s:6:\"page_1\";}s:17:\"inherit_arguments\";b:0;}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:8:\"glossary\";s:4:\"menu\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:8:\"Glossary\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.media',	'a:13:{s:4:\"uuid\";s:36:\"36a349da-87e8-43e4-89c5-350096634510\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kOTUk5XWeupgBOJuRRarCiDcFKVZcvaW-FT5MTzrML8\";}s:2:\"id\";s:5:\"media\";s:5:\"label\";s:5:\"Media\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:8:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:20:\"thumbnail__target_id\";a:37:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:9:\"thumbnail\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:5:\"media\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Media name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"bundle\";a:37:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"status\";a:37:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:10:\"Media name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:4:\"True\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:4:\"name\";s:4:\"name\";s:6:\"bundle\";s:6:\"bundle\";s:7:\"changed\";s:7:\"changed\";s:3:\"uid\";s:3:\"uid\";s:6:\"status\";s:6:\"status\";s:20:\"thumbnail__target_id\";s:20:\"thumbnail__target_id\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"bundle\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:15:\"media_page_list\";a:6:{s:2:\"id\";s:15:\"media_page_list\";s:13:\"display_title\";s:5:\"Media\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/media\";s:4:\"menu\";a:8:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Media\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.media_library',	'a:13:{s:4:\"uuid\";s:36:\"bc9a8070-9681-4b94-8d52-549af33d0dbe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:25:\"image.style.media_library\";}s:6:\"module\";a:4:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:13:\"media_library\";i:3;s:4:\"user\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9u9hwW-Q0-uQJz1vgenJTQhZGYN0FBZoOogwPD6kgkQ\";}s:2:\"id\";s:13:\"media_library\";s:5:\"label\";s:13:\"Media library\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:4:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:2:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:24;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"6, 12, 24, 48\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:13:\"Apply filters\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:3:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:12:\"Newest first\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:1;s:11:\"granularity\";s:6:\"second\";}s:4:\"name\";a:12:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:3:\"ASC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (A-Z)\";s:16:\"field_identifier\";s:4:\"name\";}s:7:\"exposed\";b:1;}s:6:\"name_1\";a:12:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (Z-A)\";s:16:\"field_identifier\";s:6:\"name_1\";}s:7:\"exposed\";b:1;}}s:7:\"filters\";a:5:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:17:\"Publishing status\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:9:\"Published\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:10:\"Media type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:10:\"Media type\";s:11:\"description\";N;s:10:\"identifier\";s:6:\"bundle\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:3:{i:1;a:0:{}i:2;a:0:{}i:3;a:0:{}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:6:\"fields\";a:5:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"edit_media\";a:26:{s:2:\"id\";s:10:\"edit_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"edit_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:15:\"Edit {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:15:\"Edit {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"Edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:12:\"delete_media\";a:26:{s:2:\"id\";s:12:\"delete_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:12:\"delete_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:18:\"entity_link_delete\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:17:\"Delete {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:17:\"Delete {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:6:\"Delete\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:8:\"defaults\";a:1:{s:6:\"fields\";b:0;}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:24:\"admin/content/media-grid\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:22:\"url.query_args:sort_by\";i:5;s:4:\"user\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"widget\";a:6:{s:2:\"id\";s:6:\"widget\";s:13:\"display_title\";s:6:\"Widget\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:12:{s:6:\"fields\";a:2:{s:25:\"media_library_select_form\";a:23:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:7:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:19:\"display_description\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:26:\"admin/content/media-widget\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"widget_table\";a:6:{s:2:\"id\";s:12:\"widget_table\";s:13:\"display_title\";s:14:\"Widget (table)\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:3;s:15:\"display_options\";a:13:{s:6:\"fields\";a:5:{s:25:\"media_library_select_form\";a:9:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:10:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:13:\"media_library\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}}s:4:\"name\";a:10:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}}s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:20:\"media_field_revision\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}}s:7:\"changed\";a:10:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:2:{s:9:\"row_class\";s:85:\"media-library-item media-library-item--table js-media-library-item js-click-to-select\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:8:\"defaults\";a:9:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:32:\"admin/content/media-widget-table\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.redirect',	'a:13:{s:4:\"uuid\";s:36:\"cb66f7a4-4661-4051-8a2d-40c096d4f55d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:8:\"redirect\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I9VqfbwK5ZyKzL7810d0fswaadU6riFT3kPL0yxcpLs\";}s:2:\"id\";s:8:\"redirect\";s:5:\"label\";s:8:\"Redirect\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:17:\"List of redirects\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"redirect\";s:10:\"base_field\";s:3:\"rid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"administer redirects\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:14:\"items_per_page\";i:50;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:12:\"‹ previous\";s:4:\"next\";s:8:\"next ›\";s:5:\"first\";s:8:\"« first\";s:4:\"last\";s:7:\"last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;s:24:\"pagination_heading_level\";s:2:\"h4\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:6:{s:21:\"redirect_source__path\";s:21:\"redirect_source__path\";s:22:\"redirect_redirect__uri\";s:22:\"redirect_redirect__uri\";s:11:\"status_code\";s:11:\"status_code\";s:8:\"language\";s:8:\"language\";s:7:\"created\";s:7:\"created\";s:10:\"operations\";s:10:\"operations\";}s:4:\"info\";a:6:{s:21:\"redirect_source__path\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:22:\"redirect_redirect__uri\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"status_code\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"language\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:6:\"fields\";a:7:{s:18:\"redirect_bulk_form\";a:26:{s:2:\"id\";s:18:\"redirect_bulk_form\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:18:\"redirect_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:14:\"With selection\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:8:\"redirect\";s:9:\"plugin_id\";s:18:\"redirect_bulk_form\";}s:21:\"redirect_source__path\";a:37:{s:2:\"id\";s:21:\"redirect_source__path\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:21:\"redirect_source__path\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:4:\"From\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:4:\"path\";s:4:\"type\";s:15:\"redirect_source\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:15:\"redirect_source\";s:9:\"plugin_id\";s:5:\"field\";}s:22:\"redirect_redirect__uri\";a:6:{s:2:\"id\";s:22:\"redirect_redirect__uri\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:22:\"redirect_redirect__uri\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:17:\"redirect_redirect\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"status_code\";a:6:{s:2:\"id\";s:11:\"status_code\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:11:\"status_code\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:11:\"status_code\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"language\";a:6:{s:2:\"id\";s:8:\"language\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:8:\"language\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:8:\"language\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:27:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:8:\"fallback\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";}s:10:\"operations\";a:5:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:10:\"operations\";s:11:\"entity_type\";s:8:\"redirect\";s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:4:{s:21:\"redirect_source__path\";a:16:{s:2:\"id\";s:21:\"redirect_source__path\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:21:\"redirect_source__path\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:24:\"redirect_source__path_op\";s:5:\"label\";s:4:\"From\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:24:\"redirect_source__path_op\";s:10:\"identifier\";s:21:\"redirect_source__path\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:15:\"redirect_source\";s:9:\"plugin_id\";s:6:\"string\";}s:22:\"redirect_redirect__uri\";a:16:{s:2:\"id\";s:22:\"redirect_redirect__uri\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:22:\"redirect_redirect__uri\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:25:\"redirect_redirect__uri_op\";s:5:\"label\";s:2:\"To\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:25:\"redirect_redirect__uri_op\";s:10:\"identifier\";s:22:\"redirect_redirect__uri\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:17:\"redirect_redirect\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"status_code\";a:16:{s:2:\"id\";s:11:\"status_code\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:11:\"status_code\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:0:\"\";}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:14:\"status_code_op\";s:5:\"label\";s:11:\"Status code\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:14:\"status_code_op\";s:10:\"identifier\";s:11:\"status_code\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:11:\"Status code\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:11:\"status_code\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:7:{i:1;a:3:{s:5:\"title\";s:20:\"300 Multiple Choices\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"300\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:2;a:3:{s:5:\"title\";s:21:\"301 Moved Permanently\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"301\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:3;a:3:{s:5:\"title\";s:9:\"302 Found\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"302\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:4;a:3:{s:5:\"title\";s:13:\"303 See Other\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"303\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:5;a:3:{s:5:\"title\";s:16:\"304 Not Modified\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"304\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:6;a:3:{s:5:\"title\";s:13:\"305 Use Proxy\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"305\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:7;a:3:{s:5:\"title\";s:22:\"307 Temporary Redirect\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"307\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:11:\"status_code\";s:9:\"plugin_id\";s:7:\"numeric\";}s:8:\"language\";a:16:{s:2:\"id\";s:8:\"language\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:8:\"language\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"language_op\";s:5:\"label\";s:17:\"Original language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"language_op\";s:10:\"identifier\";s:8:\"language\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:8:\"language\";s:9:\"plugin_id\";s:8:\"language\";}}s:5:\"sorts\";a:0:{}s:5:\"title\";s:8:\"Redirect\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"There is no redirect yet.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:0:{}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:4:{s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:9:\"cacheable\";b:0;s:7:\"max-age\";i:0;s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:14:\"display_plugin\";s:4:\"page\";s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:28:\"admin/config/search/redirect\";}s:14:\"cache_metadata\";a:4:{s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:9:\"cacheable\";b:0;s:7:\"max-age\";i:0;s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.taxonomy_term',	'a:13:{s:4:\"uuid\";s:36:\"d74333b1-feb4-4d77-9bb9-7230d2bc1f92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:3:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KejdxDJQmx8SaO-t83OVekLw6ar4ldjmsJMGcotGxnQ\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:6:\"module\";s:8:\"taxonomy\";s:11:\"description\";s:45:\"Content belonging to a certain taxonomy term.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:10:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:11:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:3:\"tid\";a:22:{s:2:\"id\";s:3:\"tid\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:3:\"tid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:18:\"taxonomy_index_tid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:0:\"\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:19:\"{{ arguments.tid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:4:{s:7:\"bundles\";a:0:{}s:6:\"access\";b:1;s:9:\"operation\";s:4:\"view\";s:8:\"multiple\";i:0;}s:12:\"break_phrase\";b:0;s:9:\"add_table\";b:0;s:13:\"require_value\";b:0;s:17:\"reduce_duplicates\";b:0;}}s:7:\"filters\";a:2:{s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:14:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:1:{s:20:\"entity_taxonomy_term\";a:12:{s:2:\"id\";s:20:\"entity_taxonomy_term\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:20:\"entity_taxonomy_term\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"entity\";s:5:\"empty\";b:1;s:6:\"target\";s:23:\"{{ raw_arguments.tid }}\";s:9:\"view_mode\";s:4:\"full\";s:8:\"tokenize\";b:1;s:13:\"bypass_access\";b:0;}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:7:\"default\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:20:\"taxonomy/term/%/feed\";s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:15:\"taxonomy/term/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.user_admin_people',	'a:13:{s:4:\"uuid\";s:36:\"dd75f214-13a9-43b5-af70-9953d491803c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FFLg74mnzRE10lgg5fspPCZWLnIEcvCnJMlNzj8OEtw\";}s:2:\"id\";s:17:\"user_admin_people\";s:5:\"label\";s:6:\"People\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:25:{s:5:\"title\";s:6:\"People\";s:6:\"fields\";a:8:{s:14:\"user_bulk_form\";a:23:{s:2:\"id\";s:14:\"user_bulk_form\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:14:\"user_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:14:\"user_bulk_form\";s:5:\"label\";s:11:\"Bulk update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Username\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:7:\"Blocked\";s:18:\"format_custom_true\";s:6:\"Active\";}}s:15:\"roles_target_id\";a:24:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:5:\"label\";s:5:\"Roles\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:2:\"ul\";s:9:\"separator\";s:2:\", \";}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Member for\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:9:\"@interval\";s:11:\"past_format\";s:9:\"@interval\";s:11:\"granularity\";i:2;}}s:6:\"access\";a:26:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last access\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:4:\"mail\";a:37:{s:2:\"id\";s:4:\"mail\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"mail\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"mail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"basic_string\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:16:\"administer users\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:20:\"No people available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:7:\"filters\";a:6:{s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:22:\"Name or email contains\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"user\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:4:\"mail\";s:4:\"mail\";}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:6:\"Active\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:7:\"Blocked\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:15:\"roles_target_id\";a:15:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:18:\"roles_target_id_op\";s:5:\"label\";s:4:\"Role\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:18:\"roles_target_id_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"role\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:10:\"permission\";a:15:{s:2:\"id\";s:10:\"permission\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:10:\"permission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"user_permissions\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:13:\"permission_op\";s:5:\"label\";s:10:\"Permission\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:13:\"permission_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:10:\"permission\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"uid_raw\";a:15:{s:2:\"id\";s:7:\"uid_raw\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"uid_raw\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:7:\"numeric\";s:8:\"operator\";s:2:\"!=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:1:\"0\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:10:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:14:\"user_bulk_form\";s:14:\"user_bulk_form\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:3:\"rid\";s:3:\"rid\";s:7:\"created\";s:7:\"created\";s:6:\"access\";s:6:\"access\";s:9:\"edit_node\";s:9:\"edit_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";}s:7:\"default\";s:7:\"created\";s:4:\"info\";a:8:{s:14:\"user_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:3:\"rid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"access\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"more\";s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:15:\"display_comment\";s:0:\"\";s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:1:{s:16:\"show_admin_links\";b:0;}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:17:\"admin/people/list\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:4:\"List\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:6:\"People\";s:11:\"description\";s:45:\"Manage user accounts, roles, and permissions.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.watchdog',	'a:13:{s:4:\"uuid\";s:36:\"1d71a232-99d5-4253-868e-76836877a513\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"dblog\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SR5P89f0vUTPC7WY2YpLAffkDx8-Ar8LKFfowVXeqNU\";}s:2:\"id\";s:8:\"watchdog\";s:5:\"label\";s:8:\"Watchdog\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:19:\"Recent log messages\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"watchdog\";s:10:\"base_field\";s:3:\"wid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:19:\"Recent log messages\";s:6:\"fields\";a:8:{s:7:\"nothing\";a:22:{s:2:\"id\";s:7:\"nothing\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"nothing\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"Icon\";s:9:\"plugin_id\";s:6:\"custom\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:4:\"icon\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:0;}s:3:\"wid\";a:22:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:3:\"WID\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"severity\";a:23:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"machine_name\";s:5:\"label\";s:8:\"Severity\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"machine_name\";b:0;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:9:\"timestamp\";a:25:{s:2:\"id\";s:9:\"timestamp\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:9:\"timestamp\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"label\";s:4:\"Date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:7:\"message\";a:23:{s:2:\"id\";s:7:\"message\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:7:\"message\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:13:\"dblog_message\";s:5:\"label\";s:7:\"Message\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/reports/dblog/event/{{ wid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:13:\"{{ message }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:56;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:1;s:4:\"trim\";b:1;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:1;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"replace_variables\";b:1;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"User\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"link\";a:22:{s:2:\"id\";s:4:\"link\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"link\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"dblog_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"access site reports\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:4:\"area\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:26:\"No log messages available.\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:26:\"No log messages available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:3:\"wid\";a:10:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"wid\";}s:7:\"exposed\";b:0;}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:4:\"type\";a:14:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"dblog_types\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"severity\";a:14:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"in_operator\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"severity_op\";s:5:\"label\";s:8:\"Severity\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"severity_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"severity\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:25:\"{{ type }} {{ severity }}\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:7:\"nothing\";s:7:\"nothing\";s:3:\"wid\";s:3:\"wid\";s:8:\"severity\";s:8:\"severity\";s:4:\"type\";s:4:\"type\";s:9:\"timestamp\";s:9:\"timestamp\";s:7:\"message\";s:7:\"message\";s:4:\"name\";s:4:\"name\";s:4:\"link\";s:4:\"link\";}s:7:\"default\";s:3:\"wid\";s:4:\"info\";a:8:{s:7:\"nothing\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:3:\"wid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:8:\"severity\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"message\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:4:\"link\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:0;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"User\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:11:\"admin-dblog\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/reports/dblog\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.webform_submissions',	'a:13:{s:4:\"uuid\";s:36:\"5c298710-8d19-4662-a5cc-dcd249b03b1d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"user\";i:1;s:7:\"webform\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ndr5pjyhumlySBPBZtyaztiGbMUclmN32B3nTQ-FRqE\";}s:2:\"id\";s:19:\"webform_submissions\";s:5:\"label\";s:19:\"Webform submissions\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:34:\"Default webform submissions views.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:18:\"webform_submission\";s:10:\"base_field\";s:3:\"sid\";s:7:\"display\";a:5:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:14:\"items_per_page\";i:25;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:6:\"‹‹\";s:4:\"next\";s:6:\"››\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:23:\"5, 10, 25, 50, 100, 200\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;s:24:\"pagination_heading_level\";s:2:\"h4\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"fields\";a:5:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:7:\"filters\";a:0:{}s:5:\"sorts\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:0;s:7:\"content\";s:34:\"Displaying @start - @end of @total\";s:9:\"plugin_id\";s:6:\"result\";}}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"No submissions available.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:5:{s:10:\"webform_id\";a:6:{s:2:\"id\";s:10:\"webform_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"webform_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:10:\"webform_id\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"entity_type\";a:6:{s:2:\"id\";s:11:\"entity_type\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"entity_type\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"entity_type\";s:9:\"plugin_id\";s:6:\"string\";}s:9:\"entity_id\";a:6:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"entity_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:6:\"string\";}s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"uid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:7:\"numeric\";}s:8:\"in_draft\";a:22:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:14:\"items_per_page\";i:25;s:8:\"override\";b:0;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"numeric\";}}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"title\";s:19:\"Webform submissions\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:16:\"embed_administer\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:16:\"embed_administer\";s:13:\"display_title\";s:17:\"Embed: Administer\";s:8:\"position\";i:2;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:23:\"Administer submissions.\";s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:8:\"defaults\";a:6:{s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:29:\"administer webform submission\";}}s:6:\"fields\";a:9:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:10:\"operations\";a:25:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;s:11:\"entity_type\";N;s:12:\"entity_field\";N;s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:13:\"embed_default\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:13:\"embed_default\";s:13:\"display_title\";s:14:\"Embed: Default\";s:8:\"position\";i:1;s:15:\"display_options\";a:5:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:20:\"Display submissions.\";s:8:\"defaults\";a:5:{s:6:\"fields\";b:1;s:5:\"style\";b:0;s:3:\"row\";b:0;s:7:\"filters\";b:1;s:13:\"filter_groups\";b:1;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:5:{s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:7:\"created\";s:7:\"created\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:5:{s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_manage\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_manage\";s:13:\"display_title\";s:13:\"Embed: Manage\";s:8:\"position\";i:3;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Manage submissions.\";s:6:\"fields\";a:10:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:4:{i:0;s:35:\"webform_submission_make_lock_action\";i:1;s:37:\"webform_submission_make_sticky_action\";i:2;s:37:\"webform_submission_make_unlock_action\";i:3;s:39:\"webform_submission_make_unsticky_action\";}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}s:23:\"edit_webform_submission\";a:26:{s:2:\"id\";s:23:\"edit_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"edit_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"edit any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_review\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_review\";s:13:\"display_title\";s:13:\"Embed: Review\";s:8:\"position\";i:4;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Review submissions.\";s:6:\"fields\";a:8:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"view any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.who_s_new',	'a:13:{s:4:\"uuid\";s:36:\"a7f5e956-bb75-4caf-908d-26f2bf0d1ceb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zji0_13MyVGK7Bn1lUMDeZyyOIZedWvqpYUeM_SioPI\";}s:2:\"id\";s:9:\"who_s_new\";s:5:\"label\";s:9:\"Who\'s new\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:53:\"Shows a list of the newest user accounts on the site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:9:\"Who\'s new\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:5;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\">\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:10:\"1970-01-01\";s:4:\"type\";s:4:\"date\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:1:{s:4:\"type\";s:9:\"html_list\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:9:\"Who\'s new\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:19:\"A list of new users\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:9:\"Who\'s new\";s:14:\"block_category\";s:4:\"User\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.who_s_online',	'a:13:{s:4:\"uuid\";s:36:\"c473d286-cede-440e-97e5-6d2909d58b05\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"suDsVMgawXoQt4rfmdfpr05EVX3z3KyfDDTYgeSM898\";}s:2:\"id\";s:12:\"who_s_online\";s:5:\"label\";s:18:\"Who\'s online block\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:93:\"Shows the user names of the most recently active users, and the total number of active users.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:12:\"Who\'s online\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access user profiles\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:35:\"There are currently 0 users online.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:6:\"access\";a:13:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"access\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:2:\">=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:11:\"-15 minutes\";s:4:\"type\";s:6:\"offset\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:9:\"access_op\";s:5:\"label\";s:11:\"Last access\";s:11:\"description\";s:77:\"A user is considered online for this long after they have last viewed a page.\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"access_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"access\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"result\";s:5:\"empty\";b:0;s:7:\"content\";s:40:\"There are currently @total users online.\";}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:18:\"who_s_online_block\";a:6:{s:2:\"id\";s:18:\"who_s_online_block\";s:13:\"display_title\";s:12:\"Who\'s online\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:19:\"display_description\";s:45:\"A list of users that are currently logged in.\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:12:\"Who\'s online\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'webform.settings',	'a:20:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eZgcriT-utjDI1pjl-24jYFW2DmCxMXaFSnJd0XoU-0\";}s:8:\"settings\";a:73:{s:14:\"default_status\";s:4:\"open\";s:18:\"default_categories\";a:0:{}s:12:\"default_page\";b:1;s:22:\"default_page_base_path\";s:5:\"/form\";s:12:\"default_ajax\";b:0;s:19:\"default_ajax_effect\";s:4:\"fade\";s:18:\"default_ajax_speed\";i:500;s:26:\"default_ajax_progress_type\";s:8:\"throbber\";s:25:\"default_form_open_message\";s:49:\"This form has not yet been opened to submissions.\";s:26:\"default_form_close_message\";s:48:\"Sorry… This form is closed to new submissions.\";s:30:\"default_form_exception_message\";s:70:\"Unable to display this webform. Please contact the site administrator.\";s:27:\"default_submit_button_label\";s:6:\"Submit\";s:26:\"default_reset_button_label\";s:5:\"Reset\";s:27:\"default_delete_button_label\";s:6:\"Delete\";s:24:\"default_form_submit_once\";b:0;s:33:\"default_form_confidential_message\";s:135:\"This form is confidential. You must <a href=\"[site:login-url]/logout?destination=[current-page:url:relative]\">Log out</a> to submit it.\";s:34:\"default_form_access_denied_message\";s:34:\"Please log in to access this form.\";s:25:\"default_form_disable_back\";b:0;s:24:\"default_form_submit_back\";b:0;s:20:\"default_form_unsaved\";b:0;s:32:\"default_form_disable_remote_addr\";b:0;s:23:\"default_form_novalidate\";b:0;s:34:\"default_form_disable_inline_errors\";b:0;s:21:\"default_form_required\";b:0;s:27:\"default_form_required_label\";s:24:\"Indicates required field\";s:27:\"default_form_details_toggle\";b:1;s:23:\"default_form_file_limit\";s:0:\"\";s:12:\"form_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:14:\"button_classes\";s:0:\"\";s:32:\"default_wizard_prev_button_label\";s:10:\"< Previous\";s:32:\"default_wizard_next_button_label\";s:6:\"Next >\";s:26:\"default_wizard_start_label\";s:5:\"Start\";s:33:\"default_wizard_confirmation_label\";s:8:\"Complete\";s:32:\"default_wizard_toggle_show_label\";s:8:\"Show all\";s:32:\"default_wizard_toggle_hide_label\";s:8:\"Hide all\";s:33:\"default_preview_next_button_label\";s:7:\"Preview\";s:33:\"default_preview_prev_button_label\";s:10:\"< Previous\";s:21:\"default_preview_label\";s:7:\"Preview\";s:21:\"default_preview_title\";s:24:\"[webform:title]: Preview\";s:23:\"default_preview_message\";s:99:\"Please review your submission. Your submission is not complete until you press the \"Submit\" button!\";s:26:\"default_draft_button_label\";s:10:\"Save Draft\";s:27:\"default_draft_saved_message\";s:91:\"Submission saved. You may return to this form later and it will restore the current values.\";s:28:\"default_draft_loaded_message\";s:77:\"A partially-completed form was found. Please complete the remaining portions.\";s:36:\"default_draft_pending_single_message\";s:83:\"You have a pending draft for this webform. <a href=\"#\">Load your pending draft</a>.\";s:38:\"default_draft_pending_multiple_message\";s:83:\"You have pending drafts for this webform. <a href=\"#\">View your pending drafts</a>.\";s:28:\"default_confirmation_message\";s:40:\"New submission added to [webform:title].\";s:31:\"default_confirmation_back_label\";s:12:\"Back to form\";s:28:\"default_confirmation_noindex\";b:1;s:24:\"default_submission_label\";s:74:\"[webform_submission:submitted-to]: Submission #[webform_submission:serial]\";s:40:\"default_submission_access_denied_message\";s:40:\"Please log in to access this submission.\";s:36:\"default_submission_exception_message\";s:73:\"Unable to process this submission. Please contact the site administrator.\";s:33:\"default_submission_locked_message\";s:32:\"This submission has been locked.\";s:22:\"default_submission_log\";b:0;s:24:\"default_submission_views\";a:0:{}s:32:\"default_submission_views_replace\";a:3:{s:13:\"global_routes\";a:2:{i:0;s:36:\"entity.webform_submission.collection\";i:1;s:30:\"entity.webform_submission.user\";}s:14:\"webform_routes\";a:3:{i:0;s:34:\"entity.webform.results_submissions\";i:1;s:26:\"entity.webform.user.drafts\";i:2;s:31:\"entity.webform.user.submissions\";}s:11:\"node_routes\";a:3:{i:0;s:39:\"entity.node.webform.results_submissions\";i:1;s:31:\"entity.node.webform.user.drafts\";i:2;s:36:\"entity.node.webform.user.submissions\";}}s:25:\"default_results_customize\";b:0;s:35:\"default_previous_submission_message\";s:87:\"You have already submitted this webform. <a href=\"#\">View your previous submission</a>.\";s:36:\"default_previous_submissions_message\";s:88:\"You have already submitted this webform. <a href=\"#\">View your previous submissions</a>.\";s:24:\"default_autofill_message\";s:66:\"This submission has been autofilled with your previous submission.\";s:15:\"preview_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:20:\"confirmation_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:25:\"confirmation_back_classes\";s:7:\"button\n\";s:27:\"default_limit_total_message\";s:34:\"No more submissions are permitted.\";s:26:\"default_limit_user_message\";s:34:\"No more submissions are permitted.\";s:13:\"default_share\";b:0;s:18:\"default_share_node\";b:0;s:24:\"default_share_theme_name\";s:0:\"\";s:6:\"dialog\";b:0;s:14:\"dialog_options\";a:3:{s:6:\"narrow\";a:2:{s:5:\"title\";s:6:\"Narrow\";s:5:\"width\";i:600;}s:6:\"normal\";a:2:{s:5:\"title\";s:6:\"Normal\";s:5:\"width\";i:800;}s:4:\"wide\";a:2:{s:5:\"title\";s:4:\"Wide\";s:5:\"width\";i:1000;}}s:17:\"webform_bulk_form\";b:1;s:25:\"webform_bulk_form_actions\";a:5:{i:0;s:19:\"webform_open_action\";i:1;s:20:\"webform_close_action\";i:2;s:22:\"webform_archive_action\";i:3;s:24:\"webform_unarchive_action\";i:4;s:21:\"webform_delete_action\";}s:28:\"webform_submission_bulk_form\";b:1;s:36:\"webform_submission_bulk_form_actions\";a:5:{i:0;s:37:\"webform_submission_make_sticky_action\";i:1;s:39:\"webform_submission_make_unsticky_action\";i:2;s:35:\"webform_submission_make_lock_action\";i:3;s:37:\"webform_submission_make_unlock_action\";i:4;s:32:\"webform_submission_delete_action\";}}s:6:\"assets\";a:2:{s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";}s:7:\"handler\";a:1:{s:17:\"excluded_handlers\";a:0:{}}s:7:\"variant\";a:1:{s:17:\"excluded_variants\";a:0:{}}s:6:\"export\";a:18:{s:14:\"temp_directory\";s:0:\"\";s:8:\"exporter\";s:9:\"delimited\";s:18:\"multiple_delimiter\";s:1:\";\";s:13:\"header_format\";s:5:\"label\";s:13:\"header_prefix\";b:1;s:29:\"header_prefix_label_delimiter\";s:2:\": \";s:27:\"header_prefix_key_delimiter\";s:2:\"__\";s:29:\"composite_element_item_format\";s:5:\"label\";s:21:\"options_single_format\";s:7:\"compact\";s:23:\"options_multiple_format\";s:7:\"compact\";s:19:\"options_item_format\";s:5:\"label\";s:22:\"entity_reference_items\";a:3:{i:0;s:2:\"id\";i:1;s:5:\"title\";i:2;s:3:\"url\";}s:21:\"likert_answers_format\";s:5:\"label\";s:16:\"signature_format\";s:6:\"status\";s:9:\"delimiter\";s:1:\",\";s:5:\"excel\";b:0;s:12:\"archive_type\";s:3:\"tar\";s:18:\"excluded_exporters\";a:0:{}}s:5:\"batch\";a:5:{s:25:\"default_batch_export_size\";i:500;s:25:\"default_batch_import_size\";i:100;s:25:\"default_batch_update_size\";i:500;s:25:\"default_batch_delete_size\";i:500;s:24:\"default_batch_email_size\";i:500;}s:5:\"purge\";a:1:{s:9:\"cron_size\";i:100;}s:4:\"form\";a:3:{s:5:\"limit\";i:50;s:15:\"filter_category\";s:0:\"\";s:12:\"filter_state\";s:0:\"\";}s:7:\"element\";a:13:{s:20:\"machine_name_pattern\";s:7:\"a-z0-9_\";s:13:\"empty_message\";s:7:\"{Empty}\";s:12:\"allowed_tags\";s:5:\"admin\";s:15:\"wrapper_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:7:\"classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:23:\"horizontal_rule_classes\";s:286:\"webform-horizontal-rule--solid\nwebform-horizontal-rule--dashed\nwebform-horizontal-rule--dotted\nwebform-horizontal-rule--gradient\nwebform-horizontal-rule--thin\nwebform-horizontal-rule--medium\nwebform-horizontal-rule--thick\nwebform-horizontal-rule--flaired\nwebform-horizontal-rule--glyph\n\";s:27:\"default_description_display\";s:0:\"\";s:18:\"default_more_title\";s:4:\"More\";s:25:\"default_section_title_tag\";s:2:\"h2\";s:20:\"default_empty_option\";b:1;s:29:\"default_empty_option_required\";s:0:\"\";s:29:\"default_empty_option_optional\";s:0:\"\";s:17:\"excluded_elements\";a:2:{s:8:\"password\";s:8:\"password\";s:16:\"password_confirm\";s:16:\"password_confirm\";}}s:11:\"html_editor\";a:5:{s:8:\"disabled\";b:0;s:14:\"element_format\";s:15:\"webform_default\";s:11:\"mail_format\";s:15:\"webform_default\";s:4:\"tidy\";b:1;s:35:\"make_unused_managed_files_temporary\";b:1;}s:4:\"file\";a:11:{s:11:\"file_public\";b:0;s:21:\"file_private_redirect\";b:1;s:29:\"file_private_redirect_message\";s:42:\"Please log in to access the uploaded file.\";s:20:\"default_max_filesize\";s:0:\"\";s:31:\"default_managed_file_extensions\";s:148:\"gif jpg jpeg png bmp eps tif pict psd txt rtf html odf pdf doc docx ppt pptx xls xlsx xml avi mov mp3 mp4 ogg wav bz2 dmg gz jar rar sit svg tar zip\";s:29:\"default_audio_file_extensions\";s:11:\"mp3 ogg wav\";s:32:\"default_document_file_extensions\";s:50:\"txt rtf pdf doc docx odt ppt pptx odp xls xlsx ods\";s:29:\"default_image_file_extensions\";s:16:\"gif jpg jpeg png\";s:29:\"default_video_file_extensions\";s:24:\"avi mov mp4 ogg wav webm\";s:35:\"make_unused_managed_files_temporary\";b:1;s:30:\"delete_temporary_managed_files\";b:1;}s:6:\"format\";a:0:{}s:4:\"mail\";a:11:{s:15:\"default_to_mail\";s:11:\"[site:mail]\";s:17:\"default_from_mail\";s:11:\"[site:mail]\";s:17:\"default_from_name\";s:11:\"[site:name]\";s:16:\"default_reply_to\";s:0:\"\";s:19:\"default_return_path\";s:0:\"\";s:19:\"default_sender_mail\";s:0:\"\";s:19:\"default_sender_name\";s:0:\"\";s:15:\"default_subject\";s:58:\"Webform submission from: [webform_submission:source-title]\";s:17:\"default_body_text\";s:133:\"Submitted on [webform_submission:created]\nSubmitted by: [webform_submission:user]\n\nSubmitted values are:\n[webform_submission:values]\n\";s:17:\"default_body_html\";s:153:\"<p>Submitted on [webform_submission:created]</p>\n<p>Submitted by: [webform_submission:user]</p>\n<p>Submitted values are:</p>\n[webform_submission:values]\n\";s:5:\"roles\";a:0:{}}s:4:\"test\";a:2:{s:5:\"types\";s:3347:\"checkbox:\n  - true\ncolor:\n  - \'#ffffcc\'\n  - \'#ffffcc\'\n  - \'#ccffff\'\nemail:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nlanguage_select:\n  - en\nmachine_name:\n  - \'loremipsum\'\n  - \'oratione\'\n  - \'dixisset\'\ntel:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ntextarea:\n  - \'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.\'\n  - \'Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;\'\n  - \'Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.\'\ntext_format:\n  - value: \'<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.</p>\'\n  - value: \'<p>Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;</p>\'\n  - value: \'<p>Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.</p>\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\nwebform_email_confirm:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nwebform_email_multiple:\n  - \'example@example.com, test@test.com, random@random.com\'\nwebform_time:\n  - \'09:00\'\n  - \'17:00\'\n\";s:5:\"names\";s:547:\"first_name:\n  - \'John\'\n  - \'Paul\'\n  - \'Ringo\'\n  - \'George\'\nlast_name:\n  - \'Lennon\'\n  - \'McCartney\'\n  - \'Starr\'\n  - \'Harrison\'\naddress:\n  - \'10 Main Street\'\n  - \'11 Brook Alley Road. APT 1\'\nzip:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\npostal_code:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\nphone:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\nfax:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ncity:\n  - \'Springfield\'\n  - \'Pleasantville\'\n  - \'Hill Valley\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\ndefault:\n  - \'Loremipsum\'\n  - \'Oratione\'\n  - \'Dixisset\'\n\";}s:2:\"ui\";a:9:{s:13:\"video_display\";s:6:\"dialog\";s:12:\"details_save\";b:1;s:13:\"help_disabled\";b:0;s:15:\"dialog_disabled\";b:0;s:18:\"offcanvas_disabled\";b:0;s:19:\"promotions_disabled\";b:0;s:16:\"support_disabled\";b:0;s:16:\"description_help\";b:1;s:12:\"toolbar_item\";b:0;}s:9:\"libraries\";a:1:{s:18:\"excluded_libraries\";a:2:{i:0;s:7:\"choices\";i:1;s:13:\"jquery.chosen\";}}s:12:\"requirements\";a:4:{s:3:\"cdn\";b:1;s:9:\"bootstrap\";b:1;s:21:\"clientside_validation\";b:1;s:4:\"spam\";b:1;}s:8:\"langcode\";s:2:\"en\";s:20:\"third_party_settings\";a:1:{s:7:\"captcha\";a:1:{s:27:\"replace_administration_mode\";b:1;}}}'),
('',	'webform.webform.contact',	'a:22:{s:4:\"uuid\";s:36:\"cff12aaa-4fd4-49c9-bed0-2556200107e6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";s:4:\"open\";s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_je-MWeeJB6gfm6iECiqjcyNetfMFbn-YIInYwZ1gIk\";}s:4:\"open\";N;s:5:\"close\";N;s:6:\"weight\";i:0;s:3:\"uid\";N;s:8:\"template\";b:0;s:7:\"archive\";b:0;s:2:\"id\";s:7:\"contact\";s:5:\"title\";s:7:\"Contact\";s:11:\"description\";s:28:\"Basic email contact webform.\";s:10:\"categories\";a:0:{}s:8:\"elements\";s:566:\"name:\n  \'#title\': \'Your Name\'\n  \'#type\': textfield\n  \'#required\': true\n  \'#default_value\': \'[current-user:display-name]\'\nemail:\n  \'#title\': \'Your Email\'\n  \'#type\': email\n  \'#required\': true\n  \'#default_value\': \'[current-user:mail]\'\nsubject:\n  \'#title\': Subject\n  \'#type\': textfield\n  \'#required\': true\n  \'#test\': \'Testing contact webform from [site:name]\'\nmessage:\n  \'#title\': Message\n  \'#type\': textarea\n  \'#required\': true\n  \'#test\': \'Please ignore this email.\'\nactions:\n  \'#type\': webform_actions\n  \'#title\': \'Submit button(s)\'\n  \'#submit__label\': \'Send message\'\n\";s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";s:8:\"settings\";a:133:{s:4:\"ajax\";b:0;s:15:\"ajax_scroll_top\";s:4:\"form\";s:18:\"ajax_progress_type\";s:0:\"\";s:11:\"ajax_effect\";s:0:\"\";s:10:\"ajax_speed\";N;s:4:\"page\";b:1;s:16:\"page_submit_path\";s:0:\"\";s:17:\"page_confirm_path\";s:0:\"\";s:15:\"page_theme_name\";s:0:\"\";s:10:\"form_title\";s:21:\"source_entity_webform\";s:16:\"form_submit_once\";b:0;s:22:\"form_exception_message\";s:0:\"\";s:17:\"form_open_message\";s:0:\"\";s:18:\"form_close_message\";s:0:\"\";s:25:\"form_previous_submissions\";b:1;s:17:\"form_confidential\";b:0;s:25:\"form_confidential_message\";s:0:\"\";s:24:\"form_disable_remote_addr\";b:0;s:22:\"form_convert_anonymous\";b:0;s:16:\"form_prepopulate\";b:0;s:30:\"form_prepopulate_source_entity\";b:0;s:39:\"form_prepopulate_source_entity_required\";b:0;s:35:\"form_prepopulate_source_entity_type\";s:0:\"\";s:10:\"form_reset\";b:0;s:25:\"form_disable_autocomplete\";b:0;s:15:\"form_novalidate\";b:0;s:26:\"form_disable_inline_errors\";b:0;s:13:\"form_required\";b:0;s:12:\"form_unsaved\";b:0;s:17:\"form_disable_back\";b:0;s:16:\"form_submit_back\";b:0;s:14:\"form_autofocus\";b:0;s:19:\"form_details_toggle\";b:0;s:18:\"form_access_denied\";s:7:\"default\";s:24:\"form_access_denied_title\";s:0:\"\";s:26:\"form_access_denied_message\";s:0:\"\";s:29:\"form_access_denied_attributes\";a:0:{}s:15:\"form_file_limit\";s:0:\"\";s:11:\"form_method\";s:0:\"\";s:11:\"form_action\";s:0:\"\";s:15:\"form_attributes\";a:0:{}s:5:\"share\";b:0;s:10:\"share_node\";b:0;s:16:\"share_theme_name\";s:0:\"\";s:11:\"share_title\";b:1;s:26:\"share_page_body_attributes\";a:0:{}s:16:\"submission_label\";s:0:\"\";s:14:\"submission_log\";b:0;s:16:\"submission_views\";a:0:{}s:24:\"submission_views_replace\";a:0:{}s:23:\"submission_user_columns\";a:0:{}s:25:\"submission_user_duplicate\";b:0;s:24:\"submission_access_denied\";s:7:\"default\";s:30:\"submission_access_denied_title\";s:0:\"\";s:32:\"submission_access_denied_message\";s:0:\"\";s:35:\"submission_access_denied_attributes\";a:0:{}s:28:\"submission_exception_message\";s:0:\"\";s:25:\"submission_locked_message\";s:0:\"\";s:28:\"submission_excluded_elements\";a:0:{}s:24:\"submission_exclude_empty\";b:0;s:33:\"submission_exclude_empty_checkbox\";b:0;s:27:\"previous_submission_message\";s:0:\"\";s:28:\"previous_submissions_message\";s:0:\"\";s:8:\"autofill\";b:0;s:16:\"autofill_message\";s:0:\"\";s:26:\"autofill_excluded_elements\";a:0:{}s:19:\"wizard_progress_bar\";b:1;s:21:\"wizard_progress_pages\";b:0;s:26:\"wizard_progress_percentage\";b:0;s:20:\"wizard_progress_link\";b:0;s:22:\"wizard_progress_states\";b:0;s:19:\"wizard_auto_forward\";b:1;s:36:\"wizard_auto_forward_hide_next_button\";b:0;s:15:\"wizard_keyboard\";b:1;s:18:\"wizard_start_label\";s:0:\"\";s:19:\"wizard_preview_link\";b:0;s:19:\"wizard_confirmation\";b:1;s:25:\"wizard_confirmation_label\";s:0:\"\";s:12:\"wizard_track\";s:0:\"\";s:24:\"wizard_prev_button_label\";s:0:\"\";s:24:\"wizard_next_button_label\";s:0:\"\";s:13:\"wizard_toggle\";b:0;s:24:\"wizard_toggle_show_label\";s:0:\"\";s:24:\"wizard_toggle_hide_label\";s:0:\"\";s:16:\"wizard_page_type\";s:9:\"container\";s:21:\"wizard_page_title_tag\";s:2:\"h2\";s:7:\"preview\";i:0;s:13:\"preview_label\";s:0:\"\";s:13:\"preview_title\";s:0:\"\";s:15:\"preview_message\";s:0:\"\";s:18:\"preview_attributes\";a:0:{}s:25:\"preview_excluded_elements\";a:0:{}s:21:\"preview_exclude_empty\";b:1;s:30:\"preview_exclude_empty_checkbox\";b:0;s:5:\"draft\";s:4:\"none\";s:14:\"draft_multiple\";b:0;s:15:\"draft_auto_save\";b:0;s:19:\"draft_saved_message\";s:0:\"\";s:20:\"draft_loaded_message\";s:0:\"\";s:28:\"draft_pending_single_message\";s:0:\"\";s:30:\"draft_pending_multiple_message\";s:0:\"\";s:17:\"confirmation_type\";s:11:\"url_message\";s:18:\"confirmation_title\";s:0:\"\";s:20:\"confirmation_message\";s:27:\"Your message has been sent.\";s:16:\"confirmation_url\";s:7:\"<front>\";s:23:\"confirmation_attributes\";a:0:{}s:17:\"confirmation_back\";b:1;s:23:\"confirmation_back_label\";s:0:\"\";s:28:\"confirmation_back_attributes\";a:0:{}s:26:\"confirmation_exclude_query\";b:0;s:26:\"confirmation_exclude_token\";b:0;s:19:\"confirmation_update\";b:0;s:11:\"limit_total\";N;s:20:\"limit_total_interval\";N;s:19:\"limit_total_message\";s:0:\"\";s:18:\"limit_total_unique\";b:0;s:10:\"limit_user\";N;s:19:\"limit_user_interval\";N;s:18:\"limit_user_message\";s:0:\"\";s:17:\"limit_user_unique\";b:0;s:18:\"entity_limit_total\";N;s:27:\"entity_limit_total_interval\";N;s:17:\"entity_limit_user\";N;s:26:\"entity_limit_user_interval\";N;s:5:\"purge\";s:4:\"none\";s:10:\"purge_days\";N;s:16:\"results_disabled\";b:0;s:23:\"results_disabled_ignore\";b:0;s:17:\"results_customize\";b:0;s:10:\"token_view\";b:0;s:12:\"token_update\";b:0;s:12:\"token_delete\";b:0;s:15:\"serial_disabled\";b:0;}s:6:\"access\";a:11:{s:6:\"create\";a:3:{s:5:\"roles\";a:2:{i:0;s:9:\"anonymous\";i:1;s:13:\"authenticated\";}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:9:\"purge_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"administer\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:4:\"test\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:13:\"configuration\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}}s:8:\"handlers\";a:2:{s:18:\"email_confirmation\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email confirmation\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_confirmation\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:1;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:19:\"[current-user:mail]\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:8:\"_default\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:8:\"_default\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}s:18:\"email_notification\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email notification\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_notification\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:2;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:8:\"_default\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:37:\"[webform_submission:values:email:raw]\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:36:\"[webform_submission:values:name:raw]\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}}s:8:\"variants\";a:0:{}}'),
('',	'webform.webform_options.country_codes',	'a:10:{s:4:\"uuid\";s:36:\"ff13f706-a0ad-416d-9f29-9d2d43722997\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"adQ16YGDPk7QfUKrfrC35o2sKdHEozdNtdpiH7CftQQ\";}s:2:\"id\";s:13:\"country_codes\";s:5:\"label\";s:13:\"Country codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.country_names',	'a:10:{s:4:\"uuid\";s:36:\"e8e266de-5ba1-42b8-aab4-68928e91aea7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zsfFP124dAM-sJkuEfnwaA7DN6o3-IsaXLgdNmObbYg\";}s:2:\"id\";s:13:\"country_names\";s:5:\"label\";s:13:\"Country names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.days',	'a:10:{s:4:\"uuid\";s:36:\"e1a9a156-02bc-4ffe-b6cb-55c0d4da6931\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNrKbYrWWjeubUUM8AsQ19KnX7cU1elACR14CZJHmdg\";}s:2:\"id\";s:4:\"days\";s:5:\"label\";s:4:\"Days\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:121:\"Sunday: Sunday\nMonday: Monday\nTuesday: Tuesday\nWednesday: Wednesday\nThursday: Thursday\nFriday: Friday\nSaturday: Saturday\n\";}'),
('',	'webform.webform_options.education',	'a:10:{s:4:\"uuid\";s:36:\"f59dde6d-88c7-46f8-9148-aa56a18a13ba\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mII4acOv33s-j8PINywrCag4OITbeJGxdPO373dnHHw\";}s:2:\"id\";s:9:\"education\";s:5:\"label\";s:9:\"Education\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:152:\"High School: High School\nAssociate Degree: Associate Degree\nGraduate or Professional Degree: Graduate or Professional Degree\nSome College: Some College\n\";}'),
('',	'webform.webform_options.employment_status',	'a:10:{s:4:\"uuid\";s:36:\"369dc8ce-cc18-40ec-b90a-91c195e015af\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8MCmsz_csdJkVItxI8g_s4zp2PM285YqCy_gWTzOLPw\";}s:2:\"id\";s:17:\"employment_status\";s:5:\"label\";s:17:\"Employment status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:113:\"\'Full Time\': \'Full Time\'\n\'Part Time\': \'Part Time\'\n\'Military\': \'Military\'\nUnemployed: Unemployed\nRetired: Retired\n\";}'),
('',	'webform.webform_options.ethnicity',	'a:10:{s:4:\"uuid\";s:36:\"d8eb5c8c-04ba-44b0-83dd-5ab55746daa9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pIPgrAC82wE2GAk1mOv2UvMYv71YQe4VT8667QIYdvI\";}s:2:\"id\";s:9:\"ethnicity\";s:5:\"label\";s:9:\"Ethnicity\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:200:\"Caucasian: Caucasian\n\'Latino/Hispanic\': \'Latino/Hispanic\'\n\'Middle Eastern\': \'Middle Eastern\'\nAfrican: African\nCaribbean: Caribbean\n\'South Asian\': \'South Asian\'\n\'East Asian\': \'East Asian\'\nMixed: Mixed\n\";}'),
('',	'webform.webform_options.gender',	'a:10:{s:4:\"uuid\";s:36:\"8e01de6b-6df3-4ff4-857e-7f18c86dba94\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yxhG0JmQs2HT-Ro6ZeDQboDc9ZWR4GglflTtyoqxK4A\";}s:2:\"id\";s:6:\"gender\";s:5:\"label\";s:6:\"Gender\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:756:\"Man: Man\nWoman: Woman\nNon-binary: Non-binary\nAgender/Genderless: Agender/Genderless\nAndrogyne/Androgynous: Androgyne/Androgynous\nAporagender: Aporagender\nBigender: Bigender\nDemi-agender: Demi-agender\nDemi-boy: Demi-boy\nDemi-fluid: Demi-fluid\nDemi-girl: Demi-girl\nDemi-gender: Demi-gender\nDemi-non-binary: Demi-non-binary\nGenderqueer: Genderqueer\nGenderflux: Genderflux\nGenderfluid: Genderfluid\nGender-indifferent: Gender-indifferent\nGender-neutral: Gender-neutral\nGraygender: Graygender\nIntergender: Intergender\nMaverique: Maverique\nMaxigender: Maxigender\nMultigender/Polygender: Multigender/Polygender\nNeutrois: Neutrois\nPangender/Omnigender: Pangender/Omnigender\nTrigender: Trigender\nTwo-spirit: Two-spirit\n\'Prefer Not to Answer\': \'Prefer Not to Answer\'\n\";}'),
('',	'webform.webform_options.industry',	'a:10:{s:4:\"uuid\";s:36:\"a1a5d982-5911-4689-8e9d-779071e6f69c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"s_SXZn2HbRGvTex-TLOCxz2oOnMYqtEZh8HD4_318QI\";}s:2:\"id\";s:8:\"industry\";s:5:\"label\";s:8:\"Industry\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1425:\"Accounting/Finance: Accounting/Finance\nAdvertising/Public Relations: Advertising/Public Relations\nAerospace/Aviation: Aerospace/Aviation\nArts/Entertainment/Publishing: Arts/Entertainment/Publishing\nAutomotive: Automotive\nBanking/Mortgage: Banking/Mortgage\nBusiness Development: Business Development\nBusiness Opportunity: Business Opportunity\nClerical/Administrative: Clerical/Administrative\nConstruction/Facilities: Construction/Facilities\nConsumer Goods: Consumer Goods\nCustomer Service: Customer Service\nEducation/Training: Education/Training\nEnergy/Utilities: Energy/Utilities\nEngineering: Engineering\nGovernment/Military: Government/Military\nHealthcare: Healthcare\nHospitality/Travel: Hospitality/Travel\nHuman Resources: Human Resources\nInstallation/Maintenance: Installation/Maintenance\nInsurance: Insurance\nInternet: Internet\nLaw Enforcement/Security: Law Enforcement/Security\nLegal: Legal\nManagement/Executive: Management/Executive\nManufacturing/Operations: Manufacturing/Operations\nMarketing: Marketing\nNon-Profit/Volunteer: Non-Profit/Volunteer\nPharmaceutical/Biotech: Pharmaceutical/Biotech\nProfessional Services: Professional Services\nReal Estate: Real Estate\nRestaurant/Food Service: Restaurant/Food Service\nRetail: Retail\nSales: Sales\nScience/Research: Science/Research\nSkilled Labor: Skilled Labor\nTechnology: Technology\nTelecommunications: Telecommunications\nTransportation/Logistics: Transportation/Logistics\n\";}'),
('',	'webform.webform_options.languages',	'a:10:{s:4:\"uuid\";s:36:\"da44f184-15d8-46b2-9d27-67fdc87883fa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mYH14Vi65Ixj10c_GFa7CipxU3D0Bt9wgo8zE8zjOfE\";}s:2:\"id\";s:9:\"languages\";s:5:\"label\";s:9:\"Languages\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.likert_agreement',	'a:10:{s:4:\"uuid\";s:36:\"c1d3035e-7928-41e6-83cb-e5d35f1ddcff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nPp-CfMKrP0yDMtyO0wQRwawEqaJVAPzQapinXmDgyU\";}s:2:\"id\";s:16:\"likert_agreement\";s:5:\"label\";s:17:\"Likert: Agreement\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:71:\"1: Strongly Disagree\n2: Disagree\n3: Neutral\n4: Agree\n5: Strongly Agree\n\";}'),
('',	'webform.webform_options.likert_comparison',	'a:10:{s:4:\"uuid\";s:36:\"c9690189-5cda-402e-bc23-4fce4d34e427\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DMG4TKTHEXtHN8ho_sG_GiZHgweZ6nrRm6BAjk0LZ_Y\";}s:2:\"id\";s:17:\"likert_comparison\";s:5:\"label\";s:18:\"Likert: Comparison\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:84:\"1: Much Worse\n2: Somewhat Worse\n3: About the Same\n4: Somewhat Better\n5: Much Better\n\";}'),
('',	'webform.webform_options.likert_importance',	'a:10:{s:4:\"uuid\";s:36:\"120774df-f15f-4a67-b020-8ecedd3cff80\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hbc8n5HtVZVs5fSBSpSbuY07CVvqkKP76csvRHN9pK8\";}s:2:\"id\";s:17:\"likert_importance\";s:5:\"label\";s:18:\"Likert: Importance\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:88:\"1: Not at all Important\n2: Somewhat Important\n3: Neutral\n4: Important\n5: Very Important\n\";}'),
('',	'webform.webform_options.likert_quality',	'a:10:{s:4:\"uuid\";s:36:\"3f51980b-fdb6-4b07-a304-fb302af23c4d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swmYtBVUbwq7aHJWWDN7ODByuvur9vMkexDC9h64NZ8\";}s:2:\"id\";s:14:\"likert_quality\";s:5:\"label\";s:15:\"Likert: Quality\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:50:\"1: Poor\n2: Fair\n3: Good\n4: Very good\n5: Excellent\n\";}'),
('',	'webform.webform_options.likert_satisfaction',	'a:10:{s:4:\"uuid\";s:36:\"3fe1c8dc-5cd9-48b5-a783-23480e3742f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AKE2SNwCpl6Mu_cmbq9ZM2_cXxCikCVj1vcPE9oHWTs\";}s:2:\"id\";s:19:\"likert_satisfaction\";s:5:\"label\";s:20:\"Likert: Satisfaction\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:77:\"1: Very Unsatisfied\n2: Unsatisfied\n3: Neutral\n4: Satisfied\n5: Very Satisfied\n\";}'),
('',	'webform.webform_options.likert_ten_scale',	'a:10:{s:4:\"uuid\";s:36:\"3bce0633-cfe2-4f52-8625-00d8c7a98f35\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zEZX8JSVqznnFtqFfpuC593h3t1JDAZhF0Q3pvA229o\";}s:2:\"id\";s:16:\"likert_ten_scale\";s:5:\"label\";s:17:\"Likert: Ten Scale\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:52:\"1: 1\n2: 2\n3: 3\n4: 4\n5: 5\n6: 6\n7: 7\n8: 8\n9: 9\n10: 10\n\";}'),
('',	'webform.webform_options.likert_would_you',	'a:10:{s:4:\"uuid\";s:36:\"ac4202f9-992c-48ac-a36b-aa22452196bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qBS2TmfAJB37Qn3TnrNM8x4AWimmDapcizzRllgo0fo\";}s:2:\"id\";s:16:\"likert_would_you\";s:5:\"label\";s:17:\"Likert: Would You\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:72:\"1: Definitely Not\n2: Probably Not\n3: Not Sure\n4: Probably\n5: Definitely\n\";}'),
('',	'webform.webform_options.marital_status',	'a:10:{s:4:\"uuid\";s:36:\"197b61b7-7127-4713-9678-b79940b929ea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cjVDbAE5BlopGrY-tfxsxMoyEibwBBNgdQwDdxOSkow\";}s:2:\"id\";s:14:\"marital_status\";s:5:\"label\";s:14:\"Marital status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:68:\"Single: Single\nMarried: Married\nDivorced: Divorced\nWidowed: Widowed\n\";}'),
('',	'webform.webform_options.months',	'a:10:{s:4:\"uuid\";s:36:\"281e6e1e-5d64-459a-86ef-5c7109ebb0cf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pZJnuQkh9afNML5IcMuKTUC__vmHMFn66Qr5IWtedZ4\";}s:2:\"id\";s:6:\"months\";s:5:\"label\";s:6:\"Months\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:184:\"January: January\nFebruary: February\nMarch: March\nApril: April\nMay: May\nJune: June\nJuly: July\nAugust: August\nSeptember: September\nOctober: October\nNovember: November\nDecember: December\n\";}'),
('',	'webform.webform_options.phone_types',	'a:10:{s:4:\"uuid\";s:36:\"13d0d301-6f64-4c63-a190-cfa2990e9a48\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LkO63Zl2cP_l9YdjzWI8dWoD9uD0pytkPiUiUM2bo9A\";}s:2:\"id\";s:11:\"phone_types\";s:5:\"label\";s:10:\"Phone type\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:37:\"Home: Home\nOffice: Office\nCell: Cell\n\";}'),
('',	'webform.webform_options.province_codes',	'a:10:{s:4:\"uuid\";s:36:\"3dd5c388-df64-4a89-9710-1557394c6222\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cR3A6XXinVGC9g5vLS-vVvTC2ppZXRNXLPWA8xBUMew\";}s:2:\"id\";s:14:\"province_codes\";s:5:\"label\";s:14:\"Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:237:\"AB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),
('',	'webform.webform_options.province_names',	'a:10:{s:4:\"uuid\";s:36:\"db9cc306-a4c9-49d1-9f1a-af8959ae1569\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aaEeYBWoWETLKX2ivmZBpUAd3uPe2iPNydaxBuLPXKc\";}s:2:\"id\";s:14:\"province_names\";s:5:\"label\";s:14:\"Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:379:\"Alberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),
('',	'webform.webform_options.relationship',	'a:10:{s:4:\"uuid\";s:36:\"c451f0ba-7456-4e0e-b2fe-5ebbebf2e2a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4J2RPG4JmsD4Fm1NlIQY0JHkrJ08UUl0qTF0_EjUxvw\";}s:2:\"id\";s:12:\"relationship\";s:5:\"label\";s:12:\"Relationship\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:101:\"Parent: Parent\n\'Significant Other\': \'Significant Other\'\nSibling: Sibling\nChild: Child\nFriend: Friend\n\";}'),
('',	'webform.webform_options.sex',	'a:10:{s:4:\"uuid\";s:36:\"e26b351c-bbe3-491b-b4e5-0c8ec30decce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WRpxpwYpfcO_i0so7BV4QXxXlbPiSVppYmAV6DAz4c0\";}s:2:\"id\";s:3:\"sex\";s:5:\"label\";s:3:\"Sex\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:26:\"Male: Male\nFemale: Female\n\";}'),
('',	'webform.webform_options.sex_icao',	'a:10:{s:4:\"uuid\";s:36:\"b54122ee-eb6e-46b5-b89b-a3d6cbff2302\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9mxo86dMII5OxkHl4mbe2l4AgQloOXuErOte57BU9IY\";}s:2:\"id\";s:8:\"sex_icao\";s:5:\"label\";s:54:\"Sex - International Civil Aviation Organization (ICAO)\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:33:\"M: Male\nF: Female\nX: Unspecified\n\";}'),
('',	'webform.webform_options.size',	'a:10:{s:4:\"uuid\";s:36:\"c06bcacf-40d2-4c65-9f65-f5429245ed23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RKkc6tf1VudvYiOtwPCf3Tp_EoA6fov6BFC34D7gMoQ\";}s:2:\"id\";s:4:\"size\";s:5:\"label\";s:4:\"Size\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:91:\"Extra Small: Extra Small\nSmall: Small\nMedium: Medium\nLarge: Large\nExtra Large: Extra Large\n\";}'),
('',	'webform.webform_options.state_codes',	'a:10:{s:4:\"uuid\";s:36:\"86b1fb55-9ca7-480a-a333-ce541cefe1ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8mYO8ewsZX3LVfNga69jXa0RNO0LNN8-EGkXLhSAMBU\";}s:2:\"id\";s:11:\"state_codes\";s:5:\"label\";s:11:\"State codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:728:\"AL: Alabama\nAK: Alaska\nAZ: Arizona\nAR: Arkansas\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPA: Pennsylvania\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\n\";}'),
('',	'webform.webform_options.state_names',	'a:10:{s:4:\"uuid\";s:36:\"f50cd86e-1ce6-4e30-a74c-4aa2a46053b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KfYqMSrFJ5iGtDzvy_rGUeRUJ4KyM7Xt-tWtYx9WjiM\";}s:2:\"id\";s:11:\"state_names\";s:5:\"label\";s:11:\"State names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1081:\"Alabama: Alabama\nAlaska: Alaska\nArizona: Arizona\nArkansas: Arkansas\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\nFlorida: Florida\nGeorgia: Georgia\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPennsylvania: Pennsylvania\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\n\";}'),
('',	'webform.webform_options.state_province_codes',	'a:10:{s:4:\"uuid\";s:36:\"6c763985-59b0-49e1-a940-e76e2992edca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ziWv9xVss1UBnP_R38EqduZOprwOAifpxjXhyOPzmys\";}s:2:\"id\";s:20:\"state_province_codes\";s:5:\"label\";s:20:\"State/Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1241:\"AL: Alabama\nAK: Alaska\nAS: \'American Samoa\'\nAZ: Arizona\nAR: Arkansas\nAE: \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\nAA: \'Armed Forces Americas\'\nAP: \'Armed Forces Pacific\'\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFM: \'Federated States of Micronesia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMH: \'Marshall Islands\'\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nMP: \'Northern Mariana Islands\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPW: Palau\nPA: Pennsylvania\nPR: \'Puerto Rico\'\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVI: \'Virgin Islands\'\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\nAB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),
('',	'webform.webform_options.state_province_names',	'a:10:{s:4:\"uuid\";s:36:\"40521304-88f4-47f9-82bb-7eb8bc136320\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d4mxS_CxdzHZK4WaGQf1H3m-Uubm5HPbu9U4ydzscuo\";}s:2:\"id\";s:20:\"state_province_names\";s:5:\"label\";s:20:\"State/Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1953:\"Alabama: Alabama\nAlaska: Alaska\n\'American Samoa\': \'American Samoa\'\nArizona: Arizona\nArkansas: Arkansas\n\'Armed Forces (Canada, Europe, Africa, or Middle East)\': \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\n\'Armed Forces Americas\': \'Armed Forces Americas\'\n\'Armed Forces Pacific\': \'Armed Forces Pacific\'\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\n\'Federated States of Micronesia\': \'Federated States of Micronesia\'\nFlorida: Florida\nGeorgia: Georgia\nGuam: Guam\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\n\'Marshall Islands\': \'Marshall Islands\'\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\n\'Northern Mariana Islands\': \'Northern Mariana Islands\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPalau: Palau\nPennsylvania: Pennsylvania\n\'Puerto Rico\': \'Puerto Rico\'\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\n\'Virgin Islands\': \'Virgin Islands\'\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\nAlberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),
('',	'webform.webform_options.time_zones',	'a:10:{s:4:\"uuid\";s:36:\"34555c98-49f4-4d02-aca0-fa11a6f7e4b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8rVcRXLnTAEoWs7zl8du-7RIUnayqUcGYnvb3JT21-o\";}s:2:\"id\";s:10:\"time_zones\";s:5:\"label\";s:10:\"Time zones\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.titles',	'a:10:{s:4:\"uuid\";s:36:\"1c50e324-cb25-4578-8344-bd2266cbca89\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PEUoedWrfYEX7oZ8CcOukfBTVxar1cPSROX8534esuU\";}s:2:\"id\";s:6:\"titles\";s:5:\"label\";s:6:\"Titles\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:41:\"Miss: Miss\nMs: Ms\nMr: Mr\nMrs: Mrs\nDr: Dr\n\";}'),
('',	'webform.webform_options.translations',	'a:10:{s:4:\"uuid\";s:36:\"84bf246e-58a4-4bad-ad87-c1ffdd4a4be4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mb_L3vE-0IBZH5s2rjpk2LNn0QHClQP9AARQdCmVLt4\";}s:2:\"id\";s:12:\"translations\";s:5:\"label\";s:12:\"Translations\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.yes_no',	'a:10:{s:4:\"uuid\";s:36:\"a55ca564-ba76-4d06-b838-79a72132103a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W88NYg31DbaVNQx1Uir_dwwXHVtF09QOq4VBGsH1Snk\";}s:2:\"id\";s:6:\"yes_no\";s:5:\"label\";s:6:\"Yes/No\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:16:\"Yes: Yes\nNo: No\n\";}');

DROP TABLE IF EXISTS `config_export`;
CREATE TABLE `config_export` (
  `collection` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object collection.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object name.',
  `data` longblob COMMENT 'A serialized configuration object data.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for configuration data.';

INSERT INTO `config_export` (`collection`, `name`, `data`) VALUES
('',	'admin_toolbar.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvTSppzcgH5wnzBhX5xnAExcp2I1CzkQ_aky65XNfYI\";}s:10:\"menu_depth\";i:4;}'),
('',	'admin_toolbar_tools.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WgdZsrd_5w9jlmcHV4R9dD2tG9OZEkYo4I_O8h7Gq8Q\";}s:17:\"max_bundle_number\";i:20;s:25:\"hoverintent_functionality\";b:1;s:16:\"show_local_tasks\";b:0;}'),
('',	'announcements_feed.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0G5pZBcxbg8ONYzNLd1RJIsvuFFewm9htnS4I-ABKJ8\";}s:7:\"max_age\";i:86400;s:13:\"cron_interval\";i:21600;s:5:\"limit\";i:10;}'),
('',	'automated_cron.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fUksROt4FfkAU9BV4hV2XvhTBSS2nTNrZS4U7S-tKrs\";}s:8:\"interval\";i:10800;}'),
('',	'block.block.claro_breadcrumbs',	'a:13:{s:4:\"uuid\";s:36:\"d1a331f5-0df6-469b-9594-7d62381385aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NjcxOBrPOiK5-38t56DwFBDVY4yer7YSlbRWXFuHe7A\";}s:2:\"id\";s:17:\"claro_breadcrumbs\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_content',	'a:13:{s:4:\"uuid\";s:36:\"40baaa9b-4ebb-41cb-a0f8-9438fc1633e2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a0Yyx1GeyKarZ4T_yXQBR_ZFKnXiFLtxAb6gWLd8nr0\";}s:2:\"id\";s:13:\"claro_content\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_help',	'a:13:{s:4:\"uuid\";s:36:\"e609269b-1f74-4c6d-8adc-b242386187c9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jccFSSVqV0WCDb6NtML1VWAWTtDbZ-zn5YgTRMgMrIM\";}s:2:\"id\";s:10:\"claro_help\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_help_search',	'a:13:{s:4:\"uuid\";s:36:\"642a14ba-b7f3-4788-b6d7-7ec847635558\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"module\";a:2:{i:0;s:6:\"search\";i:1;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}s:8:\"enforced\";a:1:{s:6:\"config\";a:1:{i:0;s:23:\"search.page.help_search\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2ToeZLvlHKTeFY74gpgu1PejLoFyCECLO_gw6rAZwqw\";}s:2:\"id\";s:17:\"claro_help_search\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:11:\"Search help\";s:13:\"label_display\";s:7:\"visible\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:11:\"help_search\";}s:10:\"visibility\";a:1:{s:12:\"request_path\";a:4:{s:2:\"id\";s:12:\"request_path\";s:6:\"negate\";b:0;s:15:\"context_mapping\";a:0:{}s:5:\"pages\";s:11:\"/admin/help\";}}}'),
('',	'block.block.claro_local_actions',	'a:13:{s:4:\"uuid\";s:36:\"b9fe9f3b-f277-4a5a-a681-c952b93cbf81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdXfDmRgAvms7EQovxxWPdYi0GitxeRbVtScYK16ZH0\";}s:2:\"id\";s:19:\"claro_local_actions\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_messages',	'a:13:{s:4:\"uuid\";s:36:\"58d2b9f3-0bea-4a38-88ec-fdb62db9ccb4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-Ac3ISpIT0PQ-whzD7_dw0SdKi6dAbRFNWdSjOiVDqg\";}s:2:\"id\";s:14:\"claro_messages\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_page_title',	'a:13:{s:4:\"uuid\";s:36:\"ecc6ef43-9d4c-491e-a458-7b4ac180124d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNwDdW063tk_ktzSWzZVeQS9wzvLooVO280BQ9WrsIs\";}s:2:\"id\";s:16:\"claro_page_title\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_primary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"d47ee844-8c65-44d3-85c0-510835e982ac\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ACjBZI5shAMiiUpsz-inLYVXDqNNXRnSzAWV3kV_8Hw\";}s:2:\"id\";s:25:\"claro_primary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_secondary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"f080d7bf-33c8-49e4-a29b-4f78db0f7c2c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2L0geP-ixCbCkEpW6BVF6H7vDUZN4ea07_Y9CociQm4\";}s:2:\"id\";s:27:\"claro_secondary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_account_menu',	'a:13:{s:4:\"uuid\";s:36:\"217ad55d-fd7d-4ae4-8bda-6030889a03b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:20:\"olivero_account_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_breadcrumbs',	'a:13:{s:4:\"uuid\";s:36:\"064ecc20-9718-4137-8404-bb79862b5dbe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:19:\"olivero_breadcrumbs\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_content',	'a:13:{s:4:\"uuid\";s:36:\"b76437ff-efaf-4c97-84ca-ae001d11fa96\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:15:\"olivero_content\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_help',	'a:13:{s:4:\"uuid\";s:36:\"53d20db2-085f-49cb-b889-bfcda4fdc4f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:12:\"olivero_help\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_main_menu',	'a:13:{s:4:\"uuid\";s:36:\"0cd82e10-9f40-455e-9bc5-67bba0594412\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:17:\"olivero_main_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_messages',	'a:13:{s:4:\"uuid\";s:36:\"f259c98a-a416-406b-8df1-73b20ade139d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:16:\"olivero_messages\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_page_title',	'a:13:{s:4:\"uuid\";s:36:\"592b2a14-a8fb-40ab-af13-fad4757b447c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:18:\"olivero_page_title\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_powered',	'a:13:{s:4:\"uuid\";s:36:\"3aa71fac-64b6-42f2-8b3d-0feb4a6f805e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYL19CLDyinGTWYQfBD1DswWzglEotE_kHnHx3AxTXM\";}s:2:\"id\";s:15:\"olivero_powered\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"footer_bottom\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_powered_by_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_powered_by_block\";s:5:\"label\";s:17:\"Powered by Drupal\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_primary_admin_actions',	'a:13:{s:4:\"uuid\";s:36:\"f3ae5ab3-e08f-4d92-8238-c0346ead125d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:29:\"olivero_primary_admin_actions\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_primary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"869275af-a038-43a0-aec0-55d644632865\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:27:\"olivero_primary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_search_form_narrow',	'a:13:{s:4:\"uuid\";s:36:\"1895f221-afd5-4f39-946d-175efff616ba\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yEBET0cqDbk8dkWzaJw-8CKft0961VBflsISoSR6Lj8\";}s:2:\"id\";s:26:\"olivero_search_form_narrow\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:20:\"Search form (narrow)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_search_form_wide',	'a:13:{s:4:\"uuid\";s:36:\"10f91465-91e8-4b68-9b23-c26342c32145\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"imMyHD6LYci0gtXq56qr9ZKGHzbEG9uFydrN5EhKtSU\";}s:2:\"id\";s:24:\"olivero_search_form_wide\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:18:\"Search form (wide)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_secondary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"a425651d-4bbc-4735-b403-60eedd891c6d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:29:\"olivero_secondary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-2;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_site_branding',	'a:13:{s:4:\"uuid\";s:36:\"9826d68e-9bcc-4b43-9656-f3d5f0c60619\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:21:\"olivero_site_branding\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_syndicate',	'a:13:{s:4:\"uuid\";s:36:\"d4871bcb-88ea-4b21-8c89-7e1c3151ed0b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0gq3VPg-_UM69FCCWurLFIrrnIjC2HLKhwo9iQNtcUo\";}s:2:\"id\";s:17:\"olivero_syndicate\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"social\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:20:\"node_syndicate_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:20:\"node_syndicate_block\";s:5:\"label\";s:8:\"RSS feed\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"node\";s:11:\"block_count\";i:10;}s:10:\"visibility\";a:0:{}}'),
('',	'block_content.type.basic',	'a:9:{s:4:\"uuid\";s:36:\"8d0c7ff5-11fa-497e-b1cb-232bad118b10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQP5iQy4SdhAMVcjDUncCfkJmTofnHVtXrsMzx4k6Yk\";}s:2:\"id\";s:5:\"basic\";s:5:\"label\";s:11:\"Basic block\";s:8:\"revision\";b:0;s:11:\"description\";s:42:\"A basic block contains a title and a body.\";}'),
('',	'block_content.type.ebt_accordion',	'a:9:{s:4:\"uuid\";s:36:\"532936a4-d4ec-4684-97d3-ea06263ffdfe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dB47Zxr808aSXzelLxShTOImxLGvz9ibkaPpIHw2XL8\";}s:2:\"id\";s:13:\"ebt_accordion\";s:5:\"label\";s:17:\"EBT Accordion/FAQ\";s:8:\"revision\";i:1;s:11:\"description\";s:37:\"Extra Block Type (EBT): Accordion/FAQ\";}'),
('',	'block_content.type.ebt_basic_button',	'a:9:{s:4:\"uuid\";s:36:\"5f0bd962-43f3-4e4c-9dad-bd8ad9ad83bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eTgR86D-XlSSjL0DOkUgyDx9iqTLZCeiiE1Wz1CNl8o\";}s:2:\"id\";s:16:\"ebt_basic_button\";s:5:\"label\";s:16:\"EBT Basic Button\";s:8:\"revision\";i:0;s:11:\"description\";s:36:\"Extra Block Type (EBT): Basic Button\";}'),
('',	'block_content.type.ebt_block',	'a:9:{s:4:\"uuid\";s:36:\"a5b41dbb-434a-4f8f-aa0f-413c4cc768db\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nKr_tXmEQ2IE6yATLpR_w5SQeEqQCm6SSKpCMIx2hKo\";}s:2:\"id\";s:9:\"ebt_block\";s:5:\"label\";s:9:\"EBT Block\";s:8:\"revision\";i:0;s:11:\"description\";s:33:\"Extra Block Type (EBT): EBT Block\";}'),
('',	'block_content.type.ebt_bootstrap_button',	'a:9:{s:4:\"uuid\";s:36:\"9575961f-7777-487f-988c-3898cad5f5b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EPwbWyfVd_vUMqmDcQcJd9ww6p2h7kUQTny9S5dPxXQ\";}s:2:\"id\";s:20:\"ebt_bootstrap_button\";s:5:\"label\";s:20:\"EBT Bootstrap Button\";s:8:\"revision\";i:0;s:11:\"description\";s:40:\"Extra Block Type (EBT): Bootstrap Button\";}'),
('',	'block_content.type.ebt_carousel',	'a:9:{s:4:\"uuid\";s:36:\"a8e8c97d-abf8-4a95-a638-a6a54e403d91\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DXQisXm71ScIY9qHGkk7imRMnjI_dBDSZfzT-uFCzwQ\";}s:2:\"id\";s:12:\"ebt_carousel\";s:5:\"label\";s:12:\"EBT Carousel\";s:8:\"revision\";i:1;s:11:\"description\";s:32:\"Extra Block Type (EBT): Carousel\";}'),
('',	'block_content.type.ebt_columns',	'a:9:{s:4:\"uuid\";s:36:\"31aff369-3823-4bb0-93db-1bca2acd3aa3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CQSPoVI2zOeWs7Xgd9ALoKdgcYScRjwZQK17EBkHKX4\";}s:2:\"id\";s:11:\"ebt_columns\";s:5:\"label\";s:23:\"EBT Columns / Container\";s:8:\"revision\";i:0;s:11:\"description\";s:47:\"Extra Block Type (EBT): EBT Columns / Container\";}'),
('',	'block_content.type.ebt_countdown',	'a:9:{s:4:\"uuid\";s:36:\"17c62d51-6c7f-493f-85b4-fce54035fcf7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"b04bwlmhn4qM9mk46Hq1ekInijGgB9DI7WydX2K6RJg\";}s:2:\"id\";s:13:\"ebt_countdown\";s:5:\"label\";s:13:\"EBT Countdown\";s:8:\"revision\";i:0;s:11:\"description\";s:37:\"Extra Block Type (EBT): EBT Countdown\";}'),
('',	'block_content.type.ebt_counter',	'a:9:{s:4:\"uuid\";s:36:\"f84bf2c7-0d7f-45e5-9e44-618e1cb84f84\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BAdc_syLOJWN_IuQiwJb7kdzLXXokTLaEplzy8ajUBs\";}s:2:\"id\";s:11:\"ebt_counter\";s:5:\"label\";s:11:\"EBT Counter\";s:8:\"revision\";i:0;s:11:\"description\";s:100:\"Extra Block Type (EBT): Counter - Adds Counter with coffee cups, projects, case studies number, etc.\";}'),
('',	'block_content.type.ebt_cta',	'a:9:{s:4:\"uuid\";s:36:\"1a560148-0ddc-4fe6-a137-e201e64082d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k9yRFHPv-0cHC5GXpNilObPbaFf1SBRHn-asOPpDpPA\";}s:2:\"id\";s:7:\"ebt_cta\";s:5:\"label\";s:24:\"EBT Call to Action (CTA)\";s:8:\"revision\";i:1;s:11:\"description\";s:44:\"Extra Block Type (EBT): Call to Action (CTA)\";}'),
('',	'block_content.type.ebt_hero',	'a:9:{s:4:\"uuid\";s:36:\"19fbd216-4f28-4209-a30c-bddd372736ae\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UndgTjioHDq7754rxxFxg1qIXgj6xzvZ2292BZOTduY\";}s:2:\"id\";s:8:\"ebt_hero\";s:5:\"label\";s:8:\"EBT Hero\";s:8:\"revision\";i:1;s:11:\"description\";s:28:\"Extra Block Type (EBT): Hero\";}'),
('',	'block_content.type.ebt_image',	'a:9:{s:4:\"uuid\";s:36:\"9fd85032-8853-4ccb-8f84-451d84cc570c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XzIeU-QRNHX9yTHUrG3pAtW39sABFIN32xzM5Roe_Zs\";}s:2:\"id\";s:9:\"ebt_image\";s:5:\"label\";s:9:\"EBT Image\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Image\";}'),
('',	'block_content.type.ebt_image_gallery',	'a:9:{s:4:\"uuid\";s:36:\"61358808-828f-49a0-a1fc-850ba4856b25\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hyvESyE2V701OB-pYMNV1fcs9afHHvGMwmKvID2dSys\";}s:2:\"id\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:17:\"EBT Image Gallery\";s:8:\"revision\";i:0;s:11:\"description\";s:37:\"Extra Block Type (EBT): Image Gallery\";}'),
('',	'block_content.type.ebt_micromodal',	'a:9:{s:4:\"uuid\";s:36:\"49a7d1d2-299c-43f7-8353-442f7c80126a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yHkIKUcC5OaWnPM6t0NLrROJ_Qie3lZd1nYZCnncyxQ\";}s:2:\"id\";s:14:\"ebt_micromodal\";s:5:\"label\";s:14:\"EBT Micromodal\";s:8:\"revision\";i:0;s:11:\"description\";s:34:\"Extra Block Type (EBT): Micromodal\";}'),
('',	'block_content.type.ebt_quote',	'a:9:{s:4:\"uuid\";s:36:\"6c094884-55e1-4ce3-9782-8302e193358e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"R3qZ2pP9HUZZOVzX7J5oHroNb9W2pfSWulgYrgRbm4g\";}s:2:\"id\";s:9:\"ebt_quote\";s:5:\"label\";s:9:\"EBT Quote\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Quote\";}'),
('',	'block_content.type.ebt_slick_slider',	'a:9:{s:4:\"uuid\";s:36:\"fe1604e8-b328-4b89-bd85-fc64bd553f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dHxKwXfScnz1cdiQPDzE2uUuw62lhpTtSqV5b2YZbrE\";}s:2:\"id\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:16:\"EBT Slick Slider\";s:8:\"revision\";i:0;s:11:\"description\";s:36:\"Extra Block Type (EBT): Slick Slider\";}'),
('',	'block_content.type.ebt_slideshow',	'a:9:{s:4:\"uuid\";s:36:\"7d164bb3-5e33-440f-b644-b566e1827e32\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W-lXlcGHuv4qnJqSIhwhzbs7aE2_VKhpa9-wZzfr-1A\";}s:2:\"id\";s:13:\"ebt_slideshow\";s:5:\"label\";s:13:\"EBT Slideshow\";s:8:\"revision\";i:0;s:11:\"description\";s:33:\"Extra Block Type (EBT): Slideshow\";}'),
('',	'block_content.type.ebt_stats',	'a:9:{s:4:\"uuid\";s:36:\"3e06d945-9c14-4d86-add4-87ce46604987\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MYrjSAxOpL7yIgF7efseTPdxreHwdIytokEU8AsyKOc\";}s:2:\"id\";s:9:\"ebt_stats\";s:5:\"label\";s:9:\"EBT Stats\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Stats\";}'),
('',	'block_content.type.ebt_tabs',	'a:9:{s:4:\"uuid\";s:36:\"a548c9cd-2123-460d-ac7a-3776cbd6628d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2Zf0IzYoN8bXlbuz0O0K2EFPtAJ-8Zgijs9KDbMjPbU\";}s:2:\"id\";s:8:\"ebt_tabs\";s:5:\"label\";s:8:\"EBT Tabs\";s:8:\"revision\";i:1;s:11:\"description\";s:28:\"Extra Block Type (EBT): Tabs\";}'),
('',	'block_content.type.ebt_text',	'a:9:{s:4:\"uuid\";s:36:\"4d70b021-1215-4212-93ff-3a65cfe166f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EfDKjvl4An381lwiUletrxyYGHVSXr0ylsIz7wG4FkM\";}s:2:\"id\";s:8:\"ebt_text\";s:5:\"label\";s:8:\"EBT Text\";s:8:\"revision\";i:1;s:11:\"description\";s:40:\"Adds Text block type with WYSIWYG editor\";}'),
('',	'block_content.type.ebt_tiles',	'a:9:{s:4:\"uuid\";s:36:\"a4695763-bb05-45b7-877a-2988bc9c0c68\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7NM6NtKtRJqDl2LKF2ttqtshhXn4nV3DIIr56XEhBGw\";}s:2:\"id\";s:9:\"ebt_tiles\";s:5:\"label\";s:9:\"EBT Tiles\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Tiles\";}'),
('',	'block_content.type.ebt_timeline',	'a:9:{s:4:\"uuid\";s:36:\"8299bf83-c3a5-401f-a1b8-bf9bb009af40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bjr_DHRSS1dmovJ9hu9PkQkEIHfJ9wcHbVFuexiFC7I\";}s:2:\"id\";s:12:\"ebt_timeline\";s:5:\"label\";s:12:\"EBT Timeline\";s:8:\"revision\";i:0;s:11:\"description\";s:32:\"Extra Block Type (EBT): Timeline\";}'),
('',	'block_content.type.ebt_video',	'a:9:{s:4:\"uuid\";s:36:\"f30a12fb-b405-4036-a46f-fc82d5b577e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Pv_CZ1UneLNgz_a4bh6MvN5tmAbmgeaL-sIZl2WyaP0\";}s:2:\"id\";s:9:\"ebt_video\";s:5:\"label\";s:9:\"EBT Video\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Video\";}'),
('',	'block_content.type.ebt_video_and_image_gallery',	'a:9:{s:4:\"uuid\";s:36:\"c8e02878-ad67-4c1d-8022-1bcae43b1e10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t5QqFRQehMUNqFlizm8etvw0z1ASVYieiYTD5A-AMwM\";}s:2:\"id\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:27:\"EBT Video and Image Gallery\";s:8:\"revision\";i:0;s:11:\"description\";s:47:\"Extra Block Type (EBT): Video and Image Gallery\";}'),
('',	'block_content.type.ebt_views',	'a:9:{s:4:\"uuid\";s:36:\"6eb11d1d-b72a-4d76-a761-9c91bacf5654\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kKtLeF4r10QhfrqB_NLR_pg7hmb7wKFxIx53f6SPZPM\";}s:2:\"id\";s:9:\"ebt_views\";s:5:\"label\";s:9:\"EBT Views\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Views\";}'),
('',	'block_content.type.ebt_webform',	'a:9:{s:4:\"uuid\";s:36:\"656280fa-6df7-4fb1-97e2-0fba6d8acda7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N2h4kIizWCZkC89K2_Xf6_WGzjG-9XpMDds_jEJjsGs\";}s:2:\"id\";s:11:\"ebt_webform\";s:5:\"label\";s:11:\"EBT Webform\";s:8:\"revision\";i:0;s:11:\"description\";s:35:\"Extra Paragraph Type (EPT): Webform\";}'),
('',	'block_content.type.ebt_webform_popup',	'a:9:{s:4:\"uuid\";s:36:\"3f1d7aa5-63b0-4cf5-8b1e-c69f240e9a70\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2PyweimMCiXZdcfL7o3WT6DPFw8x8O1FPQfufWOKf5A\";}s:2:\"id\";s:17:\"ebt_webform_popup\";s:5:\"label\";s:17:\"EBT Webform Popup\";s:8:\"revision\";i:0;s:11:\"description\";s:37:\"Extra Block Type (EBT): Webform Popup\";}'),
('',	'claro.settings',	'a:1:{s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}}'),
('',	'config_ignore.settings',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IgOVnECx6lbVt6JVFnadoEEugneDf3UblPZnOzov43Q\";}s:4:\"mode\";s:6:\"simple\";s:23:\"ignored_config_entities\";a:0:{}}'),
('',	'contact.form.feedback',	'a:12:{s:4:\"uuid\";s:36:\"816a1630-e792-4f5c-a26b-35e17703bb04\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vymHlgJy26BuI5GGj9-IXjwR3dRC5C0tij4BpWJnoqw\";}s:2:\"id\";s:8:\"feedback\";s:5:\"label\";s:16:\"Website feedback\";s:10:\"recipients\";a:1:{i:0;s:17:\"admin@example.com\";}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),
('',	'contact.form.personal',	'a:12:{s:4:\"uuid\";s:36:\"6c8348fa-3a53-48ce-ac8f-7aa4d1c5c9cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jonvgt3CkUM2eMLTFwWfHileWWDC4YtXCuIlCahTk_I\";}s:2:\"id\";s:8:\"personal\";s:5:\"label\";s:21:\"Personal contact form\";s:10:\"recipients\";a:0:{}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),
('',	'contact.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U69DBeuvXuNVOC15rVNaBjDPK2fWFbo9v4takdYSSO8\";}s:12:\"default_form\";s:8:\"feedback\";s:5:\"flood\";a:2:{s:5:\"limit\";i:5;s:8:\"interval\";i:3600;}s:20:\"user_default_enabled\";b:1;}'),
('',	'core.base_field_override.node.page.promote',	'a:17:{s:4:\"uuid\";s:36:\"708a5000-dcce-43d4-8735-a04f3c0ae480\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:14:\"node.type.page\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fPUEnm4T5zfZRr3ttDUqq7yCDd2uW3clWD-pvos4tlQ\";}s:2:\"id\";s:17:\"node.page.promote\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:22:\"Promoted to front page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),
('',	'core.date_format.fallback',	'a:9:{s:4:\"uuid\";s:36:\"7066953f-600d-4fc2-84b8-58826b84da0a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7klS5IWXrwzVaPpYZFAs6wcx8U2FF1X73OfrtTsvuvE\";}s:2:\"id\";s:8:\"fallback\";s:5:\"label\";s:20:\"Fallback date format\";s:6:\"locked\";b:1;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),
('',	'core.date_format.html_date',	'a:9:{s:4:\"uuid\";s:36:\"c8f2ea5d-ee32-44b5-b2a4-73b29881a91d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EOQltUQPmgc6UQ2rcJ4Xi_leCEJj5ui0TR-12duS-Tk\";}s:2:\"id\";s:9:\"html_date\";s:5:\"label\";s:9:\"HTML Date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-m-d\";}'),
('',	'core.date_format.html_datetime',	'a:9:{s:4:\"uuid\";s:36:\"1b677438-94c3-4570-af48-166d068688f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxfClwZIRXIdcvMrE--WkcZxDGUVoOIE3Sm2NRZlFuE\";}s:2:\"id\";s:13:\"html_datetime\";s:5:\"label\";s:13:\"HTML Datetime\";s:6:\"locked\";b:1;s:7:\"pattern\";s:13:\"Y-m-d\\TH:i:sO\";}'),
('',	'core.date_format.html_month',	'a:9:{s:4:\"uuid\";s:36:\"b6631c90-a449-4cb7-93dc-33564909142a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Z7KuCUwM_WdTNvLcoltuX3_8d-s-8FZkTN6KgNwF0eM\";}s:2:\"id\";s:10:\"html_month\";s:5:\"label\";s:10:\"HTML Month\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"Y-m\";}'),
('',	'core.date_format.html_time',	'a:9:{s:4:\"uuid\";s:36:\"387b27db-0cbb-49c6-bce9-e2ae838a4eb4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M7yqicYkU36hRy5p9drAaGBBihhUD1OyujFrAaQ93ZE\";}s:2:\"id\";s:9:\"html_time\";s:5:\"label\";s:9:\"HTML Time\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"H:i:s\";}'),
('',	'core.date_format.html_week',	'a:9:{s:4:\"uuid\";s:36:\"aab47b59-a6c1-4205-a1bf-a0a7164b9f8d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKD4WsoV_wFgv2vgI4mcAAFSIzrye17ykzdwrnApkfY\";}s:2:\"id\";s:9:\"html_week\";s:5:\"label\";s:9:\"HTML Week\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-\\WW\";}'),
('',	'core.date_format.html_year',	'a:9:{s:4:\"uuid\";s:36:\"58dd1255-3bf1-465a-af62-74c3770e7861\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjekiQuX9RbVQ2_8jOHBL94RgYLePqX7wpfNGgcQzrk\";}s:2:\"id\";s:9:\"html_year\";s:5:\"label\";s:9:\"HTML Year\";s:6:\"locked\";b:1;s:7:\"pattern\";s:1:\"Y\";}'),
('',	'core.date_format.html_yearless_date',	'a:9:{s:4:\"uuid\";s:36:\"1bea5c34-af20-4053-9459-595e10032d04\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VpawMrKPEPCkoO4YpPa0TDFO2dgiIHfTziJtwlmUxc\";}s:2:\"id\";s:18:\"html_yearless_date\";s:5:\"label\";s:18:\"HTML Yearless date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"m-d\";}'),
('',	'core.date_format.long',	'a:9:{s:4:\"uuid\";s:36:\"3228fcaa-0dfe-4342-b299-d12cfba43674\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"og8sWXhBuHbLMw3CoiBEZjgqSyhFBFmcbUW_wLcfNbo\";}s:2:\"id\";s:4:\"long\";s:5:\"label\";s:17:\"Default long date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:15:\"l, F j, Y - H:i\";}'),
('',	'core.date_format.medium',	'a:9:{s:4:\"uuid\";s:36:\"2ae289c3-6325-45f0-9ec2-99609e297832\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nzL5d024NjXIX_8TlT6uFAu973lmfkmHklJC-2i9rAE\";}s:2:\"id\";s:6:\"medium\";s:5:\"label\";s:19:\"Default medium date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),
('',	'core.date_format.olivero_medium',	'a:9:{s:4:\"uuid\";s:36:\"9f0d1e0f-c3b1-477d-8825-2a12a34e41f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mt6cmxUbDZ9XxD6p25WQ8tj3_JcX8ylfcddwZc8gcAE\";}s:2:\"id\";s:14:\"olivero_medium\";s:5:\"label\";s:14:\"Olivero Medium\";s:6:\"locked\";b:0;s:7:\"pattern\";s:8:\"j  F,  Y\";}'),
('',	'core.date_format.short',	'a:9:{s:4:\"uuid\";s:36:\"ced168ae-c45d-4704-b1d4-c36fb84b47f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AlzeyytA8InBgxIG9H2UDJYs3CG98Zj6yRsDKmlbZwA\";}s:2:\"id\";s:5:\"short\";s:5:\"label\";s:18:\"Default short date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:11:\"m/d/Y - H:i\";}'),
('',	'core.entity_form_display.block_content.basic.default',	'a:11:{s:4:\"uuid\";s:36:\"2fb7a522-cf93-4f57-be42-0cb4c4d31165\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jAps3FCxvKecABS_tgExbhCZrBLQB3bNPWw18WjE3ss\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_accordion.default',	'a:12:{s:4:\"uuid\";s:36:\"7f7f76e5-ece6-4e93-9154-f7a914b883b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:44:\"field.field.block_content.ebt_accordion.body\";i:2;s:59:\"field.field.block_content.ebt_accordion.field_ebt_accordion\";i:3;s:58:\"field.field.block_content.ebt_accordion.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:13:\"ebt_accordion\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:19:\"field_ebt_accordion\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PzCFAyJrF1CHyonIY9UYHLYTUaTzxXhcv5uiJWU41DQ\";}s:2:\"id\";s:35:\"block_content.ebt_accordion.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ebt_accordion\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:22:\"ebt_settings_accordion\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_basic_button.default',	'a:11:{s:4:\"uuid\";s:36:\"37393abe-e80e-4438-a211-2b6937d2a850\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:70:\"field.field.block_content.ebt_basic_button.field_ebt_basic_button_link\";i:2;s:61:\"field.field.block_content.ebt_basic_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:16:\"ebt_basic_button\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TL36cBmV77cMjPzUpkHgNG3I6F4EZY_Iyr9A67xICRc\";}s:2:\"id\";s:38:\"block_content.ebt_basic_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:27:\"field_ebt_basic_button_link\";a:5:{s:6:\"weight\";i:27;s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"link_default\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:25:\"ebt_settings_basic_button\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_block.default',	'a:12:{s:4:\"uuid\";s:36:\"db7027b5-0083-4c23-932e-b8140582e848\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:40:\"field.field.block_content.ebt_block.body\";i:2;s:57:\"field.field.block_content.ebt_block.field_ebt_block_block\";i:3;s:54:\"field.field.block_content.ebt_block.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:11:\"block_field\";i:1;s:8:\"ebt_core\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:21:\"field_ebt_block_block\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kmx4yzKEAL5_us-5XrISqRaGX28ieDECPBvSA4I53eM\";}s:2:\"id\";s:31:\"block_content.ebt_block.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_block_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_bootstrap_button.default',	'a:11:{s:4:\"uuid\";s:36:\"3fd59f0a-2725-4fa8-85fd-69b00e41a16c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:78:\"field.field.block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link\";i:2;s:65:\"field.field.block_content.ebt_bootstrap_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:20:\"ebt_bootstrap_button\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JwJzpFM95dLE-G20D_3HgaKN8MiWZGW-4JEwf0rWVeA\";}s:2:\"id\";s:42:\"block_content.ebt_bootstrap_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:31:\"field_ebt_bootstrap_button_link\";a:5:{s:6:\"weight\";i:27;s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"link_default\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:29:\"ebt_settings_bootstrap_button\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_carousel.default',	'a:12:{s:4:\"uuid\";s:36:\"d9501a4e-79d4-4429-a572-1bc3f75caa0e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:57:\"field.field.block_content.ebt_carousel.field_ebt_carousel\";i:2;s:57:\"field.field.block_content.ebt_carousel.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:12:\"ebt_carousel\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_carousel\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QXlNXkmdvt1D3vvq3Xts_hS6xZcsvaZ_VMIpv7HSlJ4\";}s:2:\"id\";s:34:\"block_content.ebt_carousel.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_carousel\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:21:\"ebt_settings_carousel\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_columns.default',	'a:12:{s:4:\"uuid\";s:36:\"913c0375-72d6-4813-b10b-3696ff0b8a73\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:42:\"field.field.block_content.ebt_columns.body\";i:2;s:62:\"field.field.block_content.ebt_columns.field_ebt_columns_blocks\";i:3;s:56:\"field.field.block_content.ebt_columns.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:11:\"block_field\";i:1;s:11:\"ebt_columns\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:24:\"field_ebt_columns_blocks\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"F_pGWF26Foj_C1Hq_KcX77H7LkKnWLFPV7iyltEH6CM\";}s:2:\"id\";s:33:\"block_content.ebt_columns.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_columns_blocks\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_columns\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_countdown.default',	'a:12:{s:4:\"uuid\";s:36:\"b9105cc0-df88-453b-a92d-90b5e523a386\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:44:\"field.field.block_content.ebt_countdown.body\";i:2;s:64:\"field.field.block_content.ebt_countdown.field_ebt_countdown_date\";i:3;s:58:\"field.field.block_content.ebt_countdown.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"datetime\";i:1;s:13:\"ebt_countdown\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:24:\"field_ebt_countdown_date\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GsQnmOfbEL4H_QrRxe1J3YG8Iq7SEHUP16XkMeLPtac\";}s:2:\"id\";s:35:\"block_content.ebt_countdown.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:21;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_countdown_date\";a:5:{s:4:\"type\";s:16:\"datetime_default\";s:6:\"weight\";i:22;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:22:\"ebt_settings_countdown\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_counter.default',	'a:12:{s:4:\"uuid\";s:36:\"289e89e1-cc7d-4e50-8100-bb16ed9875c1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:42:\"field.field.block_content.ebt_counter.body\";i:2;s:60:\"field.field.block_content.ebt_counter.field_ebt_counter_icon\";i:3;s:61:\"field.field.block_content.ebt_counter.field_ebt_counter_items\";i:4;s:62:\"field.field.block_content.ebt_counter.field_ebt_counter_number\";i:5;s:56:\"field.field.block_content.ebt_counter.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:11:\"ebt_counter\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:5;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:23:\"field_ebt_counter_items\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k07TlMoweT9Yz6bjpmLGKe6YvkshSJkTRnz6uGMQHkI\";}s:2:\"id\";s:33:\"block_content.ebt_counter.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_counter_items\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_counter\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:22:\"field_ebt_counter_icon\";b:1;s:24:\"field_ebt_counter_number\";b:1;}}'),
('',	'core.entity_form_display.block_content.ebt_cta.default',	'a:12:{s:4:\"uuid\";s:36:\"8a7d1838-30dd-4dc0-a2ae-b9e053ede2c9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:38:\"field.field.block_content.ebt_cta.body\";i:2;s:60:\"field.field.block_content.ebt_cta.field_ebt_cta_column_image\";i:3;s:52:\"field.field.block_content.ebt_cta.field_ebt_cta_link\";i:4;s:59:\"field.field.block_content.ebt_cta.field_ebt_cta_second_link\";i:5;s:53:\"field.field.block_content.ebt_cta.field_ebt_cta_title\";i:6;s:52:\"field.field.block_content.ebt_cta.field_ebt_settings\";}s:6:\"module\";a:5:{i:0;s:7:\"ebt_cta\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:5:{i:0;s:19:\"field_ebt_cta_title\";i:1;s:4:\"body\";i:2;s:26:\"field_ebt_cta_column_image\";i:3;s:18:\"field_ebt_cta_link\";i:4;s:25:\"field_ebt_cta_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vYgl9r_zBmBwCVILYRfEwPU5CbS9sLUc-A0mmAR2nq4\";}s:2:\"id\";s:29:\"block_content.ebt_cta.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ebt_cta_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_cta_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ebt_cta_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ebt_cta_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:16:\"ebt_settings_cta\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_hero.default',	'a:12:{s:4:\"uuid\";s:36:\"d6f88c18-d8de-40c5-9c43-c1c4d94583bd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:39:\"field.field.block_content.ebt_hero.body\";i:2;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_column_image\";i:3;s:54:\"field.field.block_content.ebt_hero.field_ebt_hero_link\";i:4;s:61:\"field.field.block_content.ebt_hero.field_ebt_hero_second_link\";i:5;s:55:\"field.field.block_content.ebt_hero.field_ebt_hero_title\";i:6;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_title_prefix\";i:7;s:53:\"field.field.block_content.ebt_hero.field_ebt_settings\";}s:6:\"module\";a:5:{i:0;s:8:\"ebt_hero\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:6:{i:0;s:20:\"field_ebt_hero_title\";i:1;s:27:\"field_ebt_hero_title_prefix\";i:2;s:4:\"body\";i:3;s:27:\"field_ebt_hero_column_image\";i:4;s:19:\"field_ebt_hero_link\";i:5;s:26:\"field_ebt_hero_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GQBJ-wowpRaxqn3ERit4j93oiUyIBZaIJDtySINgXhM\";}s:2:\"id\";s:30:\"block_content.ebt_hero.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:8:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_hero_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ebt_hero_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ebt_hero_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_hero_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_hero_title_prefix\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:17:\"ebt_settings_hero\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_image.default',	'a:12:{s:4:\"uuid\";s:36:\"d00c707c-3248-4967-a6d8-4410bbfeb58f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:51:\"field.field.block_content.ebt_image.field_ebt_image\";i:2;s:59:\"field.field.block_content.ebt_image.field_ebt_image_caption\";i:3;s:56:\"field.field.block_content.ebt_image.field_ebt_image_link\";i:4;s:54:\"field.field.block_content.ebt_image.field_ebt_settings\";}s:6:\"module\";a:5:{i:0;s:9:\"ebt_image\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ebt_image\";i:1;s:23:\"field_ebt_image_caption\";i:2;s:20:\"field_ebt_image_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DD35mMXZ3KVmfiicbnARcLgWKRQLT1HYVk6OHxJ-iBk\";}s:2:\"id\";s:31:\"block_content.ebt_image.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:15:\"field_ebt_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:26;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_image_caption\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:27;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_image_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:28;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_image\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_image_gallery.default',	'a:12:{s:4:\"uuid\";s:36:\"90302297-9a10-4688-91b6-c1672cf0a17e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:48:\"field.field.block_content.ebt_image_gallery.body\";i:2;s:67:\"field.field.block_content.ebt_image_gallery.field_ebt_image_gallery\";i:3;s:62:\"field.field.block_content.ebt_image_gallery.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:17:\"ebt_image_gallery\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:4:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:23:\"field_ebt_image_gallery\";i:3;s:8:\"langcode\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0PSdTVGfXs7VaqV30tsbYPvmzGKHhU4hZYgKxHIHVcU\";}s:2:\"id\";s:39:\"block_content.ebt_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_image_gallery\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:26:\"ebt_settings_image_gallery\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_micromodal.default',	'a:12:{s:4:\"uuid\";s:36:\"50e0e4ff-bae9-4a5d-a915-ec8cdc49ff77\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:45:\"field.field.block_content.ebt_micromodal.body\";i:2;s:67:\"field.field.block_content.ebt_micromodal.field_ebt_micromodal_title\";i:3;s:59:\"field.field.block_content.ebt_micromodal.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:14:\"ebt_micromodal\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:26:\"field_ebt_micromodal_title\";i:1;s:4:\"body\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZNJcRUtL7EWaVB-UgRyHYVB4-th0NpBsk6t-AcQiZc0\";}s:2:\"id\";s:36:\"block_content.ebt_micromodal.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ebt_micromodal_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:23:\"ebt_settings_micromodal\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_quote.default',	'a:12:{s:4:\"uuid\";s:36:\"3ac9c5a0-b4a9-4360-8947-feabad5e7f71\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:40:\"field.field.block_content.ebt_quote.body\";i:2;s:58:\"field.field.block_content.ebt_quote.field_ebt_quote_author\";i:3;s:57:\"field.field.block_content.ebt_quote.field_ebt_quote_image\";i:4;s:54:\"field.field.block_content.ebt_quote.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_quote\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:4:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:22:\"field_ebt_quote_author\";i:3;s:21:\"field_ebt_quote_image\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N-LtYp4PCPoTpwSFmV_pxSB5hcbey07dO7biDALNdbg\";}s:2:\"id\";s:31:\"block_content.ebt_quote.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ebt_quote_author\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_quote_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_quote\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_slick_slider.default',	'a:12:{s:4:\"uuid\";s:36:\"92792509-019c-4727-be95-79a35850d3e8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:47:\"field.field.block_content.ebt_slick_slider.body\";i:2;s:61:\"field.field.block_content.ebt_slick_slider.field_ebt_settings\";i:3;s:65:\"field.field.block_content.ebt_slick_slider.field_ebt_slick_slider\";}s:6:\"module\";a:4:{i:0;s:16:\"ebt_slick_slider\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:22:\"field_ebt_slick_slider\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bpVaLzDSRRw2IoN4B7lX2DmpEtGagQ_kHdtfu2QnBWk\";}s:2:\"id\";s:38:\"block_content.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:4;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:25:\"ebt_settings_slick_slider\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ebt_slick_slider\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_slideshow.default',	'a:12:{s:4:\"uuid\";s:36:\"1e354f38-03e4-4eb3-83d9-64e23ea8e653\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:58:\"field.field.block_content.ebt_slideshow.field_ebt_settings\";i:2;s:59:\"field.field.block_content.ebt_slideshow.field_ebt_slideshow\";}s:6:\"module\";a:3:{i:0;s:13:\"ebt_slideshow\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:19:\"field_ebt_slideshow\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6DA12pCUzWErNlrzV5uI2gCLocIzFk1R4r6_m3BD42A\";}s:2:\"id\";s:35:\"block_content.ebt_slideshow.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:22;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:22:\"ebt_settings_slideshow\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_slideshow\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:21;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_stats.default',	'a:12:{s:4:\"uuid\";s:36:\"52b22b0d-85e9-4340-9aa7-8f4febf9050e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:40:\"field.field.block_content.ebt_stats.body\";i:2;s:54:\"field.field.block_content.ebt_stats.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_stats.field_ebt_stats\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_stats\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:15:\"field_ebt_stats\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_L5lmPQyOe6uFAwlop2yf-ekQRX87-T_CXqJ-IIRg7Y\";}s:2:\"id\";s:31:\"block_content.ebt_stats.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:27;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_stats\";s:6:\"weight\";i:22;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ebt_stats\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:28;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_tabs.default',	'a:12:{s:4:\"uuid\";s:36:\"a7d39dc1-5b23-4427-87b3-0bbc28e7b99b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:53:\"field.field.block_content.ebt_tabs.field_ebt_settings\";i:2;s:49:\"field.field.block_content.ebt_tabs.field_ebt_tabs\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_tabs\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:14:\"field_ebt_tabs\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiD2k00iSxydyLNXRexQsZwtt3kdC7yWjKnIE2TPsds\";}s:2:\"id\";s:30:\"block_content.ebt_tabs.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:17:\"ebt_settings_tabs\";s:6:\"region\";s:7:\"content\";}s:14:\"field_ebt_tabs\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_text.default',	'a:12:{s:4:\"uuid\";s:36:\"a186725f-445b-4043-83f2-c3bc2d5b1b87\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:39:\"field.field.block_content.ebt_text.body\";i:2;s:53:\"field.field.block_content.ebt_text.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"info\";i:1;s:4:\"body\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qr5FWoE0Z8wFG-omC1KS3oG2wlcQ86J_zl7wsCOUCto\";}s:2:\"id\";s:30:\"block_content.ebt_text.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:1;s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_tiles.default',	'a:12:{s:4:\"uuid\";s:36:\"8876d1b6-9d39-4029-abb6-793bf6be88df\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:40:\"field.field.block_content.ebt_tiles.body\";i:2;s:54:\"field.field.block_content.ebt_tiles.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_tiles.field_ebt_tiles\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_tiles\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:240;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:15:\"field_ebt_tiles\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"B8B292gqxvNzedSxDhs7Ss9nrmX75yMSBzLtMUBusxw\";}s:2:\"id\";s:31:\"block_content.ebt_tiles.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_tiles\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ebt_tiles\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_timeline.default',	'a:12:{s:4:\"uuid\";s:36:\"2d00d268-fcaf-44e1-a5d2-99bf5b954cee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:57:\"field.field.block_content.ebt_timeline.field_ebt_settings\";i:2;s:57:\"field.field.block_content.ebt_timeline.field_ebt_timeline\";}s:6:\"module\";a:3:{i:0;s:12:\"ebt_timeline\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_timeline\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lnh43KY0voHRBULlVHJ5n0V8Twh6dwTa482WpJEf7nU\";}s:2:\"id\";s:34:\"block_content.ebt_timeline.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:21:\"ebt_settings_timeline\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_timeline\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_video.default',	'a:12:{s:4:\"uuid\";s:36:\"adebe1bd-2c8a-4e24-8830-be649450bd8e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:40:\"field.field.block_content.ebt_video.body\";i:2;s:54:\"field.field.block_content.ebt_video.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_video.field_ebt_video\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_video\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:15:\"field_ebt_video\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tS6jBKcl-OCTitIjmc0ugKz08ENt8SoAs6NCnjOy-ek\";}s:2:\"id\";s:31:\"block_content.ebt_video.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_video\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ebt_video\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_video_and_image_gallery.default',	'a:12:{s:4:\"uuid\";s:36:\"4de506fd-736b-43b4-b4e9-87a88229b117\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:58:\"field.field.block_content.ebt_video_and_image_gallery.body\";i:2;s:72:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_settings\";i:3;s:81:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images\";}s:6:\"module\";a:4:{i:0;s:27:\"ebt_video_and_image_gallery\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:27:\"field_ebt_videos_and_images\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QGg-MV2IynMGDSKSb1vqdwAQyQ8p83BjC_W3v8O_1lg\";}s:2:\"id\";s:49:\"block_content.ebt_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:36:\"ebt_settings_video_and_image_gallery\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_videos_and_images\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_views.default',	'a:12:{s:4:\"uuid\";s:36:\"9166e36b-940f-481e-9cf3-5aacb1ef1208\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:40:\"field.field.block_content.ebt_views.body\";i:2;s:54:\"field.field.block_content.ebt_views.field_ebt_settings\";i:3;s:57:\"field.field.block_content.ebt_views.field_ebt_views_views\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";i:3;s:14:\"viewsreference\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:21:\"field_ebt_views_views\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E47G4jhOaCiwauUu7Cp8eOG0n1xF0TbNyp6_qUkGMcI\";}s:2:\"id\";s:31:\"block_content.ebt_views.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_views_views\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_webform.default',	'a:11:{s:4:\"uuid\";s:36:\"e6638a9a-dd30-4dab-b46a-9c913eb531bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:42:\"field.field.block_content.ebt_webform.body\";i:2;s:56:\"field.field.block_content.ebt_webform.field_ebt_settings\";i:3;s:60:\"field.field.block_content.ebt_webform.field_ebt_webform_form\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rtuRBm-Z8ZrdOhT7mc0JrMlWONwesUqNR-IwTM6axEY\";}s:2:\"id\";s:33:\"block_content.ebt_webform.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:26;s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:29;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_webform_form\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:2:{s:12:\"default_data\";b:1;s:8:\"webforms\";a:0:{}}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_webform_popup.default',	'a:11:{s:4:\"uuid\";s:36:\"76422ca6-6b1c-4ebd-b6e5-d362e8bc423d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:62:\"field.field.block_content.ebt_webform_popup.field_ebt_settings\";i:2;s:72:\"field.field.block_content.ebt_webform_popup.field_ebt_webform_popup_form\";}s:6:\"module\";a:2:{i:0;s:17:\"ebt_webform_popup\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-EvEMaGTSq7rxJjzGuhqBIybUTNrM39BXJjRKhFkDos\";}s:2:\"id\";s:39:\"block_content.ebt_webform_popup.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:26:\"ebt_settings_webform_popup\";s:6:\"region\";s:7:\"content\";}s:28:\"field_ebt_webform_popup_form\";a:5:{s:6:\"weight\";i:27;s:8:\"settings\";a:2:{s:12:\"default_data\";b:1;s:8:\"webforms\";a:0:{}}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.media.audio.default',	'a:11:{s:4:\"uuid\";s:36:\"9efccee6-8cc4-4ff4-92bb-0553278490ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"G2_SKH3jmI9FQeXSUxo3KgQqiyF1hPDEkc7-3-rCSbc\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_audio_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.audio.media_library',	'a:11:{s:4:\"uuid\";s:36:\"70924fc9-698f-43ce-8125-c9f66ca37236\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:16:\"media.type.audio\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"28vwMIYtvyjPcD4RyciZXIztxtZgmuWRCNgYemr_SZE\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.document.default',	'a:11:{s:4:\"uuid\";s:36:\"c99f3040-4f5d-4326-9040-193db1713a88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aewrRkePgJzdD5kPOq8JeMcKHs6yat49nE7ZeCQzQZg\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_media_document\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.document.media_library',	'a:11:{s:4:\"uuid\";s:36:\"8df854a8-6d93-49a7-803e-4334857e73fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:19:\"media.type.document\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dcpfpqyLXOSGpulacMAJW3H-G34_LeNsjdfxd1_oCfY\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.image.default',	'a:11:{s:4:\"uuid\";s:36:\"7b876128-538a-4826-a5a4-52747a729203\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:21:\"image.style.thumbnail\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JSY4-JPyNZBiYYo6imdRYF6_SdtWQexPndrLvn3-vw4\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.image.media_library',	'a:11:{s:4:\"uuid\";s:36:\"3d16f00d-32eb-4ac9-a711-00689691832b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BMLrK4zKp8-FFnMseBdT_6h6YipUsKRfbDf_3WUB5HA\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:5:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.remote_video.default',	'a:11:{s:4:\"uuid\";s:36:\"d145d9a4-1eb4-4ece-a5e9-4e77dd7a4b2a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pM8mGlwfpvfG_y5tZn0lGAXFLXz2_yKkL7MvWZsRqdA\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_media_oembed_video\";a:5:{s:4:\"type\";s:16:\"oembed_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.remote_video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"996b87ca-42a9-4803-afcc-24ebfbdf7849\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBgPW-uaXRaICBwLaVc16rXpRiLSknDIdF9q0XL7qso\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.video.default',	'a:11:{s:4:\"uuid\";s:36:\"432d0cdf-b7f6-4927-af19-9a26a2f71c65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0kIIaDTt6dixXy8TZkat2MNGZJ6vkRG8TaBWTy3E1bM\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_video_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"eed6f1c2-957f-4ca5-9d11-57d9fb6c9564\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:16:\"media.type.video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kGv8YsopqHvzTzb7QTINWcv0fnNa5ZDQyZxpOQR2vro\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.node.article.default',	'a:11:{s:4:\"uuid\";s:36:\"c224932f-6de0-4883-88df-0c2ae5186624\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:39:\"field.field.node.article.field_metatags\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:47:\"field.field.node.article.layout_builder__layout\";i:5;s:21:\"image.style.thumbnail\";i:6;s:17:\"node.type.article\";}s:6:\"module\";a:4:{i:0;s:7:\"metatag\";i:1;s:4:\"path\";i:2;s:9:\"svg_image\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ewbd6G2uX456-bgwseM2Q-KQG3RkASoyHmTh-XR3oLU\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:12:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:11:\"field_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_metatags\";a:5:{s:4:\"type\";s:16:\"metatag_firehose\";s:6:\"weight\";i:121;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:7:\"sidebar\";b:1;s:11:\"use_details\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:10:\"field_tags\";a:5:{s:4:\"type\";s:34:\"entity_reference_autocomplete_tags\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:13:\"url_redirects\";a:4:{s:6:\"weight\";i:50;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_form_display.node.page.default',	'a:11:{s:4:\"uuid\";s:36:\"095e0e3b-5060-4869-9c69-f8044cadf927\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:26:\"field.field.node.page.body\";i:1;s:36:\"field.field.node.page.field_metatags\";i:2;s:44:\"field.field.node.page.layout_builder__layout\";i:3;s:14:\"node.type.page\";}s:6:\"module\";a:3:{i:0;s:7:\"metatag\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:10:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:31;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_metatags\";a:5:{s:4:\"type\";s:16:\"metatag_firehose\";s:6:\"weight\";i:121;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:7:\"sidebar\";b:1;s:11:\"use_details\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:13:\"url_redirects\";a:4:{s:6:\"weight\";i:50;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_accordion.default',	'a:11:{s:4:\"uuid\";s:36:\"ee2f8f98-b9f7-4254-9737-68dc2197b2fd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:60:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_text\";i:1;s:61:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_title\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VV4WvHQlFMN4Xl5jLocxzCyuI7nCn1nGWGmJZbXlG2Q\";}s:2:\"id\";s:31:\"paragraph.ebt_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ebt_accordion_text\";a:5:{s:6:\"weight\";i:1;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_accordion_title\";a:5:{s:6:\"weight\";i:0;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_carousel.default',	'a:11:{s:4:\"uuid\";s:36:\"d1b4eb72-c64f-476b-bb62-88226cb19793\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:61:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_caption\";i:1;s:59:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yERJpwaJ1QC8Q1Gr8Tezl9O_q0ufoiR8gwonaEjSspw\";}s:2:\"id\";s:30:\"paragraph.ebt_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ebt_carousel_caption\";a:5:{s:6:\"weight\";i:1;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_carousel_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_counter_item.default',	'a:11:{s:4:\"uuid\";s:36:\"4579f4f8-31b0-4cd5-b9fe-f87cd45f5fb6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_description\";i:1;s:61:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_icon\";i:2;s:63:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_number\";i:3;s:62:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"snzZLNDA9DFF0msO0Up9bLDhB8kgJR3OFtnbryzGVms\";}s:2:\"id\";s:34:\"paragraph.ebt_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ebt_counter_description\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ebt_counter_icon\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_counter_number\";a:5:{s:4:\"type\";s:6:\"number\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_counter_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_slick_slider.default',	'a:11:{s:4:\"uuid\";s:36:\"49d083c6-462d-45e8-b2da-c158f1f21e4d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:67:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_image\";i:1;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_link\";i:2;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_text\";i:3;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SrB8f_Znsaiqtv7a46b7z53joZ5A1SCIFKCJUjFizQk\";}s:2:\"id\";s:34:\"paragraph.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ebt_slick_slider_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_slick_slider_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_slick_slider_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_slideshow.default',	'a:11:{s:4:\"uuid\";s:36:\"4d6b8979-02dc-432e-a1ee-1e39bf6d0736\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_link\";i:1;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_slide\";i:2;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_text\";i:3;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_title\";i:4;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1kjXAT0qkIlX0WEGDAcnGaQHa1XeILgCDnWcPfDVJ0\";}s:2:\"id\";s:31:\"paragraph.ebt_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ebt_slideshow_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ebt_slideshow_slide\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_slideshow_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ebt_slideshow_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_stats_item.default',	'a:11:{s:4:\"uuid\";s:36:\"a7152796-e586-430a-a770-6b093d09cb7c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:59:\"field.field.paragraph.ebt_stats_item.field_stats_item_image\";i:1;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_link\";i:2;s:60:\"field.field.paragraph.ebt_stats_item.field_stats_item_number\";i:3;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_LZlRyxzZkfNDaWmAIuAHQXMASYeRLzj_Tu9HB2QGnw\";}s:2:\"id\";s:32:\"paragraph.ebt_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:22:\"field_stats_item_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_stats_item_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_stats_item_number\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_stats_item_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_tab.default',	'a:11:{s:4:\"uuid\";s:36:\"99244a65-d42c-43a2-baae-958073fef48f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_block\";i:1;s:51:\"field.field.paragraph.ebt_tab.field_ebt_tab_content\";i:2;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_page\";i:3;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_text\";i:4;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_title\";i:5;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_views\";i:6;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3tkvVlJEyrGPBNqg-NmBgDBe7aW-ckCLKwsrbQPd28E\";}s:2:\"id\";s:25:\"paragraph.ebt_tab.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:19:\"field_ebt_tab_block\";a:5:{s:6:\"weight\";i:7;s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:19:\"block_field_default\";s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_tab_content\";a:5:{s:6:\"weight\";i:1;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:14:\"options_select\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_page\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_text\";a:5:{s:6:\"weight\";i:3;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_title\";a:5:{s:6:\"weight\";i:0;s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:14:\"text_textfield\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_views\";a:5:{s:6:\"weight\";i:6;s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_tiles_item.default',	'a:11:{s:4:\"uuid\";s:36:\"fbaff897-1222-45d2-bdee-f1c92ecc517d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_tiles_item.field_ebt_clickable_tile\";i:1;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_image\";i:2;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_link\";i:3;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_text\";i:4;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aO9CEu-AEXoDrOUyi0zQ-BFKnOQQ4j-7EZboHKs25Ao\";}s:2:\"id\";s:32:\"paragraph.ebt_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ebt_clickable_tile\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_tiles_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_tiles_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_tiles_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_tiles_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_timeline.default',	'a:11:{s:4:\"uuid\";s:36:\"9ade0a26-a08a-49b3-8f21-5cc52e0a9d4a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_current\";i:1;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_date\";i:2;s:65:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_media_image\";i:3;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_text\";i:4;s:59:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_title\";i:5;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"roudiPcEWEQePvvKVTvyQOha3roMsIYNfxuZ8yhsA7o\";}s:2:\"id\";s:30:\"paragraph.ebt_timeline.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:26:\"field_ebt_timeline_current\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_timeline_date\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:30:\"field_ebt_timeline_media_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_timeline_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_timeline_title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_video_and_image_gallery_item.default',	'a:11:{s:4:\"uuid\";s:36:\"af68c1f1-a952-4c8a-ad1c-06f3eaa33777\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:85:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description\";i:1;s:79:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item\";i:2;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ajt8RnSI29uPiHiC5kZcmSORcHZviDbPeC4fnIM2VWo\";}s:2:\"id\";s:50:\"paragraph.ebt_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:30:\"field_gallery_item_description\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_video_gallery_item\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.user.user.default',	'a:11:{s:4:\"uuid\";s:36:\"2e78043c-ec7e-40d3-9893-74a39341e80d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FaQ9Ptcpxpg30AtiqRDtl_8zbJArHP1LPfug_s59TOA\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"account\";a:2:{s:6:\"weight\";i:-10;s:6:\"region\";s:7:\"content\";}s:7:\"contact\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:8:\"language\";a:2:{s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:8:\"timezone\";a:2:{s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_mode.media.media_library',	'a:10:{s:4:\"uuid\";s:36:\"4f486238-f30d-4022-ac1d-42675ab0f17a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_form_mode.user.register',	'a:10:{s:4:\"uuid\";s:36:\"2a875655-65fd-42f4-bd80-8b41714fa393\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5pE_4hurqtIlZN3XDi7eTo5RG13BMG0Rh9HYlRI3h8U\";}s:2:\"id\";s:13:\"user.register\";s:5:\"label\";s:8:\"Register\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_display.block_content.basic.default',	'a:11:{s:4:\"uuid\";s:36:\"d5902a81-52d9-49dd-b8db-4665dbc4368c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBNNDTFwakREOTa6GGMqN899Iyrii0hInwSJtQ7Kj30\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_accordion.default',	'a:11:{s:4:\"uuid\";s:36:\"4043bfd5-1d8c-40be-b5b7-7566608c0a10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:44:\"field.field.block_content.ebt_accordion.body\";i:2;s:59:\"field.field.block_content.ebt_accordion.field_ebt_accordion\";i:3;s:58:\"field.field.block_content.ebt_accordion.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WJqWWf2uiJH8b576_UiYa5phDxIJKwgJiQjqG9e3TNI\";}s:2:\"id\";s:35:\"block_content.ebt_accordion.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_accordion\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_basic_button.default',	'a:11:{s:4:\"uuid\";s:36:\"e002007d-e402-414c-a43e-0e11a4ff059c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:70:\"field.field.block_content.ebt_basic_button.field_ebt_basic_button_link\";i:2;s:61:\"field.field.block_content.ebt_basic_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"D0bWnt-1a4nvpSyJNmrOwKtHeZ4joh72qib-yadGXdo\";}s:2:\"id\";s:38:\"block_content.ebt_basic_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:27:\"field_ebt_basic_button_link\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:4:\"link\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_block.default',	'a:11:{s:4:\"uuid\";s:36:\"7dac4777-4a33-402e-a4fb-d2ec54e7bdbf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:40:\"field.field.block_content.ebt_block.body\";i:2;s:57:\"field.field.block_content.ebt_block.field_ebt_block_block\";i:3;s:54:\"field.field.block_content.ebt_block.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:8:\"ebt_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fbnp4SbjbUUixWLq5rrWDtCZ10d3rhYWoqZRmYFJPfo\";}s:2:\"id\";s:31:\"block_content.ebt_block.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_block_block\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_bootstrap_button.default',	'a:11:{s:4:\"uuid\";s:36:\"8a03d29e-a687-49e7-9a56-0dfe88836e7a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:78:\"field.field.block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link\";i:2;s:65:\"field.field.block_content.ebt_bootstrap_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"B0SuU0apEENhv8h4tMjfQJZqaMhqfIqzm2aj6K7pj8g\";}s:2:\"id\";s:42:\"block_content.ebt_bootstrap_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:31:\"field_ebt_bootstrap_button_link\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:4:\"link\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_carousel.default',	'a:11:{s:4:\"uuid\";s:36:\"5595a634-71e4-4b9c-840c-c1fcb074609f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:57:\"field.field.block_content.ebt_carousel.field_ebt_carousel\";i:2;s:57:\"field.field.block_content.ebt_carousel.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XxudurKwt1BsJ27WvP-j9wjYhEJwJoXWpngR6KCPXG8\";}s:2:\"id\";s:34:\"block_content.ebt_carousel.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_carousel\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_columns.default',	'a:11:{s:4:\"uuid\";s:36:\"86bcc126-14bc-40cd-a04a-95794d3f1e10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:42:\"field.field.block_content.ebt_columns.body\";i:2;s:62:\"field.field.block_content.ebt_columns.field_ebt_columns_blocks\";i:3;s:56:\"field.field.block_content.ebt_columns.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:8:\"ebt_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a-6glPDfvKWglLxQBv5i50OSaExRNK8Y9fdSycITPPg\";}s:2:\"id\";s:33:\"block_content.ebt_columns.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_columns_blocks\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_countdown.default',	'a:11:{s:4:\"uuid\";s:36:\"814b296d-272d-49bd-b543-8a896015c80d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:44:\"field.field.block_content.ebt_countdown.body\";i:2;s:64:\"field.field.block_content.ebt_countdown.field_ebt_countdown_date\";i:3;s:58:\"field.field.block_content.ebt_countdown.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"datetime\";i:1;s:8:\"ebt_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SD9uKkLwTaGxA9CLhoLDWa7OVamzALkQ381JeZFM12Q\";}s:2:\"id\";s:35:\"block_content.ebt_countdown.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_countdown_date\";a:6:{s:4:\"type\";s:16:\"datetime_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:2:{s:17:\"timezone_override\";s:0:\"\";s:11:\"format_type\";s:6:\"medium\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_counter.default',	'a:11:{s:4:\"uuid\";s:36:\"4117f5ae-b100-40a0-82be-376d1b9cdd5c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:42:\"field.field.block_content.ebt_counter.body\";i:2;s:60:\"field.field.block_content.ebt_counter.field_ebt_counter_icon\";i:3;s:61:\"field.field.block_content.ebt_counter.field_ebt_counter_items\";i:4;s:62:\"field.field.block_content.ebt_counter.field_ebt_counter_number\";i:5;s:56:\"field.field.block_content.ebt_counter.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U0J7ekcnrzJlts3b7XRAuCz6M0oc4laODI1JQpfnSWU\";}s:2:\"id\";s:33:\"block_content.ebt_counter.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_counter_items\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:22:\"field_ebt_counter_icon\";b:1;s:24:\"field_ebt_counter_number\";b:1;}}'),
('',	'core.entity_view_display.block_content.ebt_cta.default',	'a:11:{s:4:\"uuid\";s:36:\"0ad5cd1c-3a95-492c-a42a-3a33aad2fc81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:38:\"field.field.block_content.ebt_cta.body\";i:2;s:60:\"field.field.block_content.ebt_cta.field_ebt_cta_column_image\";i:3;s:52:\"field.field.block_content.ebt_cta.field_ebt_cta_link\";i:4;s:59:\"field.field.block_content.ebt_cta.field_ebt_cta_second_link\";i:5;s:53:\"field.field.block_content.ebt_cta.field_ebt_cta_title\";i:6;s:52:\"field.field.block_content.ebt_cta.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rJRx3IkJfHu6PnEX98fydtBu7xtB6TBPxbD0H22l5MY\";}s:2:\"id\";s:29:\"block_content.ebt_cta.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:26:\"field_ebt_cta_column_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_cta_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_cta_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_cta_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_hero.default',	'a:11:{s:4:\"uuid\";s:36:\"ef3f9c37-ba74-4569-9402-eb895497b1ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:39:\"field.field.block_content.ebt_hero.body\";i:2;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_column_image\";i:3;s:54:\"field.field.block_content.ebt_hero.field_ebt_hero_link\";i:4;s:61:\"field.field.block_content.ebt_hero.field_ebt_hero_second_link\";i:5;s:55:\"field.field.block_content.ebt_hero.field_ebt_hero_title\";i:6;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_title_prefix\";i:7;s:53:\"field.field.block_content.ebt_hero.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XtJum4t5ZIxuZCmM5WqHm32Q5cPXTBC1K_4FK0DKBak\";}s:2:\"id\";s:30:\"block_content.ebt_hero.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_hero_column_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_hero_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:26:\"field_ebt_hero_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_hero_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_hero_title_prefix\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_image.default',	'a:11:{s:4:\"uuid\";s:36:\"2b267e2d-1fdb-48ce-9cb4-9e8ab433ed76\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:51:\"field.field.block_content.ebt_image.field_ebt_image\";i:2;s:59:\"field.field.block_content.ebt_image.field_ebt_image_caption\";i:3;s:56:\"field.field.block_content.ebt_image.field_ebt_image_link\";i:4;s:54:\"field.field.block_content.ebt_image.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"D3uYbuXeXgRMCscOC7MzthncsxVzm02BUnKoPT6DgNI\";}s:2:\"id\";s:31:\"block_content.ebt_image.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:15:\"field_ebt_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_image_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_image_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_image_gallery.default',	'a:11:{s:4:\"uuid\";s:36:\"4b5d6bc4-4cc6-4319-a6bf-ffb11737fa1d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:48:\"field.field.block_content.ebt_image_gallery.body\";i:2;s:67:\"field.field.block_content.ebt_image_gallery.field_ebt_image_gallery\";i:3;s:62:\"field.field.block_content.ebt_image_gallery.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vR-7_1M__12ELdq1IjHW5dYHXbjNbXTl83IbuAVADFo\";}s:2:\"id\";s:39:\"block_content.ebt_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_image_gallery\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_micromodal.default',	'a:11:{s:4:\"uuid\";s:36:\"f5514d94-f0a7-4adb-af94-b565702bcb87\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:45:\"field.field.block_content.ebt_micromodal.body\";i:2;s:67:\"field.field.block_content.ebt_micromodal.field_ebt_micromodal_title\";i:3;s:59:\"field.field.block_content.ebt_micromodal.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UuFtw5Q8hlkws7oxPOMwDUQdLg1VvFThNrchcXpdFdc\";}s:2:\"id\";s:36:\"block_content.ebt_micromodal.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:26:\"field_ebt_micromodal_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_quote.default',	'a:11:{s:4:\"uuid\";s:36:\"7606605a-9eff-4f52-aff9-3a7d785bb2a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:40:\"field.field.block_content.ebt_quote.body\";i:2;s:58:\"field.field.block_content.ebt_quote.field_ebt_quote_author\";i:3;s:57:\"field.field.block_content.ebt_quote.field_ebt_quote_image\";i:4;s:54:\"field.field.block_content.ebt_quote.field_ebt_settings\";i:5;s:23:\"image.style.quote_image\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xpCHQRrtCqVeeuVSJ231HGw2oStHov2UFyb3zRr3Oik\";}s:2:\"id\";s:31:\"block_content.ebt_quote.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_quote_author\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_quote_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:11:\"quote_image\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_slick_slider.default',	'a:11:{s:4:\"uuid\";s:36:\"8feddd3f-45a8-46bf-a16f-2be6634a45ea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:47:\"field.field.block_content.ebt_slick_slider.body\";i:2;s:61:\"field.field.block_content.ebt_slick_slider.field_ebt_settings\";i:3;s:65:\"field.field.block_content.ebt_slick_slider.field_ebt_slick_slider\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hPQzjkILUgWxfntdmuZ6HzJR7VFbSsJzCXcSrlrzRdY\";}s:2:\"id\";s:38:\"block_content.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_slick_slider\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_slideshow.default',	'a:11:{s:4:\"uuid\";s:36:\"764e5ba9-f7cd-4885-88bb-ab706b279f69\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:58:\"field.field.block_content.ebt_slideshow.field_ebt_settings\";i:2;s:59:\"field.field.block_content.ebt_slideshow.field_ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mtWCnFfgKEeW85VC8B0w6c1438S-bOGUJEppAIJAakE\";}s:2:\"id\";s:35:\"block_content.ebt_slideshow.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:19:\"field_ebt_slideshow\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:18:\"field_ebt_settings\";b:1;}}'),
('',	'core.entity_view_display.block_content.ebt_stats.default',	'a:11:{s:4:\"uuid\";s:36:\"8c54cc11-1b16-48f3-a610-44727c203a3d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:40:\"field.field.block_content.ebt_stats.body\";i:2;s:54:\"field.field.block_content.ebt_stats.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_stats.field_ebt_stats\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M6fW5L7z_DmzcpI5BCl95NixIxJEv1cpCEL2n4x9zpo\";}s:2:\"id\";s:31:\"block_content.ebt_stats.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ebt_stats\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_tabs.default',	'a:11:{s:4:\"uuid\";s:36:\"62183f0d-0b60-47ba-bb16-40798a4776ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:53:\"field.field.block_content.ebt_tabs.field_ebt_settings\";i:2;s:49:\"field.field.block_content.ebt_tabs.field_ebt_tabs\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I2VT_ayFTNxciojtahrIwigBhAXkhZMO4_sAejsopW0\";}s:2:\"id\";s:30:\"block_content.ebt_tabs.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:14:\"field_ebt_tabs\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_text.default',	'a:11:{s:4:\"uuid\";s:36:\"b33df2ac-91d5-4257-bfa4-bb4911c6a960\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:39:\"field.field.block_content.ebt_text.body\";i:2;s:53:\"field.field.block_content.ebt_text.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l_0JH2bJx47kWrf-7eYOBgwIV1dRWjVeLv68ugJKxso\";}s:2:\"id\";s:30:\"block_content.ebt_text.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_tiles.default',	'a:11:{s:4:\"uuid\";s:36:\"fb6bfaa3-7636-41c1-a411-dff1def2fef0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:40:\"field.field.block_content.ebt_tiles.body\";i:2;s:54:\"field.field.block_content.ebt_tiles.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_tiles.field_ebt_tiles\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rX3FVFGQ9cD5O0wbYbIxbj872CHdsK9aIut1PNuAeVI\";}s:2:\"id\";s:31:\"block_content.ebt_tiles.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:15:\"field_ebt_tiles\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_timeline.default',	'a:11:{s:4:\"uuid\";s:36:\"1395e5da-67f6-420f-a32d-094a7d218bd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:57:\"field.field.block_content.ebt_timeline.field_ebt_settings\";i:2;s:57:\"field.field.block_content.ebt_timeline.field_ebt_timeline\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bfJtQm_JGhXjpffKuejK_QMbyA4fxEqMrVt-N98sqZo\";}s:2:\"id\";s:34:\"block_content.ebt_timeline.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_timeline\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_video.default',	'a:11:{s:4:\"uuid\";s:36:\"96a65454-d2c6-4d47-8247-42a53fffe403\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:40:\"field.field.block_content.ebt_video.body\";i:2;s:54:\"field.field.block_content.ebt_video.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_video.field_ebt_video\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2csH7beKeLrgGpTLBYSVXXoJzKb7u0PjD1AUlW6AzbU\";}s:2:\"id\";s:31:\"block_content.ebt_video.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:15:\"field_ebt_video\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:9:\"ebt_video\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_video_and_image_gallery.default',	'a:11:{s:4:\"uuid\";s:36:\"b7590d64-18fe-489a-8317-2999e71355e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:58:\"field.field.block_content.ebt_video_and_image_gallery.body\";i:2;s:72:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_settings\";i:3;s:81:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GRVAFs0nqUHdsiSZnjDv7msUFBQh_m8jr87a-UZhMEs\";}s:2:\"id\";s:49:\"block_content.ebt_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_videos_and_images\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_views.default',	'a:11:{s:4:\"uuid\";s:36:\"65ebcab1-d240-4884-855d-df0c65f731df\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:40:\"field.field.block_content.ebt_views.body\";i:2;s:54:\"field.field.block_content.ebt_views.field_ebt_settings\";i:3;s:57:\"field.field.block_content.ebt_views.field_ebt_views_views\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P_rfCoJ0TGHiNoFYHjaR-ngK4cjbqANziLUpxF5UBZM\";}s:2:\"id\";s:31:\"block_content.ebt_views.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_views_views\";a:6:{s:4:\"type\";s:24:\"viewsreference_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:5:{s:4:\"page\";s:4:\"page\";s:5:\"block\";s:5:\"block\";s:7:\"default\";s:1:\"0\";s:4:\"feed\";s:1:\"0\";s:5:\"embed\";s:1:\"0\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_webform.default',	'a:11:{s:4:\"uuid\";s:36:\"dc06c30d-3cfa-4f39-809f-8390cd056466\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:42:\"field.field.block_content.ebt_webform.body\";i:2;s:56:\"field.field.block_content.ebt_webform.field_ebt_settings\";i:3;s:60:\"field.field.block_content.ebt_webform.field_ebt_webform_form\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gpru4Rd0T0JY8wkKLrvgy_u9NIovpL4X5IKCjcykrUE\";}s:2:\"id\";s:33:\"block_content.ebt_webform.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:3;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_webform_form\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:13:\"source_entity\";b:1;}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_webform_popup.default',	'a:11:{s:4:\"uuid\";s:36:\"8d599765-5bbf-4aff-b2cb-bd108e6c5046\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:62:\"field.field.block_content.ebt_webform_popup.field_ebt_settings\";i:2;s:72:\"field.field.block_content.ebt_webform_popup.field_ebt_webform_popup_form\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AkhheynCt4FPPMFnHY7nwaoh-xmCWBAFHkUSVVu-DN8\";}s:2:\"id\";s:39:\"block_content.ebt_webform_popup.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:28:\"field_ebt_webform_popup_form\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:13:\"source_entity\";b:1;}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.media.audio.default',	'a:11:{s:4:\"uuid\";s:36:\"38a6ca87-814c-4d4a-b346-9326e4c72021\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AS765MdDfNpK6K5eE7WVnBvpynClz_havy1R3bO3gVo\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_audio_file\";a:6:{s:4:\"type\";s:10:\"file_audio\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:4:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.audio.media_library',	'a:11:{s:4:\"uuid\";s:36:\"ede5e29a-aefb-40b5-9859-1ac8ed22e499\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tcAUW1Xzq5Tjw5jomR6XKGSgfiXO7QiRAHJBF-n0akg\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.document.default',	'a:11:{s:4:\"uuid\";s:36:\"beb45182-e505-48ae-a153-5d34274d8013\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XxUyhaTuM0OUUZpr8G6jdrFBEh5eag7auWxBKhm6cvY\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:20:\"field_media_document\";a:6:{s:4:\"type\";s:12:\"file_default\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.document.media_library',	'a:11:{s:4:\"uuid\";s:36:\"b0e61493-d3f5-4a7d-8ead-492300acdf21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:21:\"image.style.thumbnail\";i:3;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YcWqjhIlo-2RZUM5ogvRsrKB7M3voF2XB3lVLwgOlLU\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.default',	'a:11:{s:4:\"uuid\";s:36:\"c80bfe30-db84-4270-a319-1c27729f2edf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:17:\"image.style.large\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"73xaTNkI5J6sfFcBmNYeuk070X3mQS_iwwWaPYyfG2M\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:5:\"large\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.ebt_image_gallery',	'a:11:{s:4:\"uuid\";s:36:\"a35ebe6b-2715-41f7-a570-96ae3af68c78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:45:\"core.entity_view_mode.media.ebt_image_gallery\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:29:\"image.style.ebt_gallery_image\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9KEafftKnenx_jl3tACupmwb0WA-eaq31pCE89gmGaY\";}s:2:\"id\";s:29:\"media.image.ebt_image_gallery\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:17:\"ebt_image_gallery\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:17:\"ebt_gallery_image\";s:26:\"glightbox_node_style_first\";s:17:\"ebt_gallery_image\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:6:\"parent\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.media_library',	'a:11:{s:4:\"uuid\";s:36:\"f69a9286-8f3b-42cf-a15a-5f569ca96e99\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:18:\"image.style.medium\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ILLWu5KFvbsX6J7sh2Itd4w8-lBBRhR_H8ZrmQiN2yo\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:17:\"field_media_image\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.video_and_image_gallery_item',	'a:11:{s:4:\"uuid\";s:36:\"513a5e40-b967-4358-8200-0c9cd79302cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:56:\"core.entity_view_mode.media.video_and_image_gallery_item\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:39:\"image.style.ebt_video_and_image_gallery\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"71w4ybrqWdKueRDFJwcgki2l30Gpyrl7WRkhoMS7C6M\";}s:2:\"id\";s:40:\"media.image.video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:28:\"video_and_image_gallery_item\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:27:\"ebt_video_and_image_gallery\";s:26:\"glightbox_node_style_first\";s:0:\"\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.default',	'a:11:{s:4:\"uuid\";s:36:\"7b9a2dff-1714-4265-92f5-b08cb9237f6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZdPcl2hPxl5pgv3pI-07R7h51OjeUeKJTy-ab1NfM34\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:6:\"oembed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:9:\"max_width\";i:0;s:10:\"max_height\";i:0;s:7:\"loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.ebt_video',	'a:11:{s:4:\"uuid\";s:36:\"1e1b792b-f71b-470f-9810-bc2e2d11f17f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:37:\"core.entity_view_mode.media.ebt_video\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NHnPc8vxx5bXjFmHokLtYvI3ebeo_FybRqjMNEhIVOg\";}s:2:\"id\";s:28:\"media.remote_video.ebt_video\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:9:\"ebt_video\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:4:\"post\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"e91b1f8e-5ba5-485e-9c6e-04afe2948e85\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:18:\"image.style.medium\";i:3;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PGGoP-hVkXe_S-GiJRAub4PHDu0KhMExylclrqjdJb4\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.video_and_image_gallery_item',	'a:11:{s:4:\"uuid\";s:36:\"9672ae47-7a64-49d5-904a-cba847d9377d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:56:\"core.entity_view_mode.media.video_and_image_gallery_item\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0gtodl3N0wRFdXaP60sG0h05qbgCOF8wy6ggVWOa8UY\";}s:2:\"id\";s:47:\"media.remote_video.video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:28:\"video_and_image_gallery_item\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:27:\"ebt_video_and_image_gallery\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.video.default',	'a:11:{s:4:\"uuid\";s:36:\"863188fb-17da-49e4-8e79-ddeb23903eef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SxvbuGh-6cQMxl9bBV27-hGI46u7ZvwlMm5ObaJMNnw\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_video_file\";a:6:{s:4:\"type\";s:10:\"file_video\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";s:5:\"muted\";b:0;s:5:\"width\";i:640;s:6:\"height\";i:480;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.video.ebt_video',	'a:11:{s:4:\"uuid\";s:36:\"7bab1942-d337-4497-a621-f6cc29536967\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:37:\"core.entity_view_mode.media.ebt_video\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PhLS2RcsgmXaRpOr6Z569J0KXiE9KNW5OMTC9dvUTkg\";}s:2:\"id\";s:21:\"media.video.ebt_video\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:9:\"ebt_video\";s:7:\"content\";a:1:{s:22:\"field_media_video_file\";a:6:{s:4:\"type\";s:10:\"file_video\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";s:5:\"muted\";b:0;s:5:\"width\";i:640;s:6:\"height\";i:480;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"d00b3c78-35a0-460e-a063-a98a387591cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_fnkUKwQYHkXO1Ngmq9nE6FqWUNAmkddOxAH1h5aiKg\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.node.article.default',	'a:12:{s:4:\"uuid\";s:36:\"97d9050c-f2b4-4b7e-9f3f-10de564e06a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:39:\"field.field.node.article.field_metatags\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:16:\"image.style.wide\";i:5;s:17:\"node.type.article\";}s:6:\"module\";a:5:{i:0;s:14:\"layout_builder\";i:1;s:7:\"metatag\";i:2;s:9:\"svg_image\";i:3;s:4:\"text\";i:4;s:4:\"user\";}}s:20:\"third_party_settings\";a:1:{s:14:\"layout_builder\";a:3:{s:7:\"enabled\";b:1;s:12:\"allow_custom\";b:1;s:8:\"sections\";a:1:{i:0;a:4:{s:9:\"layout_id\";s:13:\"layout_onecol\";s:15:\"layout_settings\";a:1:{s:5:\"label\";s:0:\"\";}s:10:\"components\";a:5:{s:36:\"3120cf62-1cc1-4e2b-96e0-0996d5d6928a\";a:5:{s:4:\"uuid\";s:36:\"3120cf62-1cc1-4e2b-96e0-0996d5d6928a\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:36:\"field_block:node:article:field_image\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:14:\"svg_attributes\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}s:19:\"svg_render_as_image\";b:1;}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:0;s:10:\"additional\";a:0:{}}s:36:\"7f5f46b4-472b-4e74-9a01-8a03e0321444\";a:5:{s:4:\"uuid\";s:36:\"7f5f46b4-472b-4e74-9a01-8a03e0321444\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:29:\"field_block:node:article:body\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:1;s:10:\"additional\";a:0:{}}s:36:\"b902a34b-a3ce-4efc-a85b-86bb824651b9\";a:5:{s:4:\"uuid\";s:36:\"b902a34b-a3ce-4efc-a85b-86bb824651b9\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:35:\"field_block:node:article:field_tags\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:2;s:10:\"additional\";a:0:{}}s:36:\"25d5958c-bea2-4027-8bae-b924b89dce41\";a:5:{s:4:\"uuid\";s:36:\"25d5958c-bea2-4027-8bae-b924b89dce41\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:3:{s:2:\"id\";s:36:\"extra_field_block:node:article:links\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}}s:6:\"weight\";i:3;s:10:\"additional\";a:0:{}}s:36:\"667348d3-3500-418a-b027-8b25f62317df\";a:5:{s:4:\"uuid\";s:36:\"667348d3-3500-418a-b027-8b25f62317df\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:39:\"field_block:node:article:field_metatags\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:4;s:10:\"additional\";a:0:{}}}s:20:\"third_party_settings\";a:0:{}}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"br6izr-iGEu--JvNbCJNtOBpRnxpFLXfoV5y61U9Nqc\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:14:\"svg_attributes\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}s:19:\"svg_render_as_image\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:14:\"field_metatags\";a:6:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.node.article.rss',	'a:11:{s:4:\"uuid\";s:36:\"2e2f92c3-c50a-4139-9c95-4e46ce1f757d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:39:\"field.field.node.article.field_metatags\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:47:\"field.field.node.article.layout_builder__layout\";i:6;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2rIr6K5Q0UQ9khg0zE_CK-PtJH76UL-BDDZcZnZzwCc\";}s:2:\"id\";s:16:\"node.article.rss\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:3:\"rss\";s:7:\"content\";a:1:{s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:5:{s:4:\"body\";b:1;s:11:\"field_image\";b:1;s:14:\"field_metatags\";b:1;s:10:\"field_tags\";b:1;s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_view_display.node.article.teaser',	'a:11:{s:4:\"uuid\";s:36:\"08318816-b086-4cdd-b48c-c020f5a6f328\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:39:\"field.field.node.article.field_metatags\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:47:\"field.field.node.article.layout_builder__layout\";i:6;s:18:\"image.style.medium\";i:7;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:9:\"svg_image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"O8PxzfG8DOHHRu6M23kwR6TDPq_MNfYQ10Mp367ICUQ\";}s:2:\"id\";s:19:\"node.article.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:14:\"field_metatags\";b:1;s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_view_display.node.page.default',	'a:12:{s:4:\"uuid\";s:36:\"5aaa71f3-3511-4b50-8003-331c936478f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:36:\"field.field.node.page.field_metatags\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:4:{i:0;s:14:\"layout_builder\";i:1;s:7:\"metatag\";i:2;s:4:\"text\";i:3;s:4:\"user\";}}s:20:\"third_party_settings\";a:1:{s:14:\"layout_builder\";a:3:{s:7:\"enabled\";b:1;s:12:\"allow_custom\";b:1;s:8:\"sections\";a:1:{i:0;a:4:{s:9:\"layout_id\";s:13:\"layout_onecol\";s:15:\"layout_settings\";a:1:{s:5:\"label\";s:0:\"\";}s:10:\"components\";a:3:{s:36:\"38a9abee-f957-4c37-bf25-26572a864786\";a:5:{s:4:\"uuid\";s:36:\"38a9abee-f957-4c37-bf25-26572a864786\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:26:\"field_block:node:page:body\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:0;s:10:\"additional\";a:0:{}}s:36:\"49025aed-c7ef-4f99-bdb3-01a066d936cf\";a:5:{s:4:\"uuid\";s:36:\"49025aed-c7ef-4f99-bdb3-01a066d936cf\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:3:{s:2:\"id\";s:33:\"extra_field_block:node:page:links\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}}s:6:\"weight\";i:1;s:10:\"additional\";a:0:{}}s:36:\"022c3459-1bc8-481c-aea0-dc1a493c5abb\";a:5:{s:4:\"uuid\";s:36:\"022c3459-1bc8-481c-aea0-dc1a493c5abb\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:36:\"field_block:node:page:field_metatags\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:2;s:10:\"additional\";a:0:{}}}s:20:\"third_party_settings\";a:0:{}}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Y8L5tfmhx7DR143E05YyZSpvgil6VFvqcfBWykalg\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:14:\"field_metatags\";a:6:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:102;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.node.page.teaser',	'a:11:{s:4:\"uuid\";s:36:\"0cdde055-9011-4c16-b82c-494a58ce39ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:26:\"field.field.node.page.body\";i:2;s:36:\"field.field.node.page.field_metatags\";i:3;s:44:\"field.field.node.page.layout_builder__layout\";i:4;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8BgdRtLbtQ0F__o0FHSH0Mx5fvXOra9tfT1GmNKbRYw\";}s:2:\"id\";s:16:\"node.page.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:14:\"field_metatags\";b:1;s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_view_display.paragraph.ebt_accordion.default',	'a:11:{s:4:\"uuid\";s:36:\"d7bca4fc-d99f-4966-929d-15f5247c8564\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:60:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_text\";i:1;s:61:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_title\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yn5RBnnmFE_Y5sCchtXzAOZg0joBlJrWIBEaYAnP9Ps\";}s:2:\"id\";s:31:\"paragraph.ebt_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ebt_accordion_text\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_accordion_title\";a:6:{s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_carousel.default',	'a:11:{s:4:\"uuid\";s:36:\"2e2b2311-9c14-4e94-aecd-97a3f060f45a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:61:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_caption\";i:1;s:59:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o21VkkuJdszAqDOznTVc61VIxPQJc6ocyXSW3qSQFHc\";}s:2:\"id\";s:30:\"paragraph.ebt_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ebt_carousel_caption\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_carousel_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:11:\"image_style\";s:0:\"\";s:10:\"image_link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_counter_item.default',	'a:11:{s:4:\"uuid\";s:36:\"9cd9785e-414b-4ccf-a6f4-9b5039218fd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_description\";i:1;s:61:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_icon\";i:2;s:63:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_number\";i:3;s:62:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EjbsMNoEaP6Z3U6dn1mNEir0yNE1gFyyIzkKiYVPO_4\";}s:2:\"id\";s:34:\"paragraph.ebt_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ebt_counter_description\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_counter_icon\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_counter_number\";a:6:{s:4:\"type\";s:14:\"number_integer\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_counter_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_slick_slider.default',	'a:11:{s:4:\"uuid\";s:36:\"152c6a3e-8703-40b0-ad21-283b4ae6cc5b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:67:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_image\";i:1;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_link\";i:2;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_text\";i:3;s:29:\"image.style.slick_slider_card\";i:4;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VVV9wfo5l1gK1weU695gzyXqp5on_oNav7jAwjjWowQ\";}s:2:\"id\";s:34:\"paragraph.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ebt_slick_slider_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:17:\"slick_slider_card\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_slick_slider_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_slick_slider_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_slideshow.default',	'a:11:{s:4:\"uuid\";s:36:\"5003e24e-550b-4a07-a87f-66e0dbab0e83\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_link\";i:1;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_slide\";i:2;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_text\";i:3;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_title\";i:4;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-TV7U97Wd40UA7J_3-aQjPyYv360Wi3Te0PPvYviuxU\";}s:2:\"id\";s:31:\"paragraph.ebt_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ebt_slideshow_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1023;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_slideshow_slide\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_slideshow_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_slideshow_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_stats_item.default',	'a:11:{s:4:\"uuid\";s:36:\"77949beb-f2e0-46a7-bbe3-3ede2ef7f061\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:59:\"field.field.paragraph.ebt_stats_item.field_stats_item_image\";i:1;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_link\";i:2;s:60:\"field.field.paragraph.ebt_stats_item.field_stats_item_number\";i:3;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5RDw3deJvwfKptyvRWt0uMj5O3zRyWKrJCZ_MFWk7Po\";}s:2:\"id\";s:32:\"paragraph.ebt_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:22:\"field_stats_item_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:21:\"field_stats_item_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:23:\"field_stats_item_number\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:21:\"field_stats_item_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_tab.default',	'a:11:{s:4:\"uuid\";s:36:\"4b41c82a-77c1-47f0-a052-9b87649b8136\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_block\";i:1;s:51:\"field.field.paragraph.ebt_tab.field_ebt_tab_content\";i:2;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_page\";i:3;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_text\";i:4;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_title\";i:5;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_views\";i:6;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"slUTwjnod77jaefmi2b5OQYl4vYxpAodJPHvoHGvQUA\";}s:2:\"id\";s:25:\"paragraph.ebt_tab.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:19:\"field_ebt_tab_block\";a:6:{s:6:\"weight\";i:6;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:11:\"block_field\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_page\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:4:\"link\";b:1;s:9:\"view_mode\";s:7:\"default\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:28:\"entity_reference_entity_view\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_text\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_title\";a:6:{s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_views\";a:6:{s:6:\"weight\";i:5;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:1:{i:0;s:5:\"block\";}}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:24:\"viewsreference_formatter\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:21:\"field_ebt_tab_content\";b:1;}}'),
('',	'core.entity_view_display.paragraph.ebt_tiles_item.default',	'a:11:{s:4:\"uuid\";s:36:\"4ccbb938-c11d-49a7-ba57-753328efb08b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_tiles_item.field_ebt_clickable_tile\";i:1;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_image\";i:2;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_link\";i:3;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_text\";i:4;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZHOP2C6K3eAHsBjc_FJwNsbIKZ-XL88CGUz5EexQ8nE\";}s:2:\"id\";s:32:\"paragraph.ebt_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ebt_clickable_tile\";a:6:{s:4:\"type\";s:7:\"boolean\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:3:{s:6:\"format\";s:7:\"default\";s:19:\"format_custom_false\";s:0:\"\";s:18:\"format_custom_true\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_tiles_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_tiles_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_tiles_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_tiles_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_timeline.default',	'a:11:{s:4:\"uuid\";s:36:\"553c2833-822a-4508-a2f9-99f9ffc89f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_current\";i:1;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_date\";i:2;s:65:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_media_image\";i:3;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_text\";i:4;s:59:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_title\";i:5;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kScbPfdPZDsoEdHqJtQ9QjqdBXgkz2VT-TEA4uO4yQU\";}s:2:\"id\";s:30:\"paragraph.ebt_timeline.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:26:\"field_ebt_timeline_current\";a:6:{s:4:\"type\";s:7:\"boolean\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:6:\"format\";s:7:\"default\";s:19:\"format_custom_false\";s:0:\"\";s:18:\"format_custom_true\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_timeline_date\";a:6:{s:4:\"type\";s:6:\"string\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:30:\"field_ebt_timeline_media_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_timeline_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_timeline_title\";a:6:{s:4:\"type\";s:6:\"string\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_video_and_image_gallery_item.default',	'a:11:{s:4:\"uuid\";s:36:\"0a70dbed-c211-4ec2-a7e5-7d9b701046db\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:85:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description\";i:1;s:79:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item\";i:2;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ATQKQ04wbZpenyUY_sMfDM08puKPXNvoGB5tSxGxwG0\";}s:2:\"id\";s:50:\"paragraph.ebt_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:30:\"field_gallery_item_description\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:24:\"field_video_gallery_item\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:28:\"video_and_image_gallery_item\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.user.user.compact',	'a:11:{s:4:\"uuid\";s:36:\"73223d5a-b425-4fba-9090-7b112d030f92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:34:\"core.entity_view_mode.user.compact\";i:1;s:34:\"field.field.user.user.user_picture\";i:2;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"00zr_RBdTjPjBGITD3h4c1ESQZimjdVCcHGt1trLqIY\";}s:2:\"id\";s:17:\"user.user.compact\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"compact\";s:7:\"content\";a:1:{s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:10:\"member_for\";b:1;}}'),
('',	'core.entity_view_display.user.user.default',	'a:11:{s:4:\"uuid\";s:36:\"1c220693-f471-4184-9453-cd90fc0030d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mZLyuWM9CQx2ZJVqFGSbzgFnHzudVbHBYmdU256A5Wk\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:10:\"member_for\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_mode.block.token',	'a:9:{s:4:\"uuid\";s:36:\"c298243a-fc61-46e8-8878-5de88a9bcb0b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"block\";}}s:2:\"id\";s:11:\"block.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"block\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.block_content.full',	'a:10:{s:4:\"uuid\";s:36:\"9268fa23-36f9-4a94-a9ef-799f2d1c5eb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q7yUUYeRLByl-MCGveKKF_KhAtNICLCMJuKWfugCvso\";}s:2:\"id\";s:18:\"block_content.full\";s:5:\"label\";s:4:\"Full\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.block_content.token',	'a:9:{s:4:\"uuid\";s:36:\"004ad1d4-03ad-4317-af82-4bb9f039c686\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:2:\"id\";s:19:\"block_content.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.contact_message.token',	'a:9:{s:4:\"uuid\";s:36:\"b51e5b3c-1a2e-49cf-acff-bfc2dea5ad40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"contact\";}}s:2:\"id\";s:21:\"contact_message.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:15:\"contact_message\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.file.token',	'a:9:{s:4:\"uuid\";s:36:\"99749d8d-98ee-49e8-b272-054f53d7c97f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:2:\"id\";s:10:\"file.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"file\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.ebt_image_gallery',	'a:10:{s:4:\"uuid\";s:36:\"d8772b40-e75a-46fe-a0eb-48e3c2f13441\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gx3dAzTlzUoOPV6nrqIxtsHu6AWtMEd6M4HRihgOIdc\";}s:2:\"id\";s:23:\"media.ebt_image_gallery\";s:5:\"label\";s:17:\"EBT Image Gallery\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.ebt_video',	'a:10:{s:4:\"uuid\";s:36:\"9ff59caf-8ee9-4fca-bffa-89132c94c813\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IXsnV3TXq49eaMlltbjpSWIiseAysJRe042Revn8t1s\";}s:2:\"id\";s:15:\"media.ebt_video\";s:5:\"label\";s:9:\"EBT Video\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.full',	'a:10:{s:4:\"uuid\";s:36:\"fb758fd6-28cd-4155-8eda-49912e1da3f8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dTfAUHooYV0uOVPO3saGpgv-c5PppJXDwxvwRTJOycM\";}s:2:\"id\";s:10:\"media.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.media_library',	'a:10:{s:4:\"uuid\";s:36:\"1a098749-bd7d-429f-9d91-d4e7913c8c3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.token',	'a:9:{s:4:\"uuid\";s:36:\"aa6556df-5384-471d-96b4-a6d264801693\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:2:\"id\";s:11:\"media.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.video_and_image_gallery_item',	'a:10:{s:4:\"uuid\";s:36:\"6f5a787d-85f5-4bea-aab2-4094c6f7772f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u0M3Ybb0-9QE3E30c77uKo8PW64Vexg-TwC2IHerOgs\";}s:2:\"id\";s:34:\"media.video_and_image_gallery_item\";s:5:\"label\";s:28:\"Video and Image gallery item\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.menu_link_content.token',	'a:9:{s:4:\"uuid\";s:36:\"33a56e28-1d42-4a4f-b42a-88eb552104a7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:17:\"menu_link_content\";}}s:2:\"id\";s:23:\"menu_link_content.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:17:\"menu_link_content\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.full',	'a:10:{s:4:\"uuid\";s:36:\"5aefb664-7e3c-4ebe-86a2-07194cada9f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QJ2aZ1xfVf59aq6Pz5X7fyUOa2HxuCoTwQ_RQjoulAU\";}s:2:\"id\";s:9:\"node.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.rss',	'a:10:{s:4:\"uuid\";s:36:\"6b3209c3-0ae1-46f6-8e2c-44d4391f2434\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l8fiAFE3Kng_6bhLlUDnVTkTDzXWxzYFrCWTrngVXEA\";}s:2:\"id\";s:8:\"node.rss\";s:5:\"label\";s:3:\"RSS\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.search_index',	'a:10:{s:4:\"uuid\";s:36:\"416e3f7c-ab1b-4bb4-b428-aabf9906eecf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_A0T3aTqGDwLyvoH7wLps-0PM--RHlS8UsiJe_Ac64\";}s:2:\"id\";s:17:\"node.search_index\";s:5:\"label\";s:12:\"Search index\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.search_result',	'a:10:{s:4:\"uuid\";s:36:\"c196759a-15b6-47d3-b672-f853645cc638\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d8wBEm7XvJ6H3S0IneDD9PfTBklPIH7GMpxElVemPf8\";}s:2:\"id\";s:18:\"node.search_result\";s:5:\"label\";s:32:\"Search result highlighting input\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.teaser',	'a:10:{s:4:\"uuid\";s:36:\"aa910ffb-3a87-4512-af06-273b721bc12f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KgGJDZFpMaz_8bTv6fN1bXS3Qi5LWmRJI9R53kEGsNQ\";}s:2:\"id\";s:11:\"node.teaser\";s:5:\"label\";s:6:\"Teaser\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.token',	'a:9:{s:4:\"uuid\";s:36:\"3ec23f24-50ef-434e-a7b6-3d8cb9a2a4f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:2:\"id\";s:10:\"node.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.paragraph.preview',	'a:10:{s:4:\"uuid\";s:36:\"f30f214f-6163-41a8-a996-f703e5fd92cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"h3BeHVei4Lnyqbkao3YiF4KqoY-DhRvUNfEgKG8Rgjg\";}s:2:\"id\";s:17:\"paragraph.preview\";s:5:\"label\";s:7:\"Preview\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.path_alias.token',	'a:9:{s:4:\"uuid\";s:36:\"b47111c9-dcb8-4762-af5c-3f7acca095d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"path_alias\";}}s:2:\"id\";s:16:\"path_alias.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:10:\"path_alias\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.shortcut.token',	'a:9:{s:4:\"uuid\";s:36:\"550ba8ad-246f-433e-8c0d-f2c76255df0e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"shortcut\";}}s:2:\"id\";s:14:\"shortcut.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:8:\"shortcut\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.taxonomy_term.full',	'a:10:{s:4:\"uuid\";s:36:\"e72ba8d8-dba4-4920-91d6-5e916b81a6fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iukUENpf8CFvjZbGGacKX_Ges0-lU9z6zvsd32P6kbo\";}s:2:\"id\";s:18:\"taxonomy_term.full\";s:5:\"label\";s:18:\"Taxonomy term page\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.taxonomy_term.token',	'a:9:{s:4:\"uuid\";s:36:\"ea887f34-9e29-4000-aef4-21112004577d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:2:\"id\";s:19:\"taxonomy_term.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.user.compact',	'a:10:{s:4:\"uuid\";s:36:\"06ded9f9-3e1a-44f0-a5e0-224efcca6431\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TtD7OuGskOsQfoGyxXkrdtllBpR37J19d5BMQDZWJgA\";}s:2:\"id\";s:12:\"user.compact\";s:5:\"label\";s:7:\"Compact\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.user.full',	'a:10:{s:4:\"uuid\";s:36:\"ad69e028-e0a2-4eab-9d8b-d18e904da6bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZbXunWS_xAvMZXFfinyvClDAb_RCVLt7gAzE3v16E-Q\";}s:2:\"id\";s:9:\"user.full\";s:5:\"label\";s:12:\"User account\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.user.token',	'a:9:{s:4:\"uuid\";s:36:\"676a8206-d9d0-4094-bf54-66a60c6bad53\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:10:\"user.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.webform.token',	'a:9:{s:4:\"uuid\";s:36:\"5f8faafa-6ec3-4704-a06c-08d5391b12d7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:2:\"id\";s:13:\"webform.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:7:\"webform\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.webform_submission.token',	'a:9:{s:4:\"uuid\";s:36:\"92d0137a-b4c4-4c19-b07b-84c8b8844019\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:2:\"id\";s:24:\"webform_submission.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:18:\"webform_submission\";s:5:\"cache\";b:1;}'),
('',	'core.extension',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GIX5Esnc_umpXUBj4IIocRX7Mt5fPhm4AgXfE3E56E\";}s:6:\"module\";a:107:{s:13:\"admin_toolbar\";i:0;s:19:\"admin_toolbar_tools\";i:0;s:18:\"announcements_feed\";i:0;s:14:\"automated_cron\";i:0;s:8:\"big_pipe\";i:0;s:5:\"block\";i:0;s:13:\"block_content\";i:0;s:11:\"block_field\";i:0;s:10:\"breakpoint\";i:0;s:9:\"ckeditor5\";i:0;s:21:\"ckeditor5_plugin_pack\";i:0;s:32:\"ckeditor5_plugin_pack_auto_image\";i:0;s:38:\"ckeditor5_plugin_pack_find_and_replace\";i:0;s:26:\"ckeditor5_plugin_pack_font\";i:0;s:31:\"ckeditor5_plugin_pack_highlight\";i:0;s:34:\"ckeditor5_plugin_pack_indent_block\";i:0;s:32:\"ckeditor5_plugin_pack_page_break\";i:0;s:32:\"ckeditor5_plugin_pack_select_all\";i:0;s:31:\"ckeditor5_plugin_pack_templates\";i:0;s:41:\"ckeditor5_plugin_pack_text_transformation\";i:0;s:40:\"ckeditor5_plugin_pack_todo_document_list\";i:0;s:32:\"ckeditor5_plugin_pack_word_count\";i:0;s:37:\"ckeditor5_premium_features_fullscreen\";i:0;s:6:\"config\";i:0;s:13:\"config_ignore\";i:0;s:7:\"contact\";i:0;s:10:\"contextual\";i:0;s:8:\"datetime\";i:0;s:5:\"dblog\";i:0;s:18:\"dynamic_page_cache\";i:0;s:13:\"ebt_accordion\";i:0;s:16:\"ebt_basic_button\";i:0;s:9:\"ebt_block\";i:0;s:20:\"ebt_bootstrap_button\";i:0;s:12:\"ebt_carousel\";i:0;s:11:\"ebt_columns\";i:0;s:8:\"ebt_core\";i:0;s:13:\"ebt_countdown\";i:0;s:11:\"ebt_counter\";i:0;s:7:\"ebt_cta\";i:0;s:8:\"ebt_hero\";i:0;s:9:\"ebt_image\";i:0;s:17:\"ebt_image_gallery\";i:0;s:14:\"ebt_micromodal\";i:0;s:9:\"ebt_quote\";i:0;s:16:\"ebt_slick_slider\";i:0;s:13:\"ebt_slideshow\";i:0;s:9:\"ebt_stats\";i:0;s:8:\"ebt_tabs\";i:0;s:8:\"ebt_text\";i:0;s:9:\"ebt_tiles\";i:0;s:12:\"ebt_timeline\";i:0;s:9:\"ebt_video\";i:0;s:27:\"ebt_video_and_image_gallery\";i:0;s:9:\"ebt_views\";i:0;s:11:\"ebt_webform\";i:0;s:17:\"ebt_webform_popup\";i:0;s:6:\"editor\";i:0;s:26:\"entity_reference_revisions\";i:0;s:5:\"field\";i:0;s:11:\"field_group\";i:0;s:8:\"field_ui\";i:0;s:4:\"file\";i:0;s:6:\"filter\";i:0;s:9:\"glightbox\";i:0;s:21:\"glightbox_media_video\";i:0;s:16:\"google_analytics\";i:0;s:4:\"help\";i:0;s:7:\"history\";i:0;s:5:\"image\";i:0;s:9:\"jquery_ui\";i:0;s:19:\"jquery_ui_accordion\";i:0;s:14:\"jquery_ui_tabs\";i:0;s:14:\"layout_builder\";i:0;s:16:\"layout_discovery\";i:0;s:4:\"link\";i:0;s:6:\"linkit\";i:0;s:5:\"media\";i:0;s:13:\"media_library\";i:0;s:26:\"media_library_form_element\";i:0;s:17:\"menu_link_content\";i:0;s:7:\"menu_ui\";i:0;s:7:\"metatag\";i:0;s:4:\"node\";i:0;s:7:\"options\";i:0;s:10:\"page_cache\";i:0;s:4:\"path\";i:0;s:10:\"path_alias\";i:0;s:16:\"profile_switcher\";i:0;s:8:\"redirect\";i:0;s:6:\"search\";i:0;s:8:\"shortcut\";i:0;s:9:\"svg_image\";i:0;s:6:\"system\";i:0;s:8:\"taxonomy\";i:0;s:4:\"text\";i:0;s:5:\"token\";i:0;s:7:\"toolbar\";i:0;s:6:\"update\";i:0;s:4:\"user\";i:0;s:8:\"views_ui\";i:0;s:14:\"viewsreference\";i:0;s:7:\"webform\";i:0;s:8:\"pathauto\";i:1;s:5:\"views\";i:10;s:10:\"paragraphs\";i:11;s:4:\"fast\";i:1000;}s:5:\"theme\";a:2:{s:7:\"olivero\";i:0;s:5:\"claro\";i:0;}s:7:\"profile\";s:4:\"fast\";}'),
('',	'core.menu.static_menu_link_overrides',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CXhei_vpaZk-3f_Mj2cH0YmpK-ZpKHoSzVA3yZrDq0g\";}s:11:\"definitions\";a:1:{s:18:\"contact__site_page\";a:5:{s:9:\"menu_name\";s:6:\"footer\";s:6:\"parent\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:7:\"enabled\";b:1;}}}'),
('',	'dblog.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e883aGsrt1wFrsydlYU584PZONCSfRy0DtkZ9KzHb58\";}s:9:\"row_limit\";i:1000;}'),
('',	'ebt_core.settings',	'a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VBIZ2klsa-wrUk3pFOgIi3avMLFro6A0nFNYc35MvNQ\";}s:26:\"ebt_core_mobile_breakpoint\";s:3:\"640\";s:26:\"ebt_core_tablet_breakpoint\";s:4:\"1020\";s:27:\"ebt_core_desktop_breakpoint\";s:4:\"1320\";s:22:\"ebt_core_xxsmall_width\";s:3:\"480\";s:21:\"ebt_core_xsmall_width\";s:3:\"640\";s:20:\"ebt_core_small_width\";s:3:\"768\";s:22:\"ebt_core_default_width\";s:3:\"960\";s:20:\"ebt_core_large_width\";s:4:\"1100\";s:21:\"ebt_core_xlarge_width\";s:4:\"1320\";s:22:\"ebt_core_xxlarge_width\";s:4:\"1600\";s:25:\"ebt_core_background_color\";s:7:\"#0d77b5\";}'),
('',	'editor.editor.basic_html',	'a:9:{s:4:\"uuid\";s:36:\"65aded18-2f8d-4ec3-8d69-0a602798f4dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"filter.format.basic_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qi2tIe-L97EutlMmhEvhsNxZOpOoA-RH82c4BQb5n4A\";}s:6:\"format\";s:10:\"basic_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:15:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:1:\"|\";i:3;s:4:\"link\";i:4;s:1:\"|\";i:5;s:12:\"bulletedList\";i:6;s:12:\"numberedList\";i:7;s:1:\"|\";i:8;s:10:\"blockQuote\";i:9;s:17:\"drupalInsertImage\";i:10;s:1:\"|\";i:11;s:7:\"heading\";i:12;s:4:\"code\";i:13;s:1:\"|\";i:14;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:4:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:0;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:13:{i:0;s:6:\"<cite>\";i:1;s:4:\"<dl>\";i:2;s:4:\"<dt>\";i:3;s:4:\"<dd>\";i:4;s:12:\"<a hreflang>\";i:5;s:17:\"<blockquote cite>\";i:6;s:9:\"<ul type>\";i:7;s:9:\"<ol type>\";i:8;s:7:\"<h2 id>\";i:9;s:7:\"<h3 id>\";i:10;s:7:\"<h4 id>\";i:11;s:7:\"<h5 id>\";i:12;s:7:\"<h6 id>\";}}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),
('',	'editor.editor.full_html',	'a:9:{s:4:\"uuid\";s:36:\"1926258e-dc0e-4aaa-95d1-5abf3be483cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"filter.format.full_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lurcn8yf33g3Dkzdc55cTfJa9salGp9ytSYyG1s7QMI\";}s:6:\"format\";s:9:\"full_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:21:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:13:\"strikethrough\";i:3;s:11:\"superscript\";i:4;s:9:\"subscript\";i:5;s:12:\"removeFormat\";i:6;s:1:\"|\";i:7;s:4:\"link\";i:8;s:1:\"|\";i:9;s:12:\"bulletedList\";i:10;s:12:\"numberedList\";i:11;s:1:\"|\";i:12;s:10:\"blockQuote\";i:13;s:17:\"drupalInsertImage\";i:14;s:11:\"insertTable\";i:15;s:14:\"horizontalLine\";i:16;s:1:\"|\";i:17;s:7:\"heading\";i:18;s:9:\"codeBlock\";i:19;s:1:\"|\";i:20;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:5:{s:19:\"ckeditor5_codeBlock\";a:1:{s:9:\"languages\";a:14:{i:0;a:2:{s:5:\"label\";s:10:\"Plain text\";s:8:\"language\";s:9:\"plaintext\";}i:1;a:2:{s:5:\"label\";s:1:\"C\";s:8:\"language\";s:1:\"c\";}i:2;a:2:{s:5:\"label\";s:2:\"C#\";s:8:\"language\";s:2:\"cs\";}i:3;a:2:{s:5:\"label\";s:3:\"C++\";s:8:\"language\";s:3:\"cpp\";}i:4;a:2:{s:5:\"label\";s:3:\"CSS\";s:8:\"language\";s:3:\"css\";}i:5;a:2:{s:5:\"label\";s:4:\"Diff\";s:8:\"language\";s:4:\"diff\";}i:6;a:2:{s:5:\"label\";s:4:\"HTML\";s:8:\"language\";s:4:\"html\";}i:7;a:2:{s:5:\"label\";s:4:\"Java\";s:8:\"language\";s:4:\"java\";}i:8;a:2:{s:5:\"label\";s:10:\"JavaScript\";s:8:\"language\";s:10:\"javascript\";}i:9;a:2:{s:5:\"label\";s:3:\"PHP\";s:8:\"language\";s:3:\"php\";}i:10;a:2:{s:5:\"label\";s:6:\"Python\";s:8:\"language\";s:6:\"python\";}i:11;a:2:{s:5:\"label\";s:4:\"Ruby\";s:8:\"language\";s:4:\"ruby\";}i:12;a:2:{s:5:\"label\";s:10:\"TypeScript\";s:8:\"language\";s:10:\"typescript\";}i:13;a:2:{s:5:\"label\";s:3:\"XML\";s:8:\"language\";s:3:\"xml\";}}}s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),
('',	'editor.editor.webform_default',	'a:8:{s:4:\"uuid\";s:36:\"4c6d924f-2c8d-4499-9713-799828c76079\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:6:\"format\";s:15:\"webform_default\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:20:{i:0;s:7:\"heading\";i:1;s:1:\"|\";i:2;s:4:\"bold\";i:3;s:6:\"italic\";i:4;s:9:\"subscript\";i:5;s:11:\"superscript\";i:6;s:1:\"|\";i:7;s:17:\"specialCharacters\";i:8;s:1:\"|\";i:9;s:12:\"numberedList\";i:10;s:12:\"bulletedList\";i:11;s:1:\"|\";i:12;s:4:\"link\";i:13;s:1:\"|\";i:14;s:6:\"indent\";i:15;s:7:\"outdent\";i:16;s:1:\"|\";i:17;s:10:\"blockQuote\";i:18;s:1:\"|\";i:19;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:3:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}}}s:12:\"image_upload\";a:1:{s:6:\"status\";b:0;}}'),
('',	'field.field.block_content.basic.body',	'a:17:{s:4:\"uuid\";s:36:\"22004f3b-acef-4ec7-a26a-84514e3b0755\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j00Gfs9AFqwK4x9RIsISLbPO7vA12psPR4s60wOIwQo\";}s:2:\"id\";s:24:\"block_content.basic.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_accordion.body',	'a:17:{s:4:\"uuid\";s:36:\"28cf0280-0877-4dba-9961-a719b378e9f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EcoPer3Ti0HE0G0vbR_XTjvl4J4xhtcfJlZiIpT2-ic\";}s:2:\"id\";s:32:\"block_content.ebt_accordion.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_accordion.field_ebt_accordion',	'a:17:{s:4:\"uuid\";s:36:\"da20cc91-36e0-4116-8c1e-1b5e33ccbd6e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:47:\"field.storage.block_content.field_ebt_accordion\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KleL2jMUTWlOv_XwXvSfbaLHvZFC4TO3ZGrHClNa8Jk\";}s:2:\"id\";s:47:\"block_content.ebt_accordion.field_ebt_accordion\";s:10:\"field_name\";s:19:\"field_ebt_accordion\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:9:\"Accordion\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:13:\"ebt_accordion\";s:13:\"ebt_accordion\";}s:24:\"target_bundles_drag_drop\";a:1:{s:13:\"ebt_accordion\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:3;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_accordion.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"082df8d4-f424-4ec5-9be7-fa79dca0bc70\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4JvhH84_ab4oNGRe99S5bOvjSJdmPzs1XF2s5a0tlPc\";}s:2:\"id\";s:46:\"block_content.ebt_accordion.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_basic_button.field_ebt_basic_button_link',	'a:17:{s:4:\"uuid\";s:36:\"c0f9b024-755c-40ce-9a70-2d7135b9b02d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:55:\"field.storage.block_content.field_ebt_basic_button_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sHxTdakkm0n2AWPN2_ygOqsVXsuySIH10GpOOAEbzYE\";}s:2:\"id\";s:58:\"block_content.ebt_basic_button.field_ebt_basic_button_link\";s:10:\"field_name\";s:27:\"field_ebt_basic_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:5:\"label\";s:11:\"Button LInk\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"link_type\";i:17;s:5:\"title\";i:2;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_basic_button.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"28dce901-3d51-4486-b431-ddbf214523f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TljYP0E4TAaKsPdVXhWVNLXzzFG9oPBu7BUROGtWlPY\";}s:2:\"id\";s:49:\"block_content.ebt_basic_button.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_block.body',	'a:17:{s:4:\"uuid\";s:36:\"c82da539-0efe-4f63-b7ed-cfb0c65f3022\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ze4f8wKV-sjDw10PzW5_0VDQpHaV7fUywYLVyynLOXQ\";}s:2:\"id\";s:28:\"block_content.ebt_block.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_block.field_ebt_block_block',	'a:17:{s:4:\"uuid\";s:36:\"02b3090f-c1e2-41ef-961f-8f9dbe3677b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:49:\"field.storage.block_content.field_ebt_block_block\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ODt400wjC0-0TFAwPcqdOKmEH1RCrno2RlHZAO9jMDY\";}s:2:\"id\";s:45:\"block_content.ebt_block.field_ebt_block_block\";s:10:\"field_name\";s:21:\"field_ebt_block_block\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:5:\"label\";s:5:\"Block\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:10:\"categories\";s:18:\"selection_settings\";a:1:{s:10:\"categories\";a:24:{s:5:\"Block\";s:5:\"Block\";s:14:\"Comment fields\";s:14:\"Comment fields\";s:22:\"Contact message fields\";s:22:\"Contact message fields\";s:13:\"Content block\";s:13:\"Content block\";s:20:\"Content block fields\";s:20:\"Content block fields\";s:14:\"Content fields\";s:14:\"Content fields\";s:4:\"core\";s:4:\"core\";s:23:\"Custom menu link fields\";s:23:\"Custom menu link fields\";s:11:\"File fields\";s:11:\"File fields\";s:5:\"Forms\";s:5:\"Forms\";s:4:\"Help\";s:4:\"Help\";s:13:\"Inline blocks\";s:13:\"Inline blocks\";s:13:\"Lists (Views)\";s:13:\"Lists (Views)\";s:12:\"Media fields\";s:12:\"Media fields\";s:5:\"Menus\";s:5:\"Menus\";s:16:\"Paragraph fields\";s:16:\"Paragraph fields\";s:20:\"Shortcut link fields\";s:20:\"Shortcut link fields\";s:6:\"System\";s:6:\"System\";s:20:\"Taxonomy term fields\";s:20:\"Taxonomy term fields\";s:16:\"URL alias fields\";s:16:\"URL alias fields\";s:4:\"User\";s:4:\"User\";s:11:\"User fields\";s:11:\"User fields\";s:7:\"Webform\";s:7:\"Webform\";s:25:\"Webform submission fields\";s:25:\"Webform submission fields\";}}}s:10:\"field_type\";s:11:\"block_field\";}'),
('',	'field.field.block_content.ebt_block.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"4cf8e43c-52cf-40e7-8fab-03ba24e5671d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HsmfX01jgclZMXztEvPXS8YoUBvYO2AzDJY7Olj0G5A\";}s:2:\"id\";s:42:\"block_content.ebt_block.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link',	'a:17:{s:4:\"uuid\";s:36:\"308dba68-d030-422d-b8e9-72568d1fd20a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:59:\"field.storage.block_content.field_ebt_bootstrap_button_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LHj34VkFYZYI5N_541KsHaqlWyuH7Cw_KxfjHm23woU\";}s:2:\"id\";s:66:\"block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ebt_bootstrap_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"link_type\";i:17;s:5:\"title\";i:2;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_bootstrap_button.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"b6ea63fb-dfef-42aa-bda8-892c68583ffc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-6S_O_kYEPD4uAw2AnjYuYGHz_CMhBBvkkO5sJA1DYg\";}s:2:\"id\";s:53:\"block_content.ebt_bootstrap_button.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_carousel.field_ebt_carousel',	'a:17:{s:4:\"uuid\";s:36:\"2bc22340-9888-4636-9768-5a9bc9ffd66c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:46:\"field.storage.block_content.field_ebt_carousel\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NZhceEWb8sFj-vaeEbM_eFgHPVULnofUVtBb6FO526E\";}s:2:\"id\";s:45:\"block_content.ebt_carousel.field_ebt_carousel\";s:10:\"field_name\";s:18:\"field_ebt_carousel\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:8:\"Carousel\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:12:\"ebt_carousel\";s:12:\"ebt_carousel\";}s:24:\"target_bundles_drag_drop\";a:1:{s:12:\"ebt_carousel\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:6;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_carousel.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"82540ccc-a725-412b-b6ba-bc89d09e03fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U2Ky-DS_Wo_f9KN2f-PSJN975w1XnGxWcaly7VF6-tU\";}s:2:\"id\";s:45:\"block_content.ebt_carousel.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_columns.body',	'a:17:{s:4:\"uuid\";s:36:\"b6c8e80f-807f-4acf-b36e-55ea98dc4fb3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WqbyqczhS3unr9KEuC6FRXfpi9rVW3mCtF8P2TGxkQI\";}s:2:\"id\";s:30:\"block_content.ebt_columns.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_columns.field_ebt_columns_blocks',	'a:17:{s:4:\"uuid\";s:36:\"eca7b2b8-8806-49f1-ae15-756018a6c67f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:52:\"field.storage.block_content.field_ebt_columns_blocks\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DlzRJb8gJARkGrf3IjWcpsIQfTvSJt9DmGRT1aBailQ\";}s:2:\"id\";s:50:\"block_content.ebt_columns.field_ebt_columns_blocks\";s:10:\"field_name\";s:24:\"field_ebt_columns_blocks\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:5:\"label\";s:6:\"Blocks\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:10:\"categories\";s:18:\"selection_settings\";a:1:{s:10:\"categories\";a:24:{s:5:\"Block\";s:5:\"Block\";s:14:\"Comment fields\";s:14:\"Comment fields\";s:22:\"Contact message fields\";s:22:\"Contact message fields\";s:13:\"Content block\";s:13:\"Content block\";s:20:\"Content block fields\";s:20:\"Content block fields\";s:14:\"Content fields\";s:14:\"Content fields\";s:4:\"core\";s:4:\"core\";s:23:\"Custom menu link fields\";s:23:\"Custom menu link fields\";s:11:\"File fields\";s:11:\"File fields\";s:5:\"Forms\";s:5:\"Forms\";s:4:\"Help\";s:4:\"Help\";s:13:\"Inline blocks\";s:13:\"Inline blocks\";s:13:\"Lists (Views)\";s:13:\"Lists (Views)\";s:12:\"Media fields\";s:12:\"Media fields\";s:5:\"Menus\";s:5:\"Menus\";s:16:\"Paragraph fields\";s:16:\"Paragraph fields\";s:20:\"Shortcut link fields\";s:20:\"Shortcut link fields\";s:6:\"System\";s:6:\"System\";s:20:\"Taxonomy term fields\";s:20:\"Taxonomy term fields\";s:16:\"URL alias fields\";s:16:\"URL alias fields\";s:4:\"User\";s:4:\"User\";s:11:\"User fields\";s:11:\"User fields\";s:7:\"Webform\";s:7:\"Webform\";s:25:\"Webform submission fields\";s:25:\"Webform submission fields\";}}}s:10:\"field_type\";s:11:\"block_field\";}'),
('',	'field.field.block_content.ebt_columns.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"9cc6560f-9a4a-4969-9e4b-0d667ef4817c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"97Zeg-Y42bu_WIG-So7eo7DK0hKpS1XqwrJ1kGdYY8E\";}s:2:\"id\";s:44:\"block_content.ebt_columns.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_countdown.body',	'a:17:{s:4:\"uuid\";s:36:\"7266abd1-c799-4ff0-96ef-b464471e6583\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7Eup8vFqqabcEdya_X4KmbnCSstllEkrmXRpfxOCdmU\";}s:2:\"id\";s:32:\"block_content.ebt_countdown.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_countdown.field_ebt_countdown_date',	'a:17:{s:4:\"uuid\";s:36:\"daee2d15-8abc-4764-8789-2fcf13604386\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:52:\"field.storage.block_content.field_ebt_countdown_date\";}s:6:\"module\";a:1:{i:0;s:8:\"datetime\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rS3ZCjiH3ZhM6LLmDYfxfr1x4lVA0pMJeUjgvHYJwJU\";}s:2:\"id\";s:52:\"block_content.ebt_countdown.field_ebt_countdown_date\";s:10:\"field_name\";s:24:\"field_ebt_countdown_date\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:5:\"label\";s:14:\"Countdown date\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:8:\"datetime\";}'),
('',	'field.field.block_content.ebt_countdown.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"56e05cdb-f253-4954-9c39-5253face9482\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2Z_UQh0ye99krkSwmrnf32Lbdr_bJwll60WqPfcn3WQ\";}s:2:\"id\";s:46:\"block_content.ebt_countdown.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_counter.body',	'a:17:{s:4:\"uuid\";s:36:\"c23a3476-69db-400e-a938-54992d1cfa18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aNXxUnwWYqtaYNggYYhPjJH0IhNPU6aWjGZmWwC2Ock\";}s:2:\"id\";s:30:\"block_content.ebt_counter.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"9ba660a3-d550-47fe-aaa5-4325e7ffe30d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:50:\"field.storage.block_content.field_ebt_counter_icon\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AqwI810Vi6u8gzBeecbZAAUxasqqVBWGSG3usxdzT8Y\";}s:2:\"id\";s:48:\"block_content.ebt_counter.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:4:\"Icon\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_counter_items',	'a:17:{s:4:\"uuid\";s:36:\"0776e496-c917-49a5-a502-a77f73b79b69\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:51:\"field.storage.block_content.field_ebt_counter_items\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l82_oxjYqdf0vGlc2vOu3y3PdJhm9-QYk3j9aKOI-eg\";}s:2:\"id\";s:49:\"block_content.ebt_counter.field_ebt_counter_items\";s:10:\"field_name\";s:23:\"field_ebt_counter_items\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:17:\"EBT Counter Items\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:16:\"ebt_counter_item\";s:16:\"ebt_counter_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:16:\"ebt_counter_item\";a:2:{s:6:\"weight\";i:12;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"b4ecb5ee-b852-4360-ab89-92327a624bdf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:52:\"field.storage.block_content.field_ebt_counter_number\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xYrvXZvhuSrLAZDblfVrQO8BT0HeZGJKPail-de9LYQ\";}s:2:\"id\";s:50:\"block_content.ebt_counter.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:6:\"Number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:4:{s:3:\"min\";N;s:3:\"max\";N;s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"field_type\";s:7:\"integer\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"1df891a3-3bde-4def-8c4e-79dd5182017a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-jefiww756YZOfPypjb0uMhOWdCkTYnChNabi-X7VTM\";}s:2:\"id\";s:44:\"block_content.ebt_counter.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_cta.body',	'a:17:{s:4:\"uuid\";s:36:\"55f4a1e8-6366-4c0b-aba3-0f05bdc8dccc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Xswlt75VBfRWb1lhRxDCEdmO2MWrGjyFMGZtNtNvvhs\";}s:2:\"id\";s:26:\"block_content.ebt_cta.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_column_image',	'a:17:{s:4:\"uuid\";s:36:\"13cbf6a5-260c-40e0-b225-a8dd66d72da5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:54:\"field.storage.block_content.field_ebt_cta_column_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BhJzD_e2sAj1RN0VJgS6aMUtzNeUEopdiFutXxsCBAk\";}s:2:\"id\";s:48:\"block_content.ebt_cta.field_ebt_cta_column_image\";s:10:\"field_name\";s:26:\"field_ebt_cta_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_link',	'a:17:{s:4:\"uuid\";s:36:\"b2ba6467-2022-4aa3-9527-2821ef8b3866\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:46:\"field.storage.block_content.field_ebt_cta_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kXVJG1nw4xsap-XsAKzJbpyAv6NK8jpGZ9eWXpGpewI\";}s:2:\"id\";s:40:\"block_content.ebt_cta.field_ebt_cta_link\";s:10:\"field_name\";s:18:\"field_ebt_cta_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_second_link',	'a:17:{s:4:\"uuid\";s:36:\"21e7fce1-906b-4e52-94b2-deaee971de2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:53:\"field.storage.block_content.field_ebt_cta_second_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HYewglTA2MKbS8dL349fn4qm9mA-S_FxSL-Suhi0H2k\";}s:2:\"id\";s:47:\"block_content.ebt_cta.field_ebt_cta_second_link\";s:10:\"field_name\";s:25:\"field_ebt_cta_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:11:\"Second Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_title',	'a:17:{s:4:\"uuid\";s:36:\"67606c2f-9b8c-41b7-80d6-aa24493fa0d3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:47:\"field.storage.block_content.field_ebt_cta_title\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AKUtn2Ht2dlGYr9Y8at4yVXu5P1ozFKBdcgzWq44560\";}s:2:\"id\";s:41:\"block_content.ebt_cta.field_ebt_cta_title\";s:10:\"field_name\";s:19:\"field_ebt_cta_title\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"b3a9c8ab-38aa-42a9-9c7a-8d9b4c4e0192\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o4qhawOFKN4zS8tfJKa0LamrN4V8y8cW4d55CAAP8EY\";}s:2:\"id\";s:40:\"block_content.ebt_cta.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_hero.body',	'a:17:{s:4:\"uuid\";s:36:\"b99d81f7-46a3-4dd4-8588-c20bf7f86b06\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qut8svTV-WRC6mB8zNNFw0jqqJp5gzYemzlgnt3AElM\";}s:2:\"id\";s:27:\"block_content.ebt_hero.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_column_image',	'a:17:{s:4:\"uuid\";s:36:\"47eab2ed-be4c-44cf-8125-61c4726d2170\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:55:\"field.storage.block_content.field_ebt_hero_column_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VbR985Mwa7blDm4IzjllHaKyIKieWmVaPhFiNTxALUg\";}s:2:\"id\";s:50:\"block_content.ebt_hero.field_ebt_hero_column_image\";s:10:\"field_name\";s:27:\"field_ebt_hero_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_link',	'a:17:{s:4:\"uuid\";s:36:\"8c50936f-d412-4429-a9af-fe0720478b0f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:47:\"field.storage.block_content.field_ebt_hero_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDbic2tmAxT3Nwj4frhpQJGnF8nX1JE_Q3hu02XZ10o\";}s:2:\"id\";s:42:\"block_content.ebt_hero.field_ebt_hero_link\";s:10:\"field_name\";s:19:\"field_ebt_hero_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_second_link',	'a:17:{s:4:\"uuid\";s:36:\"04371c34-46be-4086-ae87-cc361d2d3ced\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:54:\"field.storage.block_content.field_ebt_hero_second_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1RX5_6HKYaNcisy7DgpQuSjGICKop8azTX3B6B_p8xc\";}s:2:\"id\";s:49:\"block_content.ebt_hero.field_ebt_hero_second_link\";s:10:\"field_name\";s:26:\"field_ebt_hero_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:11:\"Second Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_title',	'a:17:{s:4:\"uuid\";s:36:\"11b83dfa-e605-4b74-8cab-d665ab3d12a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:48:\"field.storage.block_content.field_ebt_hero_title\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"86hFjrfGlcIjrIIrmgUrVPJ3_QyoV2KsiqXTYhCAeR8\";}s:2:\"id\";s:43:\"block_content.ebt_hero.field_ebt_hero_title\";s:10:\"field_name\";s:20:\"field_ebt_hero_title\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_title_prefix',	'a:17:{s:4:\"uuid\";s:36:\"f115e5b7-c8ee-4130-9311-4bc5ac45d6d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:55:\"field.storage.block_content.field_ebt_hero_title_prefix\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"135nCPN0Zyg7GtNdwrEY1joFOZdHSUqBoP1cfFmTlws\";}s:2:\"id\";s:50:\"block_content.ebt_hero.field_ebt_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ebt_hero_title_prefix\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:12:\"Title Prefix\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"9ab7be9d-f391-4845-abb9-9620046d2cea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T5k5YZCMxiQ-YbufcTAzxPfL6x68fxMB1znaMkjM1Ug\";}s:2:\"id\";s:41:\"block_content.ebt_hero.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_image',	'a:17:{s:4:\"uuid\";s:36:\"f07c72d3-6387-4d4d-a4eb-5a81420e247b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:43:\"field.storage.block_content.field_ebt_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W7kXKygcBjPcCe8gOrc11eBNXBHQWunB-xUjHS5ccZM\";}s:2:\"id\";s:39:\"block_content.ebt_image.field_ebt_image\";s:10:\"field_name\";s:15:\"field_ebt_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_image_caption',	'a:17:{s:4:\"uuid\";s:36:\"d7eb3cf3-fabf-4526-9e59-2559843a4b10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:51:\"field.storage.block_content.field_ebt_image_caption\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WZl4X3tBs3QDBckRJjPbxFlnn9RiKDJXSb32UI78b0Y\";}s:2:\"id\";s:47:\"block_content.ebt_image.field_ebt_image_caption\";s:10:\"field_name\";s:23:\"field_ebt_image_caption\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:13:\"Image caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_image_link',	'a:17:{s:4:\"uuid\";s:36:\"d64d6cf7-d342-4551-933f-875ccf757101\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:48:\"field.storage.block_content.field_ebt_image_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WDCm4s-2KzOBP2lD1x_6iuJ28RmYQLSfvdSJ4KTS8hc\";}s:2:\"id\";s:44:\"block_content.ebt_image.field_ebt_image_link\";s:10:\"field_name\";s:20:\"field_ebt_image_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:10:\"Image Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"4f2baecc-10aa-4164-b62a-d414a7a219b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Lo63F4kx4le3BFUXIP1j-nTj0TQ1wlVCW8T4eXa_Xu8\";}s:2:\"id\";s:42:\"block_content.ebt_image.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_image_gallery.body',	'a:17:{s:4:\"uuid\";s:36:\"20361483-5f67-45d3-a3cb-a44f2e7bbae3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RI-w_mHu5j0k1rnEr3l73w0KQBcCH3Q6ZImikN8AdBw\";}s:2:\"id\";s:36:\"block_content.ebt_image_gallery.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_image_gallery.field_ebt_image_gallery',	'a:17:{s:4:\"uuid\";s:36:\"f76e7399-746c-4735-a354-63cad22949ff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:51:\"field.storage.block_content.field_ebt_image_gallery\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FAizD6Kvuyrbl5yxVgCp1vn4NLB9d-nI3wWWaqOR-kQ\";}s:2:\"id\";s:55:\"block_content.ebt_image_gallery.field_ebt_image_gallery\";s:10:\"field_name\";s:23:\"field_ebt_image_gallery\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:13:\"Image Gallery\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_image_gallery.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"4c8c9d22-d8fd-4927-b62c-41815a17d1c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jJLv7Zyb3L4ZWqdYGWpZz_z81eZXwjYwQexwHk7WX2s\";}s:2:\"id\";s:50:\"block_content.ebt_image_gallery.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_micromodal.body',	'a:17:{s:4:\"uuid\";s:36:\"1dd47019-ce01-47d2-8520-e5625b17bd32\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfYtQCVLNmvze1_Qc3zTCMg2QFHln36_wjCm6y2MMWQ\";}s:2:\"id\";s:33:\"block_content.ebt_micromodal.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_micromodal.field_ebt_micromodal_title',	'a:17:{s:4:\"uuid\";s:36:\"59e52aef-8c74-4576-ae43-df723099b73d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:54:\"field.storage.block_content.field_ebt_micromodal_title\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lm4MPSDui0NEYaqvulzZIgmZumlIaUiE638_N0umXDI\";}s:2:\"id\";s:55:\"block_content.ebt_micromodal.field_ebt_micromodal_title\";s:10:\"field_name\";s:26:\"field_ebt_micromodal_title\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:5:\"label\";s:16:\"Micromodal Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_micromodal.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"157b9dd5-a769-42f1-9986-195e571255c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ed-JI-p3sJDcQ3-4guJZ89L_Smftc8LwJ3Z_7XCW5rE\";}s:2:\"id\";s:47:\"block_content.ebt_micromodal.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_quote.body',	'a:17:{s:4:\"uuid\";s:36:\"bcd054c1-c1e6-47a1-9c84-af43855b0dc7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RHJ2BeL7FRpMNmRALB5w7o8erlsGuBnb8MOaVvceiDo\";}s:2:\"id\";s:28:\"block_content.ebt_quote.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:5:\"Quote\";s:11:\"description\";s:20:\"Quote or Testimonial\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_quote.field_ebt_quote_author',	'a:17:{s:4:\"uuid\";s:36:\"5c41064f-97a8-4a0e-aea7-eab453f27eb0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:50:\"field.storage.block_content.field_ebt_quote_author\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bcr-ywW2dLY1kQTCKA6fqxCSgq_nrKEgCB1wj_G8rOs\";}s:2:\"id\";s:46:\"block_content.ebt_quote.field_ebt_quote_author\";s:10:\"field_name\";s:22:\"field_ebt_quote_author\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:12:\"Quote Author\";s:11:\"description\";s:44:\"Company name, Persona name and job position.\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_quote.field_ebt_quote_image',	'a:17:{s:4:\"uuid\";s:36:\"aa44dee9-e2fb-4a02-8f85-0ed2534a54e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:49:\"field.storage.block_content.field_ebt_quote_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_AaWTlSa1X6CaC-_c0qarZPGAD9IaSjpuJF_CUK9vk0\";}s:2:\"id\";s:45:\"block_content.ebt_quote.field_ebt_quote_image\";s:10:\"field_name\";s:21:\"field_ebt_quote_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:11:\"Quote Image\";s:11:\"description\";s:29:\"Persona photo or Company logo\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_quote.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"c5fb6c52-df83-49a6-982d-13cd459b5086\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gKtk0T_7VnCmUPgUgJX1z7v13az3bkGF3bazJXEwZ_o\";}s:2:\"id\";s:42:\"block_content.ebt_quote.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_slick_slider.body',	'a:17:{s:4:\"uuid\";s:36:\"ac203ba4-4731-48c0-a489-49772d98bbcc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1VYVNgk5Hp9ZSjh89NrWVzpkv3BfOpNJz3E_qlTqNkY\";}s:2:\"id\";s:35:\"block_content.ebt_slick_slider.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_slick_slider.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"35e70eb2-5981-4ca9-9540-a6263e5f01ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YIrMWNLT6TiXF-tmAzVOGQaDbDkIa_qy9_KBL0B4TxA\";}s:2:\"id\";s:49:\"block_content.ebt_slick_slider.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_slick_slider.field_ebt_slick_slider',	'a:17:{s:4:\"uuid\";s:36:\"237e10e6-95ca-4f5e-9d1b-2f1d8f7eef67\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:50:\"field.storage.block_content.field_ebt_slick_slider\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eH6HMdmAatyKEevKR8YXk2VH3AF_ntUZim5F7X5D3Cc\";}s:2:\"id\";s:53:\"block_content.ebt_slick_slider.field_ebt_slick_slider\";s:10:\"field_name\";s:22:\"field_ebt_slick_slider\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:12:\"Slick Slider\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:16:\"ebt_slick_slider\";s:16:\"ebt_slick_slider\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:16:\"ebt_slick_slider\";a:2:{s:6:\"weight\";i:9;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_slideshow.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"f6196b18-31e7-4003-842a-206131de10c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oveTq0gmp5_KAESCvT3DtytAnJElJGWzrHzr1lEb-x0\";}s:2:\"id\";s:46:\"block_content.ebt_slideshow.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_slideshow.field_ebt_slideshow',	'a:17:{s:4:\"uuid\";s:36:\"dfe1a625-168b-485c-9c9e-2e8296f0dec8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:47:\"field.storage.block_content.field_ebt_slideshow\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0sk3ViXko3tl_QC0x0GggU_08m7tEtKEoNDg9vwOE-Q\";}s:2:\"id\";s:47:\"block_content.ebt_slideshow.field_ebt_slideshow\";s:10:\"field_name\";s:19:\"field_ebt_slideshow\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:9:\"Slideshow\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:13:\"ebt_slideshow\";s:13:\"ebt_slideshow\";}s:24:\"target_bundles_drag_drop\";a:1:{s:13:\"ebt_slideshow\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:5;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_stats.body',	'a:17:{s:4:\"uuid\";s:36:\"33c69170-b2b4-49a9-9557-a9542eb08865\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qjLV8uviFQzoYVcltie2--7y-ZZpauda_owKbFf-IPA\";}s:2:\"id\";s:28:\"block_content.ebt_stats.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_stats.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"1e3aa7ba-222f-4f33-8628-7c5bf22f00fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Yhkjb0s5PYlfHuk2JdMtwch30e3IZCjz8R1KMJqE4JA\";}s:2:\"id\";s:42:\"block_content.ebt_stats.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_stats.field_ebt_stats',	'a:17:{s:4:\"uuid\";s:36:\"280d2344-5e0c-42f5-bd77-7b358f9b2c08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:43:\"field.storage.block_content.field_ebt_stats\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j6MsUG9RUUe4pToCAeVx7TIOtSMQyibl7ikftOLpXqA\";}s:2:\"id\";s:39:\"block_content.ebt_stats.field_ebt_stats\";s:10:\"field_name\";s:15:\"field_ebt_stats\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:5:\"label\";s:9:\"EBT Stats\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ebt_stats_item\";s:14:\"ebt_stats_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ebt_stats_item\";a:2:{s:6:\"weight\";i:12;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_tabs.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"1396353c-ec74-4693-9d16-7ffb5a6090cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_Gn1i1ea7T8MzoBSjiDcnQMYgfSAq2jN9g-ZJfv27PA\";}s:2:\"id\";s:41:\"block_content.ebt_tabs.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_tabs.field_ebt_tabs',	'a:17:{s:4:\"uuid\";s:36:\"b89072e5-91ec-40a1-aa9c-2a20808308cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:42:\"field.storage.block_content.field_ebt_tabs\";i:2;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4qzYKe-tuRQPHfXtyOyfFfwSfj-Onz88kqc6nsXX4ns\";}s:2:\"id\";s:37:\"block_content.ebt_tabs.field_ebt_tabs\";s:10:\"field_name\";s:14:\"field_ebt_tabs\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:5:\"label\";s:4:\"Tabs\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:7:\"ebt_tab\";s:7:\"ebt_tab\";}s:24:\"target_bundles_drag_drop\";a:1:{s:7:\"ebt_tab\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:2;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_text.body',	'a:17:{s:4:\"uuid\";s:36:\"c72f430e-7366-4a91-bce3-aa5dc0cf8726\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"htRzt66f_OSqHawgprrWKiHiaLoBZUKzc0aMsoIVRlI\";}s:2:\"id\";s:27:\"block_content.ebt_text.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_text.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"2a94aaad-3c54-4074-9d7a-fc204b0cc509\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"G1bcFZfGqQcn1FyernQez0LoRoXBRPKXAjI6-yZKMGw\";}s:2:\"id\";s:41:\"block_content.ebt_text.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_tiles.body',	'a:17:{s:4:\"uuid\";s:36:\"b13d5126-3f86-4bb5-8cdc-a9b72478ab6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hru15RrwqNoJ9o_uoGV1KT2wAkHwJsGaTj7KF0sIZxU\";}s:2:\"id\";s:28:\"block_content.ebt_tiles.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_tiles.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"34788ebc-a5ee-43a6-be6c-58bf07f8a47a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"J3ICag16O5nBkU9zwYLt76LvxEF78Qt-pDCJWA5n1Q4\";}s:2:\"id\";s:42:\"block_content.ebt_tiles.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_tiles.field_ebt_tiles',	'a:17:{s:4:\"uuid\";s:36:\"2e2ec692-0d82-4b56-9cfc-4e871f3a1882\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:43:\"field.storage.block_content.field_ebt_tiles\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"L9cDmlbMT83s3nbfD0cDfsf0BnRv1fpAyA4KTplqxJs\";}s:2:\"id\";s:39:\"block_content.ebt_tiles.field_ebt_tiles\";s:10:\"field_name\";s:15:\"field_ebt_tiles\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:5:\"label\";s:5:\"Tiles\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ebt_tiles_item\";s:14:\"ebt_tiles_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ebt_tiles_item\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_timeline.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"72a4ef65-870a-4488-8009-80269e968b1b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HN5G2K_JDpCXJ8t1Hf1GlS9QdBeEP63Bly-VhnBB6sc\";}s:2:\"id\";s:45:\"block_content.ebt_timeline.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_timeline.field_ebt_timeline',	'a:17:{s:4:\"uuid\";s:36:\"87a15adf-8be6-4080-925b-ebc76f101b32\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:46:\"field.storage.block_content.field_ebt_timeline\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OpOMqlp0m970YTcVsX9wdXHaI-hN6RW9eawnPmz3KtQ\";}s:2:\"id\";s:45:\"block_content.ebt_timeline.field_ebt_timeline\";s:10:\"field_name\";s:18:\"field_ebt_timeline\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:8:\"Timeline\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:12:\"ebt_timeline\";s:12:\"ebt_timeline\";}s:24:\"target_bundles_drag_drop\";a:1:{s:12:\"ebt_timeline\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:10;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_video.body',	'a:17:{s:4:\"uuid\";s:36:\"9b4acfb1-3d8e-4e3d-8901-6120a3b342b2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJmLT9YexVdfd-JSg5eErRWt3FrtaozSqR_v29xtRwU\";}s:2:\"id\";s:28:\"block_content.ebt_video.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_video.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"55445905-ca67-4040-b176-00e1fc2ebb3e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZSSE8vNHSVgLXEAdnpSbPDmk02qrlhm3jj3AJhOLGDs\";}s:2:\"id\";s:42:\"block_content.ebt_video.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_video.field_ebt_video',	'a:17:{s:4:\"uuid\";s:36:\"2e653244-7a00-41c7-a943-06eade5f15ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:43:\"field.storage.block_content.field_ebt_video\";i:2;s:23:\"media.type.remote_video\";i:3;s:16:\"media.type.video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HK8CWqddmUhsshgNl5XJCSCl0ZgJWByyd-uQp8gR9to\";}s:2:\"id\";s:39:\"block_content.ebt_video.field_ebt_video\";s:10:\"field_name\";s:15:\"field_ebt_video\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:2:{s:12:\"remote_video\";s:12:\"remote_video\";s:5:\"video\";s:5:\"video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:12:\"remote_video\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_video_and_image_gallery.body',	'a:17:{s:4:\"uuid\";s:36:\"161669c7-6a7e-4616-86d5-a2e3de9c8fe5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1OrJhHg5mGo5emzkaM2Z6ClqRPHEtI72w5kwSnSWOaI\";}s:2:\"id\";s:46:\"block_content.ebt_video_and_image_gallery.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_video_and_image_gallery.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"278f7615-4ab0-4e87-963f-33f2ae8f78ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5WWOgyldW7uBFXBGN623Yc_zkiry6HnXAn0L5CywrsI\";}s:2:\"id\";s:60:\"block_content.ebt_video_and_image_gallery.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images',	'a:17:{s:4:\"uuid\";s:36:\"efc991a5-26b8-4df3-977e-953a90c2f86c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:55:\"field.storage.block_content.field_ebt_videos_and_images\";i:2;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kZTsNALzCfl1z3gE4CQ1OVfS633RZUMyI5ZBPiMVnm0\";}s:2:\"id\";s:69:\"block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images\";s:10:\"field_name\";s:27:\"field_ebt_videos_and_images\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:17:\"Videos and Images\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:32:\"ebt_video_and_image_gallery_item\";s:32:\"ebt_video_and_image_gallery_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:32:\"ebt_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:16;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_views.body',	'a:17:{s:4:\"uuid\";s:36:\"f746c64f-5c49-4079-bb53-0a1a1dd1a7c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gYULmkk3OY2DQugmZyL9Fv_2Car9QCaQzCeihnGhfPI\";}s:2:\"id\";s:28:\"block_content.ebt_views.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_views.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"3a0e2513-d1ec-4966-9162-427a855b0977\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZrXPDXifY_gudYEr4cT9o_GDEspGqI6gFQgTyN_6RdM\";}s:2:\"id\";s:42:\"block_content.ebt_views.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_views.field_ebt_views_views',	'a:17:{s:4:\"uuid\";s:36:\"5f1f69e3-3f90-4442-95f1-5c1579c679ab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:49:\"field.storage.block_content.field_ebt_views_views\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MAlu-k2uullIwcqbzIvVPeeMm6-JiW5Ev0USbMEGejk\";}s:2:\"id\";s:45:\"block_content.ebt_views.field_ebt_views_views\";s:10:\"field_name\";s:21:\"field_ebt_views_views\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:5:\"label\";s:5:\"Views\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}s:12:\"plugin_types\";a:2:{s:4:\"page\";s:4:\"page\";s:5:\"block\";s:5:\"block\";}s:15:\"preselect_views\";a:0:{}s:16:\"enabled_settings\";a:0:{}}s:10:\"field_type\";s:14:\"viewsreference\";}'),
('',	'field.field.block_content.ebt_webform.body',	'a:17:{s:4:\"uuid\";s:36:\"8733818b-9c02-4e2c-91a6-045583f1e01d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Baa8yf9wUinT0D2-5V7tRKydSUOfQvZsUuTvSBeC-bQ\";}s:2:\"id\";s:30:\"block_content.ebt_webform.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_webform.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"a50fcf2c-9887-448e-a18c-78ac4e87b38c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VOgJYtNjHNsjml3J6mwuL3oMqXc4JPjPD8gGVHyGftg\";}s:2:\"id\";s:44:\"block_content.ebt_webform.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_webform.field_ebt_webform_form',	'a:17:{s:4:\"uuid\";s:36:\"9c984eac-a275-47d3-a7ac-029f8216fcb8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:50:\"field.storage.block_content.field_ebt_webform_form\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"S36GzWuHJCt3YstEnQsUPzQ1dwXpO2MKmqaAgoQ2eb4\";}s:2:\"id\";s:48:\"block_content.ebt_webform.field_ebt_webform_form\";s:10:\"field_name\";s:22:\"field_ebt_webform_form\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:5:\"label\";s:4:\"Form\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}}s:10:\"field_type\";s:7:\"webform\";}'),
('',	'field.field.block_content.ebt_webform_popup.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"7bd9f73f-8c64-46d8-9848-e86bcb5b491e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nY4Z9bxYtEWKQwTfEQV5y1aJi2T_PME930j0zdUd6e4\";}s:2:\"id\";s:50:\"block_content.ebt_webform_popup.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_webform_popup.field_ebt_webform_popup_form',	'a:17:{s:4:\"uuid\";s:36:\"ebbc4709-9eb2-4a48-bc09-0d83eaad805d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:56:\"field.storage.block_content.field_ebt_webform_popup_form\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XKxb-rFq0rOSgKq7mU1s79aoU0-O0IeICu_ZMzj9vG8\";}s:2:\"id\";s:60:\"block_content.ebt_webform_popup.field_ebt_webform_popup_form\";s:10:\"field_name\";s:28:\"field_ebt_webform_popup_form\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:5:\"label\";s:7:\"Webform\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}}s:10:\"field_type\";s:7:\"webform\";}'),
('',	'field.field.media.audio.field_media_audio_file',	'a:17:{s:4:\"uuid\";s:36:\"4fa57014-dbe5-4dc4-b5c9-e6cb3404ad5c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UlZPIbHcLyNqGY5bvydCTijGcKDmwn4Fo8oYZT85wlk\";}s:2:\"id\";s:34:\"media.audio.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:5:\"label\";s:10:\"Audio file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:11:\"mp3 wav aac\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),
('',	'field.field.media.document.field_media_document',	'a:17:{s:4:\"uuid\";s:36:\"1ebfa792-cf03-471d-9e5c-2dccd1fedd38\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:40:\"field.storage.media.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DY5HtJTxUjFRGU_PaY6ifo2nhR-nAZ0y0s6kLmUbv5g\";}s:2:\"id\";s:35:\"media.document.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:96:\"txt rtf doc docx ppt pptx xls xlsx pdf odf odg odp ods odt fodt fods fodp fodg key numbers pages\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),
('',	'field.field.media.image.field_media_image',	'a:17:{s:4:\"uuid\";s:36:\"e2b79a9d-deda-4076-bcbe-2c9ae00b616e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:37:\"field.storage.media.field_media_image\";i:1;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P7CkVOgjDXiN26Fm2hniNei-XPK3iuZTlcBGqreTbJ0\";}s:2:\"id\";s:29:\"media.image.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:25:\"png gif jpg jpeg webp svg\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),
('',	'field.field.media.remote_video.field_media_oembed_video',	'a:17:{s:4:\"uuid\";s:36:\"96b9388f-0779-4e2b-8429-6932b1a68ead\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.media.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Eo4HHenV5iZat_kEWgr_wydD3TgwURMCzwt-7qIEyoM\";}s:2:\"id\";s:43:\"media.remote_video.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:5:\"label\";s:9:\"Video URL\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),
('',	'field.field.media.video.field_media_video_file',	'a:17:{s:4:\"uuid\";s:36:\"af846c60-eb6c-4029-84b4-aa0ccf412591\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6kMMjmk2r_csGQ52qI9BUaO8r_oAzNLbxlclaj-JlDQ\";}s:2:\"id\";s:34:\"media.video.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:5:\"label\";s:10:\"Video file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:3:\"mp4\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),
('',	'field.field.node.article.body',	'a:17:{s:4:\"uuid\";s:36:\"7f75b85e-a8a9-4e63-8ba8-42cd18f1d713\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Wxs1LseZ8JsNwD9uJVIbzZqG35yQXN8Eo1Hub6NMuI\";}s:2:\"id\";s:17:\"node.article.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.node.article.field_image',	'a:17:{s:4:\"uuid\";s:36:\"ba97827c-59cc-4fb5-be06-7c44f9e98113\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"field.storage.node.field_image\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j0riO_-77ZFWNLtj0iJ31HnohiNjdn8HUL86RueCF-M\";}s:2:\"id\";s:24:\"node.article.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:12:\"Teaser Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),
('',	'field.field.node.article.field_metatags',	'a:16:{s:4:\"uuid\";s:36:\"06f91975-9ecb-430d-b7f8-3de8ae8601c8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"field.storage.node.field_metatags\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:7:\"metatag\";}}s:2:\"id\";s:27:\"node.article.field_metatags\";s:10:\"field_name\";s:14:\"field_metatags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:8:\"Metatags\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:7:\"metatag\";}'),
('',	'field.field.node.article.field_tags',	'a:17:{s:4:\"uuid\";s:36:\"61a810a4-e29c-4fbf-b132-9fe51b115626\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:29:\"field.storage.node.field_tags\";i:1;s:17:\"node.type.article\";i:2;s:24:\"taxonomy.vocabulary.tags\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QdUgf_beeoaPiyKorFv0q1fcJpWH_uZTqe_xoVJacrw\";}s:2:\"id\";s:23:\"node.article.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Tags\";s:11:\"description\";s:84:\"Enter a comma-separated list. For example: Amsterdam, Mexico City, \"Cleveland, Ohio\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:21:\"default:taxonomy_term\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.node.article.layout_builder__layout',	'a:16:{s:4:\"uuid\";s:36:\"97640446-27d5-4146-8b2a-a776d7a62ec7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:41:\"field.storage.node.layout_builder__layout\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:14:\"layout_builder\";}}s:2:\"id\";s:35:\"node.article.layout_builder__layout\";s:10:\"field_name\";s:22:\"layout_builder__layout\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:6:\"Layout\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:14:\"layout_section\";}'),
('',	'field.field.node.page.body',	'a:17:{s:4:\"uuid\";s:36:\"f2e704ba-2d4f-4bf0-976b-19d893472d4f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KHu9I-pR4FnP79crRJ5gVD_1mKGSZcJsdIm9bn64iFg\";}s:2:\"id\";s:14:\"node.page.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.node.page.field_metatags',	'a:16:{s:4:\"uuid\";s:36:\"e785ab1b-0edf-46aa-bbaf-56e645079434\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"field.storage.node.field_metatags\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:7:\"metatag\";}}s:2:\"id\";s:24:\"node.page.field_metatags\";s:10:\"field_name\";s:14:\"field_metatags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:8:\"Metatags\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:7:\"metatag\";}'),
('',	'field.field.node.page.layout_builder__layout',	'a:16:{s:4:\"uuid\";s:36:\"79c176b7-33a8-419d-b175-1853525a7e50\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:41:\"field.storage.node.layout_builder__layout\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:14:\"layout_builder\";}}s:2:\"id\";s:32:\"node.page.layout_builder__layout\";s:10:\"field_name\";s:22:\"layout_builder__layout\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:6:\"Layout\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:14:\"layout_section\";}'),
('',	'field.field.paragraph.ebt_accordion.field_ebt_accordion_text',	'a:17:{s:4:\"uuid\";s:36:\"f0b63cf1-7f17-4dea-a7e0-b54d5d7d823f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_accordion_text\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K83AQZ4cOGBmrJfAKHjN1BC5fNJE2slkMvsq-eOngms\";}s:2:\"id\";s:48:\"paragraph.ebt_accordion.field_ebt_accordion_text\";s:10:\"field_name\";s:24:\"field_ebt_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:13:\"Text / Answer\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_accordion.field_ebt_accordion_title',	'a:17:{s:4:\"uuid\";s:36:\"c7bb20d0-7c3a-4e1d-80bd-fc8145337db5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ebt_accordion_title\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4iRsnnRe66bYKBWRFqXd8sFfW3tTM7kGDHb5ZI6bRoI\";}s:2:\"id\";s:49:\"paragraph.ebt_accordion.field_ebt_accordion_title\";s:10:\"field_name\";s:25:\"field_ebt_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:16:\"Title / Question\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_carousel.field_ebt_carousel_caption',	'a:17:{s:4:\"uuid\";s:36:\"cdf69cb6-7607-44f2-8e15-66eff3ea978e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ebt_carousel_caption\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zJkgaoa5XS7hvJb5prthRdBt34u3Y3QPJJ_obTMfkfQ\";}s:2:\"id\";s:49:\"paragraph.ebt_carousel.field_ebt_carousel_caption\";s:10:\"field_name\";s:26:\"field_ebt_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:13:\"Slide caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_carousel.field_ebt_carousel_image',	'a:17:{s:4:\"uuid\";s:36:\"cf3345b8-8872-40ef-818f-2e94b33e8961\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:48:\"field.storage.paragraph.field_ebt_carousel_image\";i:1;s:16:\"media.type.image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"igPOF7Xbo0_CaEPXbAyrAz0x22az-ryGnj9S4zfXsZY\";}s:2:\"id\";s:47:\"paragraph.ebt_carousel.field_ebt_carousel_image\";s:10:\"field_name\";s:24:\"field_ebt_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:11:\"Slide image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_description',	'a:17:{s:4:\"uuid\";s:36:\"89d82ff4-da95-426e-b0c1-c9f18b4c7e6a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:53:\"field.storage.paragraph.field_ebt_counter_description\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SGPys8iAffvOl_W66tfDAlPixkXxxxidEUCONW9q7dI\";}s:2:\"id\";s:56:\"paragraph.ebt_counter_item.field_ebt_counter_description\";s:10:\"field_name\";s:29:\"field_ebt_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:11:\"Description\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"22d74b30-be52-4cee-91ea-a0aa04de5dff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_ebt_counter_icon\";i:1;s:16:\"media.type.image\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Vzl7VAXpLPJd2KXAxVHrOfGNPWB1y1s1Jr5foDGSdIg\";}s:2:\"id\";s:49:\"paragraph.ebt_counter_item.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:4:\"Icon\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"e3b02b26-e9be-46ee-be2a-9c0cdb537a47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_counter_number\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-5pDzCL0Ha9nbkySRCIjCME2yqGDQ9k92GT8A1xqWU\";}s:2:\"id\";s:51:\"paragraph.ebt_counter_item.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:6:\"Number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:4:{s:3:\"min\";N;s:3:\"max\";N;s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"field_type\";s:7:\"integer\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_title',	'a:17:{s:4:\"uuid\";s:36:\"62ea8aa7-eadf-46fe-8360-d5a565d6e339\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ebt_counter_title\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CvlljFbOKRTlxFz1hVYtYJkEdk3S-0I9UmjjS41E7_U\";}s:2:\"id\";s:50:\"paragraph.ebt_counter_item.field_ebt_counter_title\";s:10:\"field_name\";s:23:\"field_ebt_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_image',	'a:17:{s:4:\"uuid\";s:36:\"0ed191f1-4795-4501-9075-ad48a0ed7ef5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:52:\"field.storage.paragraph.field_ebt_slick_slider_image\";i:1;s:16:\"media.type.image\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pYWtlYxsR5uP9TrVPzdvPyRiMgr6Lp75dE9QtVEyu3Q\";}s:2:\"id\";s:55:\"paragraph.ebt_slick_slider.field_ebt_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ebt_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_link',	'a:17:{s:4:\"uuid\";s:36:\"ae270a12-20ca-4ebe-a2f1-69ea8b4fe6e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ebt_slick_slider_link\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jk5t1dH13MfYx1LmuLzIlSTGOi3qFvAHr8Zj5vlyM2I\";}s:2:\"id\";s:54:\"paragraph.ebt_slick_slider.field_ebt_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_text',	'a:17:{s:4:\"uuid\";s:36:\"087b3c83-4e91-4f68-b458-96330c343db8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ebt_slick_slider_text\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ob6mfPaJJwePb80FfSWg_M2reWUeqydWDbjtcshe-Bw\";}s:2:\"id\";s:54:\"paragraph.ebt_slick_slider.field_ebt_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_link',	'a:17:{s:4:\"uuid\";s:36:\"f3fdd942-959d-4943-993f-2d7c52030728\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_slideshow_link\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_fFBiyKlJ3i_w71vNv_KlKPhYmEARkECK_6O5gU5skA\";}s:2:\"id\";s:48:\"paragraph.ebt_slideshow.field_ebt_slideshow_link\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_slide',	'a:17:{s:4:\"uuid\";s:36:\"b8c36a1d-4e00-47c8-8d3b-5f5c824c1c41\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:49:\"field.storage.paragraph.field_ebt_slideshow_slide\";i:1;s:16:\"media.type.image\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZhjSOx4h5C-uQqS8wmCEX4R-expUAu-sQghZL7OK400\";}s:2:\"id\";s:49:\"paragraph.ebt_slideshow.field_ebt_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_text',	'a:17:{s:4:\"uuid\";s:36:\"db307a56-3f8e-4027-b5d1-28fe5edaa11e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_slideshow_text\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bZ0m2BBV-ldK-3Eh4BGp1MRAgA6rMqeGPulDsD9kdyg\";}s:2:\"id\";s:48:\"paragraph.ebt_slideshow.field_ebt_slideshow_text\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_title',	'a:17:{s:4:\"uuid\";s:36:\"cc62f49e-1354-4058-a151-c4c1e7e5994a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ebt_slideshow_title\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6qs_c-h6E-d-9pn4rWyP3VMtvPIx0dwfa_m8bl9Or4g\";}s:2:\"id\";s:49:\"paragraph.ebt_slideshow.field_ebt_slideshow_title\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:11:\"Slide Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_image',	'a:17:{s:4:\"uuid\";s:36:\"e7dc4733-12c7-4748-975b-b7d57accd4ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_stats_item_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1k1v70N6h-IQn541w0qMasOm8bEEp3XimOb7xSv8suk\";}s:2:\"id\";s:47:\"paragraph.ebt_stats_item.field_stats_item_image\";s:10:\"field_name\";s:22:\"field_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:16:\"Stats item image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_link',	'a:17:{s:4:\"uuid\";s:36:\"67b6c95b-30fa-471d-a031-e84ec26a1a54\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_stats_item_link\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uExk2SWTCDuqJRmvyPPMsGBSMj4ilG_32ADqZm_jKZY\";}s:2:\"id\";s:46:\"paragraph.ebt_stats_item.field_stats_item_link\";s:10:\"field_name\";s:21:\"field_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:15:\"Stats item link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_number',	'a:17:{s:4:\"uuid\";s:36:\"4ae0f11b-4c4f-43c8-a58e-9413b992ad4d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_stats_item_number\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5OFR72Rn-pvsZTbp7LEkgUVp0q21QilFZMegsC5ICbo\";}s:2:\"id\";s:48:\"paragraph.ebt_stats_item.field_stats_item_number\";s:10:\"field_name\";s:23:\"field_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:17:\"Stats item number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_text',	'a:17:{s:4:\"uuid\";s:36:\"2907b7cd-48be-4276-8c1a-ad20ca437cd4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_stats_item_text\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5YdkRFvRcJQuYp6xs1qhhjaUeyj1ysW93i6EPEh9dWU\";}s:2:\"id\";s:46:\"paragraph.ebt_stats_item.field_stats_item_text\";s:10:\"field_name\";s:21:\"field_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:15:\"Stats item text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_block',	'a:17:{s:4:\"uuid\";s:36:\"6821e0ef-8080-428a-ac78-f51249bb5e2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_block\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7dftnJ-QEc2wq727UtTNqtQGbbQis8Pwgykf0EPgU5U\";}s:2:\"id\";s:37:\"paragraph.ebt_tab.field_ebt_tab_block\";s:10:\"field_name\";s:19:\"field_ebt_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:9:\"Tab Block\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:6:\"blocks\";s:18:\"selection_settings\";a:1:{s:10:\"plugin_ids\";a:0:{}}}s:10:\"field_type\";s:11:\"block_field\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_content',	'a:17:{s:4:\"uuid\";s:36:\"9093a2e3-eafc-42f9-9d74-0c76cf2fa7e6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ebt_tab_content\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:7:\"options\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"as55Dml1Xd2yWFDU0vGxsQmoXaIr9fZ2lC4KG8TpvzA\";}s:2:\"id\";s:39:\"paragraph.ebt_tab.field_ebt_tab_content\";s:10:\"field_name\";s:21:\"field_ebt_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:11:\"Tab content\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:11:\"list_string\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_page',	'a:17:{s:4:\"uuid\";s:36:\"6b77acaf-9fab-4d2e-9843-cfe8180ce9fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:42:\"field.storage.paragraph.field_ebt_tab_page\";i:1;s:14:\"node.type.page\";i:2;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t9WpCMZrY0hReO2jvRG2Rte22ZW2y4Dq_5kF4YVAWqo\";}s:2:\"id\";s:36:\"paragraph.ebt_tab.field_ebt_tab_page\";s:10:\"field_name\";s:18:\"field_ebt_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:8:\"Tab page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:12:\"default:node\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:4:\"page\";s:4:\"page\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_text',	'a:17:{s:4:\"uuid\";s:36:\"0cb50bf8-21aa-4ea6-a7d0-90d454555f86\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ebt_tab_text\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qDqTeXYS1CTWbjbJQUSmVXGsWThhwp_YLObjCrj-4wo\";}s:2:\"id\";s:36:\"paragraph.ebt_tab.field_ebt_tab_text\";s:10:\"field_name\";s:18:\"field_ebt_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:8:\"Tab text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_title',	'a:17:{s:4:\"uuid\";s:36:\"217d9d46-984c-450c-b218-1d58121ced68\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_title\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"axHae-sP24gbeAgLnxqUi-W0N6tnY4ImUB_wdC1bCiM\";}s:2:\"id\";s:37:\"paragraph.ebt_tab.field_ebt_tab_title\";s:10:\"field_name\";s:19:\"field_ebt_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:9:\"Tab title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:4:\"text\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_views',	'a:17:{s:4:\"uuid\";s:36:\"5c306dcf-d85c-424e-b5d0-a819386f6ecc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_views\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Zc3r5Wx5CVuHBS5Fvv1jYRaHo4EnB7V2rhALuCxql_o\";}s:2:\"id\";s:37:\"paragraph.ebt_tab.field_ebt_tab_views\";s:10:\"field_name\";s:19:\"field_ebt_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:9:\"Tab views\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";i:0;}s:12:\"plugin_types\";a:5:{s:7:\"default\";s:7:\"default\";s:5:\"block\";s:5:\"block\";s:4:\"page\";i:0;s:4:\"feed\";i:0;s:5:\"embed\";i:0;}s:15:\"preselect_views\";a:14:{s:8:\"articles\";i:0;s:13:\"block_content\";i:0;s:7:\"comment\";i:0;s:15:\"comments_recent\";i:0;s:7:\"content\";i:0;s:14:\"content_recent\";i:0;s:5:\"files\";i:0;s:9:\"frontpage\";i:0;s:13:\"taxonomy_term\";i:0;s:17:\"user_admin_people\";i:0;s:8:\"watchdog\";i:0;s:19:\"webform_submissions\";i:0;s:9:\"who_s_new\";i:0;s:12:\"who_s_online\";i:0;}s:16:\"enabled_settings\";a:5:{s:5:\"pager\";i:0;s:5:\"limit\";i:0;s:6:\"offset\";i:0;s:5:\"title\";i:0;s:8:\"argument\";i:0;}}s:10:\"field_type\";s:14:\"viewsreference\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_clickable_tile',	'a:17:{s:4:\"uuid\";s:36:\"b6bcf941-67b4-43b7-9747-c95baf1b7bc4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_clickable_tile\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I8Bhnp9Mihk3DDEulISHIOOcN-avs5jkwzt9L0n-CcI\";}s:2:\"id\";s:49:\"paragraph.ebt_tiles_item.field_ebt_clickable_tile\";s:10:\"field_name\";s:24:\"field_ebt_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:14:\"Clickable Tile\";s:11:\"description\";s:66:\"Make entire tile clickable or display link separataly if unchecked\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_image',	'a:17:{s:4:\"uuid\";s:36:\"9d903341-553f-4311-8a83-c48130d410e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:45:\"field.storage.paragraph.field_ebt_tiles_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lPf_h3aKofBH6XHQRhBmyVb1lV4Z8_w0oD6vY9JLcjM\";}s:2:\"id\";s:46:\"paragraph.ebt_tiles_item.field_ebt_tiles_image\";s:10:\"field_name\";s:21:\"field_ebt_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_link',	'a:17:{s:4:\"uuid\";s:36:\"3c7cd9d7-a4c3-49a9-9bbc-1ced5ab70209\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ebt_tiles_link\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQ8lDL7PoSiLrK83cA8hSPIPNufbpw3j1qT4f1V9VUc\";}s:2:\"id\";s:45:\"paragraph.ebt_tiles_item.field_ebt_tiles_link\";s:10:\"field_name\";s:20:\"field_ebt_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_text',	'a:17:{s:4:\"uuid\";s:36:\"5201e488-c9af-4ec2-867e-3b3dbe8c8b16\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ebt_tiles_text\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yZYhpVfxBQEK7LOwoolFtOZY726XpjMHK5opPVJB4j4\";}s:2:\"id\";s:45:\"paragraph.ebt_tiles_item.field_ebt_tiles_text\";s:10:\"field_name\";s:20:\"field_ebt_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_title',	'a:17:{s:4:\"uuid\";s:36:\"1e88de7b-7c46-4562-a223-9ccf83779820\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ebt_tiles_title\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"V7UyIKTz-lufN2i-3921iDZVIjrM1K-GA3PPgZfgYTI\";}s:2:\"id\";s:46:\"paragraph.ebt_tiles_item.field_ebt_tiles_title\";s:10:\"field_name\";s:21:\"field_ebt_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_current',	'a:17:{s:4:\"uuid\";s:36:\"24fd2c38-f992-42ae-89ce-590dd574cb31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ebt_timeline_current\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Js3oBqyPFEjLEDUuAPzn29jLKcNg1wsB7M9uvAF8fwQ\";}s:2:\"id\";s:49:\"paragraph.ebt_timeline.field_ebt_timeline_current\";s:10:\"field_name\";s:26:\"field_ebt_timeline_current\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:7:\"Current\";s:11:\"description\";s:36:\"Highlight current stage in timeline.\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_date',	'a:17:{s:4:\"uuid\";s:36:\"d1569baf-9302-4e38-9ed4-987caeafa2e4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ebt_timeline_date\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ajUABeEHsfvEoCEA1JJywutAhjakBjNSR6yymicgJcQ\";}s:2:\"id\";s:46:\"paragraph.ebt_timeline.field_ebt_timeline_date\";s:10:\"field_name\";s:23:\"field_ebt_timeline_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:4:\"Date\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_media_image',	'a:17:{s:4:\"uuid\";s:36:\"a0651ff8-3cb5-478f-acbe-120dd869e921\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:54:\"field.storage.paragraph.field_ebt_timeline_media_image\";i:1;s:16:\"media.type.image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0WMqQDbMLHG-hJMnj9tohP4sS2B93Gy_jhhZoUJIA9I\";}s:2:\"id\";s:53:\"paragraph.ebt_timeline.field_ebt_timeline_media_image\";s:10:\"field_name\";s:30:\"field_ebt_timeline_media_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_text',	'a:17:{s:4:\"uuid\";s:36:\"265711bf-cab4-450f-83c7-f401aa255ff1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ebt_timeline_text\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5F87FeFRv4oMn7nyxCCJ3pjlpG-G5NBIfD-5o5No0t8\";}s:2:\"id\";s:46:\"paragraph.ebt_timeline.field_ebt_timeline_text\";s:10:\"field_name\";s:23:\"field_ebt_timeline_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_title',	'a:17:{s:4:\"uuid\";s:36:\"ae101647-2196-429e-ba3e-cbb55e4e92f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_timeline_title\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_pET64Z-ylj-Ic4NyQ0BmUF4zGO8dZ-uVWadrNKQvyo\";}s:2:\"id\";s:47:\"paragraph.ebt_timeline.field_ebt_timeline_title\";s:10:\"field_name\";s:24:\"field_ebt_timeline_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),
('',	'field.field.paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description',	'a:17:{s:4:\"uuid\";s:36:\"2c335583-7279-4b40-95b9-09d17b06fc4a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:54:\"field.storage.paragraph.field_gallery_item_description\";i:1;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lW3Ks0DIMaIjFKfbgrmmUXgP-Atqo_sKwWuBuvS3Rmg\";}s:2:\"id\";s:73:\"paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description\";s:10:\"field_name\";s:30:\"field_gallery_item_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:5:\"label\";s:24:\"Gallery item description\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item',	'a:17:{s:4:\"uuid\";s:36:\"2d4456ac-0c7c-4f72-8624-a25a5d933b9b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:4:{i:0;s:48:\"field.storage.paragraph.field_video_gallery_item\";i:1;s:16:\"media.type.image\";i:2;s:23:\"media.type.remote_video\";i:3;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JaxawDXWXvX-mf-HuaUiJYhh81uXGJm8rPPZGOoQze8\";}s:2:\"id\";s:67:\"paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item\";s:10:\"field_name\";s:24:\"field_video_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:5:\"label\";s:12:\"Gallery Item\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:2:{s:5:\"image\";s:5:\"image\";s:12:\"remote_video\";s:12:\"remote_video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:5:\"image\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.user.user.user_picture',	'a:17:{s:4:\"uuid\";s:36:\"a99bd180-01c5-4300-997c-47456c8ba004\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:31:\"field.storage.user.user_picture\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TE3gYVzd6g0deXqUl8SEu2azHwVG-SdXm3kwbrz0kHw\";}s:2:\"id\";s:22:\"user.user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:5:\"label\";s:7:\"Picture\";s:11:\"description\";s:29:\"Your virtual face or picture.\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:40:\"pictures/[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:0;s:18:\"alt_field_required\";b:0;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),
('',	'field.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJk0TAQBzlNo52ehiHI7bIEPLGi0BYqZvPdEn7Chfu0\";}s:16:\"purge_batch_size\";i:50;}'),
('',	'field.storage.block_content.body',	'a:17:{s:4:\"uuid\";s:36:\"3db51960-3062-400f-b922-f0a7373dacb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:2:\"id\";s:18:\"block_content.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_accordion',	'a:17:{s:4:\"uuid\";s:36:\"510be1fe-456a-4a0f-8638-40b7764bd46a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-9lmszSGOf8FvJqERXt4Y75SqfNFnjrUmffe3mvm63E\";}s:2:\"id\";s:33:\"block_content.field_ebt_accordion\";s:10:\"field_name\";s:19:\"field_ebt_accordion\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_basic_button_link',	'a:17:{s:4:\"uuid\";s:36:\"227cb366-5e8c-44f6-bcc0-a4197c0060f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BzBSGwNX6bKi7xiNAKiETrdJPbGYMNk27dC6VzdE2Z4\";}s:2:\"id\";s:41:\"block_content.field_ebt_basic_button_link\";s:10:\"field_name\";s:27:\"field_ebt_basic_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_block_block',	'a:17:{s:4:\"uuid\";s:36:\"93988320-9748-44ab-ac19-9ac1a6feaa9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qUmxIKbmrhd1TnlvNUsQ24_IqgsilgfToL8gamHgjPk\";}s:2:\"id\";s:35:\"block_content.field_ebt_block_block\";s:10:\"field_name\";s:21:\"field_ebt_block_block\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_bootstrap_button_link',	'a:17:{s:4:\"uuid\";s:36:\"6848e7e6-6bb4-4d7b-bfe3-64cb965c8d83\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Mn_2tFUWa7Mu6w06yP9iFQ7KLLKr83YOpxoaTd3IDo\";}s:2:\"id\";s:45:\"block_content.field_ebt_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ebt_bootstrap_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_carousel',	'a:17:{s:4:\"uuid\";s:36:\"c31eee89-5d35-4da4-a2f9-daca2ffd26b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5RyRgQO2iOVZE4gIaH8pGJ4s3UZCNOm5nqfkFXWwVvE\";}s:2:\"id\";s:32:\"block_content.field_ebt_carousel\";s:10:\"field_name\";s:18:\"field_ebt_carousel\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_columns_blocks',	'a:17:{s:4:\"uuid\";s:36:\"007c60bc-7d54-4666-8065-f77200cca762\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8ubMRbdfnR4zPhu3EFrCWZOc2hr9_Dum6gPo01gA7OE\";}s:2:\"id\";s:38:\"block_content.field_ebt_columns_blocks\";s:10:\"field_name\";s:24:\"field_ebt_columns_blocks\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_countdown_date',	'a:17:{s:4:\"uuid\";s:36:\"18c467c8-f5f7-4380-a5b7-5d8dd1bd6891\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:8:\"datetime\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tfVOPr7E66mYxIOwRxWNsSw4nFQnztb5FQbxuKg7_Dg\";}s:2:\"id\";s:38:\"block_content.field_ebt_countdown_date\";s:10:\"field_name\";s:24:\"field_ebt_countdown_date\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:8:\"datetime\";s:8:\"settings\";a:1:{s:13:\"datetime_type\";s:8:\"datetime\";}s:6:\"module\";s:8:\"datetime\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"90f3734d-9d21-4723-8027-039393a502ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bYFfyXow5e24VR-vUVn5lG3PHuSyRBkkEZ_qOShiuk\";}s:2:\"id\";s:36:\"block_content.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_counter_items',	'a:17:{s:4:\"uuid\";s:36:\"fcff8171-e2db-44a5-9585-8b9fb7992b79\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n1DI17J39aMu-YkFmfdRmeqTQflyy2-_xOR8jw99LkE\";}s:2:\"id\";s:37:\"block_content.field_ebt_counter_items\";s:10:\"field_name\";s:23:\"field_ebt_counter_items\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"62a1a67b-d505-4c27-8636-6a9c35a21cf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fzJ_kU3wKSQOA7gdcWs4erHYixRul2pFzixpKaUIEcs\";}s:2:\"id\";s:38:\"block_content.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:7:\"integer\";s:8:\"settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_column_image',	'a:17:{s:4:\"uuid\";s:36:\"1e11b0a4-9fbb-4f77-a027-2abe7c00a623\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cWseV862aJoW9_oVsbhZOp1F-1WgQGPaPWt4miaSdoM\";}s:2:\"id\";s:40:\"block_content.field_ebt_cta_column_image\";s:10:\"field_name\";s:26:\"field_ebt_cta_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_link',	'a:17:{s:4:\"uuid\";s:36:\"069a665c-1062-4320-b384-be548389f826\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rx7cMICk6v3oU3DQBozX_KkK6bXWe9gJNBM2H0aC6n4\";}s:2:\"id\";s:32:\"block_content.field_ebt_cta_link\";s:10:\"field_name\";s:18:\"field_ebt_cta_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_second_link',	'a:17:{s:4:\"uuid\";s:36:\"95a9a9f7-3de1-4e44-8f20-3d0f2dfe6baa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nldTu1l1Acs-EQQUI6pM7wxOCM_8L8QdevFiQDrvqdk\";}s:2:\"id\";s:39:\"block_content.field_ebt_cta_second_link\";s:10:\"field_name\";s:25:\"field_ebt_cta_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_title',	'a:17:{s:4:\"uuid\";s:36:\"28d853cc-13c3-4be6-9b85-37001544855b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QzI1KYIZiUFHadsdJPmZk_6XW4wCrROvPpgDNWpBa8M\";}s:2:\"id\";s:33:\"block_content.field_ebt_cta_title\";s:10:\"field_name\";s:19:\"field_ebt_cta_title\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_column_image',	'a:17:{s:4:\"uuid\";s:36:\"ef778f49-5062-47e4-bca2-1b340272972f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qRkbr3wurZNCdoGUXFQbfo3Q8o-iJ-GBBGGEAY2iPYg\";}s:2:\"id\";s:41:\"block_content.field_ebt_hero_column_image\";s:10:\"field_name\";s:27:\"field_ebt_hero_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_link',	'a:17:{s:4:\"uuid\";s:36:\"27029cab-99df-44cd-891e-de41f3558b7c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u6S6Tua-DwnyB3sGdBXHub-aGYa1PeUoR9SfeJOlpYE\";}s:2:\"id\";s:33:\"block_content.field_ebt_hero_link\";s:10:\"field_name\";s:19:\"field_ebt_hero_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_second_link',	'a:17:{s:4:\"uuid\";s:36:\"535ff977-be0f-4fa5-8d38-7803ae8b9094\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zmAY3AWa6AyFxiDtFl2a9fy666r6LZkvLTF540UTBdE\";}s:2:\"id\";s:40:\"block_content.field_ebt_hero_second_link\";s:10:\"field_name\";s:26:\"field_ebt_hero_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_title',	'a:17:{s:4:\"uuid\";s:36:\"2807bb2f-4aff-460c-9cf6-46dd6ddcf653\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tz0LPZeke3wFWFFnRzkakjNgB9UGwLj1eCtzzQv6XSA\";}s:2:\"id\";s:34:\"block_content.field_ebt_hero_title\";s:10:\"field_name\";s:20:\"field_ebt_hero_title\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_title_prefix',	'a:17:{s:4:\"uuid\";s:36:\"d972b731-9ab7-4ca0-8ee1-32320e00018b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yPT-fy4fwafnNJhdyQ0u1kFfPiRvtGiJ8-5FOUcKyaw\";}s:2:\"id\";s:41:\"block_content.field_ebt_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ebt_hero_title_prefix\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image',	'a:17:{s:4:\"uuid\";s:36:\"90e79693-e9f5-46f1-bb04-df225231b9a7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"glPjB_880Y127LFOondnNWS1FPhcaT_fJa11BR0P5BA\";}s:2:\"id\";s:29:\"block_content.field_ebt_image\";s:10:\"field_name\";s:15:\"field_ebt_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image_caption',	'a:17:{s:4:\"uuid\";s:36:\"d9f39667-4231-4f25-b5b5-7d6a627c0143\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LJgW5JIAhD9XCJuoflFRdy-F8SWYW2Cix0FvZz4SYiY\";}s:2:\"id\";s:37:\"block_content.field_ebt_image_caption\";s:10:\"field_name\";s:23:\"field_ebt_image_caption\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image_gallery',	'a:17:{s:4:\"uuid\";s:36:\"0ab015a1-cb97-4ec7-ad66-d236d2472cee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VTE6qLfHmQDITpk4f42HVWATR8Wgh7o2ygcj4yx3iNQ\";}s:2:\"id\";s:37:\"block_content.field_ebt_image_gallery\";s:10:\"field_name\";s:23:\"field_ebt_image_gallery\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image_link',	'a:17:{s:4:\"uuid\";s:36:\"d53112b6-fda3-4a60-9140-a4f4d8c03704\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wLzveDC1XvIz7oYfIvN4OjokbzzjPzDc9Ik730ZY254\";}s:2:\"id\";s:34:\"block_content.field_ebt_image_link\";s:10:\"field_name\";s:20:\"field_ebt_image_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_micromodal_title',	'a:17:{s:4:\"uuid\";s:36:\"8889dde4-ff00-4644-8af5-1d22a85992bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KxeGHZZZNOmgTH3mTuMpwjJqQoqqDIsVOiT05vaOjSQ\";}s:2:\"id\";s:40:\"block_content.field_ebt_micromodal_title\";s:10:\"field_name\";s:26:\"field_ebt_micromodal_title\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_quote_author',	'a:17:{s:4:\"uuid\";s:36:\"66105a0b-52fa-455d-9673-6bab401dd3d9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"un8UvEIKf-pPNdISDAwHz8cnHArBXUbFHb8rYis_-KU\";}s:2:\"id\";s:36:\"block_content.field_ebt_quote_author\";s:10:\"field_name\";s:22:\"field_ebt_quote_author\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_quote_image',	'a:17:{s:4:\"uuid\";s:36:\"c53a9a24-143b-4766-a552-e983659465b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"usPfnGqFjnh9WSQ4-5tqsU1G2FvbPHpJMyt4Omq2btU\";}s:2:\"id\";s:35:\"block_content.field_ebt_quote_image\";s:10:\"field_name\";s:21:\"field_ebt_quote_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"37d2f916-06b4-418e-91ad-84a23f9fe7aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ifyYbCOsv_c2p19zBnvPk39PxYWsMjVLhswFVxeoMEk\";}s:2:\"id\";s:32:\"block_content.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:12:\"ebt_settings\";s:8:\"settings\";a:0:{}s:6:\"module\";s:8:\"ebt_core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_slick_slider',	'a:17:{s:4:\"uuid\";s:36:\"4f31d892-e4c2-45d6-a14e-723ccc4c06f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvQGqiPKTXqRaJpknm7I-jiTH0_2U95OADILQZQt5zA\";}s:2:\"id\";s:36:\"block_content.field_ebt_slick_slider\";s:10:\"field_name\";s:22:\"field_ebt_slick_slider\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_slideshow',	'a:17:{s:4:\"uuid\";s:36:\"aec7f7b6-b7a3-414f-8026-620c99e80fee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pGo99IMeEAHZnIdMVP18pkNzYTjRT7opYqgiP2t4CzI\";}s:2:\"id\";s:33:\"block_content.field_ebt_slideshow\";s:10:\"field_name\";s:19:\"field_ebt_slideshow\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_stats',	'a:17:{s:4:\"uuid\";s:36:\"65f88f19-ba20-4a37-8258-22b4bbd0bed3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TCxq8NOVtHeT-j0H_fF1rrmP8AxlDhBMsOm8KSQlkrs\";}s:2:\"id\";s:29:\"block_content.field_ebt_stats\";s:10:\"field_name\";s:15:\"field_ebt_stats\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_tabs',	'a:17:{s:4:\"uuid\";s:36:\"8b001212-3460-4d07-af2d-efb8bed64599\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-l2aVtFab9PohqPfDUp_RU4Ji6kBJLDWSfB6L_rUZmo\";}s:2:\"id\";s:28:\"block_content.field_ebt_tabs\";s:10:\"field_name\";s:14:\"field_ebt_tabs\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_tiles',	'a:17:{s:4:\"uuid\";s:36:\"2fa60bf2-361b-4902-b836-53c11ea98d00\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xpk_uqKrbVXj3nCNx7pki4z-Cql8XOb4a0GLo-PxaDE\";}s:2:\"id\";s:29:\"block_content.field_ebt_tiles\";s:10:\"field_name\";s:15:\"field_ebt_tiles\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_timeline',	'a:17:{s:4:\"uuid\";s:36:\"34f357a7-4ec0-459d-9349-7c3b933ed9ca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"w5cvHJQa6dOxx4ke6vQ8dBNORP8_2BYC8XoDyNSh_ag\";}s:2:\"id\";s:32:\"block_content.field_ebt_timeline\";s:10:\"field_name\";s:18:\"field_ebt_timeline\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_video',	'a:17:{s:4:\"uuid\";s:36:\"cd7bca62-bdaa-494e-8d09-d0af7c881721\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yqpxggVM9qa9BsCQ0dK4C8x0wU_GrVyhYXeHKQe-IMI\";}s:2:\"id\";s:29:\"block_content.field_ebt_video\";s:10:\"field_name\";s:15:\"field_ebt_video\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_videos_and_images',	'a:17:{s:4:\"uuid\";s:36:\"51b55e7c-d254-49db-b70a-396cd9835bd2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gzA7OAqszgyne63vWHEzNQQzhp58wo4JD5jrt82tjk8\";}s:2:\"id\";s:41:\"block_content.field_ebt_videos_and_images\";s:10:\"field_name\";s:27:\"field_ebt_videos_and_images\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_views_views',	'a:17:{s:4:\"uuid\";s:36:\"f11fd5af-293c-41e7-91eb-52f5c2b14f5a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"crklekBdziPXiKGCBhoUfqwhWUXAuyDEQHEw0J7NdQI\";}s:2:\"id\";s:35:\"block_content.field_ebt_views_views\";s:10:\"field_name\";s:21:\"field_ebt_views_views\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_webform_form',	'a:17:{s:4:\"uuid\";s:36:\"08365941-eddc-446f-8fc9-72a7728df65c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K4nKI1yvxZ4s40vKrpuBiz09L15lK0ygK9etUTwYVRw\";}s:2:\"id\";s:36:\"block_content.field_ebt_webform_form\";s:10:\"field_name\";s:22:\"field_ebt_webform_form\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_webform_popup_form',	'a:17:{s:4:\"uuid\";s:36:\"fb27b8eb-ae9d-44ec-8d20-6aa1287b8b5f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GlZwbpK_4w1bHHs_IAnr12BJmD-fvq2QCviVBXnfiRA\";}s:2:\"id\";s:42:\"block_content.field_ebt_webform_popup_form\";s:10:\"field_name\";s:28:\"field_ebt_webform_popup_form\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_audio_file',	'a:17:{s:4:\"uuid\";s:36:\"75a1e1d5-184d-4541-96b7-8957dddb2453\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JCHoh95CpUeBx9ch24Tmi6ru0nwmNz8xWVH4Qs7RnTg\";}s:2:\"id\";s:28:\"media.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_document',	'a:17:{s:4:\"uuid\";s:36:\"2c293a08-a63a-47a3-8b49-8e7650f47903\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BdkTx7IL59MCw5a_fOZprPTOGM_wcjz-Fm8g7HV3vFk\";}s:2:\"id\";s:26:\"media.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_image',	'a:17:{s:4:\"uuid\";s:36:\"379994ed-ae76-4656-ab52-4f8661d6efc4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0N0KSFk57p6qsq3qM4lYVGSuROvzXK-tSsdwByqUh3g\";}s:2:\"id\";s:23:\"media.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_oembed_video',	'a:17:{s:4:\"uuid\";s:36:\"eca9af3a-0023-4307-a38b-526dac079818\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cNf_852Dq-fNnSaMI4LxL-J6N7bLkHuDbD9EUqOn4_U\";}s:2:\"id\";s:30:\"media.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;s:8:\"is_ascii\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_video_file',	'a:17:{s:4:\"uuid\";s:36:\"4f8a6296-0295-4cc5-8e6a-c61c708a78ba\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z5mgbn1PIVZ5TNMByBmivqo_u3Rdk58UIzpyN4ypTeM\";}s:2:\"id\";s:28:\"media.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.body',	'a:17:{s:4:\"uuid\";s:36:\"27acecd6-ddfe-41ab-ad13-d09a77410226\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:2:\"id\";s:9:\"node.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.field_image',	'a:17:{s:4:\"uuid\";s:36:\"0ce9563d-0108-4dd8-9768-e3f3f692efb8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:2:\"id\";s:16:\"node.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.field_metatags',	'a:16:{s:4:\"uuid\";s:36:\"3a56d56d-4fea-4e6d-abfd-6e9fd5799d1f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"metatag\";i:1;s:4:\"node\";}}s:2:\"id\";s:19:\"node.field_metatags\";s:10:\"field_name\";s:14:\"field_metatags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:7:\"metatag\";s:8:\"settings\";a:0:{}s:6:\"module\";s:7:\"metatag\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.field_tags',	'a:17:{s:4:\"uuid\";s:36:\"11256bc1-c4ef-404b-ae80-826c196dfc3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:2:\"id\";s:15:\"node.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.layout_builder__layout',	'a:16:{s:4:\"uuid\";s:36:\"01dcf303-887c-48ba-8de3-a183f2dc164d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:14:\"layout_builder\";i:1;s:4:\"node\";}}s:2:\"id\";s:27:\"node.layout_builder__layout\";s:10:\"field_name\";s:22:\"layout_builder__layout\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:14:\"layout_section\";s:8:\"settings\";a:0:{}s:6:\"module\";s:14:\"layout_builder\";s:6:\"locked\";b:1;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:0;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_accordion_text',	'a:17:{s:4:\"uuid\";s:36:\"c88354ca-8244-4d5a-8c63-2709d938c811\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dl3BMOx4hnrrl4qqLYkCtUssYQ_RkV9iIcbThUL8opE\";}s:2:\"id\";s:34:\"paragraph.field_ebt_accordion_text\";s:10:\"field_name\";s:24:\"field_ebt_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_accordion_title',	'a:17:{s:4:\"uuid\";s:36:\"7205b1e6-f387-4cb5-80f3-ea6e935096ea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xtdycMRMTk1-RbuIsXUkC8uoiTiAeIi8PtDCDuev5pM\";}s:2:\"id\";s:35:\"paragraph.field_ebt_accordion_title\";s:10:\"field_name\";s:25:\"field_ebt_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_carousel_caption',	'a:17:{s:4:\"uuid\";s:36:\"9950466c-7cf2-451c-a90c-6d94bc4223d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eH045cIw7DgTbyESpPO40c1yE4GkZSKAsRjv6wCv1cc\";}s:2:\"id\";s:36:\"paragraph.field_ebt_carousel_caption\";s:10:\"field_name\";s:26:\"field_ebt_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_carousel_image',	'a:17:{s:4:\"uuid\";s:36:\"c9955fe0-9e81-4347-b5c8-b3a2813ea422\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sBBtSihKznwfoZE4RCUfKLyFx5JPJOKThpsezNspQUg\";}s:2:\"id\";s:34:\"paragraph.field_ebt_carousel_image\";s:10:\"field_name\";s:24:\"field_ebt_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_clickable_tile',	'a:17:{s:4:\"uuid\";s:36:\"4a6ac85b-3418-4331-8d82-82c365e01b2a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sqyvMHG_MfFRoRtp9QsU69-Hqibbf7-n0L6nXXuy-RY\";}s:2:\"id\";s:34:\"paragraph.field_ebt_clickable_tile\";s:10:\"field_name\";s:24:\"field_ebt_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_description',	'a:17:{s:4:\"uuid\";s:36:\"474cb9c9-f18d-40c9-8bdc-2b263c5bf1bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T2aI_SC10fUAVAHAQ6YSjRx-RgZI16Y4DhBlcYV8xTY\";}s:2:\"id\";s:39:\"paragraph.field_ebt_counter_description\";s:10:\"field_name\";s:29:\"field_ebt_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"17ec174c-0286-4b9d-8d57-f5618c7d73b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A3xIcHA3Yh7nEExvOCO8fCJ2RKTLwO7PHRzSW91-6ag\";}s:2:\"id\";s:32:\"paragraph.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"fe9a8722-bb07-4268-815a-a4b9b20eb504\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"12yti1pJd8_55sJ_ipVJkKkOSBrqJNbIN1ScDohe8Ug\";}s:2:\"id\";s:34:\"paragraph.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"integer\";s:8:\"settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_title',	'a:17:{s:4:\"uuid\";s:36:\"646af88e-2cb1-4e61-9b5a-1720fbe00d94\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8SSZniajg5zo9MscuowyDAxLHlUJhnpGgVXmpef2Qfc\";}s:2:\"id\";s:33:\"paragraph.field_ebt_counter_title\";s:10:\"field_name\";s:23:\"field_ebt_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slick_slider_image',	'a:17:{s:4:\"uuid\";s:36:\"7b1e8d87-89a6-4d9c-b0ae-16292b52f88b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HwpmmxKvO4846yzGMxYlF27KAqxGN93LugyydI_mAQk\";}s:2:\"id\";s:38:\"paragraph.field_ebt_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ebt_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slick_slider_link',	'a:17:{s:4:\"uuid\";s:36:\"ce8c8911-2694-45d2-b941-6c8f08c9a8fd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2sX2ALM8UbHO085MTpnVsKr65w2_hTSuR1OGRh9yhnc\";}s:2:\"id\";s:37:\"paragraph.field_ebt_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slick_slider_text',	'a:17:{s:4:\"uuid\";s:36:\"fd3e2c50-dcff-4f84-bd3f-a28c9352ea81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bw5ktsaCO3NIoI8s4_-sX-8nheZucWVVtes3gNa3nAM\";}s:2:\"id\";s:37:\"paragraph.field_ebt_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_link',	'a:17:{s:4:\"uuid\";s:36:\"99143ce8-61ee-4652-a122-2b74cf0353a8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYqrMKPAVBTFXGukNiO0LmsHSZLTwSIqlH0B12cWoSc\";}s:2:\"id\";s:34:\"paragraph.field_ebt_slideshow_link\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_slide',	'a:17:{s:4:\"uuid\";s:36:\"20a2702c-d0d9-491e-bc0d-48bd8f4e5479\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yvMPSQ3opDpO2Y7W2gLC_lfyYsUerg7quMuaUIXTG6Y\";}s:2:\"id\";s:35:\"paragraph.field_ebt_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_text',	'a:17:{s:4:\"uuid\";s:36:\"5476f31f-53b6-41ea-919f-8ea57cf902fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l1sRS9qn9Xk0p6T25AqVsGWWAhp74-8ejyMC2cSICnA\";}s:2:\"id\";s:34:\"paragraph.field_ebt_slideshow_text\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_title',	'a:17:{s:4:\"uuid\";s:36:\"b514672e-03d7-4efa-81b8-0f04c6b94cd1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"56OfbIVnrkDV6Ei_ldSAYihwJbVyAJds03m4lf7fsqc\";}s:2:\"id\";s:35:\"paragraph.field_ebt_slideshow_title\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_block',	'a:17:{s:4:\"uuid\";s:36:\"0fc30373-baea-48fd-8769-4b6c582ae3d8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AwzF4qJWahe58UULrqET0cwFen2kxLMygeAFj96-4Kk\";}s:2:\"id\";s:29:\"paragraph.field_ebt_tab_block\";s:10:\"field_name\";s:19:\"field_ebt_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_content',	'a:17:{s:4:\"uuid\";s:36:\"d00f9fc0-b613-4eed-90b2-740af89205eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"options\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7FvDDnDFUS9rxHT4MbM9RwHPArBckbhp09KzHNMtD10\";}s:2:\"id\";s:31:\"paragraph.field_ebt_tab_content\";s:10:\"field_name\";s:21:\"field_ebt_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"list_string\";s:8:\"settings\";a:2:{s:14:\"allowed_values\";a:4:{i:0;a:2:{s:5:\"value\";s:4:\"text\";s:5:\"label\";s:4:\"Text\";}i:1;a:2:{s:5:\"value\";s:4:\"page\";s:5:\"label\";s:4:\"Page\";}i:2;a:2:{s:5:\"value\";s:5:\"block\";s:5:\"label\";s:5:\"Block\";}i:3;a:2:{s:5:\"value\";s:5:\"views\";s:5:\"label\";s:5:\"Views\";}}s:23:\"allowed_values_function\";s:0:\"\";}s:6:\"module\";s:7:\"options\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_page',	'a:17:{s:4:\"uuid\";s:36:\"527f69af-c7cb-450d-a95f-a0199f66a3fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Lx2SQWOPiXsxTotbjz7VPPAu-QERRb10_IFn-ApZRDo\";}s:2:\"id\";s:28:\"paragraph.field_ebt_tab_page\";s:10:\"field_name\";s:18:\"field_ebt_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"node\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_text',	'a:17:{s:4:\"uuid\";s:36:\"7492acc6-65ae-4f1f-b3c7-3e41a385e8cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvq8PSEOBXAVYlGbuM_TA0t_zulyHA_Bkjc6MrrkLWY\";}s:2:\"id\";s:28:\"paragraph.field_ebt_tab_text\";s:10:\"field_name\";s:18:\"field_ebt_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_title',	'a:17:{s:4:\"uuid\";s:36:\"0c03a11f-8242-48d7-ae98-2da2e80f3f2e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"chlF7z3GEcHoQnXo-49bdW3H_FSDPxAqWy0miEMc3AM\";}s:2:\"id\";s:29:\"paragraph.field_ebt_tab_title\";s:10:\"field_name\";s:19:\"field_ebt_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"text\";s:8:\"settings\";a:1:{s:10:\"max_length\";i:1023;}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_views',	'a:17:{s:4:\"uuid\";s:36:\"3dc81a0a-ea91-4e72-af8b-18c1abffc08d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QmZGd58IuoXxDcUvh8hfNHnRLR71GZA3qzfZpuVSjH4\";}s:2:\"id\";s:29:\"paragraph.field_ebt_tab_views\";s:10:\"field_name\";s:19:\"field_ebt_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_image',	'a:17:{s:4:\"uuid\";s:36:\"3988ff22-66ff-4325-be58-387a6451784f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3aeaxW3pHrK5yFagP66-FT7HXAGYacr2YhOcg-h70n0\";}s:2:\"id\";s:31:\"paragraph.field_ebt_tiles_image\";s:10:\"field_name\";s:21:\"field_ebt_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_link',	'a:17:{s:4:\"uuid\";s:36:\"f1992284-2903-4d4f-b4c2-4336abc56b45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mUN0Fv2hYJXOjWBr3fDMeZnblvk6m_qvnRncjAS5Jz0\";}s:2:\"id\";s:30:\"paragraph.field_ebt_tiles_link\";s:10:\"field_name\";s:20:\"field_ebt_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_text',	'a:17:{s:4:\"uuid\";s:36:\"6e677df8-5ee4-417d-be3a-d5036e605903\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SYBCp04_zUg3tqwrydEEBCSg6JWf7CR4f2Jym-jtu7Y\";}s:2:\"id\";s:30:\"paragraph.field_ebt_tiles_text\";s:10:\"field_name\";s:20:\"field_ebt_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_title',	'a:17:{s:4:\"uuid\";s:36:\"adfc8f4b-838d-40b5-956a-1f813f9dc592\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"__j2dIJmEb5SExuxv7f5bTbyHtFYlG0BqQD9owZgiFA\";}s:2:\"id\";s:31:\"paragraph.field_ebt_tiles_title\";s:10:\"field_name\";s:21:\"field_ebt_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_current',	'a:17:{s:4:\"uuid\";s:36:\"1043de86-9fe2-4436-8425-6f47521f1f00\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"io0Gxmv8qUwbnmMiTtgXlnMKWybAbO4f6d7W3yHn9vE\";}s:2:\"id\";s:36:\"paragraph.field_ebt_timeline_current\";s:10:\"field_name\";s:26:\"field_ebt_timeline_current\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_date',	'a:17:{s:4:\"uuid\";s:36:\"80c677f9-529e-499e-959c-dc9187ab7a49\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nmy2TG7m2qANlPD4kTWJk7016mawyxdzgYZ3omLSCVc\";}s:2:\"id\";s:33:\"paragraph.field_ebt_timeline_date\";s:10:\"field_name\";s:23:\"field_ebt_timeline_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_media_image',	'a:17:{s:4:\"uuid\";s:36:\"7089f45d-1e3c-4225-bba6-736084040e5b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yB2KT5oQDNzQfggkUQGHhoqlikRSVCE8a5MSV_5NvEo\";}s:2:\"id\";s:40:\"paragraph.field_ebt_timeline_media_image\";s:10:\"field_name\";s:30:\"field_ebt_timeline_media_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_text',	'a:17:{s:4:\"uuid\";s:36:\"fe035edd-b535-4ceb-bd54-a3c604fbae92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CFCHP9vAPguIB2d677v2iLm245zKg4MRxpfICMcUHo8\";}s:2:\"id\";s:33:\"paragraph.field_ebt_timeline_text\";s:10:\"field_name\";s:23:\"field_ebt_timeline_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_title',	'a:17:{s:4:\"uuid\";s:36:\"7b0677d8-0312-4994-b0a6-cd1c0852a050\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cM8ncQUeGNJamKPS5THMY_gIhCe_qsCwn4s-_6YPaq4\";}s:2:\"id\";s:34:\"paragraph.field_ebt_timeline_title\";s:10:\"field_name\";s:24:\"field_ebt_timeline_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:512;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_gallery_item_description',	'a:17:{s:4:\"uuid\";s:36:\"31c1cb14-3677-44d6-951e-3560a93c8f65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jf90xTmsti89Pjc4bIjB0aBV5QshhjB0mhGkqONmGjU\";}s:2:\"id\";s:40:\"paragraph.field_gallery_item_description\";s:10:\"field_name\";s:30:\"field_gallery_item_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_image',	'a:17:{s:4:\"uuid\";s:36:\"233843a3-22c1-4376-a920-f894f695b87c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ml8f47_-t_lza9fvHT7YnpccMFPtmO5CC_TKle1QMr8\";}s:2:\"id\";s:32:\"paragraph.field_stats_item_image\";s:10:\"field_name\";s:22:\"field_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_link',	'a:17:{s:4:\"uuid\";s:36:\"7003f50c-c76e-4efe-bfcc-67453daeb93c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6Xx4YNeE_zQDdDg8HySkyOGsBrl8RHNnsFsWYoC1GI4\";}s:2:\"id\";s:31:\"paragraph.field_stats_item_link\";s:10:\"field_name\";s:21:\"field_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_number',	'a:17:{s:4:\"uuid\";s:36:\"f6763f4c-c4a6-4d80-ab1d-f0e2aca44f60\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YWL60ZrNzy_L7BYYe7ipJCC3__awGcG9ewUwecK82J4\";}s:2:\"id\";s:33:\"paragraph.field_stats_item_number\";s:10:\"field_name\";s:23:\"field_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_text',	'a:17:{s:4:\"uuid\";s:36:\"0d6fd00f-5382-443f-ae8a-996e1552af22\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7R83PXXuAu39Em7tMg3vXyaerbWjilK3AuSi3IXVRYc\";}s:2:\"id\";s:31:\"paragraph.field_stats_item_text\";s:10:\"field_name\";s:21:\"field_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_video_gallery_item',	'a:17:{s:4:\"uuid\";s:36:\"5c6f70cc-17fc-4f18-bcfb-4c0d8a66500e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qNGEoWbTX-CnhncjUmfOTlH2eL2GnzBZckwY_yzsHfM\";}s:2:\"id\";s:34:\"paragraph.field_video_gallery_item\";s:10:\"field_name\";s:24:\"field_video_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.user.user_picture',	'a:17:{s:4:\"uuid\";s:36:\"13a3c6c5-6417-4477-8a58-0b066b2141c3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:2:\"id\";s:17:\"user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field_ui.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1nMi90W6YQxKzZAgJQw7Ag9U4JrsEUwkomF0lhvbIM\";}s:12:\"field_prefix\";s:6:\"field_\";}'),
('',	'file.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bwjZB1IjEYbppgZT3g7YW_5h_LDZYNa3DaDEfWX82U\";}s:11:\"description\";a:2:{s:4:\"type\";s:9:\"textfield\";s:6:\"length\";i:128;}s:4:\"icon\";a:1:{s:9:\"directory\";s:23:\"core/modules/file/icons\";}s:35:\"make_unused_managed_files_temporary\";b:0;s:21:\"filename_sanitization\";a:6:{s:13:\"transliterate\";b:1;s:18:\"replace_whitespace\";b:1;s:24:\"replace_non_alphanumeric\";b:1;s:22:\"deduplicate_separators\";b:1;s:9:\"lowercase\";b:1;s:21:\"replacement_character\";s:1:\"-\";}}'),
('',	'filter.format.basic_html',	'a:9:{s:4:\"uuid\";s:36:\"5d0c18fb-1e15-4eac-9e4b-1484b52ff943\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:6:\"editor\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mclCbTlJwWJORez4Y1eX2MqA0aGjSMAoJb3TaBABcK8\";}s:4:\"name\";s:10:\"Basic HTML\";s:6:\"format\";s:10:\"basic_html\";s:6:\"weight\";i:0;s:7:\"filters\";a:6:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:7;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:243:\"<br> <p> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id> <cite> <dl> <dt> <dd> <a hreflang href> <blockquote cite> <ul type> <ol start type> <strong> <em> <code> <li> <img src alt data-entity-uuid data-entity-type height width data-caption data-align>\";s:16:\"filter_html_help\";b:0;s:20:\"filter_html_nofollow\";b:0;}}s:24:\"filter_html_image_secure\";a:5:{s:2:\"id\";s:24:\"filter_html_image_secure\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}}}'),
('',	'filter.format.full_html',	'a:9:{s:4:\"uuid\";s:36:\"e00030fb-b30d-42df-a35b-b9dca992742e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:6:\"editor\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpZysv3RHJjhYzq7O_q5q8mVlHdrSzKELmXyiX6RtV0\";}s:4:\"name\";s:9:\"Full HTML\";s:6:\"format\";s:9:\"full_html\";s:6:\"weight\";i:2;s:7:\"filters\";a:5:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:20:\"filter_htmlcorrector\";a:5:{s:2:\"id\";s:20:\"filter_htmlcorrector\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}}}'),
('',	'filter.format.plain_text',	'a:9:{s:4:\"uuid\";s:36:\"98975409-6030-4f9b-8f64-18610166736a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JLMwODO0epnA_H-jFlH9ezVfa5YBJniRv3MmLqYNl_Q\";}s:4:\"name\";s:10:\"Plain text\";s:6:\"format\";s:10:\"plain_text\";s:6:\"weight\";i:10;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:18:\"filter_html_escape\";a:5:{s:2:\"id\";s:18:\"filter_html_escape\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:0:{}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),
('',	'filter.format.restricted_html',	'a:9:{s:4:\"uuid\";s:36:\"8ca43f73-d620-4c03-bbd7-8221d546124f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QiKqQS_YGAT3Qr4vaAgZICJknm-MGCzt_xBAMqg-tRM\";}s:4:\"name\";s:15:\"Restricted HTML\";s:6:\"format\";s:15:\"restricted_html\";s:6:\"weight\";i:1;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:149:\"<a href hreflang> <em> <strong> <cite> <blockquote cite> <code> <ul type> <ol start type> <li> <dl> <dt> <dd> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id>\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),
('',	'filter.format.webform_default',	'a:9:{s:4:\"uuid\";s:36:\"cf32d962-2f58-41c9-989d-a8f82367e8e1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EeKp_M4Oid3erARiAam9rsgBKR91uEnFkEP3aZS2ol8\";}s:4:\"name\";s:31:\"Webform (Default) - DO NOT EDIT\";s:6:\"format\";s:15:\"webform_default\";s:6:\"weight\";i:100;s:7:\"filters\";a:0:{}}'),
('',	'filter.settings',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiPjM3WdB__ruFA7B6TLwni_UcZbmek5G4b2dxQItxA\";}s:15:\"fallback_format\";s:10:\"plain_text\";s:27:\"always_show_fallback_choice\";b:0;}'),
('',	'glightbox.settings',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5G059LQS_7DV7oGUpxVTPM0aWtunW7bvDpRkgeb0KtE\";}s:6:\"custom\";a:17:{s:8:\"activate\";i:0;s:11:\"open_effect\";s:4:\"zoom\";s:12:\"close_effect\";s:4:\"zoom\";s:12:\"slide_effect\";s:5:\"slide\";s:5:\"width\";s:3:\"98%\";s:6:\"height\";s:3:\"98%\";s:11:\"videosWidth\";s:5:\"960px\";s:22:\"close_on_outside_click\";b:1;s:9:\"more_text\";s:8:\"See more\";s:11:\"more_length\";i:60;s:13:\"desc_position\";s:6:\"bottom\";s:4:\"loop\";b:0;s:8:\"zoomable\";b:1;s:9:\"draggable\";b:1;s:7:\"preload\";b:1;s:15:\"autoplay_videos\";b:1;s:16:\"autofocus_videos\";b:0;}s:8:\"advanced\";a:2:{s:12:\"unique_token\";i:0;s:16:\"compression_type\";s:8:\"minified\";}}'),
('',	'google_analytics.settings',	'a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dwMYPgAnj9KBO77SLEv9Z42NDJAbuxe0uU9eGC8qw3M\";}s:7:\"account\";s:0:\"\";s:11:\"domain_mode\";i:0;s:13:\"cross_domains\";s:0:\"\";s:10:\"visibility\";a:5:{s:17:\"request_path_mode\";i:0;s:18:\"request_path_pages\";s:53:\"/admin\n/admin/*\n/batch\n/node/add*\n/node/*/*\n/user/*/*\";s:14:\"user_role_mode\";i:0;s:15:\"user_role_roles\";a:0:{}s:17:\"user_account_mode\";i:1;}s:5:\"track\";a:13:{s:8:\"outbound\";b:1;s:6:\"mailto\";b:1;s:3:\"tel\";b:1;s:5:\"files\";b:1;s:16:\"files_extensions\";s:279:\"7z|aac|arc|arj|asf|asx|avi|bin|csv|doc(x|m)?|dot(x|m)?|exe|flv|gif|gz|gzip|hqx|jar|jpe?g|js|mp(2|3|4|e?g)|mov(ie)?|msi|msp|pdf|phps|png|ppt(x|m)?|pot(x|m)?|pps(x|m)?|ppam|sld(x|m)?|thmx|qtm?|ra(m|r)?|sea|sit|tar|tgz|torrent|txt|wav|wma|wmv|wpd|xls(x|m|b)?|xlt(x|m)|xlam|xml|z|zip\";s:8:\"colorbox\";b:1;s:6:\"linkid\";b:0;s:12:\"urlfragments\";b:0;s:6:\"userid\";b:0;s:8:\"messages\";a:0:{}s:11:\"site_search\";b:0;s:7:\"adsense\";b:0;s:15:\"displayfeatures\";b:1;}s:7:\"privacy\";a:1:{s:11:\"anonymizeip\";b:1;}s:6:\"custom\";a:1:{s:10:\"parameters\";a:0:{}}s:11:\"codesnippet\";a:3:{s:6:\"create\";a:0:{}s:6:\"before\";s:0:\"\";s:5:\"after\";s:0:\"\";}s:15:\"translation_set\";b:0;s:5:\"cache\";b:0;s:5:\"debug\";b:0;}'),
('',	'image.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-yDFHbqNfpe-Srg4sdCSqaosCl2D8uwyEY5esF8gEw\";}s:13:\"preview_image\";s:29:\"core/modules/image/sample.png\";s:26:\"allow_insecure_derivatives\";b:0;s:20:\"suppress_itok_output\";b:0;}'),
('',	'image.style.ebt_gallery_image',	'a:8:{s:4:\"uuid\";s:36:\"3387ae71-e231-4ddd-9e5f-664ca37b095b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Et29BhgBeTqvhgY2GYsCViL4QGjZRI0vsbEe5O1VON4\";}s:4:\"name\";s:17:\"ebt_gallery_image\";s:5:\"label\";s:17:\"EBT Gallery Image\";s:7:\"effects\";a:1:{s:36:\"6ab4544c-7611-414c-aaa8-4eed96b10c84\";a:4:{s:4:\"uuid\";s:36:\"6ab4544c-7611-414c-aaa8-4eed96b10c84\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:365;s:6:\"height\";i:265;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.ebt_video_and_image_gallery',	'a:8:{s:4:\"uuid\";s:36:\"c4e70146-66c8-4f81-9049-d4e41b4c5305\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9px7Sz4srt9t5bnyp1lHoLhxTyuSbHKBR0pbE7rMPJ4\";}s:4:\"name\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:27:\"EBT Video and Image gallery\";s:7:\"effects\";a:1:{s:36:\"de12b6ed-b5ac-4ec8-9cf1-0df6cb6c8d32\";a:4:{s:4:\"uuid\";s:36:\"de12b6ed-b5ac-4ec8-9cf1-0df6cb6c8d32\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:360;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.large',	'a:8:{s:4:\"uuid\";s:36:\"527e81f9-fafb-4f3e-aad6-f169b5885095\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDR2BOewa2UFH9yG4tVvrGxEVv8U7LQo-RLkJhFpERs\";}s:4:\"name\";s:5:\"large\";s:5:\"label\";s:16:\"Large (480×480)\";s:7:\"effects\";a:2:{s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";a:4:{s:4:\"uuid\";s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:480;s:7:\"upscale\";b:0;}}s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";a:4:{s:4:\"uuid\";s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.linkit_result_thumbnail',	'a:8:{s:4:\"uuid\";s:36:\"7751cf12-1253-4c81-bcd8-bc001066b67b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PY0kMp7KIxvU4kBi5mcnD_DHTKUc1OkYCfaPliXjpa8\";}s:4:\"name\";s:23:\"linkit_result_thumbnail\";s:5:\"label\";s:23:\"Linkit result thumbnail\";s:7:\"effects\";a:1:{s:36:\"2943df29-38ea-459c-ba1d-290489bb1807\";a:4:{s:4:\"uuid\";s:36:\"2943df29-38ea-459c-ba1d-290489bb1807\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:50;s:6:\"height\";i:50;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.media_library',	'a:8:{s:4:\"uuid\";s:36:\"9fcd2b87-5cd2-4214-90f8-d2a1c4229d26\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FxMdscEA4aDH0KPM73HIZtVn3zIAgC1kQ3CkBw26HYs\";}s:4:\"name\";s:13:\"media_library\";s:5:\"label\";s:34:\"Media Library thumbnail (220×220)\";s:7:\"effects\";a:2:{s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";a:4:{s:4:\"uuid\";s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";a:4:{s:4:\"uuid\";s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.medium',	'a:8:{s:4:\"uuid\";s:36:\"c8b8fa24-4235-4e63-abae-72f30beb637e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dlar76VBuGj5iMGTruB_uMZX8VbivXt9_QLemaG2q4E\";}s:4:\"name\";s:6:\"medium\";s:5:\"label\";s:17:\"Medium (220×220)\";s:7:\"effects\";a:2:{s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";a:4:{s:4:\"uuid\";s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";a:4:{s:4:\"uuid\";s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.quote_image',	'a:8:{s:4:\"uuid\";s:36:\"60fb949e-3206-43f8-8a85-d75fa8ec9bf5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xlTbw2rsxfnXJ7Hv3VCpxLp5Ekaa0jutCubC0YpGcbw\";}s:4:\"name\";s:11:\"quote_image\";s:5:\"label\";s:11:\"Quote Image\";s:7:\"effects\";a:1:{s:36:\"d8117768-053a-4efa-87bf-a1e49600d865\";a:4:{s:4:\"uuid\";s:36:\"d8117768-053a-4efa-87bf-a1e49600d865\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:2;s:4:\"data\";a:3:{s:5:\"width\";i:530;s:6:\"height\";N;s:7:\"upscale\";b:0;}}}}'),
('',	'image.style.slick_slider_card',	'a:8:{s:4:\"uuid\";s:36:\"a7519911-04cf-4e32-8dd4-55d8d342ddfc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2zkdfRMnFwX0N2JCd1N-mTn2NTGgTRwRkfqW4Uiit8c\";}s:4:\"name\";s:17:\"slick_slider_card\";s:5:\"label\";s:17:\"Slick Slider card\";s:7:\"effects\";a:1:{s:36:\"c770ae08-739c-4196-a069-6d5becc97113\";a:4:{s:4:\"uuid\";s:36:\"c770ae08-739c-4196-a069-6d5becc97113\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:2;s:4:\"data\";a:3:{s:5:\"width\";i:400;s:6:\"height\";i:300;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.thumbnail',	'a:8:{s:4:\"uuid\";s:36:\"7e8ff02c-5435-43f6-8dc3-916788ea8d9f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BgeBV-xOFINMsz-y2thm45EGesj6bRM6DTLZ6ce3V9I\";}s:4:\"name\";s:9:\"thumbnail\";s:5:\"label\";s:20:\"Thumbnail (100×100)\";s:7:\"effects\";a:2:{s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";a:4:{s:4:\"uuid\";s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:100;s:6:\"height\";i:100;s:7:\"upscale\";b:0;}}s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";a:4:{s:4:\"uuid\";s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.wide',	'a:8:{s:4:\"uuid\";s:36:\"cf4a237b-4886-4db6-90a2-e2f1348070b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XHh3ATMH7z4ljwmzdndM47qNMkgLnoYsP98rGxVgCOw\";}s:4:\"name\";s:4:\"wide\";s:5:\"label\";s:11:\"Wide (1090)\";s:7:\"effects\";a:2:{s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";a:4:{s:4:\"uuid\";s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:1090;s:6:\"height\";N;s:7:\"upscale\";b:0;}}s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";a:4:{s:4:\"uuid\";s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'linkit.linkit_profile.default',	'a:9:{s:4:\"uuid\";s:36:\"655a70f6-77d9-4568-ad74-866e455f296a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0Jw_BFJCCtWk187tIYvME58VFpYwPaAdrc4eRtAyHH0\";}s:5:\"label\";s:7:\"Default\";s:2:\"id\";s:7:\"default\";s:11:\"description\";s:24:\"A default Linkit profile\";s:8:\"matchers\";a:1:{s:36:\"556010a3-e317-48b3-b4ed-854c10f4b950\";a:4:{s:2:\"id\";s:11:\"entity:node\";s:4:\"uuid\";s:36:\"556010a3-e317-48b3-b4ed-854c10f4b950\";s:8:\"settings\";a:6:{s:8:\"metadata\";s:77:\"[node:content-type:name] #[node:nid] | [node:created:medium] by [node:author]\";s:7:\"bundles\";a:0:{}s:15:\"group_by_bundle\";b:0;s:19:\"include_unpublished\";b:0;s:17:\"substitution_type\";s:9:\"canonical\";s:5:\"limit\";i:100;}s:6:\"weight\";i:0;}}}'),
('',	'media.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WCFqLQAxMw1weToDJEhfnW1Z-iOF7cqMdL8X7YTFxBA\";}s:13:\"icon_base_uri\";s:28:\"public://media-icons/generic\";s:13:\"iframe_domain\";N;s:20:\"oembed_providers_url\";s:33:\"https://oembed.com/providers.json\";s:14:\"standalone_url\";b:0;}'),
('',	'media.type.audio',	'a:13:{s:4:\"uuid\";s:36:\"5b9f8640-5def-4f1f-8cbb-9a34ee0d322b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJw8n6Tk2tO3ZysuEeGR1gZa1yRffaZzR4t0Q7iNurs\";}s:2:\"id\";s:5:\"audio\";s:5:\"label\";s:5:\"Audio\";s:11:\"description\";s:28:\"A locally hosted audio file.\";s:6:\"source\";s:10:\"audio_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_audio_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media.type.document',	'a:13:{s:4:\"uuid\";s:36:\"474a8161-6e84-4c54-8d09-7cd6cf51ca6f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_D9q3XSnP6ik9we9UuoTvZsQKPuYNp_G9PfwVtWzgnQ\";}s:2:\"id\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:44:\"An uploaded file or document, such as a PDF.\";s:6:\"source\";s:4:\"file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:20:\"field_media_document\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media.type.image',	'a:13:{s:4:\"uuid\";s:36:\"d02792ed-7ab7-466f-94e2-1bc1eb7fc178\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6Qope5wG7HUpV0tPOBMtDI_GZkHFcF1Xj4hgD9Cu_hM\";}s:2:\"id\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:36:\"Use local images for reusable media.\";s:6:\"source\";s:5:\"image\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:17:\"field_media_image\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media.type.remote_video',	'a:13:{s:4:\"uuid\";s:36:\"59bb7b69-536f-47d7-b202-4c65a9b02036\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hIBTnDGgDKnCiP6HUZm1m7600DHUEpC6FN3LQ4sUgZ4\";}s:2:\"id\";s:12:\"remote_video\";s:5:\"label\";s:12:\"Remote video\";s:11:\"description\";s:46:\"A remotely hosted video from YouTube or Vimeo.\";s:6:\"source\";s:12:\"oembed:video\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:3:{s:12:\"source_field\";s:24:\"field_media_oembed_video\";s:20:\"thumbnails_directory\";s:44:\"public://oembed_thumbnails/[date:custom:Y-m]\";s:9:\"providers\";a:2:{i:0;s:7:\"YouTube\";i:1;s:5:\"Vimeo\";}}s:9:\"field_map\";a:1:{s:5:\"title\";s:4:\"name\";}}'),
('',	'media.type.video',	'a:13:{s:4:\"uuid\";s:36:\"47a446d2-2250-4e11-98eb-8a4c51117635\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzgvcRgZHltqWf8hBmttoWh95tCJoPL25lPq9YSIRsY\";}s:2:\"id\";s:5:\"video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:28:\"A locally hosted video file.\";s:6:\"source\";s:10:\"video_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_video_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media_library.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3gQsCnZELUjUUqHk8SSh8bXnx7TZwN95vctAeVJG60\";}s:11:\"advanced_ui\";b:0;}'),
('',	'menu_ui.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SqMarzIjxC3F8dZo9FEOxfqDKD_sdW1tbcFTV1BA2zU\";}s:24:\"override_parent_selector\";b:0;}'),
('',	'metatag.metatag_defaults.403',	'a:8:{s:4:\"uuid\";s:36:\"32de19c3-215d-4985-a7d7-d588a90d7f0d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RDCkFL0NDt75Gwioooxo1iuA1S50xTVsBOgX__c6wTw\";}s:2:\"id\";s:3:\"403\";s:5:\"label\";s:17:\"403 access denied\";s:4:\"tags\";a:3:{s:6:\"robots\";s:7:\"noindex\";s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),
('',	'metatag.metatag_defaults.404',	'a:8:{s:4:\"uuid\";s:36:\"1131c9da-259d-4688-af2b-8cd70c4d304f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"puBstSLDz8mbaWU357zaqQDBGMGsJzG0j-TQNQkjg20\";}s:2:\"id\";s:3:\"404\";s:5:\"label\";s:18:\"404 page not found\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),
('',	'metatag.metatag_defaults.front',	'a:8:{s:4:\"uuid\";s:36:\"14e6bd6a-5fd4-4abb-b304-231e944ee914\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1noCXlegCr5HFehQRF1ViXy1jhU1jZ_sNN99a8Sj5jo\";}s:2:\"id\";s:5:\"front\";s:5:\"label\";s:10:\"Front page\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),
('',	'metatag.metatag_defaults.global',	'a:8:{s:4:\"uuid\";s:36:\"c377ec68-aa9d-4ed0-8e17-b44da3051c14\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sL588ui1E_8-2c_UupwyYxcqX2OVyMFp3HTLbbFqvPc\";}s:2:\"id\";s:6:\"global\";s:5:\"label\";s:6:\"Global\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:18:\"[current-page:url]\";s:5:\"title\";s:34:\"[current-page:title] | [site:name]\";}}'),
('',	'metatag.metatag_defaults.node',	'a:8:{s:4:\"uuid\";s:36:\"3950fa9e-d155-4064-8913-f7928e563aa1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rpwvgyEURXLz_JjgMCrkS1rUv-0k3L79BpO-ReN7fDI\";}s:2:\"id\";s:4:\"node\";s:5:\"label\";s:7:\"Content\";s:4:\"tags\";a:3:{s:5:\"title\";s:26:\"[node:title] | [site:name]\";s:11:\"description\";s:14:\"[node:summary]\";s:13:\"canonical_url\";s:10:\"[node:url]\";}}'),
('',	'metatag.metatag_defaults.taxonomy_term',	'a:8:{s:4:\"uuid\";s:36:\"7175fa40-e959-4cb9-a9af-08b0acf53b23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"92bXZdyYJ5xqukdfmGRr_CYcwm1vfuS8b8aJ7X_G7E0\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:4:\"tags\";a:3:{s:13:\"canonical_url\";s:10:\"[term:url]\";s:11:\"description\";s:18:\"[term:description]\";s:5:\"title\";s:25:\"[term:name] | [site:name]\";}}'),
('',	'metatag.metatag_defaults.user',	'a:8:{s:4:\"uuid\";s:36:\"2ce7b5a6-e273-4808-988d-bd51796041d7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MvQPTbQx0Vxwy0ordSHyixdZmLCMpvMdLD69dlwkrKc\";}s:2:\"id\";s:4:\"user\";s:5:\"label\";s:4:\"User\";s:4:\"tags\";a:3:{s:13:\"canonical_url\";s:10:\"[user:url]\";s:11:\"description\";s:11:\"[site:name]\";s:5:\"title\";s:33:\"[user:display-name] | [site:name]\";}}'),
('',	'metatag.settings',	'a:7:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tKLBW2GXZVLFXqS9QgLyfTuxCLc1u_quKPQLtCia-Bw\";}s:18:\"entity_type_groups\";a:0:{}s:9:\"separator\";s:0:\"\";s:15:\"tag_trim_method\";s:11:\"beforeValue\";s:18:\"tag_trim_maxlength\";a:0:{}s:21:\"tag_scroll_max_height\";s:0:\"\";s:13:\"use_maxlength\";b:1;}'),
('',	'node.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W0cgFPhPJ3gAdqm06-az48BLf5MVcoZVS0HdByoofi0\";}s:15:\"use_admin_theme\";b:1;}'),
('',	'node.type.article',	'a:12:{s:4:\"uuid\";s:36:\"23740c9e-4bc8-422a-a456-7efd997502e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fe3N1uqaAyyKJbVkqT-btXy3t98puW8GCRD822xjl10\";}s:4:\"name\";s:7:\"Article\";s:4:\"type\";s:7:\"article\";s:11:\"description\";s:89:\"Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:1;}'),
('',	'node.type.page',	'a:12:{s:4:\"uuid\";s:36:\"1edca201-7650-4af0-af2a-47c5a971bfde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"i0snV8Wj--OkRW12UdachUiYiz3FbeMwHu_pZYfzKLc\";}s:4:\"name\";s:10:\"Basic page\";s:4:\"type\";s:4:\"page\";s:11:\"description\";s:77:\"Use <em>basic pages</em> for your static content, such as an \'About us\' page.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),
('',	'olivero.settings',	'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1TswGK46jyu77aIM7Z-0JVQs5bxHmo-gtgrvrQGMXxc\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:0;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:0;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:22:\"mobile_menu_all_widths\";i:0;s:22:\"site_branding_bg_color\";s:7:\"default\";s:18:\"base_primary_color\";s:7:\"#1b9ae4\";}'),
('',	'paragraphs.paragraphs_type.ebt_accordion',	'a:11:{s:4:\"uuid\";s:36:\"5071ad52-b6e8-4a13-88ad-a0e644e823f9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a7oBJmAAPescdOPyZ2zkmnxQR_-MkKei1Cs600-7sxM\";}s:2:\"id\";s:13:\"ebt_accordion\";s:5:\"label\";s:35:\"EBT Accordion section / FAQ section\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:46:\"Accordion or FAQ section for EBT Accordion/FAQ\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_carousel',	'a:11:{s:4:\"uuid\";s:36:\"eae57e5f-f332-4203-be4f-1ead1a6c1ebf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"F5G5bjObjmi_ofKoiKAxY1BXGoLKFMVsBTNd7Z39OuI\";}s:2:\"id\";s:12:\"ebt_carousel\";s:5:\"label\";s:17:\"EBT Carousel item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Carousel section for EBT Carousel\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_counter_item',	'a:11:{s:4:\"uuid\";s:36:\"8a0e0b99-a544-4c46-8cb3-534e418ac0e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ycgzZPt9EhNziX0konZumLTJ6y69olJaVnLJ2dtyKnI\";}s:2:\"id\";s:16:\"ebt_counter_item\";s:5:\"label\";s:16:\"EBT Counter Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:60:\"Counter Items to be used inside of Block Type: \"EBT Counter\"\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_slick_slider',	'a:11:{s:4:\"uuid\";s:36:\"70607742-51bf-4b77-8d46-c07397b718e6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7IpvZPMN9T939ox72-gNDYNrZIVrXQ7nlF-Pxkzq_7M\";}s:2:\"id\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:15:\"EBT Slick Slide\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:26:\"Slide for EBT Slick Slider\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_slideshow',	'a:11:{s:4:\"uuid\";s:36:\"68f7444a-b28e-4ac9-abc5-57a62d63fe7f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HQnVagG9vsLrOtO1nF5ggZaNQ0tRGZZhiOW1-8nLOMM\";}s:2:\"id\";s:13:\"ebt_slideshow\";s:5:\"label\";s:9:\"EBT Slide\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:35:\"Slideshow section for EBT Slideshow\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_stats_item',	'a:11:{s:4:\"uuid\";s:36:\"210023af-0ce2-4183-bbba-6adbe094a405\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mXP3gCAYTFLXux_oLacqKfa_b0MprpWFhqxO39VWGl8\";}s:2:\"id\";s:14:\"ebt_stats_item\";s:5:\"label\";s:14:\"EBT Stats Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:30:\"Stats Item for EBT Stats block\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_tab',	'a:11:{s:4:\"uuid\";s:36:\"d24c7342-50a5-4bba-a2ca-23838ec42c25\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nzTVRmvjb6HJiVMoRzf0HR02L3_n5N9VxatQ_IQQCmc\";}s:2:\"id\";s:7:\"ebt_tab\";s:5:\"label\";s:7:\"EBT Tab\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:32:\"Tab paragraph for EBT Tabs block\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_tiles_item',	'a:11:{s:4:\"uuid\";s:36:\"332e9a66-40d4-4d0f-a252-bacb76456f61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OXCYSO_8vGgFySd4voU9Be7Av6Oqe56G4XnMO_fX4EE\";}s:2:\"id\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:14:\"EBT Tiles Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:21:\"Section for EBT Tiles\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_timeline',	'a:11:{s:4:\"uuid\";s:36:\"0700c7f4-0990-4033-a96a-7eac220fe625\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"giGGVKGIGi_PVlgEPMjzx78I9q-gtwP8qRWwp4goOaE\";}s:2:\"id\";s:12:\"ebt_timeline\";s:5:\"label\";s:18:\"EBT Timeline Event\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Timeline section for EBT Timeline\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_video_and_image_gallery_item',	'a:11:{s:4:\"uuid\";s:36:\"69becd39-ca29-4229-a5e0-b50dda5e664e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ASm3yV1er7y-WJqAsPm4lUKhLJEK2A1QYjC-_eJJFIA\";}s:2:\"id\";s:32:\"ebt_video_and_image_gallery_item\";s:5:\"label\";s:32:\"EBT Video and Image gallery item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:58:\"Video and Image item for EBT Video and Image Gallery block\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7eR0sk71Eol86r_A7BMqn5_46wzenh5J1O5vZRCGKv8\";}s:16:\"show_unpublished\";b:1;}'),
('',	'pathauto.settings',	'a:13:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SwvLp8snyPEExF41CaJJYdPUVomofLqtXvwciHc4cPg\";}s:20:\"enabled_entity_types\";a:1:{i:0;s:4:\"user\";}s:11:\"punctuation\";a:1:{s:6:\"hyphen\";i:1;}s:7:\"verbose\";b:0;s:9:\"separator\";s:1:\"-\";s:10:\"max_length\";i:100;s:20:\"max_component_length\";i:100;s:13:\"transliterate\";b:1;s:12:\"reduce_ascii\";b:0;s:4:\"case\";b:1;s:12:\"ignore_words\";s:134:\"a, an, as, at, before, but, by, for, from, is, in, into, like, of, off, on, onto, per, since, than, the, this, that, to, up, via, with\";s:13:\"update_action\";i:2;s:11:\"safe_tokens\";a:6:{i:0;s:5:\"alias\";i:1;s:4:\"path\";i:2;s:9:\"join-path\";i:3;s:9:\"login-url\";i:4;s:3:\"url\";i:5;s:9:\"url-brief\";}}'),
('',	'redirect.settings',	'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FEwQLW1wXW7fiJdG1B2bxW1c_-k6w-r-3V3bSsW6PqM\";}s:13:\"auto_redirect\";b:1;s:19:\"default_status_code\";i:301;s:23:\"passthrough_querystring\";b:1;s:7:\"warning\";b:0;s:17:\"ignore_admin_path\";b:0;s:12:\"access_check\";b:0;s:24:\"route_normalizer_enabled\";b:1;}'),
('',	'search.page.help_search',	'a:11:{s:4:\"uuid\";s:36:\"fec10881-499f-4858-a42b-9b60cee45abe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RZ-bcSekNSsAbIPLW7Gmyd3uUjIOSrPvnb8RCCZYJm8\";}s:2:\"id\";s:11:\"help_search\";s:5:\"label\";s:4:\"Help\";s:4:\"path\";s:4:\"help\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"help_search\";s:13:\"configuration\";a:0:{}}'),
('',	'search.page.node_search',	'a:11:{s:4:\"uuid\";s:36:\"72642a28-df7e-4618-aa8c-3f52bf7d9f97\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"97tvtzGOa8_flb22CzSjgtm_YkiGMHvEBO-6q2K9V_U\";}s:2:\"id\";s:11:\"node_search\";s:5:\"label\";s:7:\"Content\";s:4:\"path\";s:4:\"node\";s:6:\"weight\";i:-10;s:6:\"plugin\";s:11:\"node_search\";s:13:\"configuration\";a:1:{s:8:\"rankings\";a:0:{}}}'),
('',	'search.page.user_search',	'a:11:{s:4:\"uuid\";s:36:\"294f8603-9cb9-4c47-91cb-def8653638f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k3aUaZXGDuhkek2TZIee0PApOPTvYZLadziekdyHA5A\";}s:2:\"id\";s:11:\"user_search\";s:5:\"label\";s:5:\"Users\";s:4:\"path\";s:4:\"user\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"user_search\";s:13:\"configuration\";a:0:{}}'),
('',	'search.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hvVxL1G-ZCxaq32IZws0YsfuhvaDiQE_np-0g35KjUk\";}s:12:\"and_or_limit\";i:7;s:12:\"default_page\";s:11:\"node_search\";s:5:\"index\";a:4:{s:10:\"cron_limit\";i:100;s:11:\"overlap_cjk\";b:1;s:17:\"minimum_word_size\";i:3;s:11:\"tag_weights\";a:12:{s:2:\"h1\";i:25;s:2:\"h2\";i:18;s:2:\"h3\";i:15;s:2:\"h4\";i:14;s:2:\"h5\";i:9;s:2:\"h6\";i:6;s:1:\"u\";i:3;s:1:\"b\";i:3;s:1:\"i\";i:3;s:6:\"strong\";i:3;s:2:\"em\";i:3;s:1:\"a\";i:10;}}s:7:\"logging\";b:0;}'),
('',	'shortcut.set.default',	'a:7:{s:4:\"uuid\";s:36:\"bc9830ea-c02f-4ef4-a17e-f3539c02304b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U5VlGjd_SfV0Qm_EfnaynOfc549cNscFAx48JfYoMRI\";}s:2:\"id\";s:7:\"default\";s:5:\"label\";s:7:\"Default\";}'),
('',	'system.action.media_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"62205804-910a-4719-bbcb-1c8ef9179e61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FrZy1tmuXJcOxhXlBoI1Hsnen5TT-9OCC1iolWH84go\";}s:2:\"id\";s:19:\"media_delete_action\";s:5:\"label\";s:12:\"Delete media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:26:\"entity:delete_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.media_publish_action',	'a:10:{s:4:\"uuid\";s:36:\"74ae1caf-547b-4f5b-b2c5-344fbdfc9454\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nh83qNNrmWE-CDdHz2MdFOAk60T9mzv3R-MaKfZR2jw\";}s:2:\"id\";s:20:\"media_publish_action\";s:5:\"label\";s:13:\"Publish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:27:\"entity:publish_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.media_save_action',	'a:10:{s:4:\"uuid\";s:36:\"15843e3d-3327-4414-a048-e956e137183d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VVyUA6PIaVeGtcIbgEWqJ6SYDiJdReBeojFswURFpKs\";}s:2:\"id\";s:17:\"media_save_action\";s:5:\"label\";s:10:\"Save media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:24:\"entity:save_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.media_unpublish_action',	'a:10:{s:4:\"uuid\";s:36:\"9d24595c-700e-4798-9d98-3f086528cbd9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CsK6TseQ2DatEbZgbd30swOlZ28_HHwAESU2LvEnWq0\";}s:2:\"id\";s:22:\"media_unpublish_action\";s:5:\"label\";s:15:\"Unpublish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:29:\"entity:unpublish_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"8ff0ec2c-b155-4314-9b5d-65aef57e6ed9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t43OqwzP3CTbcAagSsWKNy6KwMm_zShXo3c4-So6rQg\";}s:2:\"id\";s:18:\"node_delete_action\";s:5:\"label\";s:14:\"Delete content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"entity:delete_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_make_sticky_action',	'a:10:{s:4:\"uuid\";s:36:\"d5b780e9-4002-48fb-9961-4890d2e18a4e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sOb26JSy3fGpWkvR0WYN6_hMqj_6d1rvbvrkzp1yya0\";}s:2:\"id\";s:23:\"node_make_sticky_action\";s:5:\"label\";s:19:\"Make content sticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"node_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_make_unsticky_action',	'a:10:{s:4:\"uuid\";s:36:\"79cd458d-4e0f-42fc-8713-cf8324d4116c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lDM9mvIGAu8Sw8rt-uCO4Sr7yX5VPrDPxYcawkbKd6k\";}s:2:\"id\";s:25:\"node_make_unsticky_action\";s:5:\"label\";s:21:\"Make content unsticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"node_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_promote_action',	'a:10:{s:4:\"uuid\";s:36:\"80e483ef-5cef-449b-b6eb-338611cedfbf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N0RDBTqiK4dKoN4p4oW2j0SGWycdHyALUe9M-Ofp89U\";}s:2:\"id\";s:19:\"node_promote_action\";s:5:\"label\";s:29:\"Promote content to front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:19:\"node_promote_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_publish_action',	'a:10:{s:4:\"uuid\";s:36:\"638ab18d-e126-4bf0-934b-ca0f8e76d21a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2B9uF8NL5gutNKSdPRAhhAsDWFZZG1PJOBmx0aBGd_0\";}s:2:\"id\";s:19:\"node_publish_action\";s:5:\"label\";s:15:\"Publish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:26:\"entity:publish_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_save_action',	'a:10:{s:4:\"uuid\";s:36:\"e656d6be-7229-49e2-a65a-513fbe566776\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LhdsoZPL_pFas2fjaAWue4zvrQ_tEVofLYtcNec-JGM\";}s:2:\"id\";s:16:\"node_save_action\";s:5:\"label\";s:12:\"Save content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"entity:save_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_unpromote_action',	'a:10:{s:4:\"uuid\";s:36:\"1dc10e26-9e52-406f-aa64-78f6f7ff20b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JBptjnfuOMtsdKygklXxoOgeOCTMtQxlkymjnnj-cC0\";}s:2:\"id\";s:21:\"node_unpromote_action\";s:5:\"label\";s:30:\"Remove content from front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"node_unpromote_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_unpublish_action',	'a:10:{s:4:\"uuid\";s:36:\"12dedc3c-a189-49b8-bfa3-3925d1475a53\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C7X8h9FWlwkQ9y5mnU2JzgaZICAdc6HFbPVbhvjlAYE\";}s:2:\"id\";s:21:\"node_unpublish_action\";s:5:\"label\";s:17:\"Unpublish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:28:\"entity:unpublish_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.pathauto_update_alias_node',	'a:10:{s:4:\"uuid\";s:36:\"49be4fb0-6832-463d-8bbe-69dd46552e18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"pathauto\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lno8QThS348UX-kaUsagJtCnuPHKLXYnTQiF_9HSDWA\";}s:2:\"id\";s:26:\"pathauto_update_alias_node\";s:5:\"label\";s:16:\"Update URL alias\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"pathauto_update_alias\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.pathauto_update_alias_user',	'a:10:{s:4:\"uuid\";s:36:\"acf6f444-fa28-4103-ae56-96da6d7abcc5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"pathauto\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x_ok_ZsfA4Xk4B_hVW3O4-3PcNoK57nXLz_Dlletidg\";}s:2:\"id\";s:26:\"pathauto_update_alias_user\";s:5:\"label\";s:16:\"Update URL alias\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:21:\"pathauto_update_alias\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.redirect_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"8c900910-1bd8-48a7-abea-4493a2f89f45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vcnRZRvBqTbK3nZ2M4_lKPlEGc8GjPzgaqapYUfyX8M\";}s:2:\"id\";s:22:\"redirect_delete_action\";s:5:\"label\";s:15:\"Delete redirect\";s:4:\"type\";s:8:\"redirect\";s:6:\"plugin\";s:22:\"redirect_delete_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.taxonomy_term_publish_action',	'a:10:{s:4:\"uuid\";s:36:\"98441d8b-cb2a-44eb-863f-f500933dc072\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DoVt_VGgVLcDD4XmVbSFzr0K17SJy9imFiYusKkJBgY\";}s:2:\"id\";s:28:\"taxonomy_term_publish_action\";s:5:\"label\";s:21:\"Publish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:35:\"entity:publish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.taxonomy_term_unpublish_action',	'a:10:{s:4:\"uuid\";s:36:\"c50e2e3d-3fd4-474f-b4c3-6e9deb3aa4ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z2sNRM3ECa7FPCGnSNje_9SmZJQgwhD_6fG_L4Mr8zI\";}s:2:\"id\";s:30:\"taxonomy_term_unpublish_action\";s:5:\"label\";s:23:\"Unpublish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:37:\"entity:unpublish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.user_add_role_action.administrator',	'a:9:{s:4:\"uuid\";s:36:\"e9cdc7cd-560d-4c6e-b18d-4086edd12442\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:34:\"user_add_role_action.administrator\";s:5:\"label\";s:50:\"Add the Administrator role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),
('',	'system.action.user_block_user_action',	'a:10:{s:4:\"uuid\";s:36:\"e33d4c27-1cb5-4a82-a343-178013992c5b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DyypzTfThX10FFQw-399qPfEbLLyrhXgQrKPVsmAoJ4\";}s:2:\"id\";s:22:\"user_block_user_action\";s:5:\"label\";s:26:\"Block the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:22:\"user_block_user_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.user_cancel_user_action',	'a:10:{s:4:\"uuid\";s:36:\"47b35c2c-ef80-4dbb-9bc2-87e5467e802a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nvrL9bFilzBvm2bjO9rQnFDpBA7dBBUjShSSt6NS-DU\";}s:2:\"id\";s:23:\"user_cancel_user_action\";s:5:\"label\";s:35:\"Cancel the selected user account(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_cancel_user_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.user_remove_role_action.administrator',	'a:9:{s:4:\"uuid\";s:36:\"3a610953-8310-41e6-916e-67a38ded8605\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:37:\"user_remove_role_action.administrator\";s:5:\"label\";s:55:\"Remove the Administrator role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),
('',	'system.action.user_unblock_user_action',	'a:10:{s:4:\"uuid\";s:36:\"f372b8db-b95d-43f7-8c2b-b99a92076084\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SPsUXsR3Rc8d1y3gewzaAKWa1ncea_ywXX3f7LTn7k0\";}s:2:\"id\";s:24:\"user_unblock_user_action\";s:5:\"label\";s:28:\"Unblock the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:24:\"user_unblock_user_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_archive_action',	'a:10:{s:4:\"uuid\";s:36:\"6125548a-6827-4acb-a08b-eda4e1b25de1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OmnschvBLb9ZJn0iVyBd2odf8U8Nt0INjRbRMixZw9U\";}s:2:\"id\";s:22:\"webform_archive_action\";s:5:\"label\";s:15:\"Archive webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:22:\"webform_archive_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_close_action',	'a:10:{s:4:\"uuid\";s:36:\"9a449986-702c-4f26-a07f-3cbbae693dde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Dl-1T9PDkraB7MyMUjTJAioPEx6UNvIB9gqmnB1CRkk\";}s:2:\"id\";s:20:\"webform_close_action\";s:5:\"label\";s:13:\"Close webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:20:\"webform_close_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"d93c6987-507f-40ab-8f7a-1166f768bc12\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e1bCTp0ryXZZtnS9nlVAbtoWz3-8fmbNlqKY3GHzbsM\";}s:2:\"id\";s:21:\"webform_delete_action\";s:5:\"label\";s:14:\"Delete webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:21:\"webform_delete_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_open_action',	'a:10:{s:4:\"uuid\";s:36:\"b9252337-7eb0-41ce-b704-8142809ba069\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AK83C-dOZEPruvi6GbkuhihWLnO4VtrbesqSC6izf4o\";}s:2:\"id\";s:19:\"webform_open_action\";s:5:\"label\";s:12:\"Open webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:19:\"webform_open_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"9caf9021-aacc-4038-827b-c7fe7712e0ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBnl4vapW7sy5bRi7TcF-ueJnvz7aZNLif95ifvhfTQ\";}s:2:\"id\";s:32:\"webform_submission_delete_action\";s:5:\"label\";s:17:\"Delete submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:32:\"webform_submission_delete_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_lock_action',	'a:10:{s:4:\"uuid\";s:36:\"5e4d1084-e98f-408d-9529-89567e88b624\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MKmZlPRk3OJKNcYdYxSeZGQUh7LMah6MRShfkzch4bk\";}s:2:\"id\";s:35:\"webform_submission_make_lock_action\";s:5:\"label\";s:15:\"Lock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:35:\"webform_submission_make_lock_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_sticky_action',	'a:10:{s:4:\"uuid\";s:36:\"71eff68f-3ada-438a-93f8-5554a79cb737\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mPWBT52fKHyINRl9S3cCWFxY3rKbwkIRxaK6sIA26oo\";}s:2:\"id\";s:37:\"webform_submission_make_sticky_action\";s:5:\"label\";s:20:\"Star/flag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_unlock_action',	'a:10:{s:4:\"uuid\";s:36:\"f6b34ab3-4ded-41c8-8a32-ba4e032881fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"begZ0-RmTzO_zDAwEKA2lKvtGYw1vbFOzbQOJzUbZX0\";}s:2:\"id\";s:37:\"webform_submission_make_unlock_action\";s:5:\"label\";s:17:\"Unlock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_unlock_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_unsticky_action',	'a:10:{s:4:\"uuid\";s:36:\"326c9843-f7a5-4f11-a105-e093bfdaae75\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n4gTFiUsdp7gw6yWUlDbKFEasZLCgXWWCmm7eJejay0\";}s:2:\"id\";s:39:\"webform_submission_make_unsticky_action\";s:5:\"label\";s:24:\"Unstar/unflag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:39:\"webform_submission_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_unarchive_action',	'a:10:{s:4:\"uuid\";s:36:\"30b42137-73bc-48ad-bd3d-7b1492d2645a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aqi5Ftlnhe9KyOowpK7CanEvJMBBo8xAR1dA99bKOuc\";}s:2:\"id\";s:24:\"webform_unarchive_action\";s:5:\"label\";s:15:\"Restore webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:24:\"webform_unarchive_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.advisories',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x0FuQ_7Cg81mSDQwG028_Z0CjH3R9ib5IDlHeV2BbAo\";}s:7:\"enabled\";b:1;s:14:\"interval_hours\";i:6;}'),
('',	'system.cron',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f3yToH8v8EaBZU0NFFw2qR8ogSCuWVmQaN0hpYR1BD8\";}s:9:\"threshold\";a:2:{s:20:\"requirements_warning\";i:172800;s:18:\"requirements_error\";i:1209600;}s:7:\"logging\";b:1;}'),
('',	'system.date',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IVsFTD1mvR2NGBP_1myt9kFIFmGepH4PyaN5aQBYpno\";}s:9:\"first_day\";i:0;s:7:\"country\";a:1:{s:7:\"default\";N;}s:8:\"timezone\";a:2:{s:7:\"default\";s:15:\"Europe/Belgrade\";s:4:\"user\";a:3:{s:12:\"configurable\";b:1;s:7:\"default\";i:0;s:4:\"warn\";b:0;}}}'),
('',	'system.diff',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1WanmaEhxW_vM8_5Ktsdntj8MaO9UBHXg0lN603PsWM\";}s:7:\"context\";a:2:{s:13:\"lines_leading\";i:2;s:14:\"lines_trailing\";i:2;}}'),
('',	'system.feature_flags',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYyVj1FtPGV40Cf65YDVTUIc7YgLH6trXlotuevfs2I\";}s:16:\"linkset_endpoint\";b:0;}'),
('',	'system.file',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mguGHCYb9Dw5EcpfjwoShGV1Vjkbz3QuPRCLfxiye-g\";}s:22:\"allow_insecure_uploads\";b:0;s:14:\"default_scheme\";s:6:\"public\";s:21:\"temporary_maximum_age\";i:21600;}'),
('',	'system.image',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"durWHaKeBaq4d9Wpi4RqwADj1OufDepcnJuhVLmKN24\";}s:7:\"toolkit\";s:2:\"gd\";}'),
('',	'system.image.gd',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eNXaHfkJJUThHeF0nvkoXyPLRrKYGxgHRjORvT4F5rQ\";}s:12:\"jpeg_quality\";i:75;}'),
('',	'system.logging',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u3-njszl92FaxjrCMiq0yDcjAfcdx72w1zT1O9dx6aA\";}s:11:\"error_level\";s:4:\"hide\";}'),
('',	'system.mail',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5PvD9swkqWUeHkabdvbJ2SQqdhrzjkCT21wtD4BLfk4\";}s:9:\"interface\";a:2:{s:7:\"default\";s:8:\"php_mail\";s:7:\"webform\";s:16:\"webform_php_mail\";}s:10:\"mailer_dsn\";a:6:{s:6:\"scheme\";s:8:\"sendmail\";s:4:\"host\";s:7:\"default\";s:4:\"user\";N;s:8:\"password\";N;s:4:\"port\";N;s:7:\"options\";a:0:{}}}'),
('',	'system.maintenance',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1SNdA25INsV5YjlgAJtfC-6AM8VcWe_00xneMLb2yFg\";}s:8:\"langcode\";s:2:\"en\";s:7:\"message\";s:93:\"@site is currently under maintenance. We should be back shortly. Thank you for your patience.\";}'),
('',	'system.menu.account',	'a:9:{s:4:\"uuid\";s:36:\"c0346b12-c5cd-40d6-886c-cf0888f426ac\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Bh81osDyUQ4wV0GgU_NdBNqkzM87sLxjaCdFj9mnw\";}s:2:\"id\";s:7:\"account\";s:5:\"label\";s:17:\"User account menu\";s:11:\"description\";s:40:\"Links related to the active user account\";s:6:\"locked\";b:1;}'),
('',	'system.menu.admin',	'a:9:{s:4:\"uuid\";s:36:\"90616064-32be-41e1-baa8-be78784e75f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sapEi2YDGoI9yQIT_WgIV2vUdQ6DScH0V3fAyTadAL0\";}s:2:\"id\";s:5:\"admin\";s:5:\"label\";s:14:\"Administration\";s:11:\"description\";s:25:\"Administrative task links\";s:6:\"locked\";b:1;}'),
('',	'system.menu.footer',	'a:9:{s:4:\"uuid\";s:36:\"ba5622c9-4800-414f-8f65-c096cf34841d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7yrlW5z9zdg2eBucB2GPqXKSMQfH9lSRSO4DbWF7AFc\";}s:2:\"id\";s:6:\"footer\";s:5:\"label\";s:6:\"Footer\";s:11:\"description\";s:22:\"Site information links\";s:6:\"locked\";b:1;}'),
('',	'system.menu.main',	'a:9:{s:4:\"uuid\";s:36:\"7f6e64bf-0677-4eaf-82ae-a29df89f11b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q2Ra3jfoIVk0f3SjxJX61byRQFVBAbpzYDQOiY-kno8\";}s:2:\"id\";s:4:\"main\";s:5:\"label\";s:15:\"Main navigation\";s:11:\"description\";s:18:\"Site section links\";s:6:\"locked\";b:1;}'),
('',	'system.menu.tools',	'a:9:{s:4:\"uuid\";s:36:\"a2a145f9-0c16-431e-975e-9af61b72ef36\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCM-vV1zzRaLHN18dqAR_CuGOj8AFJvTx7BKl_8Gcxc\";}s:2:\"id\";s:5:\"tools\";s:5:\"label\";s:5:\"Tools\";s:11:\"description\";s:39:\"User tool links, often added by modules\";s:6:\"locked\";b:1;}'),
('',	'system.performance',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jtno5biznHZbrIgKwzq-ze-7XaQxLCGe6PeUOR7bRiQ\";}s:5:\"cache\";a:1:{s:4:\"page\";a:1:{s:7:\"max_age\";i:0;}}s:3:\"css\";a:2:{s:10:\"preprocess\";b:1;s:4:\"gzip\";b:1;}s:8:\"fast_404\";a:4:{s:7:\"enabled\";b:1;s:5:\"paths\";s:69:\"/\\.(?:txt|png|gif|jpe?g|css|js|ico|swf|flv|cgi|bat|pl|dll|exe|asp)$/i\";s:13:\"exclude_paths\";s:27:\"/\\/(?:styles|imagecache)\\//\";s:4:\"html\";s:162:\"<!DOCTYPE html><html><head><title>404 Not Found</title></head><body><h1>Not Found</h1><p>The requested URL \"@path\" was not found on this server.</p></body></html>\";}s:2:\"js\";a:2:{s:10:\"preprocess\";b:1;s:4:\"gzip\";b:1;}}'),
('',	'system.rss',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MIpNzlG4gPunfS7vTCwUPum6QH3GUsEBMj-qS631Jw0\";}s:5:\"items\";a:1:{s:9:\"view_mode\";s:3:\"rss\";}}'),
('',	'system.site',	'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ijfbzDTN4CbE7Sr-6ubWzy_t1vH4OtU1doNCLssVz-4\";}s:8:\"langcode\";s:2:\"en\";s:4:\"uuid\";s:36:\"81f69bca-c1ec-48e0-bfde-2d9c7e27ddda\";s:4:\"name\";s:18:\"EBT Builder Source\";s:4:\"mail\";s:17:\"admin@example.com\";s:6:\"slogan\";s:0:\"\";s:4:\"page\";a:3:{i:403;s:0:\"\";i:404;s:0:\"\";s:5:\"front\";s:5:\"/node\";}s:18:\"admin_compact_mode\";b:0;s:17:\"weight_select_max\";i:100;s:16:\"default_langcode\";s:2:\"en\";s:17:\"mail_notification\";N;}'),
('',	'system.theme',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJ529VM1gSIA_vgTy2PdiDvJuG0xhSxfQjCyl5WKlv4\";}s:5:\"admin\";s:5:\"claro\";s:7:\"default\";s:7:\"olivero\";}'),
('',	'system.theme.global',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KZiV2LB312xgJBphfq5BTjmp16xiR5KM8InBJ-pff7Y\";}s:7:\"favicon\";a:4:{s:8:\"mimetype\";s:24:\"image/vnd.microsoft.icon\";s:4:\"path\";s:0:\"\";s:3:\"url\";s:0:\"\";s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:3:{s:4:\"path\";s:0:\"\";s:3:\"url\";N;s:11:\"use_default\";b:1;}}'),
('',	'taxonomy.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zKpaWT6cJc1tVQQaTqatGELaCqU_oyRym6zTl27Yias\";}s:20:\"maintain_index_table\";b:1;s:17:\"override_selector\";b:0;s:20:\"terms_per_page_admin\";i:100;}'),
('',	'taxonomy.vocabulary.tags',	'a:10:{s:4:\"uuid\";s:36:\"bae62ed0-d39a-4ca0-a737-86bf6ae374a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iTEzwrEQ_4JIb-OYGiqzyF2TmMgWyWayresXcWgwGWM\";}s:4:\"name\";s:4:\"Tags\";s:3:\"vid\";s:4:\"tags\";s:11:\"description\";s:61:\"Use tags to group articles on similar topics into categories.\";s:6:\"weight\";i:0;s:12:\"new_revision\";b:0;}'),
('',	'text.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Bkewb77RBOK3_aXMPsp8p87gbc03NvmC5gBLzPl7hVA\";}s:22:\"default_summary_length\";i:600;}'),
('',	'update.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xbYr66-g0FjNgVBkGypCuN46vBI2XHntXN1URawq1s4\";}s:5:\"check\";a:2:{s:19:\"disabled_extensions\";b:0;s:13:\"interval_days\";i:1;}s:5:\"fetch\";a:3:{s:3:\"url\";N;s:12:\"max_attempts\";i:2;s:7:\"timeout\";i:30;}s:12:\"notification\";a:2:{s:6:\"emails\";a:1:{i:0;s:17:\"admin@example.com\";}s:9:\"threshold\";s:3:\"all\";}}'),
('',	'user.flood',	'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UYfMzeP1S8jKm9PSvxf7nQNe8DsNS-3bc2WSNNXBQWs\";}s:8:\"uid_only\";b:0;s:8:\"ip_limit\";i:50;s:9:\"ip_window\";i:3600;s:10:\"user_limit\";i:5;s:11:\"user_window\";i:21600;}'),
('',	'user.mail',	'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6CZIzFifRq3qbdq3n3nDpEOO4hWIQtKOAQNPvGNGKeM\";}s:8:\"langcode\";s:2:\"en\";s:14:\"cancel_confirm\";a:2:{s:7:\"subject\";s:67:\"Account cancellation request for [user:display-name] at [site:name]\";s:4:\"body\";s:376:\"[user:display-name]\n\nA request to cancel your account has been made at [site:name].\n\nYou may now cancel your account on [site:url-brief] by clicking this link or copying and pasting it into your browser:\n\n[user:cancel-url]\n\nNOTE: The cancellation of your account is not reversible.\n\nThis link expires in one day and nothing will happen if it is not used.\n\n--  [site:name] team\";}s:14:\"password_reset\";a:2:{s:7:\"subject\";s:68:\"Replacement login information for [user:display-name] at [site:name]\";s:4:\"body\";s:407:\"[user:display-name],\n\nA request to reset the password for your account has been made at [site:name].\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password. It expires after one day and nothing will happen if it\'s not used.\n\n--  [site:name] team\";}s:22:\"register_admin_created\";a:2:{s:7:\"subject\";s:58:\"An administrator created an account for you at [site:name]\";s:4:\"body\";s:473:\"[user:display-name],\n\nA site administrator at [site:name] has created an account for you. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:29:\"register_no_approval_required\";a:2:{s:7:\"subject\";s:54:\"Account details for [user:display-name] at [site:name]\";s:4:\"body\";s:447:\"[user:display-name],\n\nThank you for registering at [site:name]. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:25:\"register_pending_approval\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:288:\"[user:display-name],\n\nThank you for registering at [site:name]. Your application for an account is currently pending approval. Once it has been approved, you will receive another email containing information about how to log in, set your password, and other details.\n\n--  [site:name] team\";}s:31:\"register_pending_approval_admin\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:64:\"[user:display-name] has applied for an account.\n\n[user:edit-url]\";}s:16:\"status_activated\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (approved)\";s:4:\"body\";s:462:\"[user:display-name],\n\nYour account at [site:name] has been activated.\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:account-name]\npassword: Your password\n\n--  [site:name] team\";}s:14:\"status_blocked\";a:2:{s:7:\"subject\";s:64:\"Account details for [user:display-name] at [site:name] (blocked)\";s:4:\"body\";s:89:\"[user:display-name],\n\nYour account on [site:name] has been blocked.\n\n--  [site:name] team\";}s:15:\"status_canceled\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (canceled)\";s:4:\"body\";s:90:\"[user:display-name],\n\nYour account on [site:name] has been canceled.\n\n--  [site:name] team\";}}'),
('',	'user.role.administrator',	'a:10:{s:4:\"uuid\";s:36:\"55c650b9-b5a7-4ff4-bc0f-f89243b36175\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OeKGIkmZA_c-t6QLH81WNQx8gDCc1MRmxaTuQgxBByU\";}s:2:\"id\";s:13:\"administrator\";s:5:\"label\";s:13:\"Administrator\";s:6:\"weight\";i:3;s:8:\"is_admin\";b:1;s:11:\"permissions\";a:0:{}}'),
('',	'user.role.anonymous',	'a:10:{s:4:\"uuid\";s:36:\"8ae6303e-51a9-461e-9cd1-3548f02fd2f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.restricted_html\";}s:6:\"module\";a:5:{i:0;s:7:\"contact\";i:1;s:6:\"filter\";i:2;s:5:\"media\";i:3;s:6:\"search\";i:4;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6WavjUYXIegP9AAg2zXGx54MWIVoomC3SZhNiqe-Dyk\";}s:2:\"id\";s:9:\"anonymous\";s:5:\"label\";s:14:\"Anonymous user\";s:6:\"weight\";i:0;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:5:{i:0;s:14:\"access content\";i:1;s:29:\"access site-wide contact form\";i:2;s:14:\"search content\";i:3;s:31:\"use text format restricted_html\";i:4;s:10:\"view media\";}}'),
('',	'user.role.authenticated',	'a:10:{s:4:\"uuid\";s:36:\"a817234d-3eaa-4c9f-a2ec-0f6cada70063\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"filter.format.basic_html\";i:1;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:8:{i:0;s:7:\"contact\";i:1;s:4:\"file\";i:2;s:6:\"filter\";i:3;s:16:\"google_analytics\";i:4;s:5:\"media\";i:5;s:6:\"search\";i:6;s:8:\"shortcut\";i:7;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFrlqjtkTfvY3RGccjJkPf1SGIfJ942IrxTLWAO4mgA\";}s:2:\"id\";s:13:\"authenticated\";s:5:\"label\";s:18:\"Authenticated user\";s:6:\"weight\";i:1;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:9:{i:0;s:14:\"access content\";i:1;s:16:\"access shortcuts\";i:2;s:29:\"access site-wide contact form\";i:3;s:16:\"delete own files\";i:4;s:42:\"opt-in or out of google analytics tracking\";i:5;s:14:\"search content\";i:6;s:26:\"use text format basic_html\";i:7;s:31:\"use text format webform_default\";i:8;s:10:\"view media\";}}'),
('',	'user.role.content_editor',	'a:10:{s:4:\"uuid\";s:36:\"d6e980dc-d5d4-42cf-8308-888d9c255fa0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:17:\"node.type.article\";i:1;s:14:\"node.type.page\";i:2;s:24:\"taxonomy.vocabulary.tags\";}s:6:\"module\";a:7:{i:0;s:10:\"contextual\";i:1;s:4:\"file\";i:2;s:4:\"node\";i:3;s:4:\"path\";i:4;s:6:\"system\";i:5;s:8:\"taxonomy\";i:6;s:7:\"toolbar\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e_wG1u7SrGaJbY2-Szgbgl-c8T3kdirU3uTNq2c_QJQ\";}s:2:\"id\";s:14:\"content_editor\";s:5:\"label\";s:14:\"Content editor\";s:6:\"weight\";i:2;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:22:{i:0;s:27:\"access administration pages\";i:1;s:23:\"access content overview\";i:2;s:23:\"access contextual links\";i:3;s:21:\"access files overview\";i:4;s:14:\"access toolbar\";i:5;s:22:\"administer url aliases\";i:6;s:22:\"create article content\";i:7;s:19:\"create page content\";i:8;s:20:\"create terms in tags\";i:9;s:18:\"create url aliases\";i:10;s:24:\"delete article revisions\";i:11;s:26:\"delete own article content\";i:12;s:16:\"delete own files\";i:13;s:23:\"delete own page content\";i:14;s:21:\"delete page revisions\";i:15;s:24:\"edit own article content\";i:16;s:21:\"edit own page content\";i:17;s:18:\"edit terms in tags\";i:18;s:20:\"revert all revisions\";i:19;s:18:\"view all revisions\";i:20;s:28:\"view own unpublished content\";i:21;s:29:\"view the administration theme\";}}'),
('',	'user.settings',	'a:9:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-htDFWUv1S4OlJMzta2nhFl4QbhJvu0D9xsJ-clxo-M\";}s:8:\"langcode\";s:2:\"en\";s:9:\"anonymous\";s:9:\"Anonymous\";s:11:\"verify_mail\";b:1;s:6:\"notify\";a:8:{s:14:\"cancel_confirm\";b:1;s:14:\"password_reset\";b:1;s:16:\"status_activated\";b:1;s:14:\"status_blocked\";b:0;s:15:\"status_canceled\";b:0;s:22:\"register_admin_created\";b:1;s:29:\"register_no_approval_required\";b:1;s:25:\"register_pending_approval\";b:1;}s:8:\"register\";s:23:\"visitors_admin_approval\";s:13:\"cancel_method\";s:17:\"user_cancel_block\";s:22:\"password_reset_timeout\";i:86400;s:17:\"password_strength\";b:1;}'),
('',	'views.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8oDr9oPVb_ostrNnVV6V7VdphwoH_u-NqTS0u7SE7qc\";}s:17:\"display_extenders\";a:0:{}s:13:\"sql_signature\";b:0;s:2:\"ui\";a:3:{s:4:\"show\";a:7:{s:18:\"additional_queries\";b:0;s:15:\"advanced_column\";b:0;s:15:\"default_display\";b:0;s:22:\"performance_statistics\";b:0;s:19:\"preview_information\";b:1;s:9:\"sql_query\";a:2:{s:7:\"enabled\";b:0;s:5:\"where\";s:5:\"above\";}s:13:\"display_embed\";b:0;}s:19:\"always_live_preview\";b:1;s:24:\"exposed_filter_any_label\";s:7:\"old_any\";}s:22:\"field_rewrite_elements\";a:29:{s:3:\"div\";s:3:\"DIV\";s:4:\"span\";s:4:\"SPAN\";s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";s:2:\"h6\";s:2:\"H6\";s:1:\"p\";s:1:\"P\";s:6:\"header\";s:6:\"HEADER\";s:6:\"footer\";s:6:\"FOOTER\";s:7:\"article\";s:7:\"ARTICLE\";s:7:\"section\";s:7:\"SECTION\";s:5:\"aside\";s:5:\"ASIDE\";s:7:\"details\";s:7:\"DETAILS\";s:10:\"blockquote\";s:10:\"BLOCKQUOTE\";s:6:\"figure\";s:6:\"FIGURE\";s:7:\"address\";s:7:\"ADDRESS\";s:4:\"code\";s:4:\"CODE\";s:3:\"pre\";s:3:\"PRE\";s:3:\"var\";s:3:\"VAR\";s:4:\"samp\";s:4:\"SAMP\";s:3:\"kbd\";s:3:\"KBD\";s:6:\"strong\";s:6:\"STRONG\";s:2:\"em\";s:2:\"EM\";s:3:\"del\";s:3:\"DEL\";s:3:\"ins\";s:3:\"INS\";s:1:\"q\";s:1:\"Q\";s:1:\"s\";s:1:\"S\";}}'),
('',	'views.view.archive',	'a:13:{s:4:\"uuid\";s:36:\"869573d7-3210-47a6-a85b-2b4f70595558\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"exIF08PTvYSK6tJCsAzBqMEKUBKIptPorMn74SVhevc\";}s:2:\"id\";s:7:\"archive\";s:5:\"label\";s:7:\"Archive\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:22:\"All content, by month.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:15:\"Monthly archive\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:2:{s:8:\"override\";b:1;s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:2:{s:10:\"sort_order\";s:4:\"desc\";s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:0;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:1:{s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"archive\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.block_content',	'a:13:{s:4:\"uuid\";s:36:\"2b2425c7-ad13-4164-afc2-8d66592f2a30\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HfvTcWhiVuvxchoh4DjIkXhKkj9ow2TGgHkLHSvRLq8\";}s:2:\"id\";s:13:\"block_content\";s:5:\"label\";s:14:\"Content blocks\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:31:\"Find and manage content blocks.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:24:\"block_content_field_data\";s:10:\"base_field\";s:2:\"id\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:14:\"Content blocks\";s:6:\"fields\";a:4:{s:4:\"info\";a:37:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";N;s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:17:\"Block description\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Block type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access block library\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:2:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:38:\"There are no content blocks available.\";s:8:\"tokenize\";b:0;}s:27:\"block_content_listing_empty\";a:10:{s:2:\"id\";s:27:\"block_content_listing_empty\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:27:\"block_content_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:27:\"block_content_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:4:\"info\";a:16:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"info_op\";s:5:\"label\";s:17:\"Block description\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"info_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"info\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:10:\"Block type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"reusable\";a:16:{s:2:\"id\";s:8:\"reusable\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:8:\"reusable\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:8:\"reusable\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:4:\"info\";s:4:\"info\";s:4:\"type\";s:4:\"type\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:4:{s:4:\"info\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/block\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:6:\"Blocks\";s:11:\"description\";s:31:\"Create and edit content blocks.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:20:\"system.admin_content\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.content',	'a:13:{s:4:\"uuid\";s:36:\"53b483f4-38d1-4359-99b2-b24e9f23a505\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"whBYBAcXQuQblGEdvQ9QfGuuW3zC49F2-5vXSm1slFM\";}s:2:\"id\";s:7:\"content\";s:5:\"label\";s:7:\"Content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:24:\"Find and manage content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:7:\"Content\";s:6:\"fields\";a:8:{s:14:\"node_bulk_form\";a:14:{s:2:\"id\";s:14:\"node_bulk_form\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:14:\"node_bulk_form\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:14:\"node_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"title\";a:17:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Content type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:17:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:17:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}}s:7:\"changed\";a:17:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:8:\"langcode\";a:37:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Language\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:8:\"language\";s:8:\"settings\";a:2:{s:14:\"link_to_entity\";b:0;s:15:\"native_language\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:23:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:3:{s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:23:\"access content overview\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:5:\"title\";a:16:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:8:\"title_op\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:8:\"title_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:5:\"title\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:12:\"Content type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:12:\"status_extra\";a:9:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:6:\"expose\";a:2:{s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:10:{s:14:\"node_bulk_form\";s:14:\"node_bulk_form\";s:5:\"title\";s:5:\"title\";s:4:\"type\";s:4:\"type\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:7:\"changed\";s:7:\"changed\";s:9:\"edit_node\";s:9:\"edit_node\";s:11:\"delete_node\";s:11:\"delete_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";s:9:\"timestamp\";s:5:\"title\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:10:{s:14:\"node_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"title\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"delete_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:18:\"admin/content/node\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:23:\"Find and manage content\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.content_recent',	'a:13:{s:4:\"uuid\";s:36:\"0aadfe89-23e4-4ec3-a50a-3c76c79be76a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YqZN5rc7XDQcFcInc8wkzuaHJmC5YvirhTmDcrarT6M\";}s:2:\"id\";s:14:\"content_recent\";s:5:\"label\";s:14:\"Recent content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:15:\"Recent content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:22:{s:5:\"title\";s:14:\"Recent content\";s:6:\"fields\";a:2:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"More\";s:12:\"link_display\";s:1:\"0\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:1:{s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.files',	'a:13:{s:4:\"uuid\";s:36:\"534a8e69-2ee4-4c66-98d4-040cedf2dcd1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"blP1XdpU4RqVoA_8po7qnIokIbHB6DJt0lpilgY5ovM\";}s:2:\"id\";s:5:\"files\";s:5:\"label\";s:5:\"Files\";s:6:\"module\";s:4:\"file\";s:11:\"description\";s:22:\"Find and manage files.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:12:\"file_managed\";s:10:\"base_field\";s:3:\"fid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:5:\"Files\";s:6:\"fields\";a:9:{s:3:\"fid\";a:24:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:3:\"Fid\";s:7:\"exclude\";b:1;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"filename\";a:36:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"file_link\";s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:8:\"filemime\";a:25:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"MIME type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"file_filemime\";}s:8:\"filesize\";a:25:{s:2:\"id\";s:8:\"filesize\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filesize\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filesize\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Size\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"file_size\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:9:\"Temporary\";s:18:\"format_custom_true\";s:9:\"Permanent\";}}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Upload date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Changed date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:3:\"fid\";s:10:\"group_type\";s:3:\"sum\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:7:\"Used in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/content/files/usage/{{ fid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:1;s:20:\"format_plural_string\";s:21:\"1 place@count places\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access files overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No files available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:8:\"filename\";a:16:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:8:\"Filename\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filename_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filename\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"filemime\";a:16:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:9:\"MIME type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filemime_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filemime\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:11:\"file_status\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"status_op\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:3:\"fid\";s:3:\"fid\";s:8:\"filename\";s:8:\"filename\";s:8:\"filemime\";s:8:\"filemime\";s:8:\"filesize\";s:8:\"filesize\";s:6:\"status\";s:6:\"status\";s:7:\"created\";s:7:\"created\";s:7:\"changed\";s:7:\"changed\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:8:{s:3:\"fid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filename\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filemime\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:8:\"filesize\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:1;s:16:\"show_admin_links\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:14:\"Files overview\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:2:{s:5:\"pager\";b:1;s:13:\"relationships\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:0;}}s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/files\";s:4:\"menu\";a:6:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Files\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_2\";a:6:{s:2:\"id\";s:6:\"page_2\";s:13:\"display_title\";s:10:\"File usage\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:15:{s:5:\"title\";s:10:\"File usage\";s:6:\"fields\";a:4:{s:12:\"entity_label\";a:23:{s:2:\"id\";s:12:\"entity_label\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:12:\"entity_label\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"entity_label\";s:5:\"label\";s:6:\"Entity\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:14:\"link_to_entity\";b:1;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:11:\"Entity type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:6:\"module\";a:22:{s:2:\"id\";s:6:\"module\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:6:\"module\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:18:\"Registering module\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:9:\"Use count\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:0;s:20:\"format_plural_string\";s:8:\"1@count\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:5:\"empty\";a:0:{}s:9:\"arguments\";a:1:{s:3:\"fid\";a:22:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:8:\"file_fid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:46:\"File usage information for {{ arguments.fid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;}}s:7:\"filters\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:12:\"entity_label\";s:12:\"entity_label\";s:4:\"type\";s:4:\"type\";s:6:\"module\";s:6:\"module\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:12:\"entity_label\";s:4:\"info\";a:4:{s:12:\"entity_label\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:6:\"module\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:11:{s:5:\"empty\";b:0;s:5:\"title\";b:0;s:5:\"pager\";b:0;s:8:\"group_by\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:13:\"relationships\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:0;s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:27:\"admin/content/files/usage/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.frontpage',	'a:13:{s:4:\"uuid\";s:36:\"697fbe61-72f2-4f36-9ef0-93f40a5476d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OEEnRQIjfIaCFRsz8U3VqDrE82ltQKlo8wNbQJRZXu0\";}s:2:\"id\";s:9:\"frontpage\";s:5:\"label\";s:9:\"Frontpage\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:39:\"All content promoted to the front page.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:0:\"\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:3:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:181:\"No front page content has been created yet.<br/>Follow the <a target=\"_blank\" href=\"https://www.drupal.org/docs/user_guide/en/index.html\">User Guide</a> to start building your site.\";s:8:\"tokenize\";b:0;}s:18:\"node_listing_empty\";a:10:{s:2:\"id\";s:18:\"node_listing_empty\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:18:\"node_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:18:\"node_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}s:5:\"title\";a:10:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"title\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:5:\"title\";s:8:\"Welcome!\";}}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:12:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:7:\"promote\";a:16:{s:2:\"id\";s:7:\"promote\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"promote\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"promote\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:3:\"rss\";}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"rss.xml\";s:14:\"sitename_title\";b:1;s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:28:\"languages:language_interface\";i:1;s:21:\"user.node_grants:view\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:4:\"node\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.glossary',	'a:13:{s:4:\"uuid\";s:36:\"4b34ee05-e652-40b7-8ec4-c522b22c6013\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r-klgGeO4haVHqAwxW1HXZLzdzLSMUVC08OuTBrRh58\";}s:2:\"id\";s:8:\"glossary\";s:5:\"label\";s:8:\"Glossary\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:23:\"All content, by letter.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:6:\"fields\";a:3:{s:5:\"title\";a:24:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:36;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"default\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:0:{}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;s:7:\"columns\";a:3:{s:5:\"title\";s:5:\"title\";s:4:\"name\";s:4:\"name\";s:7:\"changed\";s:7:\"changed\";}s:7:\"default\";s:5:\"title\";s:4:\"info\";a:3:{s:5:\"title\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:4:\"name\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:7:\"changed\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:5:\"order\";s:3:\"asc\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"attachment_1\";a:6:{s:2:\"id\";s:12:\"attachment_1\";s:13:\"display_title\";s:10:\"Attachment\";s:14:\"display_plugin\";s:10:\"attachment\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:0;}}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:3:{s:14:\"items_per_page\";i:25;s:6:\"inline\";b:1;s:9:\"separator\";s:3:\" | \";}s:7:\"summary\";a:1:{s:6:\"format\";s:19:\"unformatted_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}s:8:\"displays\";a:2:{s:7:\"default\";s:7:\"default\";s:6:\"page_1\";s:6:\"page_1\";}s:17:\"inherit_arguments\";b:0;}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:8:\"glossary\";s:4:\"menu\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:8:\"Glossary\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.media',	'a:13:{s:4:\"uuid\";s:36:\"36a349da-87e8-43e4-89c5-350096634510\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kOTUk5XWeupgBOJuRRarCiDcFKVZcvaW-FT5MTzrML8\";}s:2:\"id\";s:5:\"media\";s:5:\"label\";s:5:\"Media\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:8:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:20:\"thumbnail__target_id\";a:37:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:9:\"thumbnail\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:5:\"media\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Media name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"bundle\";a:37:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"status\";a:37:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:10:\"Media name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:4:\"True\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:4:\"name\";s:4:\"name\";s:6:\"bundle\";s:6:\"bundle\";s:7:\"changed\";s:7:\"changed\";s:3:\"uid\";s:3:\"uid\";s:6:\"status\";s:6:\"status\";s:20:\"thumbnail__target_id\";s:20:\"thumbnail__target_id\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"bundle\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:15:\"media_page_list\";a:6:{s:2:\"id\";s:15:\"media_page_list\";s:13:\"display_title\";s:5:\"Media\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/media\";s:4:\"menu\";a:8:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Media\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.media_library',	'a:13:{s:4:\"uuid\";s:36:\"bc9a8070-9681-4b94-8d52-549af33d0dbe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:25:\"image.style.media_library\";}s:6:\"module\";a:4:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:13:\"media_library\";i:3;s:4:\"user\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9u9hwW-Q0-uQJz1vgenJTQhZGYN0FBZoOogwPD6kgkQ\";}s:2:\"id\";s:13:\"media_library\";s:5:\"label\";s:13:\"Media library\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:4:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:2:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:24;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"6, 12, 24, 48\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:13:\"Apply filters\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:3:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:12:\"Newest first\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:1;s:11:\"granularity\";s:6:\"second\";}s:4:\"name\";a:12:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:3:\"ASC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (A-Z)\";s:16:\"field_identifier\";s:4:\"name\";}s:7:\"exposed\";b:1;}s:6:\"name_1\";a:12:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (Z-A)\";s:16:\"field_identifier\";s:6:\"name_1\";}s:7:\"exposed\";b:1;}}s:7:\"filters\";a:5:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:17:\"Publishing status\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:9:\"Published\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:10:\"Media type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:10:\"Media type\";s:11:\"description\";N;s:10:\"identifier\";s:6:\"bundle\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:3:{i:1;a:0:{}i:2;a:0:{}i:3;a:0:{}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:6:\"fields\";a:5:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"edit_media\";a:26:{s:2:\"id\";s:10:\"edit_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"edit_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:15:\"Edit {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:15:\"Edit {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"Edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:12:\"delete_media\";a:26:{s:2:\"id\";s:12:\"delete_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:12:\"delete_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:18:\"entity_link_delete\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:17:\"Delete {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:17:\"Delete {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:6:\"Delete\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:8:\"defaults\";a:1:{s:6:\"fields\";b:0;}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:24:\"admin/content/media-grid\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:22:\"url.query_args:sort_by\";i:5;s:4:\"user\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"widget\";a:6:{s:2:\"id\";s:6:\"widget\";s:13:\"display_title\";s:6:\"Widget\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:12:{s:6:\"fields\";a:2:{s:25:\"media_library_select_form\";a:23:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:7:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:19:\"display_description\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:26:\"admin/content/media-widget\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"widget_table\";a:6:{s:2:\"id\";s:12:\"widget_table\";s:13:\"display_title\";s:14:\"Widget (table)\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:3;s:15:\"display_options\";a:13:{s:6:\"fields\";a:5:{s:25:\"media_library_select_form\";a:9:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:10:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:13:\"media_library\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}}s:4:\"name\";a:10:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}}s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:20:\"media_field_revision\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}}s:7:\"changed\";a:10:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:2:{s:9:\"row_class\";s:85:\"media-library-item media-library-item--table js-media-library-item js-click-to-select\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:8:\"defaults\";a:9:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:32:\"admin/content/media-widget-table\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.redirect',	'a:13:{s:4:\"uuid\";s:36:\"cb66f7a4-4661-4051-8a2d-40c096d4f55d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:8:\"redirect\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I9VqfbwK5ZyKzL7810d0fswaadU6riFT3kPL0yxcpLs\";}s:2:\"id\";s:8:\"redirect\";s:5:\"label\";s:8:\"Redirect\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:17:\"List of redirects\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"redirect\";s:10:\"base_field\";s:3:\"rid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"administer redirects\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:14:\"items_per_page\";i:50;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:12:\"‹ previous\";s:4:\"next\";s:8:\"next ›\";s:5:\"first\";s:8:\"« first\";s:4:\"last\";s:7:\"last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;s:24:\"pagination_heading_level\";s:2:\"h4\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:6:{s:21:\"redirect_source__path\";s:21:\"redirect_source__path\";s:22:\"redirect_redirect__uri\";s:22:\"redirect_redirect__uri\";s:11:\"status_code\";s:11:\"status_code\";s:8:\"language\";s:8:\"language\";s:7:\"created\";s:7:\"created\";s:10:\"operations\";s:10:\"operations\";}s:4:\"info\";a:6:{s:21:\"redirect_source__path\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:22:\"redirect_redirect__uri\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"status_code\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"language\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:6:\"fields\";a:7:{s:18:\"redirect_bulk_form\";a:26:{s:2:\"id\";s:18:\"redirect_bulk_form\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:18:\"redirect_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:14:\"With selection\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:8:\"redirect\";s:9:\"plugin_id\";s:18:\"redirect_bulk_form\";}s:21:\"redirect_source__path\";a:37:{s:2:\"id\";s:21:\"redirect_source__path\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:21:\"redirect_source__path\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:4:\"From\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:4:\"path\";s:4:\"type\";s:15:\"redirect_source\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:15:\"redirect_source\";s:9:\"plugin_id\";s:5:\"field\";}s:22:\"redirect_redirect__uri\";a:6:{s:2:\"id\";s:22:\"redirect_redirect__uri\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:22:\"redirect_redirect__uri\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:17:\"redirect_redirect\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"status_code\";a:6:{s:2:\"id\";s:11:\"status_code\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:11:\"status_code\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:11:\"status_code\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"language\";a:6:{s:2:\"id\";s:8:\"language\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:8:\"language\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:8:\"language\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:27:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:8:\"fallback\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";}s:10:\"operations\";a:5:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:10:\"operations\";s:11:\"entity_type\";s:8:\"redirect\";s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:4:{s:21:\"redirect_source__path\";a:16:{s:2:\"id\";s:21:\"redirect_source__path\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:21:\"redirect_source__path\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:24:\"redirect_source__path_op\";s:5:\"label\";s:4:\"From\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:24:\"redirect_source__path_op\";s:10:\"identifier\";s:21:\"redirect_source__path\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:15:\"redirect_source\";s:9:\"plugin_id\";s:6:\"string\";}s:22:\"redirect_redirect__uri\";a:16:{s:2:\"id\";s:22:\"redirect_redirect__uri\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:22:\"redirect_redirect__uri\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:25:\"redirect_redirect__uri_op\";s:5:\"label\";s:2:\"To\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:25:\"redirect_redirect__uri_op\";s:10:\"identifier\";s:22:\"redirect_redirect__uri\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:17:\"redirect_redirect\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"status_code\";a:16:{s:2:\"id\";s:11:\"status_code\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:11:\"status_code\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:0:\"\";}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:14:\"status_code_op\";s:5:\"label\";s:11:\"Status code\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:14:\"status_code_op\";s:10:\"identifier\";s:11:\"status_code\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:11:\"Status code\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:11:\"status_code\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:7:{i:1;a:3:{s:5:\"title\";s:20:\"300 Multiple Choices\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"300\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:2;a:3:{s:5:\"title\";s:21:\"301 Moved Permanently\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"301\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:3;a:3:{s:5:\"title\";s:9:\"302 Found\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"302\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:4;a:3:{s:5:\"title\";s:13:\"303 See Other\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"303\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:5;a:3:{s:5:\"title\";s:16:\"304 Not Modified\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"304\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:6;a:3:{s:5:\"title\";s:13:\"305 Use Proxy\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"305\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:7;a:3:{s:5:\"title\";s:22:\"307 Temporary Redirect\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"307\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:11:\"status_code\";s:9:\"plugin_id\";s:7:\"numeric\";}s:8:\"language\";a:16:{s:2:\"id\";s:8:\"language\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:8:\"language\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"language_op\";s:5:\"label\";s:17:\"Original language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"language_op\";s:10:\"identifier\";s:8:\"language\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:8:\"language\";s:9:\"plugin_id\";s:8:\"language\";}}s:5:\"sorts\";a:0:{}s:5:\"title\";s:8:\"Redirect\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"There is no redirect yet.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:0:{}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:4:{s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:9:\"cacheable\";b:0;s:7:\"max-age\";i:0;s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:14:\"display_plugin\";s:4:\"page\";s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:28:\"admin/config/search/redirect\";}s:14:\"cache_metadata\";a:4:{s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:9:\"cacheable\";b:0;s:7:\"max-age\";i:0;s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.taxonomy_term',	'a:13:{s:4:\"uuid\";s:36:\"d74333b1-feb4-4d77-9bb9-7230d2bc1f92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:3:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KejdxDJQmx8SaO-t83OVekLw6ar4ldjmsJMGcotGxnQ\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:6:\"module\";s:8:\"taxonomy\";s:11:\"description\";s:45:\"Content belonging to a certain taxonomy term.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:10:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:11:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:3:\"tid\";a:22:{s:2:\"id\";s:3:\"tid\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:3:\"tid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:18:\"taxonomy_index_tid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:0:\"\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:19:\"{{ arguments.tid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:4:{s:7:\"bundles\";a:0:{}s:6:\"access\";b:1;s:9:\"operation\";s:4:\"view\";s:8:\"multiple\";i:0;}s:12:\"break_phrase\";b:0;s:9:\"add_table\";b:0;s:13:\"require_value\";b:0;s:17:\"reduce_duplicates\";b:0;}}s:7:\"filters\";a:2:{s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:14:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:1:{s:20:\"entity_taxonomy_term\";a:12:{s:2:\"id\";s:20:\"entity_taxonomy_term\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:20:\"entity_taxonomy_term\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"entity\";s:5:\"empty\";b:1;s:6:\"target\";s:23:\"{{ raw_arguments.tid }}\";s:9:\"view_mode\";s:4:\"full\";s:8:\"tokenize\";b:1;s:13:\"bypass_access\";b:0;}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:7:\"default\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:20:\"taxonomy/term/%/feed\";s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:15:\"taxonomy/term/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.user_admin_people',	'a:13:{s:4:\"uuid\";s:36:\"dd75f214-13a9-43b5-af70-9953d491803c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FFLg74mnzRE10lgg5fspPCZWLnIEcvCnJMlNzj8OEtw\";}s:2:\"id\";s:17:\"user_admin_people\";s:5:\"label\";s:6:\"People\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:25:{s:5:\"title\";s:6:\"People\";s:6:\"fields\";a:8:{s:14:\"user_bulk_form\";a:23:{s:2:\"id\";s:14:\"user_bulk_form\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:14:\"user_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:14:\"user_bulk_form\";s:5:\"label\";s:11:\"Bulk update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Username\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:7:\"Blocked\";s:18:\"format_custom_true\";s:6:\"Active\";}}s:15:\"roles_target_id\";a:24:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:5:\"label\";s:5:\"Roles\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:2:\"ul\";s:9:\"separator\";s:2:\", \";}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Member for\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:9:\"@interval\";s:11:\"past_format\";s:9:\"@interval\";s:11:\"granularity\";i:2;}}s:6:\"access\";a:26:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last access\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:4:\"mail\";a:37:{s:2:\"id\";s:4:\"mail\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"mail\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"mail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"basic_string\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:16:\"administer users\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:20:\"No people available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:7:\"filters\";a:6:{s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:22:\"Name or email contains\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"user\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:4:\"mail\";s:4:\"mail\";}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:6:\"Active\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:7:\"Blocked\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:15:\"roles_target_id\";a:15:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:18:\"roles_target_id_op\";s:5:\"label\";s:4:\"Role\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:18:\"roles_target_id_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"role\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:10:\"permission\";a:15:{s:2:\"id\";s:10:\"permission\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:10:\"permission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"user_permissions\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:13:\"permission_op\";s:5:\"label\";s:10:\"Permission\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:13:\"permission_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:10:\"permission\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"uid_raw\";a:15:{s:2:\"id\";s:7:\"uid_raw\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"uid_raw\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:7:\"numeric\";s:8:\"operator\";s:2:\"!=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:1:\"0\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:10:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:14:\"user_bulk_form\";s:14:\"user_bulk_form\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:3:\"rid\";s:3:\"rid\";s:7:\"created\";s:7:\"created\";s:6:\"access\";s:6:\"access\";s:9:\"edit_node\";s:9:\"edit_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";}s:7:\"default\";s:7:\"created\";s:4:\"info\";a:8:{s:14:\"user_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:3:\"rid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"access\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"more\";s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:15:\"display_comment\";s:0:\"\";s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:1:{s:16:\"show_admin_links\";b:0;}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:17:\"admin/people/list\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:4:\"List\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:6:\"People\";s:11:\"description\";s:45:\"Manage user accounts, roles, and permissions.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.watchdog',	'a:13:{s:4:\"uuid\";s:36:\"1d71a232-99d5-4253-868e-76836877a513\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"dblog\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SR5P89f0vUTPC7WY2YpLAffkDx8-Ar8LKFfowVXeqNU\";}s:2:\"id\";s:8:\"watchdog\";s:5:\"label\";s:8:\"Watchdog\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:19:\"Recent log messages\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"watchdog\";s:10:\"base_field\";s:3:\"wid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:19:\"Recent log messages\";s:6:\"fields\";a:8:{s:7:\"nothing\";a:22:{s:2:\"id\";s:7:\"nothing\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"nothing\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"Icon\";s:9:\"plugin_id\";s:6:\"custom\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:4:\"icon\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:0;}s:3:\"wid\";a:22:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:3:\"WID\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"severity\";a:23:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"machine_name\";s:5:\"label\";s:8:\"Severity\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"machine_name\";b:0;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:9:\"timestamp\";a:25:{s:2:\"id\";s:9:\"timestamp\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:9:\"timestamp\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"label\";s:4:\"Date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:7:\"message\";a:23:{s:2:\"id\";s:7:\"message\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:7:\"message\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:13:\"dblog_message\";s:5:\"label\";s:7:\"Message\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/reports/dblog/event/{{ wid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:13:\"{{ message }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:56;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:1;s:4:\"trim\";b:1;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:1;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"replace_variables\";b:1;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"User\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"link\";a:22:{s:2:\"id\";s:4:\"link\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"link\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"dblog_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"access site reports\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:4:\"area\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:26:\"No log messages available.\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:26:\"No log messages available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:3:\"wid\";a:10:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"wid\";}s:7:\"exposed\";b:0;}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:4:\"type\";a:14:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"dblog_types\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"severity\";a:14:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"in_operator\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"severity_op\";s:5:\"label\";s:8:\"Severity\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"severity_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"severity\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:25:\"{{ type }} {{ severity }}\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:7:\"nothing\";s:7:\"nothing\";s:3:\"wid\";s:3:\"wid\";s:8:\"severity\";s:8:\"severity\";s:4:\"type\";s:4:\"type\";s:9:\"timestamp\";s:9:\"timestamp\";s:7:\"message\";s:7:\"message\";s:4:\"name\";s:4:\"name\";s:4:\"link\";s:4:\"link\";}s:7:\"default\";s:3:\"wid\";s:4:\"info\";a:8:{s:7:\"nothing\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:3:\"wid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:8:\"severity\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"message\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:4:\"link\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:0;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"User\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:11:\"admin-dblog\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/reports/dblog\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.webform_submissions',	'a:13:{s:4:\"uuid\";s:36:\"5c298710-8d19-4662-a5cc-dcd249b03b1d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"user\";i:1;s:7:\"webform\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ndr5pjyhumlySBPBZtyaztiGbMUclmN32B3nTQ-FRqE\";}s:2:\"id\";s:19:\"webform_submissions\";s:5:\"label\";s:19:\"Webform submissions\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:34:\"Default webform submissions views.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:18:\"webform_submission\";s:10:\"base_field\";s:3:\"sid\";s:7:\"display\";a:5:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:14:\"items_per_page\";i:25;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:6:\"‹‹\";s:4:\"next\";s:6:\"››\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:23:\"5, 10, 25, 50, 100, 200\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;s:24:\"pagination_heading_level\";s:2:\"h4\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"fields\";a:5:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:7:\"filters\";a:0:{}s:5:\"sorts\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:0;s:7:\"content\";s:34:\"Displaying @start - @end of @total\";s:9:\"plugin_id\";s:6:\"result\";}}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"No submissions available.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:5:{s:10:\"webform_id\";a:6:{s:2:\"id\";s:10:\"webform_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"webform_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:10:\"webform_id\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"entity_type\";a:6:{s:2:\"id\";s:11:\"entity_type\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"entity_type\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"entity_type\";s:9:\"plugin_id\";s:6:\"string\";}s:9:\"entity_id\";a:6:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"entity_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:6:\"string\";}s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"uid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:7:\"numeric\";}s:8:\"in_draft\";a:22:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:14:\"items_per_page\";i:25;s:8:\"override\";b:0;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"numeric\";}}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"title\";s:19:\"Webform submissions\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:16:\"embed_administer\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:16:\"embed_administer\";s:13:\"display_title\";s:17:\"Embed: Administer\";s:8:\"position\";i:2;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:23:\"Administer submissions.\";s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:8:\"defaults\";a:6:{s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:29:\"administer webform submission\";}}s:6:\"fields\";a:9:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:10:\"operations\";a:25:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;s:11:\"entity_type\";N;s:12:\"entity_field\";N;s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:13:\"embed_default\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:13:\"embed_default\";s:13:\"display_title\";s:14:\"Embed: Default\";s:8:\"position\";i:1;s:15:\"display_options\";a:5:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:20:\"Display submissions.\";s:8:\"defaults\";a:5:{s:6:\"fields\";b:1;s:5:\"style\";b:0;s:3:\"row\";b:0;s:7:\"filters\";b:1;s:13:\"filter_groups\";b:1;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:5:{s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:7:\"created\";s:7:\"created\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:5:{s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_manage\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_manage\";s:13:\"display_title\";s:13:\"Embed: Manage\";s:8:\"position\";i:3;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Manage submissions.\";s:6:\"fields\";a:10:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:4:{i:0;s:35:\"webform_submission_make_lock_action\";i:1;s:37:\"webform_submission_make_sticky_action\";i:2;s:37:\"webform_submission_make_unlock_action\";i:3;s:39:\"webform_submission_make_unsticky_action\";}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}s:23:\"edit_webform_submission\";a:26:{s:2:\"id\";s:23:\"edit_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"edit_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"edit any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_review\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_review\";s:13:\"display_title\";s:13:\"Embed: Review\";s:8:\"position\";i:4;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Review submissions.\";s:6:\"fields\";a:8:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"view any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.who_s_new',	'a:13:{s:4:\"uuid\";s:36:\"a7f5e956-bb75-4caf-908d-26f2bf0d1ceb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zji0_13MyVGK7Bn1lUMDeZyyOIZedWvqpYUeM_SioPI\";}s:2:\"id\";s:9:\"who_s_new\";s:5:\"label\";s:9:\"Who\'s new\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:53:\"Shows a list of the newest user accounts on the site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:9:\"Who\'s new\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:5;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\">\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:10:\"1970-01-01\";s:4:\"type\";s:4:\"date\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:1:{s:4:\"type\";s:9:\"html_list\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:9:\"Who\'s new\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:19:\"A list of new users\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:9:\"Who\'s new\";s:14:\"block_category\";s:4:\"User\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.who_s_online',	'a:13:{s:4:\"uuid\";s:36:\"c473d286-cede-440e-97e5-6d2909d58b05\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"suDsVMgawXoQt4rfmdfpr05EVX3z3KyfDDTYgeSM898\";}s:2:\"id\";s:12:\"who_s_online\";s:5:\"label\";s:18:\"Who\'s online block\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:93:\"Shows the user names of the most recently active users, and the total number of active users.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:12:\"Who\'s online\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access user profiles\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:35:\"There are currently 0 users online.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:6:\"access\";a:13:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"access\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:2:\">=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:11:\"-15 minutes\";s:4:\"type\";s:6:\"offset\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:9:\"access_op\";s:5:\"label\";s:11:\"Last access\";s:11:\"description\";s:77:\"A user is considered online for this long after they have last viewed a page.\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"access_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"access\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"result\";s:5:\"empty\";b:0;s:7:\"content\";s:40:\"There are currently @total users online.\";}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:18:\"who_s_online_block\";a:6:{s:2:\"id\";s:18:\"who_s_online_block\";s:13:\"display_title\";s:12:\"Who\'s online\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:19:\"display_description\";s:45:\"A list of users that are currently logged in.\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:12:\"Who\'s online\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'webform.settings',	'a:20:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eZgcriT-utjDI1pjl-24jYFW2DmCxMXaFSnJd0XoU-0\";}s:8:\"settings\";a:73:{s:14:\"default_status\";s:4:\"open\";s:18:\"default_categories\";a:0:{}s:12:\"default_page\";b:1;s:22:\"default_page_base_path\";s:5:\"/form\";s:12:\"default_ajax\";b:0;s:19:\"default_ajax_effect\";s:4:\"fade\";s:18:\"default_ajax_speed\";i:500;s:26:\"default_ajax_progress_type\";s:8:\"throbber\";s:25:\"default_form_open_message\";s:49:\"This form has not yet been opened to submissions.\";s:26:\"default_form_close_message\";s:48:\"Sorry… This form is closed to new submissions.\";s:30:\"default_form_exception_message\";s:70:\"Unable to display this webform. Please contact the site administrator.\";s:27:\"default_submit_button_label\";s:6:\"Submit\";s:26:\"default_reset_button_label\";s:5:\"Reset\";s:27:\"default_delete_button_label\";s:6:\"Delete\";s:24:\"default_form_submit_once\";b:0;s:33:\"default_form_confidential_message\";s:135:\"This form is confidential. You must <a href=\"[site:login-url]/logout?destination=[current-page:url:relative]\">Log out</a> to submit it.\";s:34:\"default_form_access_denied_message\";s:34:\"Please log in to access this form.\";s:25:\"default_form_disable_back\";b:0;s:24:\"default_form_submit_back\";b:0;s:20:\"default_form_unsaved\";b:0;s:32:\"default_form_disable_remote_addr\";b:0;s:23:\"default_form_novalidate\";b:0;s:34:\"default_form_disable_inline_errors\";b:0;s:21:\"default_form_required\";b:0;s:27:\"default_form_required_label\";s:24:\"Indicates required field\";s:27:\"default_form_details_toggle\";b:1;s:23:\"default_form_file_limit\";s:0:\"\";s:12:\"form_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:14:\"button_classes\";s:0:\"\";s:32:\"default_wizard_prev_button_label\";s:10:\"< Previous\";s:32:\"default_wizard_next_button_label\";s:6:\"Next >\";s:26:\"default_wizard_start_label\";s:5:\"Start\";s:33:\"default_wizard_confirmation_label\";s:8:\"Complete\";s:32:\"default_wizard_toggle_show_label\";s:8:\"Show all\";s:32:\"default_wizard_toggle_hide_label\";s:8:\"Hide all\";s:33:\"default_preview_next_button_label\";s:7:\"Preview\";s:33:\"default_preview_prev_button_label\";s:10:\"< Previous\";s:21:\"default_preview_label\";s:7:\"Preview\";s:21:\"default_preview_title\";s:24:\"[webform:title]: Preview\";s:23:\"default_preview_message\";s:99:\"Please review your submission. Your submission is not complete until you press the \"Submit\" button!\";s:26:\"default_draft_button_label\";s:10:\"Save Draft\";s:27:\"default_draft_saved_message\";s:91:\"Submission saved. You may return to this form later and it will restore the current values.\";s:28:\"default_draft_loaded_message\";s:77:\"A partially-completed form was found. Please complete the remaining portions.\";s:36:\"default_draft_pending_single_message\";s:83:\"You have a pending draft for this webform. <a href=\"#\">Load your pending draft</a>.\";s:38:\"default_draft_pending_multiple_message\";s:83:\"You have pending drafts for this webform. <a href=\"#\">View your pending drafts</a>.\";s:28:\"default_confirmation_message\";s:40:\"New submission added to [webform:title].\";s:31:\"default_confirmation_back_label\";s:12:\"Back to form\";s:28:\"default_confirmation_noindex\";b:1;s:24:\"default_submission_label\";s:74:\"[webform_submission:submitted-to]: Submission #[webform_submission:serial]\";s:40:\"default_submission_access_denied_message\";s:40:\"Please log in to access this submission.\";s:36:\"default_submission_exception_message\";s:73:\"Unable to process this submission. Please contact the site administrator.\";s:33:\"default_submission_locked_message\";s:32:\"This submission has been locked.\";s:22:\"default_submission_log\";b:0;s:24:\"default_submission_views\";a:0:{}s:32:\"default_submission_views_replace\";a:3:{s:13:\"global_routes\";a:2:{i:0;s:36:\"entity.webform_submission.collection\";i:1;s:30:\"entity.webform_submission.user\";}s:14:\"webform_routes\";a:3:{i:0;s:34:\"entity.webform.results_submissions\";i:1;s:26:\"entity.webform.user.drafts\";i:2;s:31:\"entity.webform.user.submissions\";}s:11:\"node_routes\";a:3:{i:0;s:39:\"entity.node.webform.results_submissions\";i:1;s:31:\"entity.node.webform.user.drafts\";i:2;s:36:\"entity.node.webform.user.submissions\";}}s:25:\"default_results_customize\";b:0;s:35:\"default_previous_submission_message\";s:87:\"You have already submitted this webform. <a href=\"#\">View your previous submission</a>.\";s:36:\"default_previous_submissions_message\";s:88:\"You have already submitted this webform. <a href=\"#\">View your previous submissions</a>.\";s:24:\"default_autofill_message\";s:66:\"This submission has been autofilled with your previous submission.\";s:15:\"preview_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:20:\"confirmation_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:25:\"confirmation_back_classes\";s:7:\"button\n\";s:27:\"default_limit_total_message\";s:34:\"No more submissions are permitted.\";s:26:\"default_limit_user_message\";s:34:\"No more submissions are permitted.\";s:13:\"default_share\";b:0;s:18:\"default_share_node\";b:0;s:24:\"default_share_theme_name\";s:0:\"\";s:6:\"dialog\";b:0;s:14:\"dialog_options\";a:3:{s:6:\"narrow\";a:2:{s:5:\"title\";s:6:\"Narrow\";s:5:\"width\";i:600;}s:6:\"normal\";a:2:{s:5:\"title\";s:6:\"Normal\";s:5:\"width\";i:800;}s:4:\"wide\";a:2:{s:5:\"title\";s:4:\"Wide\";s:5:\"width\";i:1000;}}s:17:\"webform_bulk_form\";b:1;s:25:\"webform_bulk_form_actions\";a:5:{i:0;s:19:\"webform_open_action\";i:1;s:20:\"webform_close_action\";i:2;s:22:\"webform_archive_action\";i:3;s:24:\"webform_unarchive_action\";i:4;s:21:\"webform_delete_action\";}s:28:\"webform_submission_bulk_form\";b:1;s:36:\"webform_submission_bulk_form_actions\";a:5:{i:0;s:37:\"webform_submission_make_sticky_action\";i:1;s:39:\"webform_submission_make_unsticky_action\";i:2;s:35:\"webform_submission_make_lock_action\";i:3;s:37:\"webform_submission_make_unlock_action\";i:4;s:32:\"webform_submission_delete_action\";}}s:6:\"assets\";a:2:{s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";}s:7:\"handler\";a:1:{s:17:\"excluded_handlers\";a:0:{}}s:7:\"variant\";a:1:{s:17:\"excluded_variants\";a:0:{}}s:6:\"export\";a:18:{s:14:\"temp_directory\";s:0:\"\";s:8:\"exporter\";s:9:\"delimited\";s:18:\"multiple_delimiter\";s:1:\";\";s:13:\"header_format\";s:5:\"label\";s:13:\"header_prefix\";b:1;s:29:\"header_prefix_label_delimiter\";s:2:\": \";s:27:\"header_prefix_key_delimiter\";s:2:\"__\";s:29:\"composite_element_item_format\";s:5:\"label\";s:21:\"options_single_format\";s:7:\"compact\";s:23:\"options_multiple_format\";s:7:\"compact\";s:19:\"options_item_format\";s:5:\"label\";s:22:\"entity_reference_items\";a:3:{i:0;s:2:\"id\";i:1;s:5:\"title\";i:2;s:3:\"url\";}s:21:\"likert_answers_format\";s:5:\"label\";s:16:\"signature_format\";s:6:\"status\";s:9:\"delimiter\";s:1:\",\";s:5:\"excel\";b:0;s:12:\"archive_type\";s:3:\"tar\";s:18:\"excluded_exporters\";a:0:{}}s:5:\"batch\";a:5:{s:25:\"default_batch_export_size\";i:500;s:25:\"default_batch_import_size\";i:100;s:25:\"default_batch_update_size\";i:500;s:25:\"default_batch_delete_size\";i:500;s:24:\"default_batch_email_size\";i:500;}s:5:\"purge\";a:1:{s:9:\"cron_size\";i:100;}s:4:\"form\";a:3:{s:5:\"limit\";i:50;s:15:\"filter_category\";s:0:\"\";s:12:\"filter_state\";s:0:\"\";}s:7:\"element\";a:13:{s:20:\"machine_name_pattern\";s:7:\"a-z0-9_\";s:13:\"empty_message\";s:7:\"{Empty}\";s:12:\"allowed_tags\";s:5:\"admin\";s:15:\"wrapper_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:7:\"classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:23:\"horizontal_rule_classes\";s:286:\"webform-horizontal-rule--solid\nwebform-horizontal-rule--dashed\nwebform-horizontal-rule--dotted\nwebform-horizontal-rule--gradient\nwebform-horizontal-rule--thin\nwebform-horizontal-rule--medium\nwebform-horizontal-rule--thick\nwebform-horizontal-rule--flaired\nwebform-horizontal-rule--glyph\n\";s:27:\"default_description_display\";s:0:\"\";s:18:\"default_more_title\";s:4:\"More\";s:25:\"default_section_title_tag\";s:2:\"h2\";s:20:\"default_empty_option\";b:1;s:29:\"default_empty_option_required\";s:0:\"\";s:29:\"default_empty_option_optional\";s:0:\"\";s:17:\"excluded_elements\";a:2:{s:8:\"password\";s:8:\"password\";s:16:\"password_confirm\";s:16:\"password_confirm\";}}s:11:\"html_editor\";a:5:{s:8:\"disabled\";b:0;s:14:\"element_format\";s:15:\"webform_default\";s:11:\"mail_format\";s:15:\"webform_default\";s:4:\"tidy\";b:1;s:35:\"make_unused_managed_files_temporary\";b:1;}s:4:\"file\";a:11:{s:11:\"file_public\";b:0;s:21:\"file_private_redirect\";b:1;s:29:\"file_private_redirect_message\";s:42:\"Please log in to access the uploaded file.\";s:20:\"default_max_filesize\";s:0:\"\";s:31:\"default_managed_file_extensions\";s:148:\"gif jpg jpeg png bmp eps tif pict psd txt rtf html odf pdf doc docx ppt pptx xls xlsx xml avi mov mp3 mp4 ogg wav bz2 dmg gz jar rar sit svg tar zip\";s:29:\"default_audio_file_extensions\";s:11:\"mp3 ogg wav\";s:32:\"default_document_file_extensions\";s:50:\"txt rtf pdf doc docx odt ppt pptx odp xls xlsx ods\";s:29:\"default_image_file_extensions\";s:16:\"gif jpg jpeg png\";s:29:\"default_video_file_extensions\";s:24:\"avi mov mp4 ogg wav webm\";s:35:\"make_unused_managed_files_temporary\";b:1;s:30:\"delete_temporary_managed_files\";b:1;}s:6:\"format\";a:0:{}s:4:\"mail\";a:11:{s:15:\"default_to_mail\";s:11:\"[site:mail]\";s:17:\"default_from_mail\";s:11:\"[site:mail]\";s:17:\"default_from_name\";s:11:\"[site:name]\";s:16:\"default_reply_to\";s:0:\"\";s:19:\"default_return_path\";s:0:\"\";s:19:\"default_sender_mail\";s:0:\"\";s:19:\"default_sender_name\";s:0:\"\";s:15:\"default_subject\";s:58:\"Webform submission from: [webform_submission:source-title]\";s:17:\"default_body_text\";s:133:\"Submitted on [webform_submission:created]\nSubmitted by: [webform_submission:user]\n\nSubmitted values are:\n[webform_submission:values]\n\";s:17:\"default_body_html\";s:153:\"<p>Submitted on [webform_submission:created]</p>\n<p>Submitted by: [webform_submission:user]</p>\n<p>Submitted values are:</p>\n[webform_submission:values]\n\";s:5:\"roles\";a:0:{}}s:4:\"test\";a:2:{s:5:\"types\";s:3347:\"checkbox:\n  - true\ncolor:\n  - \'#ffffcc\'\n  - \'#ffffcc\'\n  - \'#ccffff\'\nemail:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nlanguage_select:\n  - en\nmachine_name:\n  - \'loremipsum\'\n  - \'oratione\'\n  - \'dixisset\'\ntel:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ntextarea:\n  - \'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.\'\n  - \'Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;\'\n  - \'Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.\'\ntext_format:\n  - value: \'<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.</p>\'\n  - value: \'<p>Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;</p>\'\n  - value: \'<p>Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.</p>\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\nwebform_email_confirm:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nwebform_email_multiple:\n  - \'example@example.com, test@test.com, random@random.com\'\nwebform_time:\n  - \'09:00\'\n  - \'17:00\'\n\";s:5:\"names\";s:547:\"first_name:\n  - \'John\'\n  - \'Paul\'\n  - \'Ringo\'\n  - \'George\'\nlast_name:\n  - \'Lennon\'\n  - \'McCartney\'\n  - \'Starr\'\n  - \'Harrison\'\naddress:\n  - \'10 Main Street\'\n  - \'11 Brook Alley Road. APT 1\'\nzip:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\npostal_code:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\nphone:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\nfax:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ncity:\n  - \'Springfield\'\n  - \'Pleasantville\'\n  - \'Hill Valley\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\ndefault:\n  - \'Loremipsum\'\n  - \'Oratione\'\n  - \'Dixisset\'\n\";}s:2:\"ui\";a:9:{s:13:\"video_display\";s:6:\"dialog\";s:12:\"details_save\";b:1;s:13:\"help_disabled\";b:0;s:15:\"dialog_disabled\";b:0;s:18:\"offcanvas_disabled\";b:0;s:19:\"promotions_disabled\";b:0;s:16:\"support_disabled\";b:0;s:16:\"description_help\";b:1;s:12:\"toolbar_item\";b:0;}s:9:\"libraries\";a:1:{s:18:\"excluded_libraries\";a:2:{i:0;s:7:\"choices\";i:1;s:13:\"jquery.chosen\";}}s:12:\"requirements\";a:4:{s:3:\"cdn\";b:1;s:9:\"bootstrap\";b:1;s:21:\"clientside_validation\";b:1;s:4:\"spam\";b:1;}s:8:\"langcode\";s:2:\"en\";s:20:\"third_party_settings\";a:1:{s:7:\"captcha\";a:1:{s:27:\"replace_administration_mode\";b:1;}}}'),
('',	'webform.webform.contact',	'a:22:{s:4:\"uuid\";s:36:\"cff12aaa-4fd4-49c9-bed0-2556200107e6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";s:4:\"open\";s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_je-MWeeJB6gfm6iECiqjcyNetfMFbn-YIInYwZ1gIk\";}s:4:\"open\";N;s:5:\"close\";N;s:6:\"weight\";i:0;s:3:\"uid\";N;s:8:\"template\";b:0;s:7:\"archive\";b:0;s:2:\"id\";s:7:\"contact\";s:5:\"title\";s:7:\"Contact\";s:11:\"description\";s:28:\"Basic email contact webform.\";s:10:\"categories\";a:0:{}s:8:\"elements\";s:566:\"name:\n  \'#title\': \'Your Name\'\n  \'#type\': textfield\n  \'#required\': true\n  \'#default_value\': \'[current-user:display-name]\'\nemail:\n  \'#title\': \'Your Email\'\n  \'#type\': email\n  \'#required\': true\n  \'#default_value\': \'[current-user:mail]\'\nsubject:\n  \'#title\': Subject\n  \'#type\': textfield\n  \'#required\': true\n  \'#test\': \'Testing contact webform from [site:name]\'\nmessage:\n  \'#title\': Message\n  \'#type\': textarea\n  \'#required\': true\n  \'#test\': \'Please ignore this email.\'\nactions:\n  \'#type\': webform_actions\n  \'#title\': \'Submit button(s)\'\n  \'#submit__label\': \'Send message\'\n\";s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";s:8:\"settings\";a:133:{s:4:\"ajax\";b:0;s:15:\"ajax_scroll_top\";s:4:\"form\";s:18:\"ajax_progress_type\";s:0:\"\";s:11:\"ajax_effect\";s:0:\"\";s:10:\"ajax_speed\";N;s:4:\"page\";b:1;s:16:\"page_submit_path\";s:0:\"\";s:17:\"page_confirm_path\";s:0:\"\";s:15:\"page_theme_name\";s:0:\"\";s:10:\"form_title\";s:21:\"source_entity_webform\";s:16:\"form_submit_once\";b:0;s:22:\"form_exception_message\";s:0:\"\";s:17:\"form_open_message\";s:0:\"\";s:18:\"form_close_message\";s:0:\"\";s:25:\"form_previous_submissions\";b:1;s:17:\"form_confidential\";b:0;s:25:\"form_confidential_message\";s:0:\"\";s:24:\"form_disable_remote_addr\";b:0;s:22:\"form_convert_anonymous\";b:0;s:16:\"form_prepopulate\";b:0;s:30:\"form_prepopulate_source_entity\";b:0;s:39:\"form_prepopulate_source_entity_required\";b:0;s:35:\"form_prepopulate_source_entity_type\";s:0:\"\";s:10:\"form_reset\";b:0;s:25:\"form_disable_autocomplete\";b:0;s:15:\"form_novalidate\";b:0;s:26:\"form_disable_inline_errors\";b:0;s:13:\"form_required\";b:0;s:12:\"form_unsaved\";b:0;s:17:\"form_disable_back\";b:0;s:16:\"form_submit_back\";b:0;s:14:\"form_autofocus\";b:0;s:19:\"form_details_toggle\";b:0;s:18:\"form_access_denied\";s:7:\"default\";s:24:\"form_access_denied_title\";s:0:\"\";s:26:\"form_access_denied_message\";s:0:\"\";s:29:\"form_access_denied_attributes\";a:0:{}s:15:\"form_file_limit\";s:0:\"\";s:11:\"form_method\";s:0:\"\";s:11:\"form_action\";s:0:\"\";s:15:\"form_attributes\";a:0:{}s:5:\"share\";b:0;s:10:\"share_node\";b:0;s:16:\"share_theme_name\";s:0:\"\";s:11:\"share_title\";b:1;s:26:\"share_page_body_attributes\";a:0:{}s:16:\"submission_label\";s:0:\"\";s:14:\"submission_log\";b:0;s:16:\"submission_views\";a:0:{}s:24:\"submission_views_replace\";a:0:{}s:23:\"submission_user_columns\";a:0:{}s:25:\"submission_user_duplicate\";b:0;s:24:\"submission_access_denied\";s:7:\"default\";s:30:\"submission_access_denied_title\";s:0:\"\";s:32:\"submission_access_denied_message\";s:0:\"\";s:35:\"submission_access_denied_attributes\";a:0:{}s:28:\"submission_exception_message\";s:0:\"\";s:25:\"submission_locked_message\";s:0:\"\";s:28:\"submission_excluded_elements\";a:0:{}s:24:\"submission_exclude_empty\";b:0;s:33:\"submission_exclude_empty_checkbox\";b:0;s:27:\"previous_submission_message\";s:0:\"\";s:28:\"previous_submissions_message\";s:0:\"\";s:8:\"autofill\";b:0;s:16:\"autofill_message\";s:0:\"\";s:26:\"autofill_excluded_elements\";a:0:{}s:19:\"wizard_progress_bar\";b:1;s:21:\"wizard_progress_pages\";b:0;s:26:\"wizard_progress_percentage\";b:0;s:20:\"wizard_progress_link\";b:0;s:22:\"wizard_progress_states\";b:0;s:19:\"wizard_auto_forward\";b:1;s:36:\"wizard_auto_forward_hide_next_button\";b:0;s:15:\"wizard_keyboard\";b:1;s:18:\"wizard_start_label\";s:0:\"\";s:19:\"wizard_preview_link\";b:0;s:19:\"wizard_confirmation\";b:1;s:25:\"wizard_confirmation_label\";s:0:\"\";s:12:\"wizard_track\";s:0:\"\";s:24:\"wizard_prev_button_label\";s:0:\"\";s:24:\"wizard_next_button_label\";s:0:\"\";s:13:\"wizard_toggle\";b:0;s:24:\"wizard_toggle_show_label\";s:0:\"\";s:24:\"wizard_toggle_hide_label\";s:0:\"\";s:16:\"wizard_page_type\";s:9:\"container\";s:21:\"wizard_page_title_tag\";s:2:\"h2\";s:7:\"preview\";i:0;s:13:\"preview_label\";s:0:\"\";s:13:\"preview_title\";s:0:\"\";s:15:\"preview_message\";s:0:\"\";s:18:\"preview_attributes\";a:0:{}s:25:\"preview_excluded_elements\";a:0:{}s:21:\"preview_exclude_empty\";b:1;s:30:\"preview_exclude_empty_checkbox\";b:0;s:5:\"draft\";s:4:\"none\";s:14:\"draft_multiple\";b:0;s:15:\"draft_auto_save\";b:0;s:19:\"draft_saved_message\";s:0:\"\";s:20:\"draft_loaded_message\";s:0:\"\";s:28:\"draft_pending_single_message\";s:0:\"\";s:30:\"draft_pending_multiple_message\";s:0:\"\";s:17:\"confirmation_type\";s:11:\"url_message\";s:18:\"confirmation_title\";s:0:\"\";s:20:\"confirmation_message\";s:27:\"Your message has been sent.\";s:16:\"confirmation_url\";s:7:\"<front>\";s:23:\"confirmation_attributes\";a:0:{}s:17:\"confirmation_back\";b:1;s:23:\"confirmation_back_label\";s:0:\"\";s:28:\"confirmation_back_attributes\";a:0:{}s:26:\"confirmation_exclude_query\";b:0;s:26:\"confirmation_exclude_token\";b:0;s:19:\"confirmation_update\";b:0;s:11:\"limit_total\";N;s:20:\"limit_total_interval\";N;s:19:\"limit_total_message\";s:0:\"\";s:18:\"limit_total_unique\";b:0;s:10:\"limit_user\";N;s:19:\"limit_user_interval\";N;s:18:\"limit_user_message\";s:0:\"\";s:17:\"limit_user_unique\";b:0;s:18:\"entity_limit_total\";N;s:27:\"entity_limit_total_interval\";N;s:17:\"entity_limit_user\";N;s:26:\"entity_limit_user_interval\";N;s:5:\"purge\";s:4:\"none\";s:10:\"purge_days\";N;s:16:\"results_disabled\";b:0;s:23:\"results_disabled_ignore\";b:0;s:17:\"results_customize\";b:0;s:10:\"token_view\";b:0;s:12:\"token_update\";b:0;s:12:\"token_delete\";b:0;s:15:\"serial_disabled\";b:0;}s:6:\"access\";a:11:{s:6:\"create\";a:3:{s:5:\"roles\";a:2:{i:0;s:9:\"anonymous\";i:1;s:13:\"authenticated\";}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:9:\"purge_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"administer\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:4:\"test\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:13:\"configuration\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}}s:8:\"handlers\";a:2:{s:18:\"email_confirmation\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email confirmation\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_confirmation\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:1;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:19:\"[current-user:mail]\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:8:\"_default\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:8:\"_default\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}s:18:\"email_notification\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email notification\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_notification\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:2;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:8:\"_default\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:37:\"[webform_submission:values:email:raw]\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:36:\"[webform_submission:values:name:raw]\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}}s:8:\"variants\";a:0:{}}'),
('',	'webform.webform_options.country_codes',	'a:10:{s:4:\"uuid\";s:36:\"ff13f706-a0ad-416d-9f29-9d2d43722997\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"adQ16YGDPk7QfUKrfrC35o2sKdHEozdNtdpiH7CftQQ\";}s:2:\"id\";s:13:\"country_codes\";s:5:\"label\";s:13:\"Country codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.country_names',	'a:10:{s:4:\"uuid\";s:36:\"e8e266de-5ba1-42b8-aab4-68928e91aea7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zsfFP124dAM-sJkuEfnwaA7DN6o3-IsaXLgdNmObbYg\";}s:2:\"id\";s:13:\"country_names\";s:5:\"label\";s:13:\"Country names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.days',	'a:10:{s:4:\"uuid\";s:36:\"e1a9a156-02bc-4ffe-b6cb-55c0d4da6931\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNrKbYrWWjeubUUM8AsQ19KnX7cU1elACR14CZJHmdg\";}s:2:\"id\";s:4:\"days\";s:5:\"label\";s:4:\"Days\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:121:\"Sunday: Sunday\nMonday: Monday\nTuesday: Tuesday\nWednesday: Wednesday\nThursday: Thursday\nFriday: Friday\nSaturday: Saturday\n\";}'),
('',	'webform.webform_options.education',	'a:10:{s:4:\"uuid\";s:36:\"f59dde6d-88c7-46f8-9148-aa56a18a13ba\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mII4acOv33s-j8PINywrCag4OITbeJGxdPO373dnHHw\";}s:2:\"id\";s:9:\"education\";s:5:\"label\";s:9:\"Education\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:152:\"High School: High School\nAssociate Degree: Associate Degree\nGraduate or Professional Degree: Graduate or Professional Degree\nSome College: Some College\n\";}'),
('',	'webform.webform_options.employment_status',	'a:10:{s:4:\"uuid\";s:36:\"369dc8ce-cc18-40ec-b90a-91c195e015af\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8MCmsz_csdJkVItxI8g_s4zp2PM285YqCy_gWTzOLPw\";}s:2:\"id\";s:17:\"employment_status\";s:5:\"label\";s:17:\"Employment status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:113:\"\'Full Time\': \'Full Time\'\n\'Part Time\': \'Part Time\'\n\'Military\': \'Military\'\nUnemployed: Unemployed\nRetired: Retired\n\";}'),
('',	'webform.webform_options.ethnicity',	'a:10:{s:4:\"uuid\";s:36:\"d8eb5c8c-04ba-44b0-83dd-5ab55746daa9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pIPgrAC82wE2GAk1mOv2UvMYv71YQe4VT8667QIYdvI\";}s:2:\"id\";s:9:\"ethnicity\";s:5:\"label\";s:9:\"Ethnicity\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:200:\"Caucasian: Caucasian\n\'Latino/Hispanic\': \'Latino/Hispanic\'\n\'Middle Eastern\': \'Middle Eastern\'\nAfrican: African\nCaribbean: Caribbean\n\'South Asian\': \'South Asian\'\n\'East Asian\': \'East Asian\'\nMixed: Mixed\n\";}'),
('',	'webform.webform_options.gender',	'a:10:{s:4:\"uuid\";s:36:\"8e01de6b-6df3-4ff4-857e-7f18c86dba94\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yxhG0JmQs2HT-Ro6ZeDQboDc9ZWR4GglflTtyoqxK4A\";}s:2:\"id\";s:6:\"gender\";s:5:\"label\";s:6:\"Gender\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:756:\"Man: Man\nWoman: Woman\nNon-binary: Non-binary\nAgender/Genderless: Agender/Genderless\nAndrogyne/Androgynous: Androgyne/Androgynous\nAporagender: Aporagender\nBigender: Bigender\nDemi-agender: Demi-agender\nDemi-boy: Demi-boy\nDemi-fluid: Demi-fluid\nDemi-girl: Demi-girl\nDemi-gender: Demi-gender\nDemi-non-binary: Demi-non-binary\nGenderqueer: Genderqueer\nGenderflux: Genderflux\nGenderfluid: Genderfluid\nGender-indifferent: Gender-indifferent\nGender-neutral: Gender-neutral\nGraygender: Graygender\nIntergender: Intergender\nMaverique: Maverique\nMaxigender: Maxigender\nMultigender/Polygender: Multigender/Polygender\nNeutrois: Neutrois\nPangender/Omnigender: Pangender/Omnigender\nTrigender: Trigender\nTwo-spirit: Two-spirit\n\'Prefer Not to Answer\': \'Prefer Not to Answer\'\n\";}'),
('',	'webform.webform_options.industry',	'a:10:{s:4:\"uuid\";s:36:\"a1a5d982-5911-4689-8e9d-779071e6f69c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"s_SXZn2HbRGvTex-TLOCxz2oOnMYqtEZh8HD4_318QI\";}s:2:\"id\";s:8:\"industry\";s:5:\"label\";s:8:\"Industry\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1425:\"Accounting/Finance: Accounting/Finance\nAdvertising/Public Relations: Advertising/Public Relations\nAerospace/Aviation: Aerospace/Aviation\nArts/Entertainment/Publishing: Arts/Entertainment/Publishing\nAutomotive: Automotive\nBanking/Mortgage: Banking/Mortgage\nBusiness Development: Business Development\nBusiness Opportunity: Business Opportunity\nClerical/Administrative: Clerical/Administrative\nConstruction/Facilities: Construction/Facilities\nConsumer Goods: Consumer Goods\nCustomer Service: Customer Service\nEducation/Training: Education/Training\nEnergy/Utilities: Energy/Utilities\nEngineering: Engineering\nGovernment/Military: Government/Military\nHealthcare: Healthcare\nHospitality/Travel: Hospitality/Travel\nHuman Resources: Human Resources\nInstallation/Maintenance: Installation/Maintenance\nInsurance: Insurance\nInternet: Internet\nLaw Enforcement/Security: Law Enforcement/Security\nLegal: Legal\nManagement/Executive: Management/Executive\nManufacturing/Operations: Manufacturing/Operations\nMarketing: Marketing\nNon-Profit/Volunteer: Non-Profit/Volunteer\nPharmaceutical/Biotech: Pharmaceutical/Biotech\nProfessional Services: Professional Services\nReal Estate: Real Estate\nRestaurant/Food Service: Restaurant/Food Service\nRetail: Retail\nSales: Sales\nScience/Research: Science/Research\nSkilled Labor: Skilled Labor\nTechnology: Technology\nTelecommunications: Telecommunications\nTransportation/Logistics: Transportation/Logistics\n\";}'),
('',	'webform.webform_options.languages',	'a:10:{s:4:\"uuid\";s:36:\"da44f184-15d8-46b2-9d27-67fdc87883fa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mYH14Vi65Ixj10c_GFa7CipxU3D0Bt9wgo8zE8zjOfE\";}s:2:\"id\";s:9:\"languages\";s:5:\"label\";s:9:\"Languages\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.likert_agreement',	'a:10:{s:4:\"uuid\";s:36:\"c1d3035e-7928-41e6-83cb-e5d35f1ddcff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nPp-CfMKrP0yDMtyO0wQRwawEqaJVAPzQapinXmDgyU\";}s:2:\"id\";s:16:\"likert_agreement\";s:5:\"label\";s:17:\"Likert: Agreement\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:71:\"1: Strongly Disagree\n2: Disagree\n3: Neutral\n4: Agree\n5: Strongly Agree\n\";}'),
('',	'webform.webform_options.likert_comparison',	'a:10:{s:4:\"uuid\";s:36:\"c9690189-5cda-402e-bc23-4fce4d34e427\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DMG4TKTHEXtHN8ho_sG_GiZHgweZ6nrRm6BAjk0LZ_Y\";}s:2:\"id\";s:17:\"likert_comparison\";s:5:\"label\";s:18:\"Likert: Comparison\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:84:\"1: Much Worse\n2: Somewhat Worse\n3: About the Same\n4: Somewhat Better\n5: Much Better\n\";}'),
('',	'webform.webform_options.likert_importance',	'a:10:{s:4:\"uuid\";s:36:\"120774df-f15f-4a67-b020-8ecedd3cff80\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hbc8n5HtVZVs5fSBSpSbuY07CVvqkKP76csvRHN9pK8\";}s:2:\"id\";s:17:\"likert_importance\";s:5:\"label\";s:18:\"Likert: Importance\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:88:\"1: Not at all Important\n2: Somewhat Important\n3: Neutral\n4: Important\n5: Very Important\n\";}'),
('',	'webform.webform_options.likert_quality',	'a:10:{s:4:\"uuid\";s:36:\"3f51980b-fdb6-4b07-a304-fb302af23c4d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swmYtBVUbwq7aHJWWDN7ODByuvur9vMkexDC9h64NZ8\";}s:2:\"id\";s:14:\"likert_quality\";s:5:\"label\";s:15:\"Likert: Quality\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:50:\"1: Poor\n2: Fair\n3: Good\n4: Very good\n5: Excellent\n\";}'),
('',	'webform.webform_options.likert_satisfaction',	'a:10:{s:4:\"uuid\";s:36:\"3fe1c8dc-5cd9-48b5-a783-23480e3742f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AKE2SNwCpl6Mu_cmbq9ZM2_cXxCikCVj1vcPE9oHWTs\";}s:2:\"id\";s:19:\"likert_satisfaction\";s:5:\"label\";s:20:\"Likert: Satisfaction\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:77:\"1: Very Unsatisfied\n2: Unsatisfied\n3: Neutral\n4: Satisfied\n5: Very Satisfied\n\";}'),
('',	'webform.webform_options.likert_ten_scale',	'a:10:{s:4:\"uuid\";s:36:\"3bce0633-cfe2-4f52-8625-00d8c7a98f35\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zEZX8JSVqznnFtqFfpuC593h3t1JDAZhF0Q3pvA229o\";}s:2:\"id\";s:16:\"likert_ten_scale\";s:5:\"label\";s:17:\"Likert: Ten Scale\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:52:\"1: 1\n2: 2\n3: 3\n4: 4\n5: 5\n6: 6\n7: 7\n8: 8\n9: 9\n10: 10\n\";}'),
('',	'webform.webform_options.likert_would_you',	'a:10:{s:4:\"uuid\";s:36:\"ac4202f9-992c-48ac-a36b-aa22452196bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qBS2TmfAJB37Qn3TnrNM8x4AWimmDapcizzRllgo0fo\";}s:2:\"id\";s:16:\"likert_would_you\";s:5:\"label\";s:17:\"Likert: Would You\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:72:\"1: Definitely Not\n2: Probably Not\n3: Not Sure\n4: Probably\n5: Definitely\n\";}'),
('',	'webform.webform_options.marital_status',	'a:10:{s:4:\"uuid\";s:36:\"197b61b7-7127-4713-9678-b79940b929ea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cjVDbAE5BlopGrY-tfxsxMoyEibwBBNgdQwDdxOSkow\";}s:2:\"id\";s:14:\"marital_status\";s:5:\"label\";s:14:\"Marital status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:68:\"Single: Single\nMarried: Married\nDivorced: Divorced\nWidowed: Widowed\n\";}'),
('',	'webform.webform_options.months',	'a:10:{s:4:\"uuid\";s:36:\"281e6e1e-5d64-459a-86ef-5c7109ebb0cf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pZJnuQkh9afNML5IcMuKTUC__vmHMFn66Qr5IWtedZ4\";}s:2:\"id\";s:6:\"months\";s:5:\"label\";s:6:\"Months\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:184:\"January: January\nFebruary: February\nMarch: March\nApril: April\nMay: May\nJune: June\nJuly: July\nAugust: August\nSeptember: September\nOctober: October\nNovember: November\nDecember: December\n\";}'),
('',	'webform.webform_options.phone_types',	'a:10:{s:4:\"uuid\";s:36:\"13d0d301-6f64-4c63-a190-cfa2990e9a48\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LkO63Zl2cP_l9YdjzWI8dWoD9uD0pytkPiUiUM2bo9A\";}s:2:\"id\";s:11:\"phone_types\";s:5:\"label\";s:10:\"Phone type\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:37:\"Home: Home\nOffice: Office\nCell: Cell\n\";}'),
('',	'webform.webform_options.province_codes',	'a:10:{s:4:\"uuid\";s:36:\"3dd5c388-df64-4a89-9710-1557394c6222\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cR3A6XXinVGC9g5vLS-vVvTC2ppZXRNXLPWA8xBUMew\";}s:2:\"id\";s:14:\"province_codes\";s:5:\"label\";s:14:\"Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:237:\"AB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),
('',	'webform.webform_options.province_names',	'a:10:{s:4:\"uuid\";s:36:\"db9cc306-a4c9-49d1-9f1a-af8959ae1569\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aaEeYBWoWETLKX2ivmZBpUAd3uPe2iPNydaxBuLPXKc\";}s:2:\"id\";s:14:\"province_names\";s:5:\"label\";s:14:\"Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:379:\"Alberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),
('',	'webform.webform_options.relationship',	'a:10:{s:4:\"uuid\";s:36:\"c451f0ba-7456-4e0e-b2fe-5ebbebf2e2a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4J2RPG4JmsD4Fm1NlIQY0JHkrJ08UUl0qTF0_EjUxvw\";}s:2:\"id\";s:12:\"relationship\";s:5:\"label\";s:12:\"Relationship\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:101:\"Parent: Parent\n\'Significant Other\': \'Significant Other\'\nSibling: Sibling\nChild: Child\nFriend: Friend\n\";}'),
('',	'webform.webform_options.sex',	'a:10:{s:4:\"uuid\";s:36:\"e26b351c-bbe3-491b-b4e5-0c8ec30decce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WRpxpwYpfcO_i0so7BV4QXxXlbPiSVppYmAV6DAz4c0\";}s:2:\"id\";s:3:\"sex\";s:5:\"label\";s:3:\"Sex\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:26:\"Male: Male\nFemale: Female\n\";}'),
('',	'webform.webform_options.sex_icao',	'a:10:{s:4:\"uuid\";s:36:\"b54122ee-eb6e-46b5-b89b-a3d6cbff2302\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9mxo86dMII5OxkHl4mbe2l4AgQloOXuErOte57BU9IY\";}s:2:\"id\";s:8:\"sex_icao\";s:5:\"label\";s:54:\"Sex - International Civil Aviation Organization (ICAO)\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:33:\"M: Male\nF: Female\nX: Unspecified\n\";}'),
('',	'webform.webform_options.size',	'a:10:{s:4:\"uuid\";s:36:\"c06bcacf-40d2-4c65-9f65-f5429245ed23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RKkc6tf1VudvYiOtwPCf3Tp_EoA6fov6BFC34D7gMoQ\";}s:2:\"id\";s:4:\"size\";s:5:\"label\";s:4:\"Size\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:91:\"Extra Small: Extra Small\nSmall: Small\nMedium: Medium\nLarge: Large\nExtra Large: Extra Large\n\";}'),
('',	'webform.webform_options.state_codes',	'a:10:{s:4:\"uuid\";s:36:\"86b1fb55-9ca7-480a-a333-ce541cefe1ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8mYO8ewsZX3LVfNga69jXa0RNO0LNN8-EGkXLhSAMBU\";}s:2:\"id\";s:11:\"state_codes\";s:5:\"label\";s:11:\"State codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:728:\"AL: Alabama\nAK: Alaska\nAZ: Arizona\nAR: Arkansas\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPA: Pennsylvania\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\n\";}'),
('',	'webform.webform_options.state_names',	'a:10:{s:4:\"uuid\";s:36:\"f50cd86e-1ce6-4e30-a74c-4aa2a46053b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KfYqMSrFJ5iGtDzvy_rGUeRUJ4KyM7Xt-tWtYx9WjiM\";}s:2:\"id\";s:11:\"state_names\";s:5:\"label\";s:11:\"State names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1081:\"Alabama: Alabama\nAlaska: Alaska\nArizona: Arizona\nArkansas: Arkansas\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\nFlorida: Florida\nGeorgia: Georgia\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPennsylvania: Pennsylvania\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\n\";}'),
('',	'webform.webform_options.state_province_codes',	'a:10:{s:4:\"uuid\";s:36:\"6c763985-59b0-49e1-a940-e76e2992edca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ziWv9xVss1UBnP_R38EqduZOprwOAifpxjXhyOPzmys\";}s:2:\"id\";s:20:\"state_province_codes\";s:5:\"label\";s:20:\"State/Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1241:\"AL: Alabama\nAK: Alaska\nAS: \'American Samoa\'\nAZ: Arizona\nAR: Arkansas\nAE: \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\nAA: \'Armed Forces Americas\'\nAP: \'Armed Forces Pacific\'\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFM: \'Federated States of Micronesia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMH: \'Marshall Islands\'\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nMP: \'Northern Mariana Islands\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPW: Palau\nPA: Pennsylvania\nPR: \'Puerto Rico\'\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVI: \'Virgin Islands\'\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\nAB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),
('',	'webform.webform_options.state_province_names',	'a:10:{s:4:\"uuid\";s:36:\"40521304-88f4-47f9-82bb-7eb8bc136320\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d4mxS_CxdzHZK4WaGQf1H3m-Uubm5HPbu9U4ydzscuo\";}s:2:\"id\";s:20:\"state_province_names\";s:5:\"label\";s:20:\"State/Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1953:\"Alabama: Alabama\nAlaska: Alaska\n\'American Samoa\': \'American Samoa\'\nArizona: Arizona\nArkansas: Arkansas\n\'Armed Forces (Canada, Europe, Africa, or Middle East)\': \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\n\'Armed Forces Americas\': \'Armed Forces Americas\'\n\'Armed Forces Pacific\': \'Armed Forces Pacific\'\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\n\'Federated States of Micronesia\': \'Federated States of Micronesia\'\nFlorida: Florida\nGeorgia: Georgia\nGuam: Guam\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\n\'Marshall Islands\': \'Marshall Islands\'\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\n\'Northern Mariana Islands\': \'Northern Mariana Islands\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPalau: Palau\nPennsylvania: Pennsylvania\n\'Puerto Rico\': \'Puerto Rico\'\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\n\'Virgin Islands\': \'Virgin Islands\'\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\nAlberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),
('',	'webform.webform_options.time_zones',	'a:10:{s:4:\"uuid\";s:36:\"34555c98-49f4-4d02-aca0-fa11a6f7e4b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8rVcRXLnTAEoWs7zl8du-7RIUnayqUcGYnvb3JT21-o\";}s:2:\"id\";s:10:\"time_zones\";s:5:\"label\";s:10:\"Time zones\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.titles',	'a:10:{s:4:\"uuid\";s:36:\"1c50e324-cb25-4578-8344-bd2266cbca89\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PEUoedWrfYEX7oZ8CcOukfBTVxar1cPSROX8534esuU\";}s:2:\"id\";s:6:\"titles\";s:5:\"label\";s:6:\"Titles\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:41:\"Miss: Miss\nMs: Ms\nMr: Mr\nMrs: Mrs\nDr: Dr\n\";}'),
('',	'webform.webform_options.translations',	'a:10:{s:4:\"uuid\";s:36:\"84bf246e-58a4-4bad-ad87-c1ffdd4a4be4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mb_L3vE-0IBZH5s2rjpk2LNn0QHClQP9AARQdCmVLt4\";}s:2:\"id\";s:12:\"translations\";s:5:\"label\";s:12:\"Translations\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.yes_no',	'a:10:{s:4:\"uuid\";s:36:\"a55ca564-ba76-4d06-b838-79a72132103a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W88NYg31DbaVNQx1Uir_dwwXHVtF09QOq4VBGsH1Snk\";}s:2:\"id\";s:6:\"yes_no\";s:5:\"label\";s:6:\"Yes/No\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:16:\"Yes: Yes\nNo: No\n\";}');

DROP TABLE IF EXISTS `config_import`;
CREATE TABLE `config_import` (
  `collection` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object collection.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Config object name.',
  `data` longblob COMMENT 'A serialized configuration object data.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for configuration data.';

INSERT INTO `config_import` (`collection`, `name`, `data`) VALUES
('',	'admin_toolbar.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvTSppzcgH5wnzBhX5xnAExcp2I1CzkQ_aky65XNfYI\";}s:10:\"menu_depth\";i:4;}'),
('',	'admin_toolbar_tools.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WgdZsrd_5w9jlmcHV4R9dD2tG9OZEkYo4I_O8h7Gq8Q\";}s:17:\"max_bundle_number\";i:20;s:25:\"hoverintent_functionality\";b:1;s:16:\"show_local_tasks\";b:0;}'),
('',	'announcements_feed.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0G5pZBcxbg8ONYzNLd1RJIsvuFFewm9htnS4I-ABKJ8\";}s:7:\"max_age\";i:86400;s:13:\"cron_interval\";i:21600;s:5:\"limit\";i:10;}'),
('',	'automated_cron.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fUksROt4FfkAU9BV4hV2XvhTBSS2nTNrZS4U7S-tKrs\";}s:8:\"interval\";i:10800;}'),
('',	'block.block.claro_breadcrumbs',	'a:13:{s:4:\"uuid\";s:36:\"d1a331f5-0df6-469b-9594-7d62381385aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NjcxOBrPOiK5-38t56DwFBDVY4yer7YSlbRWXFuHe7A\";}s:2:\"id\";s:17:\"claro_breadcrumbs\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_content',	'a:13:{s:4:\"uuid\";s:36:\"40baaa9b-4ebb-41cb-a0f8-9438fc1633e2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a0Yyx1GeyKarZ4T_yXQBR_ZFKnXiFLtxAb6gWLd8nr0\";}s:2:\"id\";s:13:\"claro_content\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_help',	'a:13:{s:4:\"uuid\";s:36:\"e609269b-1f74-4c6d-8adc-b242386187c9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jccFSSVqV0WCDb6NtML1VWAWTtDbZ-zn5YgTRMgMrIM\";}s:2:\"id\";s:10:\"claro_help\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_help_search',	'a:13:{s:4:\"uuid\";s:36:\"642a14ba-b7f3-4788-b6d7-7ec847635558\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"module\";a:2:{i:0;s:6:\"search\";i:1;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}s:8:\"enforced\";a:1:{s:6:\"config\";a:1:{i:0;s:23:\"search.page.help_search\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2ToeZLvlHKTeFY74gpgu1PejLoFyCECLO_gw6rAZwqw\";}s:2:\"id\";s:17:\"claro_help_search\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:4:\"help\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:11:\"Search help\";s:13:\"label_display\";s:7:\"visible\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:11:\"help_search\";}s:10:\"visibility\";a:1:{s:12:\"request_path\";a:4:{s:2:\"id\";s:12:\"request_path\";s:6:\"negate\";b:0;s:15:\"context_mapping\";a:0:{}s:5:\"pages\";s:11:\"/admin/help\";}}}'),
('',	'block.block.claro_local_actions',	'a:13:{s:4:\"uuid\";s:36:\"b9fe9f3b-f277-4a5a-a681-c952b93cbf81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CdXfDmRgAvms7EQovxxWPdYi0GitxeRbVtScYK16ZH0\";}s:2:\"id\";s:19:\"claro_local_actions\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:-10;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_messages',	'a:13:{s:4:\"uuid\";s:36:\"58d2b9f3-0bea-4a38-88ec-fdb62db9ccb4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-Ac3ISpIT0PQ-whzD7_dw0SdKi6dAbRFNWdSjOiVDqg\";}s:2:\"id\";s:14:\"claro_messages\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_page_title',	'a:13:{s:4:\"uuid\";s:36:\"ecc6ef43-9d4c-491e-a458-7b4ac180124d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fNwDdW063tk_ktzSWzZVeQS9wzvLooVO280BQ9WrsIs\";}s:2:\"id\";s:16:\"claro_page_title\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:-30;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_primary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"d47ee844-8c65-44d3-85c0-510835e982ac\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ACjBZI5shAMiiUpsz-inLYVXDqNNXRnSzAWV3kV_8Hw\";}s:2:\"id\";s:25:\"claro_primary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.claro_secondary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"f080d7bf-33c8-49e4-a29b-4f78db0f7c2c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:5:\"claro\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2L0geP-ixCbCkEpW6BVF6H7vDUZN4ea07_Y9CociQm4\";}s:2:\"id\";s:27:\"claro_secondary_local_tasks\";s:5:\"theme\";s:5:\"claro\";s:6:\"region\";s:11:\"pre_content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_account_menu',	'a:13:{s:4:\"uuid\";s:36:\"217ad55d-fd7d-4ae4-8bda-6030889a03b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:19:\"system.menu.account\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gmxYWWHmgbe0Pnv8y48ZLSLH5mEHejOjAP6RLxUfdzU\";}s:2:\"id\";s:20:\"olivero_account_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:25:\"system_menu_block:account\";s:8:\"settings\";a:7:{s:2:\"id\";s:25:\"system_menu_block:account\";s:5:\"label\";s:17:\"User account menu\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:1;s:16:\"expand_all_items\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_breadcrumbs',	'a:13:{s:4:\"uuid\";s:36:\"064ecc20-9718-4137-8404-bb79862b5dbe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VhBzWb7lMRtIOg9G7VSw_0uopi-7zXeHq4vXqqV1HFE\";}s:2:\"id\";s:19:\"olivero_breadcrumbs\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:10:\"breadcrumb\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_breadcrumb_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_breadcrumb_block\";s:5:\"label\";s:11:\"Breadcrumbs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_content',	'a:13:{s:4:\"uuid\";s:36:\"b76437ff-efaf-4c97-84ca-ae001d11fa96\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"erQSEZF2XUjNmgTl0uNRBzmg18ZGXwUcw2FhApoeuHk\";}s:2:\"id\";s:15:\"olivero_content\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:7:\"content\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"system_main_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:17:\"system_main_block\";s:5:\"label\";s:17:\"Main page content\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_help',	'a:13:{s:4:\"uuid\";s:36:\"53d20db2-085f-49cb-b889-bfcda4fdc4f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfPFqqxfkomud5CO8DUijw85QIl9GIxh_nIxLOYESxg\";}s:2:\"id\";s:12:\"olivero_help\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:10:\"help_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:10:\"help_block\";s:5:\"label\";s:4:\"Help\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"help\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_main_menu',	'a:13:{s:4:\"uuid\";s:36:\"0cd82e10-9f40-455e-9bc5-67bba0594412\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KWAiziL39uEzmOJEql_wbUP2RtqGceL3WM2CfxhMelE\";}s:2:\"id\";s:17:\"olivero_main_menu\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:22:\"system_menu_block:main\";s:8:\"settings\";a:7:{s:2:\"id\";s:22:\"system_menu_block:main\";s:5:\"label\";s:15:\"Main navigation\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:5:\"level\";i:1;s:5:\"depth\";i:2;s:16:\"expand_all_items\";b:1;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_messages',	'a:13:{s:4:\"uuid\";s:36:\"f259c98a-a416-406b-8df1-73b20ade139d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BZ5tpW7H8X4PVGRm3MImTIHd2tN0eF7zOtp4SpRYUA0\";}s:2:\"id\";s:16:\"olivero_messages\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_messages_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:21:\"system_messages_block\";s:5:\"label\";s:15:\"Status messages\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_page_title',	'a:13:{s:4:\"uuid\";s:36:\"592b2a14-a8fb-40ab-af13-fad4757b447c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6aOgWsNTXjqrDm98TXSAjP6qd2nCijD1xw45MrnbK-Y\";}s:2:\"id\";s:18:\"olivero_page_title\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"content_above\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:16:\"page_title_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:16:\"page_title_block\";s:5:\"label\";s:10:\"Page title\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_powered',	'a:13:{s:4:\"uuid\";s:36:\"3aa71fac-64b6-42f2-8b3d-0feb4a6f805e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eYL19CLDyinGTWYQfBD1DswWzglEotE_kHnHx3AxTXM\";}s:2:\"id\";s:15:\"olivero_powered\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:13:\"footer_bottom\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:23:\"system_powered_by_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:23:\"system_powered_by_block\";s:5:\"label\";s:17:\"Powered by Drupal\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_primary_admin_actions',	'a:13:{s:4:\"uuid\";s:36:\"f3ae5ab3-e08f-4d92-8238-c0346ead125d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q9_2whdOj1YIomfvsIfopROW4FT_X5pY0DjdOiOaQ5U\";}s:2:\"id\";s:29:\"olivero_primary_admin_actions\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:19:\"local_actions_block\";s:8:\"settings\";a:4:{s:2:\"id\";s:19:\"local_actions_block\";s:5:\"label\";s:21:\"Primary admin actions\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_primary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"869275af-a038-43a0-aec0-55d644632865\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nGE3EoPQQaQCuqTUtZgw0-KIzmrqdKDzdNQf2JyPUt4\";}s:2:\"id\";s:27:\"olivero_primary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:12:\"Primary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:1;s:9:\"secondary\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_search_form_narrow',	'a:13:{s:4:\"uuid\";s:36:\"1895f221-afd5-4f39-946d-175efff616ba\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yEBET0cqDbk8dkWzaJw-8CKft0961VBflsISoSR6Lj8\";}s:2:\"id\";s:26:\"olivero_search_form_narrow\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:12:\"primary_menu\";s:6:\"weight\";i:-4;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:20:\"Search form (narrow)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_search_form_wide',	'a:13:{s:4:\"uuid\";s:36:\"10f91465-91e8-4b68-9b23-c26342c32145\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"search\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"imMyHD6LYci0gtXq56qr9ZKGHzbEG9uFydrN5EhKtSU\";}s:2:\"id\";s:24:\"olivero_search_form_wide\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:14:\"secondary_menu\";s:6:\"weight\";i:-5;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"search_form_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:17:\"search_form_block\";s:5:\"label\";s:18:\"Search form (wide)\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"search\";s:7:\"page_id\";s:0:\"\";}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_secondary_local_tasks',	'a:13:{s:4:\"uuid\";s:36:\"a425651d-4bbc-4735-b403-60eedd891c6d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ydSxdq7R66I8UMC460rOzlfzvlUL4VRbdwc6z9DWaUI\";}s:2:\"id\";s:29:\"olivero_secondary_local_tasks\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:11:\"highlighted\";s:6:\"weight\";i:-2;s:8:\"provider\";N;s:6:\"plugin\";s:17:\"local_tasks_block\";s:8:\"settings\";a:6:{s:2:\"id\";s:17:\"local_tasks_block\";s:5:\"label\";s:14:\"Secondary tabs\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"core\";s:7:\"primary\";b:0;s:9:\"secondary\";b:1;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_site_branding',	'a:13:{s:4:\"uuid\";s:36:\"9826d68e-9bcc-4b43-9656-f3d5f0c60619\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:6:\"system\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n_nlgjggHVfQt2H__zvLOKB2YtjPDbQ5tHijF9LE1aM\";}s:2:\"id\";s:21:\"olivero_site_branding\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"header\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:21:\"system_branding_block\";s:8:\"settings\";a:7:{s:2:\"id\";s:21:\"system_branding_block\";s:5:\"label\";s:13:\"Site branding\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:6:\"system\";s:13:\"use_site_logo\";b:1;s:13:\"use_site_name\";b:1;s:15:\"use_site_slogan\";b:0;}s:10:\"visibility\";a:0:{}}'),
('',	'block.block.olivero_syndicate',	'a:13:{s:4:\"uuid\";s:36:\"d4871bcb-88ea-4b21-8c89-7e1c3151ed0b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0gq3VPg-_UM69FCCWurLFIrrnIjC2HLKhwo9iQNtcUo\";}s:2:\"id\";s:17:\"olivero_syndicate\";s:5:\"theme\";s:7:\"olivero\";s:6:\"region\";s:6:\"social\";s:6:\"weight\";i:0;s:8:\"provider\";N;s:6:\"plugin\";s:20:\"node_syndicate_block\";s:8:\"settings\";a:5:{s:2:\"id\";s:20:\"node_syndicate_block\";s:5:\"label\";s:8:\"RSS feed\";s:13:\"label_display\";s:1:\"0\";s:8:\"provider\";s:4:\"node\";s:11:\"block_count\";i:10;}s:10:\"visibility\";a:0:{}}'),
('',	'block_content.type.basic',	'a:9:{s:4:\"uuid\";s:36:\"8d0c7ff5-11fa-497e-b1cb-232bad118b10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQP5iQy4SdhAMVcjDUncCfkJmTofnHVtXrsMzx4k6Yk\";}s:2:\"id\";s:5:\"basic\";s:5:\"label\";s:11:\"Basic block\";s:8:\"revision\";b:0;s:11:\"description\";s:42:\"A basic block contains a title and a body.\";}'),
('',	'block_content.type.ebt_accordion',	'a:9:{s:4:\"uuid\";s:36:\"532936a4-d4ec-4684-97d3-ea06263ffdfe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dB47Zxr808aSXzelLxShTOImxLGvz9ibkaPpIHw2XL8\";}s:2:\"id\";s:13:\"ebt_accordion\";s:5:\"label\";s:17:\"EBT Accordion/FAQ\";s:8:\"revision\";i:1;s:11:\"description\";s:37:\"Extra Block Type (EBT): Accordion/FAQ\";}'),
('',	'block_content.type.ebt_basic_button',	'a:9:{s:4:\"uuid\";s:36:\"5f0bd962-43f3-4e4c-9dad-bd8ad9ad83bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eTgR86D-XlSSjL0DOkUgyDx9iqTLZCeiiE1Wz1CNl8o\";}s:2:\"id\";s:16:\"ebt_basic_button\";s:5:\"label\";s:16:\"EBT Basic Button\";s:8:\"revision\";i:0;s:11:\"description\";s:36:\"Extra Block Type (EBT): Basic Button\";}'),
('',	'block_content.type.ebt_block',	'a:9:{s:4:\"uuid\";s:36:\"a5b41dbb-434a-4f8f-aa0f-413c4cc768db\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nKr_tXmEQ2IE6yATLpR_w5SQeEqQCm6SSKpCMIx2hKo\";}s:2:\"id\";s:9:\"ebt_block\";s:5:\"label\";s:9:\"EBT Block\";s:8:\"revision\";i:0;s:11:\"description\";s:33:\"Extra Block Type (EBT): EBT Block\";}'),
('',	'block_content.type.ebt_bootstrap_button',	'a:9:{s:4:\"uuid\";s:36:\"9575961f-7777-487f-988c-3898cad5f5b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EPwbWyfVd_vUMqmDcQcJd9ww6p2h7kUQTny9S5dPxXQ\";}s:2:\"id\";s:20:\"ebt_bootstrap_button\";s:5:\"label\";s:20:\"EBT Bootstrap Button\";s:8:\"revision\";i:0;s:11:\"description\";s:40:\"Extra Block Type (EBT): Bootstrap Button\";}'),
('',	'block_content.type.ebt_carousel',	'a:9:{s:4:\"uuid\";s:36:\"a8e8c97d-abf8-4a95-a638-a6a54e403d91\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DXQisXm71ScIY9qHGkk7imRMnjI_dBDSZfzT-uFCzwQ\";}s:2:\"id\";s:12:\"ebt_carousel\";s:5:\"label\";s:12:\"EBT Carousel\";s:8:\"revision\";i:1;s:11:\"description\";s:32:\"Extra Block Type (EBT): Carousel\";}'),
('',	'block_content.type.ebt_columns',	'a:9:{s:4:\"uuid\";s:36:\"31aff369-3823-4bb0-93db-1bca2acd3aa3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CQSPoVI2zOeWs7Xgd9ALoKdgcYScRjwZQK17EBkHKX4\";}s:2:\"id\";s:11:\"ebt_columns\";s:5:\"label\";s:23:\"EBT Columns / Container\";s:8:\"revision\";i:0;s:11:\"description\";s:47:\"Extra Block Type (EBT): EBT Columns / Container\";}'),
('',	'block_content.type.ebt_countdown',	'a:9:{s:4:\"uuid\";s:36:\"17c62d51-6c7f-493f-85b4-fce54035fcf7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"b04bwlmhn4qM9mk46Hq1ekInijGgB9DI7WydX2K6RJg\";}s:2:\"id\";s:13:\"ebt_countdown\";s:5:\"label\";s:13:\"EBT Countdown\";s:8:\"revision\";i:0;s:11:\"description\";s:37:\"Extra Block Type (EBT): EBT Countdown\";}'),
('',	'block_content.type.ebt_counter',	'a:9:{s:4:\"uuid\";s:36:\"f84bf2c7-0d7f-45e5-9e44-618e1cb84f84\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BAdc_syLOJWN_IuQiwJb7kdzLXXokTLaEplzy8ajUBs\";}s:2:\"id\";s:11:\"ebt_counter\";s:5:\"label\";s:11:\"EBT Counter\";s:8:\"revision\";i:0;s:11:\"description\";s:100:\"Extra Block Type (EBT): Counter - Adds Counter with coffee cups, projects, case studies number, etc.\";}'),
('',	'block_content.type.ebt_cta',	'a:9:{s:4:\"uuid\";s:36:\"1a560148-0ddc-4fe6-a137-e201e64082d5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k9yRFHPv-0cHC5GXpNilObPbaFf1SBRHn-asOPpDpPA\";}s:2:\"id\";s:7:\"ebt_cta\";s:5:\"label\";s:24:\"EBT Call to Action (CTA)\";s:8:\"revision\";i:1;s:11:\"description\";s:44:\"Extra Block Type (EBT): Call to Action (CTA)\";}'),
('',	'block_content.type.ebt_hero',	'a:9:{s:4:\"uuid\";s:36:\"19fbd216-4f28-4209-a30c-bddd372736ae\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UndgTjioHDq7754rxxFxg1qIXgj6xzvZ2292BZOTduY\";}s:2:\"id\";s:8:\"ebt_hero\";s:5:\"label\";s:8:\"EBT Hero\";s:8:\"revision\";i:1;s:11:\"description\";s:28:\"Extra Block Type (EBT): Hero\";}'),
('',	'block_content.type.ebt_image',	'a:9:{s:4:\"uuid\";s:36:\"9fd85032-8853-4ccb-8f84-451d84cc570c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XzIeU-QRNHX9yTHUrG3pAtW39sABFIN32xzM5Roe_Zs\";}s:2:\"id\";s:9:\"ebt_image\";s:5:\"label\";s:9:\"EBT Image\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Image\";}'),
('',	'block_content.type.ebt_image_gallery',	'a:9:{s:4:\"uuid\";s:36:\"61358808-828f-49a0-a1fc-850ba4856b25\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hyvESyE2V701OB-pYMNV1fcs9afHHvGMwmKvID2dSys\";}s:2:\"id\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:17:\"EBT Image Gallery\";s:8:\"revision\";i:0;s:11:\"description\";s:37:\"Extra Block Type (EBT): Image Gallery\";}'),
('',	'block_content.type.ebt_micromodal',	'a:9:{s:4:\"uuid\";s:36:\"49a7d1d2-299c-43f7-8353-442f7c80126a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yHkIKUcC5OaWnPM6t0NLrROJ_Qie3lZd1nYZCnncyxQ\";}s:2:\"id\";s:14:\"ebt_micromodal\";s:5:\"label\";s:14:\"EBT Micromodal\";s:8:\"revision\";i:0;s:11:\"description\";s:34:\"Extra Block Type (EBT): Micromodal\";}'),
('',	'block_content.type.ebt_quote',	'a:9:{s:4:\"uuid\";s:36:\"6c094884-55e1-4ce3-9782-8302e193358e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"R3qZ2pP9HUZZOVzX7J5oHroNb9W2pfSWulgYrgRbm4g\";}s:2:\"id\";s:9:\"ebt_quote\";s:5:\"label\";s:9:\"EBT Quote\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Quote\";}'),
('',	'block_content.type.ebt_slick_slider',	'a:9:{s:4:\"uuid\";s:36:\"fe1604e8-b328-4b89-bd85-fc64bd553f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dHxKwXfScnz1cdiQPDzE2uUuw62lhpTtSqV5b2YZbrE\";}s:2:\"id\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:16:\"EBT Slick Slider\";s:8:\"revision\";i:0;s:11:\"description\";s:36:\"Extra Block Type (EBT): Slick Slider\";}'),
('',	'block_content.type.ebt_slideshow',	'a:9:{s:4:\"uuid\";s:36:\"7d164bb3-5e33-440f-b644-b566e1827e32\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W-lXlcGHuv4qnJqSIhwhzbs7aE2_VKhpa9-wZzfr-1A\";}s:2:\"id\";s:13:\"ebt_slideshow\";s:5:\"label\";s:13:\"EBT Slideshow\";s:8:\"revision\";i:0;s:11:\"description\";s:33:\"Extra Block Type (EBT): Slideshow\";}'),
('',	'block_content.type.ebt_stats',	'a:9:{s:4:\"uuid\";s:36:\"3e06d945-9c14-4d86-add4-87ce46604987\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MYrjSAxOpL7yIgF7efseTPdxreHwdIytokEU8AsyKOc\";}s:2:\"id\";s:9:\"ebt_stats\";s:5:\"label\";s:9:\"EBT Stats\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Stats\";}'),
('',	'block_content.type.ebt_tabs',	'a:9:{s:4:\"uuid\";s:36:\"a548c9cd-2123-460d-ac7a-3776cbd6628d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2Zf0IzYoN8bXlbuz0O0K2EFPtAJ-8Zgijs9KDbMjPbU\";}s:2:\"id\";s:8:\"ebt_tabs\";s:5:\"label\";s:8:\"EBT Tabs\";s:8:\"revision\";i:1;s:11:\"description\";s:28:\"Extra Block Type (EBT): Tabs\";}'),
('',	'block_content.type.ebt_text',	'a:9:{s:4:\"uuid\";s:36:\"4d70b021-1215-4212-93ff-3a65cfe166f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EfDKjvl4An381lwiUletrxyYGHVSXr0ylsIz7wG4FkM\";}s:2:\"id\";s:8:\"ebt_text\";s:5:\"label\";s:8:\"EBT Text\";s:8:\"revision\";i:1;s:11:\"description\";s:40:\"Adds Text block type with WYSIWYG editor\";}'),
('',	'block_content.type.ebt_tiles',	'a:9:{s:4:\"uuid\";s:36:\"a4695763-bb05-45b7-877a-2988bc9c0c68\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7NM6NtKtRJqDl2LKF2ttqtshhXn4nV3DIIr56XEhBGw\";}s:2:\"id\";s:9:\"ebt_tiles\";s:5:\"label\";s:9:\"EBT Tiles\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Tiles\";}'),
('',	'block_content.type.ebt_timeline',	'a:9:{s:4:\"uuid\";s:36:\"8299bf83-c3a5-401f-a1b8-bf9bb009af40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bjr_DHRSS1dmovJ9hu9PkQkEIHfJ9wcHbVFuexiFC7I\";}s:2:\"id\";s:12:\"ebt_timeline\";s:5:\"label\";s:12:\"EBT Timeline\";s:8:\"revision\";i:0;s:11:\"description\";s:32:\"Extra Block Type (EBT): Timeline\";}'),
('',	'block_content.type.ebt_video',	'a:9:{s:4:\"uuid\";s:36:\"f30a12fb-b405-4036-a46f-fc82d5b577e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Pv_CZ1UneLNgz_a4bh6MvN5tmAbmgeaL-sIZl2WyaP0\";}s:2:\"id\";s:9:\"ebt_video\";s:5:\"label\";s:9:\"EBT Video\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Video\";}'),
('',	'block_content.type.ebt_video_and_image_gallery',	'a:9:{s:4:\"uuid\";s:36:\"c8e02878-ad67-4c1d-8022-1bcae43b1e10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t5QqFRQehMUNqFlizm8etvw0z1ASVYieiYTD5A-AMwM\";}s:2:\"id\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:27:\"EBT Video and Image Gallery\";s:8:\"revision\";i:0;s:11:\"description\";s:47:\"Extra Block Type (EBT): Video and Image Gallery\";}'),
('',	'block_content.type.ebt_views',	'a:9:{s:4:\"uuid\";s:36:\"6eb11d1d-b72a-4d76-a761-9c91bacf5654\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kKtLeF4r10QhfrqB_NLR_pg7hmb7wKFxIx53f6SPZPM\";}s:2:\"id\";s:9:\"ebt_views\";s:5:\"label\";s:9:\"EBT Views\";s:8:\"revision\";i:0;s:11:\"description\";s:29:\"Extra Block Type (EBT): Views\";}'),
('',	'block_content.type.ebt_webform',	'a:9:{s:4:\"uuid\";s:36:\"656280fa-6df7-4fb1-97e2-0fba6d8acda7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N2h4kIizWCZkC89K2_Xf6_WGzjG-9XpMDds_jEJjsGs\";}s:2:\"id\";s:11:\"ebt_webform\";s:5:\"label\";s:11:\"EBT Webform\";s:8:\"revision\";i:0;s:11:\"description\";s:35:\"Extra Paragraph Type (EPT): Webform\";}'),
('',	'block_content.type.ebt_webform_popup',	'a:9:{s:4:\"uuid\";s:36:\"3f1d7aa5-63b0-4cf5-8b1e-c69f240e9a70\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2PyweimMCiXZdcfL7o3WT6DPFw8x8O1FPQfufWOKf5A\";}s:2:\"id\";s:17:\"ebt_webform_popup\";s:5:\"label\";s:17:\"EBT Webform Popup\";s:8:\"revision\";i:0;s:11:\"description\";s:37:\"Extra Block Type (EBT): Webform Popup\";}'),
('',	'claro.settings',	'a:1:{s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}}'),
('',	'config_ignore.settings',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IgOVnECx6lbVt6JVFnadoEEugneDf3UblPZnOzov43Q\";}s:4:\"mode\";s:6:\"simple\";s:23:\"ignored_config_entities\";a:0:{}}'),
('',	'contact.form.feedback',	'a:12:{s:4:\"uuid\";s:36:\"816a1630-e792-4f5c-a26b-35e17703bb04\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vymHlgJy26BuI5GGj9-IXjwR3dRC5C0tij4BpWJnoqw\";}s:2:\"id\";s:8:\"feedback\";s:5:\"label\";s:16:\"Website feedback\";s:10:\"recipients\";a:1:{i:0;s:17:\"admin@example.com\";}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),
('',	'contact.form.personal',	'a:12:{s:4:\"uuid\";s:36:\"6c8348fa-3a53-48ce-ac8f-7aa4d1c5c9cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jonvgt3CkUM2eMLTFwWfHileWWDC4YtXCuIlCahTk_I\";}s:2:\"id\";s:8:\"personal\";s:5:\"label\";s:21:\"Personal contact form\";s:10:\"recipients\";a:0:{}s:5:\"reply\";s:0:\"\";s:6:\"weight\";i:0;s:7:\"message\";s:27:\"Your message has been sent.\";s:8:\"redirect\";s:0:\"\";}'),
('',	'contact.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U69DBeuvXuNVOC15rVNaBjDPK2fWFbo9v4takdYSSO8\";}s:12:\"default_form\";s:8:\"feedback\";s:5:\"flood\";a:2:{s:5:\"limit\";i:5;s:8:\"interval\";i:3600;}s:20:\"user_default_enabled\";b:1;}'),
('',	'core.base_field_override.node.page.promote',	'a:17:{s:4:\"uuid\";s:36:\"708a5000-dcce-43d4-8735-a04f3c0ae480\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:1:{i:0;s:14:\"node.type.page\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fPUEnm4T5zfZRr3ttDUqq7yCDd2uW3clWD-pvos4tlQ\";}s:2:\"id\";s:17:\"node.page.promote\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:22:\"Promoted to front page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),
('',	'core.date_format.fallback',	'a:9:{s:4:\"uuid\";s:36:\"7066953f-600d-4fc2-84b8-58826b84da0a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7klS5IWXrwzVaPpYZFAs6wcx8U2FF1X73OfrtTsvuvE\";}s:2:\"id\";s:8:\"fallback\";s:5:\"label\";s:20:\"Fallback date format\";s:6:\"locked\";b:1;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),
('',	'core.date_format.html_date',	'a:9:{s:4:\"uuid\";s:36:\"c8f2ea5d-ee32-44b5-b2a4-73b29881a91d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EOQltUQPmgc6UQ2rcJ4Xi_leCEJj5ui0TR-12duS-Tk\";}s:2:\"id\";s:9:\"html_date\";s:5:\"label\";s:9:\"HTML Date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-m-d\";}'),
('',	'core.date_format.html_datetime',	'a:9:{s:4:\"uuid\";s:36:\"1b677438-94c3-4570-af48-166d068688f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jxfClwZIRXIdcvMrE--WkcZxDGUVoOIE3Sm2NRZlFuE\";}s:2:\"id\";s:13:\"html_datetime\";s:5:\"label\";s:13:\"HTML Datetime\";s:6:\"locked\";b:1;s:7:\"pattern\";s:13:\"Y-m-d\\TH:i:sO\";}'),
('',	'core.date_format.html_month',	'a:9:{s:4:\"uuid\";s:36:\"b6631c90-a449-4cb7-93dc-33564909142a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Z7KuCUwM_WdTNvLcoltuX3_8d-s-8FZkTN6KgNwF0eM\";}s:2:\"id\";s:10:\"html_month\";s:5:\"label\";s:10:\"HTML Month\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"Y-m\";}'),
('',	'core.date_format.html_time',	'a:9:{s:4:\"uuid\";s:36:\"387b27db-0cbb-49c6-bce9-e2ae838a4eb4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M7yqicYkU36hRy5p9drAaGBBihhUD1OyujFrAaQ93ZE\";}s:2:\"id\";s:9:\"html_time\";s:5:\"label\";s:9:\"HTML Time\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"H:i:s\";}'),
('',	'core.date_format.html_week',	'a:9:{s:4:\"uuid\";s:36:\"aab47b59-a6c1-4205-a1bf-a0a7164b9f8d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wKD4WsoV_wFgv2vgI4mcAAFSIzrye17ykzdwrnApkfY\";}s:2:\"id\";s:9:\"html_week\";s:5:\"label\";s:9:\"HTML Week\";s:6:\"locked\";b:1;s:7:\"pattern\";s:5:\"Y-\\WW\";}'),
('',	'core.date_format.html_year',	'a:9:{s:4:\"uuid\";s:36:\"58dd1255-3bf1-465a-af62-74c3770e7861\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OjekiQuX9RbVQ2_8jOHBL94RgYLePqX7wpfNGgcQzrk\";}s:2:\"id\";s:9:\"html_year\";s:5:\"label\";s:9:\"HTML Year\";s:6:\"locked\";b:1;s:7:\"pattern\";s:1:\"Y\";}'),
('',	'core.date_format.html_yearless_date',	'a:9:{s:4:\"uuid\";s:36:\"1bea5c34-af20-4053-9459-595e10032d04\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5VpawMrKPEPCkoO4YpPa0TDFO2dgiIHfTziJtwlmUxc\";}s:2:\"id\";s:18:\"html_yearless_date\";s:5:\"label\";s:18:\"HTML Yearless date\";s:6:\"locked\";b:1;s:7:\"pattern\";s:3:\"m-d\";}'),
('',	'core.date_format.long',	'a:9:{s:4:\"uuid\";s:36:\"3228fcaa-0dfe-4342-b299-d12cfba43674\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"og8sWXhBuHbLMw3CoiBEZjgqSyhFBFmcbUW_wLcfNbo\";}s:2:\"id\";s:4:\"long\";s:5:\"label\";s:17:\"Default long date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:15:\"l, F j, Y - H:i\";}'),
('',	'core.date_format.medium',	'a:9:{s:4:\"uuid\";s:36:\"2ae289c3-6325-45f0-9ec2-99609e297832\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nzL5d024NjXIX_8TlT6uFAu973lmfkmHklJC-2i9rAE\";}s:2:\"id\";s:6:\"medium\";s:5:\"label\";s:19:\"Default medium date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:14:\"D, m/d/Y - H:i\";}'),
('',	'core.date_format.olivero_medium',	'a:9:{s:4:\"uuid\";s:36:\"9f0d1e0f-c3b1-477d-8825-2a12a34e41f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:5:\"theme\";a:1:{i:0;s:7:\"olivero\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mt6cmxUbDZ9XxD6p25WQ8tj3_JcX8ylfcddwZc8gcAE\";}s:2:\"id\";s:14:\"olivero_medium\";s:5:\"label\";s:14:\"Olivero Medium\";s:6:\"locked\";b:0;s:7:\"pattern\";s:8:\"j  F,  Y\";}'),
('',	'core.date_format.short',	'a:9:{s:4:\"uuid\";s:36:\"ced168ae-c45d-4704-b1d4-c36fb84b47f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AlzeyytA8InBgxIG9H2UDJYs3CG98Zj6yRsDKmlbZwA\";}s:2:\"id\";s:5:\"short\";s:5:\"label\";s:18:\"Default short date\";s:6:\"locked\";b:0;s:7:\"pattern\";s:11:\"m/d/Y - H:i\";}'),
('',	'core.entity_form_display.block_content.basic.default',	'a:11:{s:4:\"uuid\";s:36:\"2fb7a522-cf93-4f57-be42-0cb4c4d31165\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jAps3FCxvKecABS_tgExbhCZrBLQB3bNPWw18WjE3ss\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_accordion.default',	'a:12:{s:4:\"uuid\";s:36:\"7f7f76e5-ece6-4e93-9154-f7a914b883b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:44:\"field.field.block_content.ebt_accordion.body\";i:2;s:59:\"field.field.block_content.ebt_accordion.field_ebt_accordion\";i:3;s:58:\"field.field.block_content.ebt_accordion.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:13:\"ebt_accordion\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:19:\"field_ebt_accordion\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PzCFAyJrF1CHyonIY9UYHLYTUaTzxXhcv5uiJWU41DQ\";}s:2:\"id\";s:35:\"block_content.ebt_accordion.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:-4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ebt_accordion\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:22:\"ebt_settings_accordion\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_basic_button.default',	'a:11:{s:4:\"uuid\";s:36:\"37393abe-e80e-4438-a211-2b6937d2a850\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:70:\"field.field.block_content.ebt_basic_button.field_ebt_basic_button_link\";i:2;s:61:\"field.field.block_content.ebt_basic_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:16:\"ebt_basic_button\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TL36cBmV77cMjPzUpkHgNG3I6F4EZY_Iyr9A67xICRc\";}s:2:\"id\";s:38:\"block_content.ebt_basic_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:27:\"field_ebt_basic_button_link\";a:5:{s:6:\"weight\";i:27;s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"link_default\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:25:\"ebt_settings_basic_button\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_block.default',	'a:12:{s:4:\"uuid\";s:36:\"db7027b5-0083-4c23-932e-b8140582e848\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:40:\"field.field.block_content.ebt_block.body\";i:2;s:57:\"field.field.block_content.ebt_block.field_ebt_block_block\";i:3;s:54:\"field.field.block_content.ebt_block.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:11:\"block_field\";i:1;s:8:\"ebt_core\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:21:\"field_ebt_block_block\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Kmx4yzKEAL5_us-5XrISqRaGX28ieDECPBvSA4I53eM\";}s:2:\"id\";s:31:\"block_content.ebt_block.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_block_block\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_bootstrap_button.default',	'a:11:{s:4:\"uuid\";s:36:\"3fd59f0a-2725-4fa8-85fd-69b00e41a16c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:78:\"field.field.block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link\";i:2;s:65:\"field.field.block_content.ebt_bootstrap_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:20:\"ebt_bootstrap_button\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JwJzpFM95dLE-G20D_3HgaKN8MiWZGW-4JEwf0rWVeA\";}s:2:\"id\";s:42:\"block_content.ebt_bootstrap_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:31:\"field_ebt_bootstrap_button_link\";a:5:{s:6:\"weight\";i:27;s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"link_default\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:29:\"ebt_settings_bootstrap_button\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_carousel.default',	'a:12:{s:4:\"uuid\";s:36:\"d9501a4e-79d4-4429-a572-1bc3f75caa0e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:57:\"field.field.block_content.ebt_carousel.field_ebt_carousel\";i:2;s:57:\"field.field.block_content.ebt_carousel.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:12:\"ebt_carousel\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_carousel\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QXlNXkmdvt1D3vvq3Xts_hS6xZcsvaZ_VMIpv7HSlJ4\";}s:2:\"id\";s:34:\"block_content.ebt_carousel.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_carousel\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:21:\"ebt_settings_carousel\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_columns.default',	'a:12:{s:4:\"uuid\";s:36:\"913c0375-72d6-4813-b10b-3696ff0b8a73\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:42:\"field.field.block_content.ebt_columns.body\";i:2;s:62:\"field.field.block_content.ebt_columns.field_ebt_columns_blocks\";i:3;s:56:\"field.field.block_content.ebt_columns.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:11:\"block_field\";i:1;s:11:\"ebt_columns\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:24:\"field_ebt_columns_blocks\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"F_pGWF26Foj_C1Hq_KcX77H7LkKnWLFPV7iyltEH6CM\";}s:2:\"id\";s:33:\"block_content.ebt_columns.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_columns_blocks\";a:5:{s:4:\"type\";s:19:\"block_field_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_columns\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_countdown.default',	'a:12:{s:4:\"uuid\";s:36:\"b9105cc0-df88-453b-a92d-90b5e523a386\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:44:\"field.field.block_content.ebt_countdown.body\";i:2;s:64:\"field.field.block_content.ebt_countdown.field_ebt_countdown_date\";i:3;s:58:\"field.field.block_content.ebt_countdown.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"datetime\";i:1;s:13:\"ebt_countdown\";i:2;s:11:\"field_group\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:24:\"field_ebt_countdown_date\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GsQnmOfbEL4H_QrRxe1J3YG8Iq7SEHUP16XkMeLPtac\";}s:2:\"id\";s:35:\"block_content.ebt_countdown.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:21;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_countdown_date\";a:5:{s:4:\"type\";s:16:\"datetime_default\";s:6:\"weight\";i:22;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:22:\"ebt_settings_countdown\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_counter.default',	'a:12:{s:4:\"uuid\";s:36:\"289e89e1-cc7d-4e50-8100-bb16ed9875c1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:42:\"field.field.block_content.ebt_counter.body\";i:2;s:60:\"field.field.block_content.ebt_counter.field_ebt_counter_icon\";i:3;s:61:\"field.field.block_content.ebt_counter.field_ebt_counter_items\";i:4;s:62:\"field.field.block_content.ebt_counter.field_ebt_counter_number\";i:5;s:56:\"field.field.block_content.ebt_counter.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:11:\"ebt_counter\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:5;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:23:\"field_ebt_counter_items\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k07TlMoweT9Yz6bjpmLGKe6YvkshSJkTRnz6uGMQHkI\";}s:2:\"id\";s:33:\"block_content.ebt_counter.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_counter_items\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_counter\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:22:\"field_ebt_counter_icon\";b:1;s:24:\"field_ebt_counter_number\";b:1;}}'),
('',	'core.entity_form_display.block_content.ebt_cta.default',	'a:12:{s:4:\"uuid\";s:36:\"8a7d1838-30dd-4dc0-a2ae-b9e053ede2c9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:38:\"field.field.block_content.ebt_cta.body\";i:2;s:60:\"field.field.block_content.ebt_cta.field_ebt_cta_column_image\";i:3;s:52:\"field.field.block_content.ebt_cta.field_ebt_cta_link\";i:4;s:59:\"field.field.block_content.ebt_cta.field_ebt_cta_second_link\";i:5;s:53:\"field.field.block_content.ebt_cta.field_ebt_cta_title\";i:6;s:52:\"field.field.block_content.ebt_cta.field_ebt_settings\";}s:6:\"module\";a:5:{i:0;s:7:\"ebt_cta\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:5:{i:0;s:19:\"field_ebt_cta_title\";i:1;s:4:\"body\";i:2;s:26:\"field_ebt_cta_column_image\";i:3;s:18:\"field_ebt_cta_link\";i:4;s:25:\"field_ebt_cta_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vYgl9r_zBmBwCVILYRfEwPU5CbS9sLUc-A0mmAR2nq4\";}s:2:\"id\";s:29:\"block_content.ebt_cta.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ebt_cta_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_cta_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ebt_cta_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ebt_cta_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:16:\"ebt_settings_cta\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_hero.default',	'a:12:{s:4:\"uuid\";s:36:\"d6f88c18-d8de-40c5-9c43-c1c4d94583bd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:39:\"field.field.block_content.ebt_hero.body\";i:2;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_column_image\";i:3;s:54:\"field.field.block_content.ebt_hero.field_ebt_hero_link\";i:4;s:61:\"field.field.block_content.ebt_hero.field_ebt_hero_second_link\";i:5;s:55:\"field.field.block_content.ebt_hero.field_ebt_hero_title\";i:6;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_title_prefix\";i:7;s:53:\"field.field.block_content.ebt_hero.field_ebt_settings\";}s:6:\"module\";a:5:{i:0;s:8:\"ebt_hero\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:6:{i:0;s:20:\"field_ebt_hero_title\";i:1;s:27:\"field_ebt_hero_title_prefix\";i:2;s:4:\"body\";i:3;s:27:\"field_ebt_hero_column_image\";i:4;s:19:\"field_ebt_hero_link\";i:5;s:26:\"field_ebt_hero_second_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GQBJ-wowpRaxqn3ERit4j93oiUyIBZaIJDtySINgXhM\";}s:2:\"id\";s:30:\"block_content.ebt_hero.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:8:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:8;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_hero_column_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:9;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:19:\"field_ebt_hero_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ebt_hero_second_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:11;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_hero_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_hero_title_prefix\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:17:\"ebt_settings_hero\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_image.default',	'a:12:{s:4:\"uuid\";s:36:\"d00c707c-3248-4967-a6d8-4410bbfeb58f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:51:\"field.field.block_content.ebt_image.field_ebt_image\";i:2;s:59:\"field.field.block_content.ebt_image.field_ebt_image_caption\";i:3;s:56:\"field.field.block_content.ebt_image.field_ebt_image_link\";i:4;s:54:\"field.field.block_content.ebt_image.field_ebt_settings\";}s:6:\"module\";a:5:{i:0;s:9:\"ebt_image\";i:1;s:11:\"field_group\";i:2;s:4:\"link\";i:3;s:13:\"media_library\";i:4;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:15:\"field_ebt_image\";i:1;s:23:\"field_ebt_image_caption\";i:2;s:20:\"field_ebt_image_link\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DD35mMXZ3KVmfiicbnARcLgWKRQLT1HYVk6OHxJ-iBk\";}s:2:\"id\";s:31:\"block_content.ebt_image.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:15:\"field_ebt_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:26;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_image_caption\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:27;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_image_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:28;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_image\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_image_gallery.default',	'a:12:{s:4:\"uuid\";s:36:\"90302297-9a10-4688-91b6-c1672cf0a17e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:48:\"field.field.block_content.ebt_image_gallery.body\";i:2;s:67:\"field.field.block_content.ebt_image_gallery.field_ebt_image_gallery\";i:3;s:62:\"field.field.block_content.ebt_image_gallery.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:17:\"ebt_image_gallery\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:4:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:23:\"field_ebt_image_gallery\";i:3;s:8:\"langcode\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0PSdTVGfXs7VaqV30tsbYPvmzGKHhU4hZYgKxHIHVcU\";}s:2:\"id\";s:39:\"block_content.ebt_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_image_gallery\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:26:\"ebt_settings_image_gallery\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_micromodal.default',	'a:12:{s:4:\"uuid\";s:36:\"50e0e4ff-bae9-4a5d-a915-ec8cdc49ff77\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:45:\"field.field.block_content.ebt_micromodal.body\";i:2;s:67:\"field.field.block_content.ebt_micromodal.field_ebt_micromodal_title\";i:3;s:59:\"field.field.block_content.ebt_micromodal.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:14:\"ebt_micromodal\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:26:\"field_ebt_micromodal_title\";i:1;s:4:\"body\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:2;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:3;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZNJcRUtL7EWaVB-UgRyHYVB4-th0NpBsk6t-AcQiZc0\";}s:2:\"id\";s:36:\"block_content.ebt_micromodal.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:26:\"field_ebt_micromodal_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:23:\"ebt_settings_micromodal\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_quote.default',	'a:12:{s:4:\"uuid\";s:36:\"3ac9c5a0-b4a9-4360-8947-feabad5e7f71\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:40:\"field.field.block_content.ebt_quote.body\";i:2;s:58:\"field.field.block_content.ebt_quote.field_ebt_quote_author\";i:3;s:57:\"field.field.block_content.ebt_quote.field_ebt_quote_image\";i:4;s:54:\"field.field.block_content.ebt_quote.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_quote\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:4:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:22:\"field_ebt_quote_author\";i:3;s:21:\"field_ebt_quote_image\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N-LtYp4PCPoTpwSFmV_pxSB5hcbey07dO7biDALNdbg\";}s:2:\"id\";s:31:\"block_content.ebt_quote.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ebt_quote_author\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_quote_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_quote\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_slick_slider.default',	'a:12:{s:4:\"uuid\";s:36:\"92792509-019c-4727-be95-79a35850d3e8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:47:\"field.field.block_content.ebt_slick_slider.body\";i:2;s:61:\"field.field.block_content.ebt_slick_slider.field_ebt_settings\";i:3;s:65:\"field.field.block_content.ebt_slick_slider.field_ebt_slick_slider\";}s:6:\"module\";a:4:{i:0;s:16:\"ebt_slick_slider\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:22:\"field_ebt_slick_slider\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:8;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bpVaLzDSRRw2IoN4B7lX2DmpEtGagQ_kHdtfu2QnBWk\";}s:2:\"id\";s:38:\"block_content.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:4;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:25:\"ebt_settings_slick_slider\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ebt_slick_slider\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:7;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_slideshow.default',	'a:12:{s:4:\"uuid\";s:36:\"1e354f38-03e4-4eb3-83d9-64e23ea8e653\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:58:\"field.field.block_content.ebt_slideshow.field_ebt_settings\";i:2;s:59:\"field.field.block_content.ebt_slideshow.field_ebt_slideshow\";}s:6:\"module\";a:3:{i:0;s:13:\"ebt_slideshow\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:19:\"field_ebt_slideshow\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6DA12pCUzWErNlrzV5uI2gCLocIzFk1R4r6_m3BD42A\";}s:2:\"id\";s:35:\"block_content.ebt_slideshow.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:22;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:22:\"ebt_settings_slideshow\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_slideshow\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:21;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_stats.default',	'a:12:{s:4:\"uuid\";s:36:\"52b22b0d-85e9-4340-9aa7-8f4febf9050e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:40:\"field.field.block_content.ebt_stats.body\";i:2;s:54:\"field.field.block_content.ebt_stats.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_stats.field_ebt_stats\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_stats\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:1;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:15:\"field_ebt_stats\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_L5lmPQyOe6uFAwlop2yf-ekQRX87-T_CXqJ-IIRg7Y\";}s:2:\"id\";s:31:\"block_content.ebt_stats.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:27;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_stats\";s:6:\"weight\";i:22;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ebt_stats\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:28;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_tabs.default',	'a:12:{s:4:\"uuid\";s:36:\"a7d39dc1-5b23-4427-87b3-0bbc28e7b99b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:53:\"field.field.block_content.ebt_tabs.field_ebt_settings\";i:2;s:49:\"field.field.block_content.ebt_tabs.field_ebt_tabs\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_tabs\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:14:\"field_ebt_tabs\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiD2k00iSxydyLNXRexQsZwtt3kdC7yWjKnIE2TPsds\";}s:2:\"id\";s:30:\"block_content.ebt_tabs.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:17:\"ebt_settings_tabs\";s:6:\"region\";s:7:\"content\";}s:14:\"field_ebt_tabs\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_text.default',	'a:12:{s:4:\"uuid\";s:36:\"a186725f-445b-4043-83f2-c3bc2d5b1b87\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:39:\"field.field.block_content.ebt_text.body\";i:2;s:53:\"field.field.block_content.ebt_text.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"info\";i:1;s:4:\"body\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qr5FWoE0Z8wFG-omC1KS3oG2wlcQ86J_zl7wsCOUCto\";}s:2:\"id\";s:30:\"block_content.ebt_text.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:1;s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_tiles.default',	'a:12:{s:4:\"uuid\";s:36:\"8876d1b6-9d39-4029-abb6-793bf6be88df\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:40:\"field.field.block_content.ebt_tiles.body\";i:2;s:54:\"field.field.block_content.ebt_tiles.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_tiles.field_ebt_tiles\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_tiles\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:240;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:15:\"field_ebt_tiles\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"B8B292gqxvNzedSxDhs7Ss9nrmX75yMSBzLtMUBusxw\";}s:2:\"id\";s:31:\"block_content.ebt_tiles.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_tiles\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ebt_tiles\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_timeline.default',	'a:12:{s:4:\"uuid\";s:36:\"2d00d268-fcaf-44e1-a5d2-99bf5b954cee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:57:\"field.field.block_content.ebt_timeline.field_ebt_settings\";i:2;s:57:\"field.field.block_content.ebt_timeline.field_ebt_timeline\";}s:6:\"module\";a:3:{i:0;s:12:\"ebt_timeline\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:3;s:11:\"format_type\";s:4:\"tabs\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:5:{s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;}s:5:\"label\";s:4:\"Tabs\";}s:13:\"group_content\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_timeline\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:4;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:7:\"Content\";}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:6:\"region\";s:7:\"content\";s:15:\"format_settings\";a:6:{s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:7:\"classes\";s:0:\"\";s:11:\"description\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:15:\"required_fields\";b:1;}s:5:\"label\";s:8:\"Settings\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lnh43KY0voHRBULlVHJ5n0V8Twh6dwTa482WpJEf7nU\";}s:2:\"id\";s:34:\"block_content.ebt_timeline.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:21:\"ebt_settings_timeline\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_timeline\";a:5:{s:4:\"type\";s:27:\"entity_reference_paragraphs\";s:6:\"weight\";i:1;s:8:\"settings\";a:6:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_video.default',	'a:12:{s:4:\"uuid\";s:36:\"adebe1bd-2c8a-4e24-8830-be649450bd8e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:40:\"field.field.block_content.ebt_video.body\";i:2;s:54:\"field.field.block_content.ebt_video.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_video.field_ebt_video\";}s:6:\"module\";a:4:{i:0;s:9:\"ebt_video\";i:1;s:11:\"field_group\";i:2;s:13:\"media_library\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:640;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:15:\"field_ebt_video\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:5;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:6;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tS6jBKcl-OCTitIjmc0ugKz08ENt8SoAs6NCnjOy-ek\";}s:2:\"id\";s:31:\"block_content.ebt_video.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:18:\"ebt_settings_video\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:15:\"field_ebt_video\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_video_and_image_gallery.default',	'a:12:{s:4:\"uuid\";s:36:\"4de506fd-736b-43b4-b4e9-87a88229b117\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:58:\"field.field.block_content.ebt_video_and_image_gallery.body\";i:2;s:72:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_settings\";i:3;s:81:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images\";}s:6:\"module\";a:4:{i:0;s:27:\"ebt_video_and_image_gallery\";i:1;s:11:\"field_group\";i:2;s:10:\"paragraphs\";i:3;s:4:\"text\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:2;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:2:{i:0;s:4:\"body\";i:1;s:27:\"field_ebt_videos_and_images\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QGg-MV2IynMGDSKSb1vqdwAQyQ8p83BjC_W3v8O_1lg\";}s:2:\"id\";s:49:\"block_content.ebt_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:36:\"ebt_settings_video_and_image_gallery\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_videos_and_images\";a:5:{s:4:\"type\";s:10:\"paragraphs\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:10:{s:5:\"title\";s:9:\"Paragraph\";s:12:\"title_plural\";s:10:\"Paragraphs\";s:9:\"edit_mode\";s:4:\"open\";s:11:\"closed_mode\";s:7:\"summary\";s:12:\"autocollapse\";s:4:\"none\";s:21:\"closed_mode_threshold\";i:0;s:8:\"add_mode\";s:8:\"dropdown\";s:17:\"form_display_mode\";s:7:\"default\";s:22:\"default_paragraph_type\";s:0:\"\";s:8:\"features\";a:2:{s:17:\"collapse_edit_all\";s:17:\"collapse_edit_all\";s:9:\"duplicate\";s:9:\"duplicate\";}}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_views.default',	'a:12:{s:4:\"uuid\";s:36:\"9166e36b-940f-481e-9cf3-5aacb1ef1208\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:40:\"field.field.block_content.ebt_views.body\";i:2;s:54:\"field.field.block_content.ebt_views.field_ebt_settings\";i:3;s:57:\"field.field.block_content.ebt_views.field_ebt_views_views\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:11:\"field_group\";i:2;s:4:\"text\";i:3;s:14:\"viewsreference\";}}s:20:\"third_party_settings\";a:1:{s:11:\"field_group\";a:3:{s:10:\"group_tabs\";a:7:{s:8:\"children\";a:2:{i:0;s:13:\"group_content\";i:1;s:14:\"group_settings\";}s:5:\"label\";s:4:\"Tabs\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:0:\"\";s:6:\"weight\";i:0;s:11:\"format_type\";s:4:\"tabs\";s:15:\"format_settings\";a:5:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"direction\";s:10:\"horizontal\";s:16:\"width_breakpoint\";i:120;}}s:13:\"group_content\";a:7:{s:8:\"children\";a:3:{i:0;s:4:\"info\";i:1;s:4:\"body\";i:2;s:21:\"field_ebt_views_views\";}s:5:\"label\";s:7:\"Content\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:20;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:4:\"open\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}s:14:\"group_settings\";a:7:{s:8:\"children\";a:1:{i:0;s:18:\"field_ebt_settings\";}s:5:\"label\";s:8:\"Settings\";s:6:\"region\";s:7:\"content\";s:11:\"parent_name\";s:10:\"group_tabs\";s:6:\"weight\";i:21;s:11:\"format_type\";s:3:\"tab\";s:15:\"format_settings\";a:6:{s:7:\"classes\";s:0:\"\";s:17:\"show_empty_fields\";b:0;s:2:\"id\";s:0:\"\";s:9:\"formatter\";s:6:\"closed\";s:11:\"description\";s:0:\"\";s:15:\"required_fields\";b:1;}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"E47G4jhOaCiwauUu7Cp8eOG0n1xF0TbNyp6_qUkGMcI\";}s:2:\"id\";s:31:\"block_content.ebt_views.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:18:\"field_ebt_settings\";a:5:{s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_views_views\";a:5:{s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_webform.default',	'a:11:{s:4:\"uuid\";s:36:\"e6638a9a-dd30-4dab-b46a-9c913eb531bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:42:\"field.field.block_content.ebt_webform.body\";i:2;s:56:\"field.field.block_content.ebt_webform.field_ebt_settings\";i:3;s:60:\"field.field.block_content.ebt_webform.field_ebt_webform_form\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rtuRBm-Z8ZrdOhT7mc0JrMlWONwesUqNR-IwTM6axEY\";}s:2:\"id\";s:33:\"block_content.ebt_webform.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:26;s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:29;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_webform_form\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:2:{s:12:\"default_data\";b:1;s:8:\"webforms\";a:0:{}}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.block_content.ebt_webform_popup.default',	'a:11:{s:4:\"uuid\";s:36:\"76422ca6-6b1c-4ebd-b6e5-d362e8bc423d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:62:\"field.field.block_content.ebt_webform_popup.field_ebt_settings\";i:2;s:72:\"field.field.block_content.ebt_webform_popup.field_ebt_webform_popup_form\";}s:6:\"module\";a:2:{i:0;s:17:\"ebt_webform_popup\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-EvEMaGTSq7rxJjzGuhqBIybUTNrM39BXJjRKhFkDos\";}s:2:\"id\";s:39:\"block_content.ebt_webform_popup.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:18:\"field_ebt_settings\";a:5:{s:6:\"weight\";i:28;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:26:\"ebt_settings_webform_popup\";s:6:\"region\";s:7:\"content\";}s:28:\"field_ebt_webform_popup_form\";a:5:{s:6:\"weight\";i:27;s:8:\"settings\";a:2:{s:12:\"default_data\";b:1;s:8:\"webforms\";a:0:{}}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:31:\"webform_entity_reference_select\";s:6:\"region\";s:7:\"content\";}s:4:\"info\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_display.media.audio.default',	'a:11:{s:4:\"uuid\";s:36:\"9efccee6-8cc4-4ff4-92bb-0553278490ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"G2_SKH3jmI9FQeXSUxo3KgQqiyF1hPDEkc7-3-rCSbc\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_audio_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.audio.media_library',	'a:11:{s:4:\"uuid\";s:36:\"70924fc9-698f-43ce-8125-c9f66ca37236\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:16:\"media.type.audio\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"28vwMIYtvyjPcD4RyciZXIztxtZgmuWRCNgYemr_SZE\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.document.default',	'a:11:{s:4:\"uuid\";s:36:\"c99f3040-4f5d-4326-9040-193db1713a88\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aewrRkePgJzdD5kPOq8JeMcKHs6yat49nE7ZeCQzQZg\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_media_document\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.document.media_library',	'a:11:{s:4:\"uuid\";s:36:\"8df854a8-6d93-49a7-803e-4334857e73fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:19:\"media.type.document\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dcpfpqyLXOSGpulacMAJW3H-G34_LeNsjdfxd1_oCfY\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.image.default',	'a:11:{s:4:\"uuid\";s:36:\"7b876128-538a-4826-a5a4-52747a729203\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:21:\"image.style.thumbnail\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JSY4-JPyNZBiYYo6imdRYF6_SdtWQexPndrLvn3-vw4\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.image.media_library',	'a:11:{s:4:\"uuid\";s:36:\"3d16f00d-32eb-4ac9-a711-00689691832b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BMLrK4zKp8-FFnMseBdT_6h6YipUsKRfbDf_3WUB5HA\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:5:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.remote_video.default',	'a:11:{s:4:\"uuid\";s:36:\"d145d9a4-1eb4-4ece-a5e9-4e77dd7a4b2a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pM8mGlwfpvfG_y5tZn0lGAXFLXz2_yKkL7MvWZsRqdA\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_media_oembed_video\";a:5:{s:4:\"type\";s:16:\"oembed_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.remote_video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"996b87ca-42a9-4803-afcc-24ebfbdf7849\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBgPW-uaXRaICBwLaVc16rXpRiLSknDIdF9q0XL7qso\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.media.video.default',	'a:11:{s:4:\"uuid\";s:36:\"432d0cdf-b7f6-4927-af19-9a26a2f71c65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"path\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0kIIaDTt6dixXy8TZkat2MNGZJ6vkRG8TaBWTy3E1bM\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_media_video_file\";a:5:{s:4:\"type\";s:12:\"file_generic\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:18:\"progress_indicator\";s:8:\"throbber\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:4:\"name\";b:1;}}'),
('',	'core.entity_form_display.media.video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"eed6f1c2-957f-4ca5-9d11-57d9fb6c9564\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:41:\"core.entity_form_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:16:\"media.type.video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kGv8YsopqHvzTzb7QTINWcv0fnNa5ZDQyZxpOQR2vro\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:0:{}s:6:\"hidden\";a:6:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:4:\"path\";b:1;s:6:\"status\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_form_display.node.article.default',	'a:11:{s:4:\"uuid\";s:36:\"c224932f-6de0-4883-88df-0c2ae5186624\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:39:\"field.field.node.article.field_metatags\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:47:\"field.field.node.article.layout_builder__layout\";i:5;s:21:\"image.style.thumbnail\";i:6;s:17:\"node.type.article\";}s:6:\"module\";a:4:{i:0;s:7:\"metatag\";i:1;s:4:\"path\";i:2;s:9:\"svg_image\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ewbd6G2uX456-bgwseM2Q-KQG3RkASoyHmTh-XR3oLU\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:12:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:11:\"field_image\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_metatags\";a:5:{s:4:\"type\";s:16:\"metatag_firehose\";s:6:\"weight\";i:121;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:7:\"sidebar\";b:1;s:11:\"use_details\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:10:\"field_tags\";a:5:{s:4:\"type\";s:34:\"entity_reference_autocomplete_tags\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:13:\"url_redirects\";a:4:{s:6:\"weight\";i:50;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_form_display.node.page.default',	'a:11:{s:4:\"uuid\";s:36:\"095e0e3b-5060-4869-9c69-f8044cadf927\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:26:\"field.field.node.page.body\";i:1;s:36:\"field.field.node.page.field_metatags\";i:2;s:44:\"field.field.node.page.layout_builder__layout\";i:3;s:14:\"node.type.page\";}s:6:\"module\";a:3:{i:0;s:7:\"metatag\";i:1;s:4:\"path\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SfpLhPExzvR0MgFp0Wp7CrmgEnhcqQ-fXIWFhbf4ue0\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:10:{s:4:\"body\";a:5:{s:4:\"type\";s:26:\"text_textarea_with_summary\";s:6:\"weight\";i:31;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:4:\"rows\";i:9;s:12:\"summary_rows\";i:3;s:11:\"placeholder\";s:0:\"\";s:12:\"show_summary\";b:0;}s:20:\"third_party_settings\";a:0:{}}s:7:\"created\";a:5:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:14:\"field_metatags\";a:5:{s:4:\"type\";s:16:\"metatag_firehose\";s:6:\"weight\";i:121;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:7:\"sidebar\";b:1;s:11:\"use_details\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:4:\"path\";a:5:{s:4:\"type\";s:4:\"path\";s:6:\"weight\";i:30;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}s:7:\"promote\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:15;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"status\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:120;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:6:\"sticky\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:16;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:5:\"title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:3:\"uid\";a:5:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:13:\"url_redirects\";a:4:{s:6:\"weight\";i:50;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:1:{s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_accordion.default',	'a:11:{s:4:\"uuid\";s:36:\"ee2f8f98-b9f7-4254-9737-68dc2197b2fd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:60:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_text\";i:1;s:61:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_title\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VV4WvHQlFMN4Xl5jLocxzCyuI7nCn1nGWGmJZbXlG2Q\";}s:2:\"id\";s:31:\"paragraph.ebt_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ebt_accordion_text\";a:5:{s:6:\"weight\";i:1;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_accordion_title\";a:5:{s:6:\"weight\";i:0;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_carousel.default',	'a:11:{s:4:\"uuid\";s:36:\"d1b4eb72-c64f-476b-bb62-88226cb19793\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:61:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_caption\";i:1;s:59:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yERJpwaJ1QC8Q1Gr8Tezl9O_q0ufoiR8gwonaEjSspw\";}s:2:\"id\";s:30:\"paragraph.ebt_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ebt_carousel_caption\";a:5:{s:6:\"weight\";i:1;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_carousel_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_counter_item.default',	'a:11:{s:4:\"uuid\";s:36:\"4579f4f8-31b0-4cd5-b9fe-f87cd45f5fb6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_description\";i:1;s:61:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_icon\";i:2;s:63:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_number\";i:3;s:62:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"snzZLNDA9DFF0msO0Up9bLDhB8kgJR3OFtnbryzGVms\";}s:2:\"id\";s:34:\"paragraph.ebt_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ebt_counter_description\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:22:\"field_ebt_counter_icon\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_counter_number\";a:5:{s:4:\"type\";s:6:\"number\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_counter_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_slick_slider.default',	'a:11:{s:4:\"uuid\";s:36:\"49d083c6-462d-45e8-b2da-c158f1f21e4d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:67:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_image\";i:1;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_link\";i:2;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_text\";i:3;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SrB8f_Znsaiqtv7a46b7z53joZ5A1SCIFKCJUjFizQk\";}s:2:\"id\";s:34:\"paragraph.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ebt_slick_slider_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_slick_slider_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:27:\"field_ebt_slick_slider_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_slideshow.default',	'a:11:{s:4:\"uuid\";s:36:\"4d6b8979-02dc-432e-a1ee-1e39bf6d0736\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_link\";i:1;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_slide\";i:2;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_text\";i:3;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_title\";i:4;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1kjXAT0qkIlX0WEGDAcnGaQHa1XeILgCDnWcPfDVJ0\";}s:2:\"id\";s:31:\"paragraph.ebt_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ebt_slideshow_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ebt_slideshow_slide\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_slideshow_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:25:\"field_ebt_slideshow_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_stats_item.default',	'a:11:{s:4:\"uuid\";s:36:\"a7152796-e586-430a-a770-6b093d09cb7c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:59:\"field.field.paragraph.ebt_stats_item.field_stats_item_image\";i:1;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_link\";i:2;s:60:\"field.field.paragraph.ebt_stats_item.field_stats_item_number\";i:3;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_LZlRyxzZkfNDaWmAIuAHQXMASYeRLzj_Tu9HB2QGnw\";}s:2:\"id\";s:32:\"paragraph.ebt_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:22:\"field_stats_item_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_stats_item_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_stats_item_number\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_stats_item_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_tab.default',	'a:11:{s:4:\"uuid\";s:36:\"99244a65-d42c-43a2-baae-958073fef48f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_block\";i:1;s:51:\"field.field.paragraph.ebt_tab.field_ebt_tab_content\";i:2;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_page\";i:3;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_text\";i:4;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_title\";i:5;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_views\";i:6;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3tkvVlJEyrGPBNqg-NmBgDBe7aW-ckCLKwsrbQPd28E\";}s:2:\"id\";s:25:\"paragraph.ebt_tab.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:19:\"field_ebt_tab_block\";a:5:{s:6:\"weight\";i:7;s:8:\"settings\";a:3:{s:9:\"plugin_id\";s:0:\"\";s:8:\"settings\";a:0:{}s:18:\"configuration_form\";s:4:\"full\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:19:\"block_field_default\";s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_tab_content\";a:5:{s:6:\"weight\";i:1;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:14:\"options_select\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_page\";a:5:{s:6:\"weight\";i:2;s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_text\";a:5:{s:6:\"weight\";i:3;s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:13:\"text_textarea\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_title\";a:5:{s:6:\"weight\";i:0;s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:14:\"text_textfield\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_views\";a:5:{s:6:\"weight\";i:6;s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:27:\"viewsreference_autocomplete\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_tiles_item.default',	'a:11:{s:4:\"uuid\";s:36:\"fbaff897-1222-45d2-bdee-f1c92ecc517d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_tiles_item.field_ebt_clickable_tile\";i:1;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_image\";i:2;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_link\";i:3;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_text\";i:4;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:13:\"media_library\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aO9CEu-AEXoDrOUyi0zQ-BFKnOQQ4j-7EZboHKs25Ao\";}s:2:\"id\";s:32:\"paragraph.ebt_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ebt_clickable_tile\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_tiles_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_tiles_link\";a:5:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:15:\"placeholder_url\";s:0:\"\";s:17:\"placeholder_title\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:20:\"field_ebt_tiles_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:21:\"field_ebt_tiles_title\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:2;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_timeline.default',	'a:11:{s:4:\"uuid\";s:36:\"9ade0a26-a08a-49b3-8f21-5cc52e0a9d4a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_current\";i:1;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_date\";i:2;s:65:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_media_image\";i:3;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_text\";i:4;s:59:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_title\";i:5;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"roudiPcEWEQePvvKVTvyQOha3roMsIYNfxuZ8yhsA7o\";}s:2:\"id\";s:30:\"paragraph.ebt_timeline.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:26:\"field_ebt_timeline_current\";a:5:{s:4:\"type\";s:16:\"boolean_checkbox\";s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_timeline_date\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:30:\"field_ebt_timeline_media_image\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}s:23:\"field_ebt_timeline_text\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_ebt_timeline_title\";a:5:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"size\";i:60;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.paragraph.ebt_video_and_image_gallery_item.default',	'a:11:{s:4:\"uuid\";s:36:\"af68c1f1-a952-4c8a-ad1c-06f3eaa33777\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:85:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description\";i:1;s:79:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item\";i:2;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:2:{i:0;s:13:\"media_library\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Ajt8RnSI29uPiHiC5kZcmSORcHZviDbPeC4fnIM2VWo\";}s:2:\"id\";s:50:\"paragraph.ebt_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:30:\"field_gallery_item_description\";a:5:{s:4:\"type\";s:13:\"text_textarea\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:4:\"rows\";i:5;s:11:\"placeholder\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}}s:24:\"field_video_gallery_item\";a:5:{s:4:\"type\";s:20:\"media_library_widget\";s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:1:{s:11:\"media_types\";a:0:{}}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:2:{s:7:\"created\";b:1;s:6:\"status\";b:1;}}'),
('',	'core.entity_form_display.user.user.default',	'a:11:{s:4:\"uuid\";s:36:\"2e78043c-ec7e-40d3-9893-74a39341e80d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FaQ9Ptcpxpg30AtiqRDtl_8zbJArHP1LPfug_s59TOA\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:7:\"account\";a:2:{s:6:\"weight\";i:-10;s:6:\"region\";s:7:\"content\";}s:7:\"contact\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:8:\"language\";a:2:{s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:8:\"timezone\";a:2:{s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:5:{s:4:\"type\";s:11:\"image_image\";s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";s:8:\"settings\";a:2:{s:18:\"progress_indicator\";s:8:\"throbber\";s:19:\"preview_image_style\";s:9:\"thumbnail\";}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_form_mode.media.media_library',	'a:10:{s:4:\"uuid\";s:36:\"4f486238-f30d-4022-ac1d-42675ab0f17a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_form_mode.user.register',	'a:10:{s:4:\"uuid\";s:36:\"2a875655-65fd-42f4-bd80-8b41714fa393\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5pE_4hurqtIlZN3XDi7eTo5RG13BMG0Rh9HYlRI3h8U\";}s:2:\"id\";s:13:\"user.register\";s:5:\"label\";s:8:\"Register\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_display.block_content.basic.default',	'a:11:{s:4:\"uuid\";s:36:\"d5902a81-52d9-49dd-b8db-4665dbc4368c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:36:\"field.field.block_content.basic.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hBNNDTFwakREOTa6GGMqN899Iyrii0hInwSJtQ7Kj30\";}s:2:\"id\";s:27:\"block_content.basic.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_accordion.default',	'a:11:{s:4:\"uuid\";s:36:\"4043bfd5-1d8c-40be-b5b7-7566608c0a10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:44:\"field.field.block_content.ebt_accordion.body\";i:2;s:59:\"field.field.block_content.ebt_accordion.field_ebt_accordion\";i:3;s:58:\"field.field.block_content.ebt_accordion.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WJqWWf2uiJH8b576_UiYa5phDxIJKwgJiQjqG9e3TNI\";}s:2:\"id\";s:35:\"block_content.ebt_accordion.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_accordion\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_basic_button.default',	'a:11:{s:4:\"uuid\";s:36:\"e002007d-e402-414c-a43e-0e11a4ff059c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:70:\"field.field.block_content.ebt_basic_button.field_ebt_basic_button_link\";i:2;s:61:\"field.field.block_content.ebt_basic_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"D0bWnt-1a4nvpSyJNmrOwKtHeZ4joh72qib-yadGXdo\";}s:2:\"id\";s:38:\"block_content.ebt_basic_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:27:\"field_ebt_basic_button_link\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:4:\"link\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_block.default',	'a:11:{s:4:\"uuid\";s:36:\"7dac4777-4a33-402e-a4fb-d2ec54e7bdbf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:40:\"field.field.block_content.ebt_block.body\";i:2;s:57:\"field.field.block_content.ebt_block.field_ebt_block_block\";i:3;s:54:\"field.field.block_content.ebt_block.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:8:\"ebt_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fbnp4SbjbUUixWLq5rrWDtCZ10d3rhYWoqZRmYFJPfo\";}s:2:\"id\";s:31:\"block_content.ebt_block.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_block_block\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_bootstrap_button.default',	'a:11:{s:4:\"uuid\";s:36:\"8a03d29e-a687-49e7-9a56-0dfe88836e7a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:78:\"field.field.block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link\";i:2;s:65:\"field.field.block_content.ebt_bootstrap_button.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"B0SuU0apEENhv8h4tMjfQJZqaMhqfIqzm2aj6K7pj8g\";}s:2:\"id\";s:42:\"block_content.ebt_bootstrap_button.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:31:\"field_ebt_bootstrap_button_link\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:4:\"link\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_carousel.default',	'a:11:{s:4:\"uuid\";s:36:\"5595a634-71e4-4b9c-840c-c1fcb074609f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:57:\"field.field.block_content.ebt_carousel.field_ebt_carousel\";i:2;s:57:\"field.field.block_content.ebt_carousel.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XxudurKwt1BsJ27WvP-j9wjYhEJwJoXWpngR6KCPXG8\";}s:2:\"id\";s:34:\"block_content.ebt_carousel.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_carousel\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_columns.default',	'a:11:{s:4:\"uuid\";s:36:\"86bcc126-14bc-40cd-a04a-95794d3f1e10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:42:\"field.field.block_content.ebt_columns.body\";i:2;s:62:\"field.field.block_content.ebt_columns.field_ebt_columns_blocks\";i:3;s:56:\"field.field.block_content.ebt_columns.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:8:\"ebt_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a-6glPDfvKWglLxQBv5i50OSaExRNK8Y9fdSycITPPg\";}s:2:\"id\";s:33:\"block_content.ebt_columns.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_columns_blocks\";a:6:{s:4:\"type\";s:11:\"block_field\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_countdown.default',	'a:11:{s:4:\"uuid\";s:36:\"814b296d-272d-49bd-b543-8a896015c80d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:44:\"field.field.block_content.ebt_countdown.body\";i:2;s:64:\"field.field.block_content.ebt_countdown.field_ebt_countdown_date\";i:3;s:58:\"field.field.block_content.ebt_countdown.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"datetime\";i:1;s:8:\"ebt_core\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SD9uKkLwTaGxA9CLhoLDWa7OVamzALkQ381JeZFM12Q\";}s:2:\"id\";s:35:\"block_content.ebt_countdown.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_countdown_date\";a:6:{s:4:\"type\";s:16:\"datetime_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:2:{s:17:\"timezone_override\";s:0:\"\";s:11:\"format_type\";s:6:\"medium\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_counter.default',	'a:11:{s:4:\"uuid\";s:36:\"4117f5ae-b100-40a0-82be-376d1b9cdd5c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:42:\"field.field.block_content.ebt_counter.body\";i:2;s:60:\"field.field.block_content.ebt_counter.field_ebt_counter_icon\";i:3;s:61:\"field.field.block_content.ebt_counter.field_ebt_counter_items\";i:4;s:62:\"field.field.block_content.ebt_counter.field_ebt_counter_number\";i:5;s:56:\"field.field.block_content.ebt_counter.field_ebt_settings\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U0J7ekcnrzJlts3b7XRAuCz6M0oc4laODI1JQpfnSWU\";}s:2:\"id\";s:33:\"block_content.ebt_counter.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_counter_items\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:22:\"field_ebt_counter_icon\";b:1;s:24:\"field_ebt_counter_number\";b:1;}}'),
('',	'core.entity_view_display.block_content.ebt_cta.default',	'a:11:{s:4:\"uuid\";s:36:\"0ad5cd1c-3a95-492c-a42a-3a33aad2fc81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:38:\"field.field.block_content.ebt_cta.body\";i:2;s:60:\"field.field.block_content.ebt_cta.field_ebt_cta_column_image\";i:3;s:52:\"field.field.block_content.ebt_cta.field_ebt_cta_link\";i:4;s:59:\"field.field.block_content.ebt_cta.field_ebt_cta_second_link\";i:5;s:53:\"field.field.block_content.ebt_cta.field_ebt_cta_title\";i:6;s:52:\"field.field.block_content.ebt_cta.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rJRx3IkJfHu6PnEX98fydtBu7xtB6TBPxbD0H22l5MY\";}s:2:\"id\";s:29:\"block_content.ebt_cta.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:6:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:26:\"field_ebt_cta_column_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_cta_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_cta_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_cta_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_hero.default',	'a:11:{s:4:\"uuid\";s:36:\"ef3f9c37-ba74-4569-9402-eb895497b1ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:39:\"field.field.block_content.ebt_hero.body\";i:2;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_column_image\";i:3;s:54:\"field.field.block_content.ebt_hero.field_ebt_hero_link\";i:4;s:61:\"field.field.block_content.ebt_hero.field_ebt_hero_second_link\";i:5;s:55:\"field.field.block_content.ebt_hero.field_ebt_hero_title\";i:6;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_title_prefix\";i:7;s:53:\"field.field.block_content.ebt_hero.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XtJum4t5ZIxuZCmM5WqHm32Q5cPXTBC1K_4FK0DKBak\";}s:2:\"id\";s:30:\"block_content.ebt_hero.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:7:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_hero_column_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_hero_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:26:\"field_ebt_hero_second_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_hero_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_hero_title_prefix\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:6;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_image.default',	'a:11:{s:4:\"uuid\";s:36:\"2b267e2d-1fdb-48ce-9cb4-9e8ab433ed76\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:51:\"field.field.block_content.ebt_image.field_ebt_image\";i:2;s:59:\"field.field.block_content.ebt_image.field_ebt_image_caption\";i:3;s:56:\"field.field.block_content.ebt_image.field_ebt_image_link\";i:4;s:54:\"field.field.block_content.ebt_image.field_ebt_settings\";}s:6:\"module\";a:4:{i:0;s:8:\"ebt_core\";i:1;s:4:\"link\";i:2;s:5:\"media\";i:3;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"D3uYbuXeXgRMCscOC7MzthncsxVzm02BUnKoPT6DgNI\";}s:2:\"id\";s:31:\"block_content.ebt_image.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:15:\"field_ebt_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_image_caption\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_image_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_image_gallery.default',	'a:11:{s:4:\"uuid\";s:36:\"4b5d6bc4-4cc6-4319-a6bf-ffb11737fa1d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:48:\"field.field.block_content.ebt_image_gallery.body\";i:2;s:67:\"field.field.block_content.ebt_image_gallery.field_ebt_image_gallery\";i:3;s:62:\"field.field.block_content.ebt_image_gallery.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vR-7_1M__12ELdq1IjHW5dYHXbjNbXTl83IbuAVADFo\";}s:2:\"id\";s:39:\"block_content.ebt_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_image_gallery\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_micromodal.default',	'a:11:{s:4:\"uuid\";s:36:\"f5514d94-f0a7-4adb-af94-b565702bcb87\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:45:\"field.field.block_content.ebt_micromodal.body\";i:2;s:67:\"field.field.block_content.ebt_micromodal.field_ebt_micromodal_title\";i:3;s:59:\"field.field.block_content.ebt_micromodal.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UuFtw5Q8hlkws7oxPOMwDUQdLg1VvFThNrchcXpdFdc\";}s:2:\"id\";s:36:\"block_content.ebt_micromodal.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:26:\"field_ebt_micromodal_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_quote.default',	'a:11:{s:4:\"uuid\";s:36:\"7606605a-9eff-4f52-aff9-3a7d785bb2a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:40:\"field.field.block_content.ebt_quote.body\";i:2;s:58:\"field.field.block_content.ebt_quote.field_ebt_quote_author\";i:3;s:57:\"field.field.block_content.ebt_quote.field_ebt_quote_image\";i:4;s:54:\"field.field.block_content.ebt_quote.field_ebt_settings\";i:5;s:23:\"image.style.quote_image\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xpCHQRrtCqVeeuVSJ231HGw2oStHov2UFyb3zRr3Oik\";}s:2:\"id\";s:31:\"block_content.ebt_quote.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_quote_author\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_quote_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:11:\"quote_image\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_slick_slider.default',	'a:11:{s:4:\"uuid\";s:36:\"8feddd3f-45a8-46bf-a16f-2be6634a45ea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:47:\"field.field.block_content.ebt_slick_slider.body\";i:2;s:61:\"field.field.block_content.ebt_slick_slider.field_ebt_settings\";i:3;s:65:\"field.field.block_content.ebt_slick_slider.field_ebt_slick_slider\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hPQzjkILUgWxfntdmuZ6HzJR7VFbSsJzCXcSrlrzRdY\";}s:2:\"id\";s:38:\"block_content.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_slick_slider\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_slideshow.default',	'a:11:{s:4:\"uuid\";s:36:\"764e5ba9-f7cd-4885-88bb-ab706b279f69\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:58:\"field.field.block_content.ebt_slideshow.field_ebt_settings\";i:2;s:59:\"field.field.block_content.ebt_slideshow.field_ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mtWCnFfgKEeW85VC8B0w6c1438S-bOGUJEppAIJAakE\";}s:2:\"id\";s:35:\"block_content.ebt_slideshow.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:19:\"field_ebt_slideshow\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:18:\"field_ebt_settings\";b:1;}}'),
('',	'core.entity_view_display.block_content.ebt_stats.default',	'a:11:{s:4:\"uuid\";s:36:\"8c54cc11-1b16-48f3-a610-44727c203a3d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:40:\"field.field.block_content.ebt_stats.body\";i:2;s:54:\"field.field.block_content.ebt_stats.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_stats.field_ebt_stats\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M6fW5L7z_DmzcpI5BCl95NixIxJEv1cpCEL2n4x9zpo\";}s:2:\"id\";s:31:\"block_content.ebt_stats.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:15:\"field_ebt_stats\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_tabs.default',	'a:11:{s:4:\"uuid\";s:36:\"62183f0d-0b60-47ba-bb16-40798a4776ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:53:\"field.field.block_content.ebt_tabs.field_ebt_settings\";i:2;s:49:\"field.field.block_content.ebt_tabs.field_ebt_tabs\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I2VT_ayFTNxciojtahrIwigBhAXkhZMO4_sAejsopW0\";}s:2:\"id\";s:30:\"block_content.ebt_tabs.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:14:\"field_ebt_tabs\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_text.default',	'a:11:{s:4:\"uuid\";s:36:\"b33df2ac-91d5-4257-bfa4-bb4911c6a960\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:39:\"field.field.block_content.ebt_text.body\";i:2;s:53:\"field.field.block_content.ebt_text.field_ebt_settings\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l_0JH2bJx47kWrf-7eYOBgwIV1dRWjVeLv68ugJKxso\";}s:2:\"id\";s:30:\"block_content.ebt_text.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_tiles.default',	'a:11:{s:4:\"uuid\";s:36:\"fb6bfaa3-7636-41c1-a411-dff1def2fef0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:40:\"field.field.block_content.ebt_tiles.body\";i:2;s:54:\"field.field.block_content.ebt_tiles.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_tiles.field_ebt_tiles\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rX3FVFGQ9cD5O0wbYbIxbj872CHdsK9aIut1PNuAeVI\";}s:2:\"id\";s:31:\"block_content.ebt_tiles.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:15:\"field_ebt_tiles\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_timeline.default',	'a:11:{s:4:\"uuid\";s:36:\"1395e5da-67f6-420f-a32d-094a7d218bd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:57:\"field.field.block_content.ebt_timeline.field_ebt_settings\";i:2;s:57:\"field.field.block_content.ebt_timeline.field_ebt_timeline\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bfJtQm_JGhXjpffKuejK_QMbyA4fxEqMrVt-N98sqZo\";}s:2:\"id\";s:34:\"block_content.ebt_timeline.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_timeline\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_video.default',	'a:11:{s:4:\"uuid\";s:36:\"96a65454-d2c6-4d47-8247-42a53fffe403\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:40:\"field.field.block_content.ebt_video.body\";i:2;s:54:\"field.field.block_content.ebt_video.field_ebt_settings\";i:3;s:51:\"field.field.block_content.ebt_video.field_ebt_video\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2csH7beKeLrgGpTLBYSVXXoJzKb7u0PjD1AUlW6AzbU\";}s:2:\"id\";s:31:\"block_content.ebt_video.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:15:\"field_ebt_video\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:9:\"ebt_video\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_video_and_image_gallery.default',	'a:11:{s:4:\"uuid\";s:36:\"b7590d64-18fe-489a-8317-2999e71355e3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:58:\"field.field.block_content.ebt_video_and_image_gallery.body\";i:2;s:72:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_settings\";i:3;s:81:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:26:\"entity_reference_revisions\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GRVAFs0nqUHdsiSZnjDv7msUFBQh_m8jr87a-UZhMEs\";}s:2:\"id\";s:49:\"block_content.ebt_video_and_image_gallery.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_videos_and_images\";a:6:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_views.default',	'a:11:{s:4:\"uuid\";s:36:\"65ebcab1-d240-4884-855d-df0c65f731df\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:40:\"field.field.block_content.ebt_views.body\";i:2;s:54:\"field.field.block_content.ebt_views.field_ebt_settings\";i:3;s:57:\"field.field.block_content.ebt_views.field_ebt_views_views\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P_rfCoJ0TGHiNoFYHjaR-ngK4cjbqANziLUpxF5UBZM\";}s:2:\"id\";s:31:\"block_content.ebt_views.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:4:\"type\";s:20:\"ebt_settings_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_views_views\";a:6:{s:4:\"type\";s:24:\"viewsreference_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:5:{s:4:\"page\";s:4:\"page\";s:5:\"block\";s:5:\"block\";s:7:\"default\";s:1:\"0\";s:4:\"feed\";s:1:\"0\";s:5:\"embed\";s:1:\"0\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_webform.default',	'a:11:{s:4:\"uuid\";s:36:\"dc06c30d-3cfa-4f39-809f-8390cd056466\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:42:\"field.field.block_content.ebt_webform.body\";i:2;s:56:\"field.field.block_content.ebt_webform.field_ebt_settings\";i:3;s:60:\"field.field.block_content.ebt_webform.field_ebt_webform_form\";}s:6:\"module\";a:3:{i:0;s:8:\"ebt_core\";i:1;s:4:\"text\";i:2;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gpru4Rd0T0JY8wkKLrvgy_u9NIovpL4X5IKCjcykrUE\";}s:2:\"id\";s:33:\"block_content.ebt_webform.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:3;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_webform_form\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:13:\"source_entity\";b:1;}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.block_content.ebt_webform_popup.default',	'a:11:{s:4:\"uuid\";s:36:\"8d599765-5bbf-4aff-b2cb-bd108e6c5046\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:62:\"field.field.block_content.ebt_webform_popup.field_ebt_settings\";i:2;s:72:\"field.field.block_content.ebt_webform_popup.field_ebt_webform_popup_form\";}s:6:\"module\";a:2:{i:0;s:8:\"ebt_core\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AkhheynCt4FPPMFnHY7nwaoh-xmCWBAFHkUSVVu-DN8\";}s:2:\"id\";s:39:\"block_content.ebt_webform_popup.default\";s:16:\"targetEntityType\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:18:\"field_ebt_settings\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:20:\"ebt_settings_default\";s:6:\"region\";s:7:\"content\";}s:28:\"field_ebt_webform_popup_form\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:13:\"source_entity\";b:1;}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:36:\"webform_entity_reference_entity_view\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.media.audio.default',	'a:11:{s:4:\"uuid\";s:36:\"38a6ca87-814c-4d4a-b346-9326e4c72021\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AS765MdDfNpK6K5eE7WVnBvpynClz_havy1R3bO3gVo\";}s:2:\"id\";s:19:\"media.audio.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_audio_file\";a:6:{s:4:\"type\";s:10:\"file_audio\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:4:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.audio.media_library',	'a:11:{s:4:\"uuid\";s:36:\"ede5e29a-aefb-40b5-9859-1ac8ed22e499\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.audio.field_media_audio_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tcAUW1Xzq5Tjw5jomR6XKGSgfiXO7QiRAHJBF-n0akg\";}s:2:\"id\";s:25:\"media.audio.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_audio_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.document.default',	'a:11:{s:4:\"uuid\";s:36:\"beb45182-e505-48ae-a153-5d34274d8013\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.field.media.document.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XxUyhaTuM0OUUZpr8G6jdrFBEh5eag7auWxBKhm6cvY\";}s:2:\"id\";s:22:\"media.document.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:20:\"field_media_document\";a:6:{s:4:\"type\";s:12:\"file_default\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.document.media_library',	'a:11:{s:4:\"uuid\";s:36:\"b0e61493-d3f5-4a7d-8ead-492300acdf21\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:47:\"field.field.media.document.field_media_document\";i:2;s:21:\"image.style.thumbnail\";i:3;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YcWqjhIlo-2RZUM5ogvRsrKB7M3voF2XB3lVLwgOlLU\";}s:2:\"id\";s:28:\"media.document.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:20:\"field_media_document\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.default',	'a:11:{s:4:\"uuid\";s:36:\"c80bfe30-db84-4270-a319-1c27729f2edf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:41:\"field.field.media.image.field_media_image\";i:1;s:17:\"image.style.large\";i:2;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"73xaTNkI5J6sfFcBmNYeuk070X3mQS_iwwWaPYyfG2M\";}s:2:\"id\";s:19:\"media.image.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:5:\"large\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.ebt_image_gallery',	'a:11:{s:4:\"uuid\";s:36:\"a35ebe6b-2715-41f7-a570-96ae3af68c78\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:45:\"core.entity_view_mode.media.ebt_image_gallery\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:29:\"image.style.ebt_gallery_image\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9KEafftKnenx_jl3tACupmwb0WA-eaq31pCE89gmGaY\";}s:2:\"id\";s:29:\"media.image.ebt_image_gallery\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:17:\"ebt_image_gallery\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:17:\"ebt_gallery_image\";s:26:\"glightbox_node_style_first\";s:17:\"ebt_gallery_image\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:6:\"parent\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.media_library',	'a:11:{s:4:\"uuid\";s:36:\"f69a9286-8f3b-42cf-a15a-5f569ca96e99\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:18:\"image.style.medium\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ILLWu5KFvbsX6J7sh2Itd4w8-lBBRhR_H8ZrmQiN2yo\";}s:2:\"id\";s:25:\"media.image.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:17:\"field_media_image\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.image.video_and_image_gallery_item',	'a:11:{s:4:\"uuid\";s:36:\"513a5e40-b967-4358-8200-0c9cd79302cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:56:\"core.entity_view_mode.media.video_and_image_gallery_item\";i:1;s:41:\"field.field.media.image.field_media_image\";i:2;s:39:\"image.style.ebt_video_and_image_gallery\";i:3;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:9:\"glightbox\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"71w4ybrqWdKueRDFJwcgki2l30Gpyrl7WRkhoMS7C6M\";}s:2:\"id\";s:40:\"media.image.video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:4:\"mode\";s:28:\"video_and_image_gallery_item\";s:7:\"content\";a:1:{s:17:\"field_media_image\";a:6:{s:4:\"type\";s:9:\"glightbox\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:20:\"glightbox_node_style\";s:27:\"ebt_video_and_image_gallery\";s:26:\"glightbox_node_style_first\";s:0:\"\";s:21:\"glightbox_image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.default',	'a:11:{s:4:\"uuid\";s:36:\"7b9a2dff-1714-4265-92f5-b08cb9237f6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZdPcl2hPxl5pgv3pI-07R7h51OjeUeKJTy-ab1NfM34\";}s:2:\"id\";s:26:\"media.remote_video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:6:\"oembed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:9:\"max_width\";i:0;s:10:\"max_height\";i:0;s:7:\"loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.ebt_video',	'a:11:{s:4:\"uuid\";s:36:\"1e1b792b-f71b-470f-9810-bc2e2d11f17f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:37:\"core.entity_view_mode.media.ebt_video\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NHnPc8vxx5bXjFmHokLtYvI3ebeo_FybRqjMNEhIVOg\";}s:2:\"id\";s:28:\"media.remote_video.ebt_video\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:9:\"ebt_video\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:0:\"\";s:17:\"glightbox_gallery\";s:4:\"post\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"e91b1f8e-5ba5-485e-9c6e-04afe2948e85\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:18:\"image.style.medium\";i:3;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PGGoP-hVkXe_S-GiJRAub4PHDu0KhMExylclrqjdJb4\";}s:2:\"id\";s:32:\"media.remote_video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:6:\"medium\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:24:\"field_media_oembed_video\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.remote_video.video_and_image_gallery_item',	'a:11:{s:4:\"uuid\";s:36:\"9672ae47-7a64-49d5-904a-cba847d9377d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:56:\"core.entity_view_mode.media.video_and_image_gallery_item\";i:1;s:55:\"field.field.media.remote_video.field_media_oembed_video\";i:2;s:23:\"media.type.remote_video\";}s:6:\"module\";a:1:{i:0;s:21:\"glightbox_media_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0gtodl3N0wRFdXaP60sG0h05qbgCOF8wy6ggVWOa8UY\";}s:2:\"id\";s:47:\"media.remote_video.video_and_image_gallery_item\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:4:\"mode\";s:28:\"video_and_image_gallery_item\";s:7:\"content\";a:1:{s:24:\"field_media_oembed_video\";a:6:{s:4:\"type\";s:28:\"glightbox_media_remote_video\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:10:{s:9:\"max_width\";s:1:\"0\";s:10:\"max_height\";s:1:\"0\";s:7:\"loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:7:\"display\";s:9:\"thumbnail\";s:9:\"link_text\";s:10:\"View Video\";s:11:\"image_style\";s:27:\"ebt_video_and_image_gallery\";s:17:\"glightbox_gallery\";s:9:\"paragraph\";s:24:\"glightbox_gallery_custom\";s:0:\"\";s:17:\"glightbox_caption\";s:4:\"auto\";s:24:\"glightbox_caption_custom\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.video.default',	'a:11:{s:4:\"uuid\";s:36:\"863188fb-17da-49e4-8e79-ddeb23903eef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"field.field.media.video.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SxvbuGh-6cQMxl9bBV27-hGI46u7ZvwlMm5ObaJMNnw\";}s:2:\"id\";s:19:\"media.video.default\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:1:{s:22:\"field_media_video_file\";a:6:{s:4:\"type\";s:10:\"file_video\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";s:5:\"muted\";b:0;s:5:\"width\";i:640;s:6:\"height\";i:480;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.video.ebt_video',	'a:11:{s:4:\"uuid\";s:36:\"7bab1942-d337-4497-a621-f6cc29536967\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:37:\"core.entity_view_mode.media.ebt_video\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PhLS2RcsgmXaRpOr6Z569J0KXiE9KNW5OMTC9dvUTkg\";}s:2:\"id\";s:21:\"media.video.ebt_video\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:9:\"ebt_video\";s:7:\"content\";a:1:{s:22:\"field_media_video_file\";a:6:{s:4:\"type\";s:10:\"file_video\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:7:{s:8:\"controls\";b:1;s:8:\"autoplay\";b:0;s:4:\"loop\";b:0;s:26:\"multiple_file_display_type\";s:4:\"tags\";s:5:\"muted\";b:0;s:5:\"width\";i:640;s:6:\"height\";i:480;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:4:\"name\";b:1;s:9:\"thumbnail\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.media.video.media_library',	'a:11:{s:4:\"uuid\";s:36:\"d00b3c78-35a0-460e-a063-a98a387591cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:4:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:46:\"field.field.media.video.field_media_video_file\";i:2;s:21:\"image.style.thumbnail\";i:3;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_fnkUKwQYHkXO1Ngmq9nE6FqWUNAmkddOxAH1h5aiKg\";}s:2:\"id\";s:25:\"media.video.media_library\";s:16:\"targetEntityType\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:4:\"mode\";s:13:\"media_library\";s:7:\"content\";a:1:{s:9:\"thumbnail\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:4:{s:7:\"created\";b:1;s:22:\"field_media_video_file\";b:1;s:4:\"name\";b:1;s:3:\"uid\";b:1;}}'),
('',	'core.entity_view_display.node.article.default',	'a:12:{s:4:\"uuid\";s:36:\"97d9050c-f2b4-4b7e-9f3f-10de564e06a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:29:\"field.field.node.article.body\";i:1;s:36:\"field.field.node.article.field_image\";i:2;s:39:\"field.field.node.article.field_metatags\";i:3;s:35:\"field.field.node.article.field_tags\";i:4;s:16:\"image.style.wide\";i:5;s:17:\"node.type.article\";}s:6:\"module\";a:5:{i:0;s:14:\"layout_builder\";i:1;s:7:\"metatag\";i:2;s:9:\"svg_image\";i:3;s:4:\"text\";i:4;s:4:\"user\";}}s:20:\"third_party_settings\";a:1:{s:14:\"layout_builder\";a:3:{s:7:\"enabled\";b:1;s:12:\"allow_custom\";b:1;s:8:\"sections\";a:1:{i:0;a:4:{s:9:\"layout_id\";s:13:\"layout_onecol\";s:15:\"layout_settings\";a:1:{s:5:\"label\";s:0:\"\";}s:10:\"components\";a:5:{s:36:\"3120cf62-1cc1-4e2b-96e0-0996d5d6928a\";a:5:{s:4:\"uuid\";s:36:\"3120cf62-1cc1-4e2b-96e0-0996d5d6928a\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:36:\"field_block:node:article:field_image\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:14:\"svg_attributes\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}s:19:\"svg_render_as_image\";b:1;}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:0;s:10:\"additional\";a:0:{}}s:36:\"7f5f46b4-472b-4e74-9a01-8a03e0321444\";a:5:{s:4:\"uuid\";s:36:\"7f5f46b4-472b-4e74-9a01-8a03e0321444\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:29:\"field_block:node:article:body\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:1;s:10:\"additional\";a:0:{}}s:36:\"b902a34b-a3ce-4efc-a85b-86bb824651b9\";a:5:{s:4:\"uuid\";s:36:\"b902a34b-a3ce-4efc-a85b-86bb824651b9\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:35:\"field_block:node:article:field_tags\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:2;s:10:\"additional\";a:0:{}}s:36:\"25d5958c-bea2-4027-8bae-b924b89dce41\";a:5:{s:4:\"uuid\";s:36:\"25d5958c-bea2-4027-8bae-b924b89dce41\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:3:{s:2:\"id\";s:36:\"extra_field_block:node:article:links\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}}s:6:\"weight\";i:3;s:10:\"additional\";a:0:{}}s:36:\"667348d3-3500-418a-b027-8b25f62317df\";a:5:{s:4:\"uuid\";s:36:\"667348d3-3500-418a-b027-8b25f62317df\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:39:\"field_block:node:article:field_metatags\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:4;s:10:\"additional\";a:0:{}}}s:20:\"third_party_settings\";a:0:{}}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"br6izr-iGEu--JvNbCJNtOBpRnxpFLXfoV5y61U9Nqc\";}s:2:\"id\";s:20:\"node.article.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:4:\"wide\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}s:14:\"svg_attributes\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}s:19:\"svg_render_as_image\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:14:\"field_metatags\";a:6:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.node.article.rss',	'a:11:{s:4:\"uuid\";s:36:\"2e2f92c3-c50a-4139-9c95-4e46ce1f757d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:39:\"field.field.node.article.field_metatags\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:47:\"field.field.node.article.layout_builder__layout\";i:6;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2rIr6K5Q0UQ9khg0zE_CK-PtJH76UL-BDDZcZnZzwCc\";}s:2:\"id\";s:16:\"node.article.rss\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:3:\"rss\";s:7:\"content\";a:1:{s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:5:{s:4:\"body\";b:1;s:11:\"field_image\";b:1;s:14:\"field_metatags\";b:1;s:10:\"field_tags\";b:1;s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_view_display.node.article.teaser',	'a:11:{s:4:\"uuid\";s:36:\"08318816-b086-4cdd-b48c-c020f5a6f328\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:8:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:29:\"field.field.node.article.body\";i:2;s:36:\"field.field.node.article.field_image\";i:3;s:39:\"field.field.node.article.field_metatags\";i:4;s:35:\"field.field.node.article.field_tags\";i:5;s:47:\"field.field.node.article.layout_builder__layout\";i:6;s:18:\"image.style.medium\";i:7;s:17:\"node.type.article\";}s:6:\"module\";a:3:{i:0;s:9:\"svg_image\";i:1;s:4:\"text\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"O8PxzfG8DOHHRu6M23kwR6TDPq_MNfYQ10Mp367ICUQ\";}s:2:\"id\";s:19:\"node.article.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:4:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:11:\"field_image\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:7:\"content\";s:11:\"image_style\";s:6:\"medium\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:-1;s:6:\"region\";s:7:\"content\";}s:10:\"field_tags\";a:6:{s:4:\"type\";s:22:\"entity_reference_label\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:10;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:14:\"field_metatags\";b:1;s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_view_display.node.page.default',	'a:12:{s:4:\"uuid\";s:36:\"5aaa71f3-3511-4b50-8003-331c936478f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:26:\"field.field.node.page.body\";i:1;s:36:\"field.field.node.page.field_metatags\";i:2;s:14:\"node.type.page\";}s:6:\"module\";a:4:{i:0;s:14:\"layout_builder\";i:1;s:7:\"metatag\";i:2;s:4:\"text\";i:3;s:4:\"user\";}}s:20:\"third_party_settings\";a:1:{s:14:\"layout_builder\";a:3:{s:7:\"enabled\";b:1;s:12:\"allow_custom\";b:1;s:8:\"sections\";a:1:{i:0;a:4:{s:9:\"layout_id\";s:13:\"layout_onecol\";s:15:\"layout_settings\";a:1:{s:5:\"label\";s:0:\"\";}s:10:\"components\";a:3:{s:36:\"38a9abee-f957-4c37-bf25-26572a864786\";a:5:{s:4:\"uuid\";s:36:\"38a9abee-f957-4c37-bf25-26572a864786\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:26:\"field_block:node:page:body\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:0;s:10:\"additional\";a:0:{}}s:36:\"49025aed-c7ef-4f99-bdb3-01a066d936cf\";a:5:{s:4:\"uuid\";s:36:\"49025aed-c7ef-4f99-bdb3-01a066d936cf\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:3:{s:2:\"id\";s:33:\"extra_field_block:node:page:links\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}}s:6:\"weight\";i:1;s:10:\"additional\";a:0:{}}s:36:\"022c3459-1bc8-481c-aea0-dc1a493c5abb\";a:5:{s:4:\"uuid\";s:36:\"022c3459-1bc8-481c-aea0-dc1a493c5abb\";s:6:\"region\";s:7:\"content\";s:13:\"configuration\";a:4:{s:2:\"id\";s:36:\"field_block:node:page:field_metatags\";s:13:\"label_display\";s:1:\"0\";s:15:\"context_mapping\";a:1:{s:6:\"entity\";s:21:\"layout_builder.entity\";}s:9:\"formatter\";a:4:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}}}s:6:\"weight\";i:2;s:10:\"additional\";a:0:{}}}s:20:\"third_party_settings\";a:0:{}}}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Y8L5tfmhx7DR143E05YyZSpvgil6VFvqcfBWykalg\";}s:2:\"id\";s:17:\"node.page.default\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:4:\"body\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:14:\"field_metatags\";a:6:{s:4:\"type\";s:23:\"metatag_empty_formatter\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:102;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:4:{s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.node.page.teaser',	'a:11:{s:4:\"uuid\";s:36:\"0cdde055-9011-4c16-b82c-494a58ce39ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:33:\"core.entity_view_mode.node.teaser\";i:1;s:26:\"field.field.node.page.body\";i:2;s:36:\"field.field.node.page.field_metatags\";i:3;s:44:\"field.field.node.page.layout_builder__layout\";i:4;s:14:\"node.type.page\";}s:6:\"module\";a:2:{i:0;s:4:\"text\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8BgdRtLbtQ0F__o0FHSH0Mx5fvXOra9tfT1GmNKbRYw\";}s:2:\"id\";s:16:\"node.page.teaser\";s:16:\"targetEntityType\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:4:\"mode\";s:6:\"teaser\";s:7:\"content\";a:2:{s:4:\"body\";a:6:{s:4:\"type\";s:23:\"text_summary_or_trimmed\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"trim_length\";i:600;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:100;s:6:\"region\";s:7:\"content\";}s:5:\"links\";a:2:{s:6:\"weight\";i:101;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:2:{s:14:\"field_metatags\";b:1;s:22:\"layout_builder__layout\";b:1;}}'),
('',	'core.entity_view_display.paragraph.ebt_accordion.default',	'a:11:{s:4:\"uuid\";s:36:\"d7bca4fc-d99f-4966-929d-15f5247c8564\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:60:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_text\";i:1;s:61:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_title\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yn5RBnnmFE_Y5sCchtXzAOZg0joBlJrWIBEaYAnP9Ps\";}s:2:\"id\";s:31:\"paragraph.ebt_accordion.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:24:\"field_ebt_accordion_text\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_accordion_title\";a:6:{s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_carousel.default',	'a:11:{s:4:\"uuid\";s:36:\"2e2b2311-9c14-4e94-aecd-97a3f060f45a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:61:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_caption\";i:1;s:59:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o21VkkuJdszAqDOznTVc61VIxPQJc6ocyXSW3qSQFHc\";}s:2:\"id\";s:30:\"paragraph.ebt_carousel.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:26:\"field_ebt_carousel_caption\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_carousel_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:11:\"image_style\";s:0:\"\";s:10:\"image_link\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_counter_item.default',	'a:11:{s:4:\"uuid\";s:36:\"9cd9785e-414b-4ccf-a6f4-9b5039218fd0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:68:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_description\";i:1;s:61:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_icon\";i:2;s:63:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_number\";i:3;s:62:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_title\";i:4;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EjbsMNoEaP6Z3U6dn1mNEir0yNE1gFyyIzkKiYVPO_4\";}s:2:\"id\";s:34:\"paragraph.ebt_counter_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:29:\"field_ebt_counter_description\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:22:\"field_ebt_counter_icon\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_counter_number\";a:6:{s:4:\"type\";s:14:\"number_integer\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_counter_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_slick_slider.default',	'a:11:{s:4:\"uuid\";s:36:\"152c6a3e-8703-40b0-ad21-283b4ae6cc5b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:67:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_image\";i:1;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_link\";i:2;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_text\";i:3;s:29:\"image.style.slick_slider_card\";i:4;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VVV9wfo5l1gK1weU695gzyXqp5on_oNav7jAwjjWowQ\";}s:2:\"id\";s:34:\"paragraph.ebt_slick_slider.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:3:{s:28:\"field_ebt_slick_slider_image\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:17:\"slick_slider_card\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_slick_slider_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:27:\"field_ebt_slick_slider_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_slideshow.default',	'a:11:{s:4:\"uuid\";s:36:\"5003e24e-550b-4a07-a87f-66e0dbab0e83\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_link\";i:1;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_slide\";i:2;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_text\";i:3;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_title\";i:4;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:5:\"media\";i:2;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-TV7U97Wd40UA7J_3-aQjPyYv360Wi3Te0PPvYviuxU\";}s:2:\"id\";s:31:\"paragraph.ebt_slideshow.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:24:\"field_ebt_slideshow_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1023;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_slideshow_slide\";a:6:{s:4:\"type\";s:15:\"media_thumbnail\";s:5:\"label\";s:15:\"visually_hidden\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:0:\"\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_slideshow_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:25:\"field_ebt_slideshow_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_stats_item.default',	'a:11:{s:4:\"uuid\";s:36:\"77949beb-f2e0-46a7-bbe3-3ede2ef7f061\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:5:{i:0;s:59:\"field.field.paragraph.ebt_stats_item.field_stats_item_image\";i:1;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_link\";i:2;s:60:\"field.field.paragraph.ebt_stats_item.field_stats_item_number\";i:3;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_text\";i:4;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5RDw3deJvwfKptyvRWt0uMj5O3zRyWKrJCZ_MFWk7Po\";}s:2:\"id\";s:32:\"paragraph.ebt_stats_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:4:{s:22:\"field_stats_item_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:21:\"field_stats_item_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:1024;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:23:\"field_stats_item_number\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:21:\"field_stats_item_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_tab.default',	'a:11:{s:4:\"uuid\";s:36:\"4b41c82a-77c1-47f0-a052-9b87649b8136\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:7:{i:0;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_block\";i:1;s:51:\"field.field.paragraph.ebt_tab.field_ebt_tab_content\";i:2;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_page\";i:3;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_text\";i:4;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_title\";i:5;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_views\";i:6;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:3:{i:0;s:11:\"block_field\";i:1;s:4:\"text\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"slUTwjnod77jaefmi2b5OQYl4vYxpAodJPHvoHGvQUA\";}s:2:\"id\";s:25:\"paragraph.ebt_tab.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:19:\"field_ebt_tab_block\";a:6:{s:6:\"weight\";i:6;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:11:\"block_field\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_page\";a:6:{s:6:\"weight\";i:1;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:4:\"link\";b:1;s:9:\"view_mode\";s:7:\"default\";}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:28:\"entity_reference_entity_view\";s:6:\"region\";s:7:\"content\";}s:18:\"field_ebt_tab_text\";a:6:{s:6:\"weight\";i:2;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_title\";a:6:{s:6:\"weight\";i:0;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:12:\"text_default\";s:6:\"region\";s:7:\"content\";}s:19:\"field_ebt_tab_views\";a:6:{s:6:\"weight\";i:5;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:12:\"plugin_types\";a:1:{i:0;s:5:\"block\";}}s:20:\"third_party_settings\";a:0:{}s:4:\"type\";s:24:\"viewsreference_formatter\";s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:21:\"field_ebt_tab_content\";b:1;}}'),
('',	'core.entity_view_display.paragraph.ebt_tiles_item.default',	'a:11:{s:4:\"uuid\";s:36:\"4ccbb938-c11d-49a7-ba57-753328efb08b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_tiles_item.field_ebt_clickable_tile\";i:1;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_image\";i:2;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_link\";i:3;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_text\";i:4;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_title\";i:5;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZHOP2C6K3eAHsBjc_FJwNsbIKZ-XL88CGUz5EexQ8nE\";}s:2:\"id\";s:32:\"paragraph.ebt_tiles_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:24:\"field_ebt_clickable_tile\";a:6:{s:4:\"type\";s:7:\"boolean\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:3:{s:6:\"format\";s:7:\"default\";s:19:\"format_custom_false\";s:0:\"\";s:18:\"format_custom_true\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_tiles_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_tiles_link\";a:6:{s:4:\"type\";s:4:\"link\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:5:{s:11:\"trim_length\";i:800;s:8:\"url_only\";b:0;s:9:\"url_plain\";b:0;s:3:\"rel\";s:1:\"0\";s:6:\"target\";s:1:\"0\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:3;s:6:\"region\";s:7:\"content\";}s:20:\"field_ebt_tiles_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:21:\"field_ebt_tiles_title\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_timeline.default',	'a:11:{s:4:\"uuid\";s:36:\"553c2833-822a-4508-a2f9-99f9ffc89f33\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:6:{i:0;s:61:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_current\";i:1;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_date\";i:2;s:65:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_media_image\";i:3;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_text\";i:4;s:59:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_title\";i:5;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kScbPfdPZDsoEdHqJtQ9QjqdBXgkz2VT-TEA4uO4yQU\";}s:2:\"id\";s:30:\"paragraph.ebt_timeline.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:5:{s:26:\"field_ebt_timeline_current\";a:6:{s:4:\"type\";s:7:\"boolean\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:6:\"format\";s:7:\"default\";s:19:\"format_custom_false\";s:0:\"\";s:18:\"format_custom_true\";s:0:\"\";}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:4;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_timeline_date\";a:6:{s:4:\"type\";s:6:\"string\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}s:30:\"field_ebt_timeline_media_image\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:5:\"above\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:7:\"default\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:23:\"field_ebt_timeline_text\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:2;s:6:\"region\";s:7:\"content\";}s:24:\"field_ebt_timeline_title\";a:6:{s:4:\"type\";s:6:\"string\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.paragraph.ebt_video_and_image_gallery_item.default',	'a:11:{s:4:\"uuid\";s:36:\"0a70dbed-c211-4ec2-a7e5-7d9b701046db\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:85:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description\";i:1;s:79:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item\";i:2;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ATQKQ04wbZpenyUY_sMfDM08puKPXNvoGB5tSxGxwG0\";}s:2:\"id\";s:50:\"paragraph.ebt_video_and_image_gallery_item.default\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:30:\"field_gallery_item_description\";a:6:{s:4:\"type\";s:12:\"text_default\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:0:{}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:1;s:6:\"region\";s:7:\"content\";}s:24:\"field_video_gallery_item\";a:6:{s:4:\"type\";s:28:\"entity_reference_entity_view\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:2:{s:9:\"view_mode\";s:28:\"video_and_image_gallery_item\";s:4:\"link\";b:0;}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_display.user.user.compact',	'a:11:{s:4:\"uuid\";s:36:\"73223d5a-b425-4fba-9090-7b112d030f92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:34:\"core.entity_view_mode.user.compact\";i:1;s:34:\"field.field.user.user.user_picture\";i:2;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"00zr_RBdTjPjBGITD3h4c1ESQZimjdVCcHGt1trLqIY\";}s:2:\"id\";s:17:\"user.user.compact\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"compact\";s:7:\"content\";a:1:{s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:1:{s:10:\"member_for\";b:1;}}'),
('',	'core.entity_view_display.user.user.default',	'a:11:{s:4:\"uuid\";s:36:\"1c220693-f471-4184-9453-cd90fc0030d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:34:\"field.field.user.user.user_picture\";i:1;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mZLyuWM9CQx2ZJVqFGSbzgFnHzudVbHBYmdU256A5Wk\";}s:2:\"id\";s:17:\"user.user.default\";s:16:\"targetEntityType\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:4:\"mode\";s:7:\"default\";s:7:\"content\";a:2:{s:10:\"member_for\";a:2:{s:6:\"weight\";i:5;s:6:\"region\";s:7:\"content\";}s:12:\"user_picture\";a:6:{s:4:\"type\";s:5:\"image\";s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:3:{s:11:\"image_style\";s:9:\"thumbnail\";s:10:\"image_link\";s:7:\"content\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:20:\"third_party_settings\";a:0:{}s:6:\"weight\";i:0;s:6:\"region\";s:7:\"content\";}}s:6:\"hidden\";a:0:{}}'),
('',	'core.entity_view_mode.block.token',	'a:9:{s:4:\"uuid\";s:36:\"c298243a-fc61-46e8-8878-5de88a9bcb0b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"block\";}}s:2:\"id\";s:11:\"block.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"block\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.block_content.full',	'a:10:{s:4:\"uuid\";s:36:\"9268fa23-36f9-4a94-a9ef-799f2d1c5eb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q7yUUYeRLByl-MCGveKKF_KhAtNICLCMJuKWfugCvso\";}s:2:\"id\";s:18:\"block_content.full\";s:5:\"label\";s:4:\"Full\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.block_content.token',	'a:9:{s:4:\"uuid\";s:36:\"004ad1d4-03ad-4317-af82-4bb9f039c686\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:2:\"id\";s:19:\"block_content.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"block_content\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.contact_message.token',	'a:9:{s:4:\"uuid\";s:36:\"b51e5b3c-1a2e-49cf-acff-bfc2dea5ad40\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"contact\";}}s:2:\"id\";s:21:\"contact_message.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:15:\"contact_message\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.file.token',	'a:9:{s:4:\"uuid\";s:36:\"99749d8d-98ee-49e8-b272-054f53d7c97f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:2:\"id\";s:10:\"file.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"file\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.ebt_image_gallery',	'a:10:{s:4:\"uuid\";s:36:\"d8772b40-e75a-46fe-a0eb-48e3c2f13441\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gx3dAzTlzUoOPV6nrqIxtsHu6AWtMEd6M4HRihgOIdc\";}s:2:\"id\";s:23:\"media.ebt_image_gallery\";s:5:\"label\";s:17:\"EBT Image Gallery\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.ebt_video',	'a:10:{s:4:\"uuid\";s:36:\"9ff59caf-8ee9-4fca-bffa-89132c94c813\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IXsnV3TXq49eaMlltbjpSWIiseAysJRe042Revn8t1s\";}s:2:\"id\";s:15:\"media.ebt_video\";s:5:\"label\";s:9:\"EBT Video\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.full',	'a:10:{s:4:\"uuid\";s:36:\"fb758fd6-28cd-4155-8eda-49912e1da3f8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dTfAUHooYV0uOVPO3saGpgv-c5PppJXDwxvwRTJOycM\";}s:2:\"id\";s:10:\"media.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.media_library',	'a:10:{s:4:\"uuid\";s:36:\"1a098749-bd7d-429f-9d91-d4e7913c8c3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"04_dAqpWYP1WmsXZ7IXJ7-yarCvNddD10EUkBDtIFy4\";}s:2:\"id\";s:19:\"media.media_library\";s:5:\"label\";s:13:\"Media library\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.token',	'a:9:{s:4:\"uuid\";s:36:\"aa6556df-5384-471d-96b4-a6d264801693\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:2:\"id\";s:11:\"media.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.media.video_and_image_gallery_item',	'a:10:{s:4:\"uuid\";s:36:\"6f5a787d-85f5-4bea-aab2-4094c6f7772f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u0M3Ybb0-9QE3E30c77uKo8PW64Vexg-TwC2IHerOgs\";}s:2:\"id\";s:34:\"media.video_and_image_gallery_item\";s:5:\"label\";s:28:\"Video and Image gallery item\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:5:\"media\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.menu_link_content.token',	'a:9:{s:4:\"uuid\";s:36:\"33a56e28-1d42-4a4f-b42a-88eb552104a7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:17:\"menu_link_content\";}}s:2:\"id\";s:23:\"menu_link_content.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:17:\"menu_link_content\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.full',	'a:10:{s:4:\"uuid\";s:36:\"5aefb664-7e3c-4ebe-86a2-07194cada9f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QJ2aZ1xfVf59aq6Pz5X7fyUOa2HxuCoTwQ_RQjoulAU\";}s:2:\"id\";s:9:\"node.full\";s:5:\"label\";s:12:\"Full content\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.rss',	'a:10:{s:4:\"uuid\";s:36:\"6b3209c3-0ae1-46f6-8e2c-44d4391f2434\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l8fiAFE3Kng_6bhLlUDnVTkTDzXWxzYFrCWTrngVXEA\";}s:2:\"id\";s:8:\"node.rss\";s:5:\"label\";s:3:\"RSS\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.search_index',	'a:10:{s:4:\"uuid\";s:36:\"416e3f7c-ab1b-4bb4-b428-aabf9906eecf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r_A0T3aTqGDwLyvoH7wLps-0PM--RHlS8UsiJe_Ac64\";}s:2:\"id\";s:17:\"node.search_index\";s:5:\"label\";s:12:\"Search index\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.search_result',	'a:10:{s:4:\"uuid\";s:36:\"c196759a-15b6-47d3-b672-f853645cc638\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d8wBEm7XvJ6H3S0IneDD9PfTBklPIH7GMpxElVemPf8\";}s:2:\"id\";s:18:\"node.search_result\";s:5:\"label\";s:32:\"Search result highlighting input\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.teaser',	'a:10:{s:4:\"uuid\";s:36:\"aa910ffb-3a87-4512-af06-273b721bc12f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KgGJDZFpMaz_8bTv6fN1bXS3Qi5LWmRJI9R53kEGsNQ\";}s:2:\"id\";s:11:\"node.teaser\";s:5:\"label\";s:6:\"Teaser\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.node.token',	'a:9:{s:4:\"uuid\";s:36:\"3ec23f24-50ef-434e-a7b6-3d8cb9a2a4f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:2:\"id\";s:10:\"node.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"node\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.paragraph.preview',	'a:10:{s:4:\"uuid\";s:36:\"f30f214f-6163-41a8-a996-f703e5fd92cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"h3BeHVei4Lnyqbkao3YiF4KqoY-DhRvUNfEgKG8Rgjg\";}s:2:\"id\";s:17:\"paragraph.preview\";s:5:\"label\";s:7:\"Preview\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:9:\"paragraph\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.path_alias.token',	'a:9:{s:4:\"uuid\";s:36:\"b47111c9-dcb8-4762-af5c-3f7acca095d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"path_alias\";}}s:2:\"id\";s:16:\"path_alias.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:10:\"path_alias\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.shortcut.token',	'a:9:{s:4:\"uuid\";s:36:\"550ba8ad-246f-433e-8c0d-f2c76255df0e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"shortcut\";}}s:2:\"id\";s:14:\"shortcut.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:8:\"shortcut\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.taxonomy_term.full',	'a:10:{s:4:\"uuid\";s:36:\"e72ba8d8-dba4-4920-91d6-5e916b81a6fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iukUENpf8CFvjZbGGacKX_Ges0-lU9z6zvsd32P6kbo\";}s:2:\"id\";s:18:\"taxonomy_term.full\";s:5:\"label\";s:18:\"Taxonomy term page\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.taxonomy_term.token',	'a:9:{s:4:\"uuid\";s:36:\"ea887f34-9e29-4000-aef4-21112004577d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:2:\"id\";s:19:\"taxonomy_term.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:13:\"taxonomy_term\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.user.compact',	'a:10:{s:4:\"uuid\";s:36:\"06ded9f9-3e1a-44f0-a5e0-224efcca6431\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TtD7OuGskOsQfoGyxXkrdtllBpR37J19d5BMQDZWJgA\";}s:2:\"id\";s:12:\"user.compact\";s:5:\"label\";s:7:\"Compact\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.user.full',	'a:10:{s:4:\"uuid\";s:36:\"ad69e028-e0a2-4eab-9d8b-d18e904da6bf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZbXunWS_xAvMZXFfinyvClDAb_RCVLt7gAzE3v16E-Q\";}s:2:\"id\";s:9:\"user.full\";s:5:\"label\";s:12:\"User account\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.user.token',	'a:9:{s:4:\"uuid\";s:36:\"676a8206-d9d0-4094-bf54-66a60c6bad53\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:10:\"user.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:4:\"user\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.webform.token',	'a:9:{s:4:\"uuid\";s:36:\"5f8faafa-6ec3-4704-a06c-08d5391b12d7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:2:\"id\";s:13:\"webform.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:7:\"webform\";s:5:\"cache\";b:1;}'),
('',	'core.entity_view_mode.webform_submission.token',	'a:9:{s:4:\"uuid\";s:36:\"92d0137a-b4c4-4c19-b07b-84c8b8844019\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:2:\"id\";s:24:\"webform_submission.token\";s:5:\"label\";s:5:\"Token\";s:11:\"description\";s:0:\"\";s:16:\"targetEntityType\";s:18:\"webform_submission\";s:5:\"cache\";b:1;}'),
('',	'core.extension',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4GIX5Esnc_umpXUBj4IIocRX7Mt5fPhm4AgXfE3E56E\";}s:6:\"module\";a:106:{s:13:\"admin_toolbar\";i:0;s:19:\"admin_toolbar_tools\";i:0;s:18:\"announcements_feed\";i:0;s:14:\"automated_cron\";i:0;s:8:\"big_pipe\";i:0;s:5:\"block\";i:0;s:13:\"block_content\";i:0;s:11:\"block_field\";i:0;s:10:\"breakpoint\";i:0;s:9:\"ckeditor5\";i:0;s:21:\"ckeditor5_plugin_pack\";i:0;s:32:\"ckeditor5_plugin_pack_auto_image\";i:0;s:38:\"ckeditor5_plugin_pack_find_and_replace\";i:0;s:26:\"ckeditor5_plugin_pack_font\";i:0;s:31:\"ckeditor5_plugin_pack_highlight\";i:0;s:34:\"ckeditor5_plugin_pack_indent_block\";i:0;s:32:\"ckeditor5_plugin_pack_page_break\";i:0;s:32:\"ckeditor5_plugin_pack_select_all\";i:0;s:31:\"ckeditor5_plugin_pack_templates\";i:0;s:41:\"ckeditor5_plugin_pack_text_transformation\";i:0;s:40:\"ckeditor5_plugin_pack_todo_document_list\";i:0;s:32:\"ckeditor5_plugin_pack_word_count\";i:0;s:37:\"ckeditor5_premium_features_fullscreen\";i:0;s:6:\"config\";i:0;s:13:\"config_ignore\";i:0;s:7:\"contact\";i:0;s:10:\"contextual\";i:0;s:8:\"datetime\";i:0;s:5:\"dblog\";i:0;s:18:\"dynamic_page_cache\";i:0;s:13:\"ebt_accordion\";i:0;s:16:\"ebt_basic_button\";i:0;s:9:\"ebt_block\";i:0;s:20:\"ebt_bootstrap_button\";i:0;s:12:\"ebt_carousel\";i:0;s:11:\"ebt_columns\";i:0;s:8:\"ebt_core\";i:0;s:13:\"ebt_countdown\";i:0;s:11:\"ebt_counter\";i:0;s:7:\"ebt_cta\";i:0;s:8:\"ebt_hero\";i:0;s:9:\"ebt_image\";i:0;s:17:\"ebt_image_gallery\";i:0;s:14:\"ebt_micromodal\";i:0;s:9:\"ebt_quote\";i:0;s:16:\"ebt_slick_slider\";i:0;s:13:\"ebt_slideshow\";i:0;s:9:\"ebt_stats\";i:0;s:8:\"ebt_tabs\";i:0;s:8:\"ebt_text\";i:0;s:9:\"ebt_tiles\";i:0;s:12:\"ebt_timeline\";i:0;s:9:\"ebt_video\";i:0;s:27:\"ebt_video_and_image_gallery\";i:0;s:9:\"ebt_views\";i:0;s:11:\"ebt_webform\";i:0;s:17:\"ebt_webform_popup\";i:0;s:6:\"editor\";i:0;s:26:\"entity_reference_revisions\";i:0;s:5:\"field\";i:0;s:11:\"field_group\";i:0;s:8:\"field_ui\";i:0;s:4:\"file\";i:0;s:6:\"filter\";i:0;s:9:\"glightbox\";i:0;s:21:\"glightbox_media_video\";i:0;s:16:\"google_analytics\";i:0;s:4:\"help\";i:0;s:7:\"history\";i:0;s:5:\"image\";i:0;s:9:\"jquery_ui\";i:0;s:19:\"jquery_ui_accordion\";i:0;s:14:\"jquery_ui_tabs\";i:0;s:14:\"layout_builder\";i:0;s:16:\"layout_discovery\";i:0;s:4:\"link\";i:0;s:6:\"linkit\";i:0;s:5:\"media\";i:0;s:13:\"media_library\";i:0;s:26:\"media_library_form_element\";i:0;s:17:\"menu_link_content\";i:0;s:7:\"menu_ui\";i:0;s:7:\"metatag\";i:0;s:4:\"node\";i:0;s:7:\"options\";i:0;s:10:\"page_cache\";i:0;s:4:\"path\";i:0;s:10:\"path_alias\";i:0;s:8:\"redirect\";i:0;s:6:\"search\";i:0;s:8:\"shortcut\";i:0;s:9:\"svg_image\";i:0;s:6:\"system\";i:0;s:8:\"taxonomy\";i:0;s:4:\"text\";i:0;s:5:\"token\";i:0;s:7:\"toolbar\";i:0;s:6:\"update\";i:0;s:4:\"user\";i:0;s:8:\"views_ui\";i:0;s:14:\"viewsreference\";i:0;s:7:\"webform\";i:0;s:8:\"pathauto\";i:1;s:5:\"views\";i:10;s:10:\"paragraphs\";i:11;s:4:\"fast\";i:1000;}s:5:\"theme\";a:2:{s:7:\"olivero\";i:0;s:5:\"claro\";i:0;}s:7:\"profile\";s:4:\"fast\";}'),
('',	'core.menu.static_menu_link_overrides',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CXhei_vpaZk-3f_Mj2cH0YmpK-ZpKHoSzVA3yZrDq0g\";}s:11:\"definitions\";a:1:{s:18:\"contact__site_page\";a:5:{s:9:\"menu_name\";s:6:\"footer\";s:6:\"parent\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:7:\"enabled\";b:1;}}}'),
('',	'dblog.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e883aGsrt1wFrsydlYU584PZONCSfRy0DtkZ9KzHb58\";}s:9:\"row_limit\";i:1000;}'),
('',	'ebt_core.settings',	'a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VBIZ2klsa-wrUk3pFOgIi3avMLFro6A0nFNYc35MvNQ\";}s:26:\"ebt_core_mobile_breakpoint\";s:3:\"640\";s:26:\"ebt_core_tablet_breakpoint\";s:4:\"1020\";s:27:\"ebt_core_desktop_breakpoint\";s:4:\"1320\";s:22:\"ebt_core_xxsmall_width\";s:3:\"480\";s:21:\"ebt_core_xsmall_width\";s:3:\"640\";s:20:\"ebt_core_small_width\";s:3:\"768\";s:22:\"ebt_core_default_width\";s:3:\"960\";s:20:\"ebt_core_large_width\";s:4:\"1100\";s:21:\"ebt_core_xlarge_width\";s:4:\"1320\";s:22:\"ebt_core_xxlarge_width\";s:4:\"1600\";s:25:\"ebt_core_background_color\";s:7:\"#0d77b5\";}'),
('',	'editor.editor.basic_html',	'a:9:{s:4:\"uuid\";s:36:\"65aded18-2f8d-4ec3-8d69-0a602798f4dd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:24:\"filter.format.basic_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qi2tIe-L97EutlMmhEvhsNxZOpOoA-RH82c4BQb5n4A\";}s:6:\"format\";s:10:\"basic_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:15:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:1:\"|\";i:3;s:4:\"link\";i:4;s:1:\"|\";i:5;s:12:\"bulletedList\";i:6;s:12:\"numberedList\";i:7;s:1:\"|\";i:8;s:10:\"blockQuote\";i:9;s:17:\"drupalInsertImage\";i:10;s:1:\"|\";i:11;s:7:\"heading\";i:12;s:4:\"code\";i:13;s:1:\"|\";i:14;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:4:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:0;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:13:{i:0;s:6:\"<cite>\";i:1;s:4:\"<dl>\";i:2;s:4:\"<dt>\";i:3;s:4:\"<dd>\";i:4;s:12:\"<a hreflang>\";i:5;s:17:\"<blockquote cite>\";i:6;s:9:\"<ul type>\";i:7;s:9:\"<ol type>\";i:8;s:7:\"<h2 id>\";i:9;s:7:\"<h3 id>\";i:10;s:7:\"<h4 id>\";i:11;s:7:\"<h5 id>\";i:12;s:7:\"<h6 id>\";}}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),
('',	'editor.editor.full_html',	'a:9:{s:4:\"uuid\";s:36:\"1926258e-dc0e-4aaa-95d1-5abf3be483cd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"filter.format.full_html\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lurcn8yf33g3Dkzdc55cTfJa9salGp9ytSYyG1s7QMI\";}s:6:\"format\";s:9:\"full_html\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:21:{i:0;s:4:\"bold\";i:1;s:6:\"italic\";i:2;s:13:\"strikethrough\";i:3;s:11:\"superscript\";i:4;s:9:\"subscript\";i:5;s:12:\"removeFormat\";i:6;s:1:\"|\";i:7;s:4:\"link\";i:8;s:1:\"|\";i:9;s:12:\"bulletedList\";i:10;s:12:\"numberedList\";i:11;s:1:\"|\";i:12;s:10:\"blockQuote\";i:13;s:17:\"drupalInsertImage\";i:14;s:11:\"insertTable\";i:15;s:14:\"horizontalLine\";i:16;s:1:\"|\";i:17;s:7:\"heading\";i:18;s:9:\"codeBlock\";i:19;s:1:\"|\";i:20;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:5:{s:19:\"ckeditor5_codeBlock\";a:1:{s:9:\"languages\";a:14:{i:0;a:2:{s:5:\"label\";s:10:\"Plain text\";s:8:\"language\";s:9:\"plaintext\";}i:1;a:2:{s:5:\"label\";s:1:\"C\";s:8:\"language\";s:1:\"c\";}i:2;a:2:{s:5:\"label\";s:2:\"C#\";s:8:\"language\";s:2:\"cs\";}i:3;a:2:{s:5:\"label\";s:3:\"C++\";s:8:\"language\";s:3:\"cpp\";}i:4;a:2:{s:5:\"label\";s:3:\"CSS\";s:8:\"language\";s:3:\"css\";}i:5;a:2:{s:5:\"label\";s:4:\"Diff\";s:8:\"language\";s:4:\"diff\";}i:6;a:2:{s:5:\"label\";s:4:\"HTML\";s:8:\"language\";s:4:\"html\";}i:7;a:2:{s:5:\"label\";s:4:\"Java\";s:8:\"language\";s:4:\"java\";}i:8;a:2:{s:5:\"label\";s:10:\"JavaScript\";s:8:\"language\";s:10:\"javascript\";}i:9;a:2:{s:5:\"label\";s:3:\"PHP\";s:8:\"language\";s:3:\"php\";}i:10;a:2:{s:5:\"label\";s:6:\"Python\";s:8:\"language\";s:6:\"python\";}i:11;a:2:{s:5:\"label\";s:4:\"Ruby\";s:8:\"language\";s:4:\"ruby\";}i:12;a:2:{s:5:\"label\";s:10:\"TypeScript\";s:8:\"language\";s:10:\"typescript\";}i:13;a:2:{s:5:\"label\";s:3:\"XML\";s:8:\"language\";s:3:\"xml\";}}}s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:21:\"ckeditor5_imageResize\";a:1:{s:12:\"allow_resize\";b:1;}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}}}s:12:\"image_upload\";a:5:{s:6:\"status\";b:1;s:6:\"scheme\";s:6:\"public\";s:9:\"directory\";s:13:\"inline-images\";s:8:\"max_size\";N;s:14:\"max_dimensions\";a:2:{s:5:\"width\";N;s:6:\"height\";N;}}}'),
('',	'editor.editor.webform_default',	'a:8:{s:4:\"uuid\";s:36:\"4c6d924f-2c8d-4499-9713-799828c76079\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:1:{i:0;s:9:\"ckeditor5\";}}s:6:\"format\";s:15:\"webform_default\";s:6:\"editor\";s:9:\"ckeditor5\";s:8:\"settings\";a:2:{s:7:\"toolbar\";a:1:{s:5:\"items\";a:20:{i:0;s:7:\"heading\";i:1;s:1:\"|\";i:2;s:4:\"bold\";i:3;s:6:\"italic\";i:4;s:9:\"subscript\";i:5;s:11:\"superscript\";i:6;s:1:\"|\";i:7;s:17:\"specialCharacters\";i:8;s:1:\"|\";i:9;s:12:\"numberedList\";i:10;s:12:\"bulletedList\";i:11;s:1:\"|\";i:12;s:4:\"link\";i:13;s:1:\"|\";i:14;s:6:\"indent\";i:15;s:7:\"outdent\";i:16;s:1:\"|\";i:17;s:10:\"blockQuote\";i:18;s:1:\"|\";i:19;s:13:\"sourceEditing\";}}s:7:\"plugins\";a:3:{s:17:\"ckeditor5_heading\";a:1:{s:16:\"enabled_headings\";a:5:{i:0;s:8:\"heading2\";i:1;s:8:\"heading3\";i:2;s:8:\"heading4\";i:3;s:8:\"heading5\";i:4;s:8:\"heading6\";}}s:14:\"ckeditor5_list\";a:2:{s:10:\"properties\";a:2:{s:8:\"reversed\";b:1;s:10:\"startIndex\";b:1;}s:10:\"multiBlock\";b:1;}s:23:\"ckeditor5_sourceEditing\";a:1:{s:12:\"allowed_tags\";a:0:{}}}}s:12:\"image_upload\";a:1:{s:6:\"status\";b:0;}}'),
('',	'field.field.block_content.basic.body',	'a:17:{s:4:\"uuid\";s:36:\"22004f3b-acef-4ec7-a26a-84514e3b0755\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"block_content.type.basic\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j00Gfs9AFqwK4x9RIsISLbPO7vA12psPR4s60wOIwQo\";}s:2:\"id\";s:24:\"block_content.basic.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:5:\"basic\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_accordion.body',	'a:17:{s:4:\"uuid\";s:36:\"28cf0280-0877-4dba-9961-a719b378e9f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EcoPer3Ti0HE0G0vbR_XTjvl4J4xhtcfJlZiIpT2-ic\";}s:2:\"id\";s:32:\"block_content.ebt_accordion.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_accordion.field_ebt_accordion',	'a:17:{s:4:\"uuid\";s:36:\"da20cc91-36e0-4116-8c1e-1b5e33ccbd6e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:47:\"field.storage.block_content.field_ebt_accordion\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KleL2jMUTWlOv_XwXvSfbaLHvZFC4TO3ZGrHClNa8Jk\";}s:2:\"id\";s:47:\"block_content.ebt_accordion.field_ebt_accordion\";s:10:\"field_name\";s:19:\"field_ebt_accordion\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:9:\"Accordion\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:13:\"ebt_accordion\";s:13:\"ebt_accordion\";}s:24:\"target_bundles_drag_drop\";a:1:{s:13:\"ebt_accordion\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:3;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_accordion.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"082df8d4-f424-4ec5-9be7-fa79dca0bc70\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_accordion\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4JvhH84_ab4oNGRe99S5bOvjSJdmPzs1XF2s5a0tlPc\";}s:2:\"id\";s:46:\"block_content.ebt_accordion.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_basic_button.field_ebt_basic_button_link',	'a:17:{s:4:\"uuid\";s:36:\"c0f9b024-755c-40ce-9a70-2d7135b9b02d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:55:\"field.storage.block_content.field_ebt_basic_button_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sHxTdakkm0n2AWPN2_ygOqsVXsuySIH10GpOOAEbzYE\";}s:2:\"id\";s:58:\"block_content.ebt_basic_button.field_ebt_basic_button_link\";s:10:\"field_name\";s:27:\"field_ebt_basic_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:5:\"label\";s:11:\"Button LInk\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"link_type\";i:17;s:5:\"title\";i:2;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_basic_button.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"28dce901-3d51-4486-b431-ddbf214523f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_basic_button\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TljYP0E4TAaKsPdVXhWVNLXzzFG9oPBu7BUROGtWlPY\";}s:2:\"id\";s:49:\"block_content.ebt_basic_button.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_basic_button\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_block.body',	'a:17:{s:4:\"uuid\";s:36:\"c82da539-0efe-4f63-b7ed-cfb0c65f3022\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ze4f8wKV-sjDw10PzW5_0VDQpHaV7fUywYLVyynLOXQ\";}s:2:\"id\";s:28:\"block_content.ebt_block.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_block.field_ebt_block_block',	'a:17:{s:4:\"uuid\";s:36:\"02b3090f-c1e2-41ef-961f-8f9dbe3677b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:49:\"field.storage.block_content.field_ebt_block_block\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ODt400wjC0-0TFAwPcqdOKmEH1RCrno2RlHZAO9jMDY\";}s:2:\"id\";s:45:\"block_content.ebt_block.field_ebt_block_block\";s:10:\"field_name\";s:21:\"field_ebt_block_block\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:5:\"label\";s:5:\"Block\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:10:\"categories\";s:18:\"selection_settings\";a:1:{s:10:\"categories\";a:24:{s:5:\"Block\";s:5:\"Block\";s:14:\"Comment fields\";s:14:\"Comment fields\";s:22:\"Contact message fields\";s:22:\"Contact message fields\";s:13:\"Content block\";s:13:\"Content block\";s:20:\"Content block fields\";s:20:\"Content block fields\";s:14:\"Content fields\";s:14:\"Content fields\";s:4:\"core\";s:4:\"core\";s:23:\"Custom menu link fields\";s:23:\"Custom menu link fields\";s:11:\"File fields\";s:11:\"File fields\";s:5:\"Forms\";s:5:\"Forms\";s:4:\"Help\";s:4:\"Help\";s:13:\"Inline blocks\";s:13:\"Inline blocks\";s:13:\"Lists (Views)\";s:13:\"Lists (Views)\";s:12:\"Media fields\";s:12:\"Media fields\";s:5:\"Menus\";s:5:\"Menus\";s:16:\"Paragraph fields\";s:16:\"Paragraph fields\";s:20:\"Shortcut link fields\";s:20:\"Shortcut link fields\";s:6:\"System\";s:6:\"System\";s:20:\"Taxonomy term fields\";s:20:\"Taxonomy term fields\";s:16:\"URL alias fields\";s:16:\"URL alias fields\";s:4:\"User\";s:4:\"User\";s:11:\"User fields\";s:11:\"User fields\";s:7:\"Webform\";s:7:\"Webform\";s:25:\"Webform submission fields\";s:25:\"Webform submission fields\";}}}s:10:\"field_type\";s:11:\"block_field\";}'),
('',	'field.field.block_content.ebt_block.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"4cf8e43c-52cf-40e7-8fab-03ba24e5671d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_block\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HsmfX01jgclZMXztEvPXS8YoUBvYO2AzDJY7Olj0G5A\";}s:2:\"id\";s:42:\"block_content.ebt_block.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_block\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link',	'a:17:{s:4:\"uuid\";s:36:\"308dba68-d030-422d-b8e9-72568d1fd20a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:59:\"field.storage.block_content.field_ebt_bootstrap_button_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LHj34VkFYZYI5N_541KsHaqlWyuH7Cw_KxfjHm23woU\";}s:2:\"id\";s:66:\"block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ebt_bootstrap_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"link_type\";i:17;s:5:\"title\";i:2;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_bootstrap_button.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"b6ea63fb-dfef-42aa-bda8-892c68583ffc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-6S_O_kYEPD4uAw2AnjYuYGHz_CMhBBvkkO5sJA1DYg\";}s:2:\"id\";s:53:\"block_content.ebt_bootstrap_button.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:20:\"ebt_bootstrap_button\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_carousel.field_ebt_carousel',	'a:17:{s:4:\"uuid\";s:36:\"2bc22340-9888-4636-9768-5a9bc9ffd66c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:46:\"field.storage.block_content.field_ebt_carousel\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"NZhceEWb8sFj-vaeEbM_eFgHPVULnofUVtBb6FO526E\";}s:2:\"id\";s:45:\"block_content.ebt_carousel.field_ebt_carousel\";s:10:\"field_name\";s:18:\"field_ebt_carousel\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:8:\"Carousel\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:12:\"ebt_carousel\";s:12:\"ebt_carousel\";}s:24:\"target_bundles_drag_drop\";a:1:{s:12:\"ebt_carousel\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:6;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_carousel.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"82540ccc-a725-412b-b6ba-bc89d09e03fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:31:\"block_content.type.ebt_carousel\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U2Ky-DS_Wo_f9KN2f-PSJN975w1XnGxWcaly7VF6-tU\";}s:2:\"id\";s:45:\"block_content.ebt_carousel.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_columns.body',	'a:17:{s:4:\"uuid\";s:36:\"b6c8e80f-807f-4acf-b36e-55ea98dc4fb3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WqbyqczhS3unr9KEuC6FRXfpi9rVW3mCtF8P2TGxkQI\";}s:2:\"id\";s:30:\"block_content.ebt_columns.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_columns.field_ebt_columns_blocks',	'a:17:{s:4:\"uuid\";s:36:\"eca7b2b8-8806-49f1-ae15-756018a6c67f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:52:\"field.storage.block_content.field_ebt_columns_blocks\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DlzRJb8gJARkGrf3IjWcpsIQfTvSJt9DmGRT1aBailQ\";}s:2:\"id\";s:50:\"block_content.ebt_columns.field_ebt_columns_blocks\";s:10:\"field_name\";s:24:\"field_ebt_columns_blocks\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:5:\"label\";s:6:\"Blocks\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:10:\"categories\";s:18:\"selection_settings\";a:1:{s:10:\"categories\";a:24:{s:5:\"Block\";s:5:\"Block\";s:14:\"Comment fields\";s:14:\"Comment fields\";s:22:\"Contact message fields\";s:22:\"Contact message fields\";s:13:\"Content block\";s:13:\"Content block\";s:20:\"Content block fields\";s:20:\"Content block fields\";s:14:\"Content fields\";s:14:\"Content fields\";s:4:\"core\";s:4:\"core\";s:23:\"Custom menu link fields\";s:23:\"Custom menu link fields\";s:11:\"File fields\";s:11:\"File fields\";s:5:\"Forms\";s:5:\"Forms\";s:4:\"Help\";s:4:\"Help\";s:13:\"Inline blocks\";s:13:\"Inline blocks\";s:13:\"Lists (Views)\";s:13:\"Lists (Views)\";s:12:\"Media fields\";s:12:\"Media fields\";s:5:\"Menus\";s:5:\"Menus\";s:16:\"Paragraph fields\";s:16:\"Paragraph fields\";s:20:\"Shortcut link fields\";s:20:\"Shortcut link fields\";s:6:\"System\";s:6:\"System\";s:20:\"Taxonomy term fields\";s:20:\"Taxonomy term fields\";s:16:\"URL alias fields\";s:16:\"URL alias fields\";s:4:\"User\";s:4:\"User\";s:11:\"User fields\";s:11:\"User fields\";s:7:\"Webform\";s:7:\"Webform\";s:25:\"Webform submission fields\";s:25:\"Webform submission fields\";}}}s:10:\"field_type\";s:11:\"block_field\";}'),
('',	'field.field.block_content.ebt_columns.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"9cc6560f-9a4a-4969-9e4b-0d667ef4817c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_columns\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"97Zeg-Y42bu_WIG-So7eo7DK0hKpS1XqwrJ1kGdYY8E\";}s:2:\"id\";s:44:\"block_content.ebt_columns.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_columns\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_countdown.body',	'a:17:{s:4:\"uuid\";s:36:\"7266abd1-c799-4ff0-96ef-b464471e6583\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7Eup8vFqqabcEdya_X4KmbnCSstllEkrmXRpfxOCdmU\";}s:2:\"id\";s:32:\"block_content.ebt_countdown.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_countdown.field_ebt_countdown_date',	'a:17:{s:4:\"uuid\";s:36:\"daee2d15-8abc-4764-8789-2fcf13604386\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:52:\"field.storage.block_content.field_ebt_countdown_date\";}s:6:\"module\";a:1:{i:0;s:8:\"datetime\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rS3ZCjiH3ZhM6LLmDYfxfr1x4lVA0pMJeUjgvHYJwJU\";}s:2:\"id\";s:52:\"block_content.ebt_countdown.field_ebt_countdown_date\";s:10:\"field_name\";s:24:\"field_ebt_countdown_date\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:5:\"label\";s:14:\"Countdown date\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:8:\"datetime\";}'),
('',	'field.field.block_content.ebt_countdown.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"56e05cdb-f253-4954-9c39-5253face9482\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_countdown\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2Z_UQh0ye99krkSwmrnf32Lbdr_bJwll60WqPfcn3WQ\";}s:2:\"id\";s:46:\"block_content.ebt_countdown.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_countdown\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_counter.body',	'a:17:{s:4:\"uuid\";s:36:\"c23a3476-69db-400e-a938-54992d1cfa18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aNXxUnwWYqtaYNggYYhPjJH0IhNPU6aWjGZmWwC2Ock\";}s:2:\"id\";s:30:\"block_content.ebt_counter.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"9ba660a3-d550-47fe-aaa5-4325e7ffe30d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:50:\"field.storage.block_content.field_ebt_counter_icon\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AqwI810Vi6u8gzBeecbZAAUxasqqVBWGSG3usxdzT8Y\";}s:2:\"id\";s:48:\"block_content.ebt_counter.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:4:\"Icon\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_counter_items',	'a:17:{s:4:\"uuid\";s:36:\"0776e496-c917-49a5-a502-a77f73b79b69\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:51:\"field.storage.block_content.field_ebt_counter_items\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l82_oxjYqdf0vGlc2vOu3y3PdJhm9-QYk3j9aKOI-eg\";}s:2:\"id\";s:49:\"block_content.ebt_counter.field_ebt_counter_items\";s:10:\"field_name\";s:23:\"field_ebt_counter_items\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:17:\"EBT Counter Items\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:16:\"ebt_counter_item\";s:16:\"ebt_counter_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:16:\"ebt_counter_item\";a:2:{s:6:\"weight\";i:12;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"b4ecb5ee-b852-4360-ab89-92327a624bdf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:52:\"field.storage.block_content.field_ebt_counter_number\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xYrvXZvhuSrLAZDblfVrQO8BT0HeZGJKPail-de9LYQ\";}s:2:\"id\";s:50:\"block_content.ebt_counter.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:6:\"Number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:4:{s:3:\"min\";N;s:3:\"max\";N;s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"field_type\";s:7:\"integer\";}'),
('',	'field.field.block_content.ebt_counter.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"1df891a3-3bde-4def-8c4e-79dd5182017a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_counter\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-jefiww756YZOfPypjb0uMhOWdCkTYnChNabi-X7VTM\";}s:2:\"id\";s:44:\"block_content.ebt_counter.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_counter\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_cta.body',	'a:17:{s:4:\"uuid\";s:36:\"55f4a1e8-6366-4c0b-aba3-0f05bdc8dccc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Xswlt75VBfRWb1lhRxDCEdmO2MWrGjyFMGZtNtNvvhs\";}s:2:\"id\";s:26:\"block_content.ebt_cta.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_column_image',	'a:17:{s:4:\"uuid\";s:36:\"13cbf6a5-260c-40e0-b225-a8dd66d72da5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:54:\"field.storage.block_content.field_ebt_cta_column_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BhJzD_e2sAj1RN0VJgS6aMUtzNeUEopdiFutXxsCBAk\";}s:2:\"id\";s:48:\"block_content.ebt_cta.field_ebt_cta_column_image\";s:10:\"field_name\";s:26:\"field_ebt_cta_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_link',	'a:17:{s:4:\"uuid\";s:36:\"b2ba6467-2022-4aa3-9527-2821ef8b3866\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:46:\"field.storage.block_content.field_ebt_cta_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kXVJG1nw4xsap-XsAKzJbpyAv6NK8jpGZ9eWXpGpewI\";}s:2:\"id\";s:40:\"block_content.ebt_cta.field_ebt_cta_link\";s:10:\"field_name\";s:18:\"field_ebt_cta_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_second_link',	'a:17:{s:4:\"uuid\";s:36:\"21e7fce1-906b-4e52-94b2-deaee971de2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:53:\"field.storage.block_content.field_ebt_cta_second_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HYewglTA2MKbS8dL349fn4qm9mA-S_FxSL-Suhi0H2k\";}s:2:\"id\";s:47:\"block_content.ebt_cta.field_ebt_cta_second_link\";s:10:\"field_name\";s:25:\"field_ebt_cta_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:11:\"Second Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_cta_title',	'a:17:{s:4:\"uuid\";s:36:\"67606c2f-9b8c-41b7-80d6-aa24493fa0d3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:47:\"field.storage.block_content.field_ebt_cta_title\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AKUtn2Ht2dlGYr9Y8at4yVXu5P1ozFKBdcgzWq44560\";}s:2:\"id\";s:41:\"block_content.ebt_cta.field_ebt_cta_title\";s:10:\"field_name\";s:19:\"field_ebt_cta_title\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_cta.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"b3a9c8ab-38aa-42a9-9c7a-8d9b4c4e0192\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:26:\"block_content.type.ebt_cta\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"o4qhawOFKN4zS8tfJKa0LamrN4V8y8cW4d55CAAP8EY\";}s:2:\"id\";s:40:\"block_content.ebt_cta.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:7:\"ebt_cta\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_hero.body',	'a:17:{s:4:\"uuid\";s:36:\"b99d81f7-46a3-4dd4-8588-c20bf7f86b06\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Qut8svTV-WRC6mB8zNNFw0jqqJp5gzYemzlgnt3AElM\";}s:2:\"id\";s:27:\"block_content.ebt_hero.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_column_image',	'a:17:{s:4:\"uuid\";s:36:\"47eab2ed-be4c-44cf-8125-61c4726d2170\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:55:\"field.storage.block_content.field_ebt_hero_column_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VbR985Mwa7blDm4IzjllHaKyIKieWmVaPhFiNTxALUg\";}s:2:\"id\";s:50:\"block_content.ebt_hero.field_ebt_hero_column_image\";s:10:\"field_name\";s:27:\"field_ebt_hero_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:12:\"Column Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_link',	'a:17:{s:4:\"uuid\";s:36:\"8c50936f-d412-4429-a9af-fe0720478b0f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:47:\"field.storage.block_content.field_ebt_hero_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDbic2tmAxT3Nwj4frhpQJGnF8nX1JE_Q3hu02XZ10o\";}s:2:\"id\";s:42:\"block_content.ebt_hero.field_ebt_hero_link\";s:10:\"field_name\";s:19:\"field_ebt_hero_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_second_link',	'a:17:{s:4:\"uuid\";s:36:\"04371c34-46be-4086-ae87-cc361d2d3ced\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:54:\"field.storage.block_content.field_ebt_hero_second_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1RX5_6HKYaNcisy7DgpQuSjGICKop8azTX3B6B_p8xc\";}s:2:\"id\";s:49:\"block_content.ebt_hero.field_ebt_hero_second_link\";s:10:\"field_name\";s:26:\"field_ebt_hero_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:11:\"Second Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_title',	'a:17:{s:4:\"uuid\";s:36:\"11b83dfa-e605-4b74-8cab-d665ab3d12a3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:48:\"field.storage.block_content.field_ebt_hero_title\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"86hFjrfGlcIjrIIrmgUrVPJ3_QyoV2KsiqXTYhCAeR8\";}s:2:\"id\";s:43:\"block_content.ebt_hero.field_ebt_hero_title\";s:10:\"field_name\";s:20:\"field_ebt_hero_title\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_hero_title_prefix',	'a:17:{s:4:\"uuid\";s:36:\"f115e5b7-c8ee-4130-9311-4bc5ac45d6d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:55:\"field.storage.block_content.field_ebt_hero_title_prefix\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"135nCPN0Zyg7GtNdwrEY1joFOZdHSUqBoP1cfFmTlws\";}s:2:\"id\";s:50:\"block_content.ebt_hero.field_ebt_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ebt_hero_title_prefix\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:12:\"Title Prefix\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_hero.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"9ab7be9d-f391-4845-abb9-9620046d2cea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_hero\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T5k5YZCMxiQ-YbufcTAzxPfL6x68fxMB1znaMkjM1Ug\";}s:2:\"id\";s:41:\"block_content.ebt_hero.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_hero\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_image',	'a:17:{s:4:\"uuid\";s:36:\"f07c72d3-6387-4d4d-a4eb-5a81420e247b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:43:\"field.storage.block_content.field_ebt_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W7kXKygcBjPcCe8gOrc11eBNXBHQWunB-xUjHS5ccZM\";}s:2:\"id\";s:39:\"block_content.ebt_image.field_ebt_image\";s:10:\"field_name\";s:15:\"field_ebt_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_image_caption',	'a:17:{s:4:\"uuid\";s:36:\"d7eb3cf3-fabf-4526-9e59-2559843a4b10\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:51:\"field.storage.block_content.field_ebt_image_caption\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WZl4X3tBs3QDBckRJjPbxFlnn9RiKDJXSb32UI78b0Y\";}s:2:\"id\";s:47:\"block_content.ebt_image.field_ebt_image_caption\";s:10:\"field_name\";s:23:\"field_ebt_image_caption\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:13:\"Image caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_image_link',	'a:17:{s:4:\"uuid\";s:36:\"d64d6cf7-d342-4551-933f-875ccf757101\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:48:\"field.storage.block_content.field_ebt_image_link\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WDCm4s-2KzOBP2lD1x_6iuJ28RmYQLSfvdSJ4KTS8hc\";}s:2:\"id\";s:44:\"block_content.ebt_image.field_ebt_image_link\";s:10:\"field_name\";s:20:\"field_ebt_image_link\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:10:\"Image Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.block_content.ebt_image.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"4f2baecc-10aa-4164-b62a-d414a7a219b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_image\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Lo63F4kx4le3BFUXIP1j-nTj0TQ1wlVCW8T4eXa_Xu8\";}s:2:\"id\";s:42:\"block_content.ebt_image.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_image\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_image_gallery.body',	'a:17:{s:4:\"uuid\";s:36:\"20361483-5f67-45d3-a3cb-a44f2e7bbae3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RI-w_mHu5j0k1rnEr3l73w0KQBcCH3Q6ZImikN8AdBw\";}s:2:\"id\";s:36:\"block_content.ebt_image_gallery.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_image_gallery.field_ebt_image_gallery',	'a:17:{s:4:\"uuid\";s:36:\"f76e7399-746c-4735-a354-63cad22949ff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:51:\"field.storage.block_content.field_ebt_image_gallery\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FAizD6Kvuyrbl5yxVgCp1vn4NLB9d-nI3wWWaqOR-kQ\";}s:2:\"id\";s:55:\"block_content.ebt_image_gallery.field_ebt_image_gallery\";s:10:\"field_name\";s:23:\"field_ebt_image_gallery\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:13:\"Image Gallery\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_image_gallery.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"4c8c9d22-d8fd-4927-b62c-41815a17d1c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_image_gallery\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jJLv7Zyb3L4ZWqdYGWpZz_z81eZXwjYwQexwHk7WX2s\";}s:2:\"id\";s:50:\"block_content.ebt_image_gallery.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_image_gallery\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_micromodal.body',	'a:17:{s:4:\"uuid\";s:36:\"1dd47019-ce01-47d2-8520-e5625b17bd32\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VfYtQCVLNmvze1_Qc3zTCMg2QFHln36_wjCm6y2MMWQ\";}s:2:\"id\";s:33:\"block_content.ebt_micromodal.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_micromodal.field_ebt_micromodal_title',	'a:17:{s:4:\"uuid\";s:36:\"59e52aef-8c74-4576-ae43-df723099b73d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:54:\"field.storage.block_content.field_ebt_micromodal_title\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lm4MPSDui0NEYaqvulzZIgmZumlIaUiE638_N0umXDI\";}s:2:\"id\";s:55:\"block_content.ebt_micromodal.field_ebt_micromodal_title\";s:10:\"field_name\";s:26:\"field_ebt_micromodal_title\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:5:\"label\";s:16:\"Micromodal Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_micromodal.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"157b9dd5-a769-42f1-9986-195e571255c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"block_content.type.ebt_micromodal\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ed-JI-p3sJDcQ3-4guJZ89L_Smftc8LwJ3Z_7XCW5rE\";}s:2:\"id\";s:47:\"block_content.ebt_micromodal.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:14:\"ebt_micromodal\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_quote.body',	'a:17:{s:4:\"uuid\";s:36:\"bcd054c1-c1e6-47a1-9c84-af43855b0dc7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RHJ2BeL7FRpMNmRALB5w7o8erlsGuBnb8MOaVvceiDo\";}s:2:\"id\";s:28:\"block_content.ebt_quote.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:5:\"Quote\";s:11:\"description\";s:20:\"Quote or Testimonial\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_quote.field_ebt_quote_author',	'a:17:{s:4:\"uuid\";s:36:\"5c41064f-97a8-4a0e-aea7-eab453f27eb0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:50:\"field.storage.block_content.field_ebt_quote_author\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bcr-ywW2dLY1kQTCKA6fqxCSgq_nrKEgCB1wj_G8rOs\";}s:2:\"id\";s:46:\"block_content.ebt_quote.field_ebt_quote_author\";s:10:\"field_name\";s:22:\"field_ebt_quote_author\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:12:\"Quote Author\";s:11:\"description\";s:44:\"Company name, Persona name and job position.\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.block_content.ebt_quote.field_ebt_quote_image',	'a:17:{s:4:\"uuid\";s:36:\"aa44dee9-e2fb-4a02-8f85-0ed2534a54e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:49:\"field.storage.block_content.field_ebt_quote_image\";i:2;s:16:\"media.type.image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_AaWTlSa1X6CaC-_c0qarZPGAD9IaSjpuJF_CUK9vk0\";}s:2:\"id\";s:45:\"block_content.ebt_quote.field_ebt_quote_image\";s:10:\"field_name\";s:21:\"field_ebt_quote_image\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:11:\"Quote Image\";s:11:\"description\";s:29:\"Persona photo or Company logo\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_quote.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"c5fb6c52-df83-49a6-982d-13cd459b5086\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_quote\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gKtk0T_7VnCmUPgUgJX1z7v13az3bkGF3bazJXEwZ_o\";}s:2:\"id\";s:42:\"block_content.ebt_quote.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_quote\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_slick_slider.body',	'a:17:{s:4:\"uuid\";s:36:\"ac203ba4-4731-48c0-a489-49772d98bbcc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1VYVNgk5Hp9ZSjh89NrWVzpkv3BfOpNJz3E_qlTqNkY\";}s:2:\"id\";s:35:\"block_content.ebt_slick_slider.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_slick_slider.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"35e70eb2-5981-4ca9-9540-a6263e5f01ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YIrMWNLT6TiXF-tmAzVOGQaDbDkIa_qy9_KBL0B4TxA\";}s:2:\"id\";s:49:\"block_content.ebt_slick_slider.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_slick_slider.field_ebt_slick_slider',	'a:17:{s:4:\"uuid\";s:36:\"237e10e6-95ca-4f5e-9d1b-2f1d8f7eef67\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:35:\"block_content.type.ebt_slick_slider\";i:1;s:50:\"field.storage.block_content.field_ebt_slick_slider\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eH6HMdmAatyKEevKR8YXk2VH3AF_ntUZim5F7X5D3Cc\";}s:2:\"id\";s:53:\"block_content.ebt_slick_slider.field_ebt_slick_slider\";s:10:\"field_name\";s:22:\"field_ebt_slick_slider\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:12:\"Slick Slider\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:16:\"ebt_slick_slider\";s:16:\"ebt_slick_slider\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:16:\"ebt_slick_slider\";a:2:{s:6:\"weight\";i:9;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_slideshow.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"f6196b18-31e7-4003-842a-206131de10c0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"oveTq0gmp5_KAESCvT3DtytAnJElJGWzrHzr1lEb-x0\";}s:2:\"id\";s:46:\"block_content.ebt_slideshow.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_slideshow.field_ebt_slideshow',	'a:17:{s:4:\"uuid\";s:36:\"dfe1a625-168b-485c-9c9e-2e8296f0dec8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:32:\"block_content.type.ebt_slideshow\";i:1;s:47:\"field.storage.block_content.field_ebt_slideshow\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0sk3ViXko3tl_QC0x0GggU_08m7tEtKEoNDg9vwOE-Q\";}s:2:\"id\";s:47:\"block_content.ebt_slideshow.field_ebt_slideshow\";s:10:\"field_name\";s:19:\"field_ebt_slideshow\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:9:\"Slideshow\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:13:\"ebt_slideshow\";s:13:\"ebt_slideshow\";}s:24:\"target_bundles_drag_drop\";a:1:{s:13:\"ebt_slideshow\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:5;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_stats.body',	'a:17:{s:4:\"uuid\";s:36:\"33c69170-b2b4-49a9-9557-a9542eb08865\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qjLV8uviFQzoYVcltie2--7y-ZZpauda_owKbFf-IPA\";}s:2:\"id\";s:28:\"block_content.ebt_stats.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_stats.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"1e3aa7ba-222f-4f33-8628-7c5bf22f00fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Yhkjb0s5PYlfHuk2JdMtwch30e3IZCjz8R1KMJqE4JA\";}s:2:\"id\";s:42:\"block_content.ebt_stats.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_stats.field_ebt_stats',	'a:17:{s:4:\"uuid\";s:36:\"280d2344-5e0c-42f5-bd77-7b358f9b2c08\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_stats\";i:1;s:43:\"field.storage.block_content.field_ebt_stats\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j6MsUG9RUUe4pToCAeVx7TIOtSMQyibl7ikftOLpXqA\";}s:2:\"id\";s:39:\"block_content.ebt_stats.field_ebt_stats\";s:10:\"field_name\";s:15:\"field_ebt_stats\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_stats\";s:5:\"label\";s:9:\"EBT Stats\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ebt_stats_item\";s:14:\"ebt_stats_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ebt_stats_item\";a:2:{s:6:\"weight\";i:12;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_tabs.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"1396353c-ec74-4693-9d16-7ffb5a6090cc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_Gn1i1ea7T8MzoBSjiDcnQMYgfSAq2jN9g-ZJfv27PA\";}s:2:\"id\";s:41:\"block_content.ebt_tabs.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_tabs.field_ebt_tabs',	'a:17:{s:4:\"uuid\";s:36:\"b89072e5-91ec-40a1-aa9c-2a20808308cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:27:\"block_content.type.ebt_tabs\";i:1;s:42:\"field.storage.block_content.field_ebt_tabs\";i:2;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4qzYKe-tuRQPHfXtyOyfFfwSfj-Onz88kqc6nsXX4ns\";}s:2:\"id\";s:37:\"block_content.ebt_tabs.field_ebt_tabs\";s:10:\"field_name\";s:14:\"field_ebt_tabs\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_tabs\";s:5:\"label\";s:4:\"Tabs\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:7:\"ebt_tab\";s:7:\"ebt_tab\";}s:24:\"target_bundles_drag_drop\";a:1:{s:7:\"ebt_tab\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:2;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_text.body',	'a:17:{s:4:\"uuid\";s:36:\"c72f430e-7366-4a91-bce3-aa5dc0cf8726\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"htRzt66f_OSqHawgprrWKiHiaLoBZUKzc0aMsoIVRlI\";}s:2:\"id\";s:27:\"block_content.ebt_text.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_text.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"2a94aaad-3c54-4074-9d7a-fc204b0cc509\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:27:\"block_content.type.ebt_text\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"G1bcFZfGqQcn1FyernQez0LoRoXBRPKXAjI6-yZKMGw\";}s:2:\"id\";s:41:\"block_content.ebt_text.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:8:\"ebt_text\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_tiles.body',	'a:17:{s:4:\"uuid\";s:36:\"b13d5126-3f86-4bb5-8cdc-a9b72478ab6b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hru15RrwqNoJ9o_uoGV1KT2wAkHwJsGaTj7KF0sIZxU\";}s:2:\"id\";s:28:\"block_content.ebt_tiles.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_tiles.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"34788ebc-a5ee-43a6-be6c-58bf07f8a47a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"J3ICag16O5nBkU9zwYLt76LvxEF78Qt-pDCJWA5n1Q4\";}s:2:\"id\";s:42:\"block_content.ebt_tiles.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_tiles.field_ebt_tiles',	'a:17:{s:4:\"uuid\";s:36:\"2e2ec692-0d82-4b56-9cfc-4e871f3a1882\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:28:\"block_content.type.ebt_tiles\";i:1;s:43:\"field.storage.block_content.field_ebt_tiles\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"L9cDmlbMT83s3nbfD0cDfsf0BnRv1fpAyA4KTplqxJs\";}s:2:\"id\";s:39:\"block_content.ebt_tiles.field_ebt_tiles\";s:10:\"field_name\";s:15:\"field_ebt_tiles\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_tiles\";s:5:\"label\";s:5:\"Tiles\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:14:\"ebt_tiles_item\";s:14:\"ebt_tiles_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:14:\"ebt_tiles_item\";a:2:{s:6:\"weight\";i:45;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_timeline.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"72a4ef65-870a-4488-8009-80269e968b1b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HN5G2K_JDpCXJ8t1Hf1GlS9QdBeEP63Bly-VhnBB6sc\";}s:2:\"id\";s:45:\"block_content.ebt_timeline.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_timeline.field_ebt_timeline',	'a:17:{s:4:\"uuid\";s:36:\"87a15adf-8be6-4080-925b-ebc76f101b32\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:31:\"block_content.type.ebt_timeline\";i:1;s:46:\"field.storage.block_content.field_ebt_timeline\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OpOMqlp0m970YTcVsX9wdXHaI-hN6RW9eawnPmz3KtQ\";}s:2:\"id\";s:45:\"block_content.ebt_timeline.field_ebt_timeline\";s:10:\"field_name\";s:18:\"field_ebt_timeline\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:8:\"Timeline\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:6:\"negate\";i:0;s:14:\"target_bundles\";a:1:{s:12:\"ebt_timeline\";s:12:\"ebt_timeline\";}s:24:\"target_bundles_drag_drop\";a:1:{s:12:\"ebt_timeline\";a:2:{s:7:\"enabled\";b:1;s:6:\"weight\";i:10;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_video.body',	'a:17:{s:4:\"uuid\";s:36:\"9b4acfb1-3d8e-4e3d-8901-6120a3b342b2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJmLT9YexVdfd-JSg5eErRWt3FrtaozSqR_v29xtRwU\";}s:2:\"id\";s:28:\"block_content.ebt_video.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_video.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"55445905-ca67-4040-b176-00e1fc2ebb3e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZSSE8vNHSVgLXEAdnpSbPDmk02qrlhm3jj3AJhOLGDs\";}s:2:\"id\";s:42:\"block_content.ebt_video.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_video.field_ebt_video',	'a:17:{s:4:\"uuid\";s:36:\"2e653244-7a00-41c7-a943-06eade5f15ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:4:{i:0;s:28:\"block_content.type.ebt_video\";i:1;s:43:\"field.storage.block_content.field_ebt_video\";i:2;s:23:\"media.type.remote_video\";i:3;s:16:\"media.type.video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HK8CWqddmUhsshgNl5XJCSCl0ZgJWByyd-uQp8gR9to\";}s:2:\"id\";s:39:\"block_content.ebt_video.field_ebt_video\";s:10:\"field_name\";s:15:\"field_ebt_video\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:2:{s:12:\"remote_video\";s:12:\"remote_video\";s:5:\"video\";s:5:\"video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:12:\"remote_video\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.block_content.ebt_video_and_image_gallery.body',	'a:17:{s:4:\"uuid\";s:36:\"161669c7-6a7e-4616-86d5-a2e3de9c8fe5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1OrJhHg5mGo5emzkaM2Z6ClqRPHEtI72w5kwSnSWOaI\";}s:2:\"id\";s:46:\"block_content.ebt_video_and_image_gallery.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_video_and_image_gallery.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"278f7615-4ab0-4e87-963f-33f2ae8f78ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5WWOgyldW7uBFXBGN623Yc_zkiry6HnXAn0L5CywrsI\";}s:2:\"id\";s:60:\"block_content.ebt_video_and_image_gallery.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:12:\"ebt_settings\";a:2:{s:26:\"pass_options_to_javascript\";b:0;s:14:\"design_options\";a:2:{s:4:\"box1\";a:5:{s:10:\"margin_top\";s:0:\"\";s:12:\"margin_right\";s:0:\"\";s:13:\"margin_bottom\";s:0:\"\";s:11:\"margin_left\";s:0:\"\";s:4:\"box2\";a:5:{s:10:\"border_top\";s:0:\"\";s:12:\"border_right\";s:0:\"\";s:13:\"border_bottom\";s:0:\"\";s:11:\"border_left\";s:0:\"\";s:4:\"box3\";a:4:{s:11:\"padding_top\";s:0:\"\";s:13:\"padding_right\";s:0:\"\";s:14:\"padding_bottom\";s:0:\"\";s:12:\"padding_left\";s:0:\"\";}}}s:14:\"other_settings\";a:8:{s:12:\"border_color\";s:0:\"\";s:12:\"border_style\";s:5:\"solid\";s:13:\"border_radius\";s:4:\"none\";s:16:\"background_color\";s:0:\"\";s:16:\"background_media\";N;s:22:\"background_image_style\";s:7:\"default\";s:12:\"edge_to_edge\";i:0;s:15:\"container_width\";s:4:\"auto\";}}}}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images',	'a:17:{s:4:\"uuid\";s:36:\"efc991a5-26b8-4df3-977e-953a90c2f86c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";i:1;s:55:\"field.storage.block_content.field_ebt_videos_and_images\";i:2;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:26:\"entity_reference_revisions\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kZTsNALzCfl1z3gE4CQ1OVfS633RZUMyI5ZBPiMVnm0\";}s:2:\"id\";s:69:\"block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images\";s:10:\"field_name\";s:27:\"field_ebt_videos_and_images\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:17:\"Videos and Images\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:17:\"default:paragraph\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:32:\"ebt_video_and_image_gallery_item\";s:32:\"ebt_video_and_image_gallery_item\";}s:6:\"negate\";i:0;s:24:\"target_bundles_drag_drop\";a:1:{s:32:\"ebt_video_and_image_gallery_item\";a:2:{s:6:\"weight\";i:16;s:7:\"enabled\";b:1;}}}}s:10:\"field_type\";s:26:\"entity_reference_revisions\";}'),
('',	'field.field.block_content.ebt_views.body',	'a:17:{s:4:\"uuid\";s:36:\"f746c64f-5c49-4079-bb53-0a1a1dd1a7c4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gYULmkk3OY2DQugmZyL9Fv_2Car9QCaQzCeihnGhfPI\";}s:2:\"id\";s:28:\"block_content.ebt_views.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_views.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"3a0e2513-d1ec-4966-9162-427a855b0977\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZrXPDXifY_gudYEr4cT9o_GDEspGqI6gFQgTyN_6RdM\";}s:2:\"id\";s:42:\"block_content.ebt_views.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_views.field_ebt_views_views',	'a:17:{s:4:\"uuid\";s:36:\"5f1f69e3-3f90-4442-95f1-5c1579c679ab\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:28:\"block_content.type.ebt_views\";i:1;s:49:\"field.storage.block_content.field_ebt_views_views\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MAlu-k2uullIwcqbzIvVPeeMm6-JiW5Ev0USbMEGejk\";}s:2:\"id\";s:45:\"block_content.ebt_views.field_ebt_views_views\";s:10:\"field_name\";s:21:\"field_ebt_views_views\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:9:\"ebt_views\";s:5:\"label\";s:5:\"Views\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}s:12:\"plugin_types\";a:2:{s:4:\"page\";s:4:\"page\";s:5:\"block\";s:5:\"block\";}s:15:\"preselect_views\";a:0:{}s:16:\"enabled_settings\";a:0:{}}s:10:\"field_type\";s:14:\"viewsreference\";}'),
('',	'field.field.block_content.ebt_webform.body',	'a:17:{s:4:\"uuid\";s:36:\"8733818b-9c02-4e2c-91a6-045583f1e01d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:32:\"field.storage.block_content.body\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Baa8yf9wUinT0D2-5V7tRKydSUOfQvZsUuTvSBeC-bQ\";}s:2:\"id\";s:30:\"block_content.ebt_webform.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:0;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.block_content.ebt_webform.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"a50fcf2c-9887-448e-a18c-78ac4e87b38c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VOgJYtNjHNsjml3J6mwuL3oMqXc4JPjPD8gGVHyGftg\";}s:2:\"id\";s:44:\"block_content.ebt_webform.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_webform.field_ebt_webform_form',	'a:17:{s:4:\"uuid\";s:36:\"9c984eac-a275-47d3-a7ac-029f8216fcb8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"block_content.type.ebt_webform\";i:1;s:50:\"field.storage.block_content.field_ebt_webform_form\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"S36GzWuHJCt3YstEnQsUPzQ1dwXpO2MKmqaAgoQ2eb4\";}s:2:\"id\";s:48:\"block_content.ebt_webform.field_ebt_webform_form\";s:10:\"field_name\";s:22:\"field_ebt_webform_form\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:11:\"ebt_webform\";s:5:\"label\";s:4:\"Form\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}}s:10:\"field_type\";s:7:\"webform\";}'),
('',	'field.field.block_content.ebt_webform_popup.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"7bd9f73f-8c64-46d8-9848-e86bcb5b491e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:46:\"field.storage.block_content.field_ebt_settings\";}s:6:\"module\";a:1:{i:0;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nY4Z9bxYtEWKQwTfEQV5y1aJi2T_PME930j0zdUd6e4\";}s:2:\"id\";s:50:\"block_content.ebt_webform_popup.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:5:\"label\";s:14:\"Block settings\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:12:\"ebt_settings\";}'),
('',	'field.field.block_content.ebt_webform_popup.field_ebt_webform_popup_form',	'a:17:{s:4:\"uuid\";s:36:\"ebbc4709-9eb2-4a48-bc09-0d83eaad805d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:36:\"block_content.type.ebt_webform_popup\";i:1;s:56:\"field.storage.block_content.field_ebt_webform_popup_form\";}s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XKxb-rFq0rOSgKq7mU1s79aoU0-O0IeICu_ZMzj9vG8\";}s:2:\"id\";s:60:\"block_content.ebt_webform_popup.field_ebt_webform_popup_form\";s:10:\"field_name\";s:28:\"field_ebt_webform_popup_form\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";s:17:\"ebt_webform_popup\";s:5:\"label\";s:7:\"Webform\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:15:\"default:webform\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";b:0;}}s:10:\"field_type\";s:7:\"webform\";}'),
('',	'field.field.media.audio.field_media_audio_file',	'a:17:{s:4:\"uuid\";s:36:\"4fa57014-dbe5-4dc4-b5c9-e6cb3404ad5c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_audio_file\";i:1;s:16:\"media.type.audio\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UlZPIbHcLyNqGY5bvydCTijGcKDmwn4Fo8oYZT85wlk\";}s:2:\"id\";s:34:\"media.audio.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"audio\";s:5:\"label\";s:10:\"Audio file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:11:\"mp3 wav aac\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),
('',	'field.field.media.document.field_media_document',	'a:17:{s:4:\"uuid\";s:36:\"1ebfa792-cf03-471d-9e5c-2dccd1fedd38\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:40:\"field.storage.media.field_media_document\";i:1;s:19:\"media.type.document\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DY5HtJTxUjFRGU_PaY6ifo2nhR-nAZ0y0s6kLmUbv5g\";}s:2:\"id\";s:35:\"media.document.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:96:\"txt rtf doc docx ppt pptx xls xlsx pdf odf odg odp ods odt fodt fods fodp fodg key numbers pages\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),
('',	'field.field.media.image.field_media_image',	'a:17:{s:4:\"uuid\";s:36:\"e2b79a9d-deda-4076-bcbe-2c9ae00b616e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:37:\"field.storage.media.field_media_image\";i:1;s:16:\"media.type.image\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"P7CkVOgjDXiN26Fm2hniNei-XPK3iuZTlcBGqreTbJ0\";}s:2:\"id\";s:29:\"media.image.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:25:\"png gif jpg jpeg webp svg\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),
('',	'field.field.media.remote_video.field_media_oembed_video',	'a:17:{s:4:\"uuid\";s:36:\"96b9388f-0779-4e2b-8429-6932b1a68ead\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.media.field_media_oembed_video\";i:1;s:23:\"media.type.remote_video\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Eo4HHenV5iZat_kEWgr_wydD3TgwURMCzwt-7qIEyoM\";}s:2:\"id\";s:43:\"media.remote_video.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:12:\"remote_video\";s:5:\"label\";s:9:\"Video URL\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),
('',	'field.field.media.video.field_media_video_file',	'a:17:{s:4:\"uuid\";s:36:\"af846c60-eb6c-4029-84b4-aa0ccf412591\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.media.field_media_video_file\";i:1;s:16:\"media.type.video\";}s:6:\"module\";a:1:{i:0;s:4:\"file\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6kMMjmk2r_csGQ52qI9BUaO8r_oAzNLbxlclaj-JlDQ\";}s:2:\"id\";s:34:\"media.video.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";s:5:\"video\";s:5:\"label\";s:10:\"Video file\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:6:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:3:\"mp4\";s:12:\"max_filesize\";s:0:\"\";s:17:\"description_field\";b:0;}s:10:\"field_type\";s:4:\"file\";}'),
('',	'field.field.node.article.body',	'a:17:{s:4:\"uuid\";s:36:\"7f75b85e-a8a9-4e63-8ba8-42cd18f1d713\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Wxs1LseZ8JsNwD9uJVIbzZqG35yQXN8Eo1Hub6NMuI\";}s:2:\"id\";s:17:\"node.article.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.node.article.field_image',	'a:17:{s:4:\"uuid\";s:36:\"ba97827c-59cc-4fb5-be06-7c44f9e98113\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"field.storage.node.field_image\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:5:\"image\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"j0riO_-77ZFWNLtj0iJ31HnohiNjdn8HUL86RueCF-M\";}s:2:\"id\";s:24:\"node.article.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:12:\"Teaser Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:1;s:18:\"alt_field_required\";b:1;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),
('',	'field.field.node.article.field_metatags',	'a:16:{s:4:\"uuid\";s:36:\"06f91975-9ecb-430d-b7f8-3de8ae8601c8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"field.storage.node.field_metatags\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:7:\"metatag\";}}s:2:\"id\";s:27:\"node.article.field_metatags\";s:10:\"field_name\";s:14:\"field_metatags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:8:\"Metatags\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:7:\"metatag\";}'),
('',	'field.field.node.article.field_tags',	'a:17:{s:4:\"uuid\";s:36:\"61a810a4-e29c-4fbf-b132-9fe51b115626\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:29:\"field.storage.node.field_tags\";i:1;s:17:\"node.type.article\";i:2;s:24:\"taxonomy.vocabulary.tags\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QdUgf_beeoaPiyKorFv0q1fcJpWH_uZTqe_xoVJacrw\";}s:2:\"id\";s:23:\"node.article.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:4:\"Tags\";s:11:\"description\";s:84:\"Enter a comma-separated list. For example: Amsterdam, Mexico City, \"Cleveland, Ohio\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:21:\"default:taxonomy_term\";s:16:\"handler_settings\";a:3:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.node.article.layout_builder__layout',	'a:16:{s:4:\"uuid\";s:36:\"97640446-27d5-4146-8b2a-a776d7a62ec7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:41:\"field.storage.node.layout_builder__layout\";i:1;s:17:\"node.type.article\";}s:6:\"module\";a:1:{i:0;s:14:\"layout_builder\";}}s:2:\"id\";s:35:\"node.article.layout_builder__layout\";s:10:\"field_name\";s:22:\"layout_builder__layout\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:7:\"article\";s:5:\"label\";s:6:\"Layout\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:14:\"layout_section\";}'),
('',	'field.field.node.page.body',	'a:17:{s:4:\"uuid\";s:36:\"f2e704ba-2d4f-4bf0-976b-19d893472d4f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:23:\"field.storage.node.body\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KHu9I-pR4FnP79crRJ5gVD_1mKGSZcJsdIm9bn64iFg\";}s:2:\"id\";s:14:\"node.page.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:4:\"Body\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:3:{s:15:\"display_summary\";b:1;s:16:\"required_summary\";b:0;s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:17:\"text_with_summary\";}'),
('',	'field.field.node.page.field_metatags',	'a:16:{s:4:\"uuid\";s:36:\"e785ab1b-0edf-46aa-bbaf-56e645079434\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:33:\"field.storage.node.field_metatags\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:7:\"metatag\";}}s:2:\"id\";s:24:\"node.page.field_metatags\";s:10:\"field_name\";s:14:\"field_metatags\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:8:\"Metatags\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:7:\"metatag\";}'),
('',	'field.field.node.page.layout_builder__layout',	'a:16:{s:4:\"uuid\";s:36:\"79c176b7-33a8-419d-b175-1853525a7e50\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:41:\"field.storage.node.layout_builder__layout\";i:1;s:14:\"node.type.page\";}s:6:\"module\";a:1:{i:0;s:14:\"layout_builder\";}}s:2:\"id\";s:32:\"node.page.layout_builder__layout\";s:10:\"field_name\";s:22:\"layout_builder__layout\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";s:4:\"page\";s:5:\"label\";s:6:\"Layout\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:14:\"layout_section\";}'),
('',	'field.field.paragraph.ebt_accordion.field_ebt_accordion_text',	'a:17:{s:4:\"uuid\";s:36:\"f0b63cf1-7f17-4dea-a7e0-b54d5d7d823f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_accordion_text\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K83AQZ4cOGBmrJfAKHjN1BC5fNJE2slkMvsq-eOngms\";}s:2:\"id\";s:48:\"paragraph.ebt_accordion.field_ebt_accordion_text\";s:10:\"field_name\";s:24:\"field_ebt_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:13:\"Text / Answer\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_accordion.field_ebt_accordion_title',	'a:17:{s:4:\"uuid\";s:36:\"c7bb20d0-7c3a-4e1d-80bd-fc8145337db5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ebt_accordion_title\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4iRsnnRe66bYKBWRFqXd8sFfW3tTM7kGDHb5ZI6bRoI\";}s:2:\"id\";s:49:\"paragraph.ebt_accordion.field_ebt_accordion_title\";s:10:\"field_name\";s:25:\"field_ebt_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_accordion\";s:5:\"label\";s:16:\"Title / Question\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_carousel.field_ebt_carousel_caption',	'a:17:{s:4:\"uuid\";s:36:\"cdf69cb6-7607-44f2-8e15-66eff3ea978e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ebt_carousel_caption\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zJkgaoa5XS7hvJb5prthRdBt34u3Y3QPJJ_obTMfkfQ\";}s:2:\"id\";s:49:\"paragraph.ebt_carousel.field_ebt_carousel_caption\";s:10:\"field_name\";s:26:\"field_ebt_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:13:\"Slide caption\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_carousel.field_ebt_carousel_image',	'a:17:{s:4:\"uuid\";s:36:\"cf3345b8-8872-40ef-818f-2e94b33e8961\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:48:\"field.storage.paragraph.field_ebt_carousel_image\";i:1;s:16:\"media.type.image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"igPOF7Xbo0_CaEPXbAyrAz0x22az-ryGnj9S4zfXsZY\";}s:2:\"id\";s:47:\"paragraph.ebt_carousel.field_ebt_carousel_image\";s:10:\"field_name\";s:24:\"field_ebt_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_carousel\";s:5:\"label\";s:11:\"Slide image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_description',	'a:17:{s:4:\"uuid\";s:36:\"89d82ff4-da95-426e-b0c1-c9f18b4c7e6a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:53:\"field.storage.paragraph.field_ebt_counter_description\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SGPys8iAffvOl_W66tfDAlPixkXxxxidEUCONW9q7dI\";}s:2:\"id\";s:56:\"paragraph.ebt_counter_item.field_ebt_counter_description\";s:10:\"field_name\";s:29:\"field_ebt_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:11:\"Description\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"22d74b30-be52-4cee-91ea-a0aa04de5dff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_ebt_counter_icon\";i:1;s:16:\"media.type.image\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Vzl7VAXpLPJd2KXAxVHrOfGNPWB1y1s1Jr5foDGSdIg\";}s:2:\"id\";s:49:\"paragraph.ebt_counter_item.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:4:\"Icon\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"e3b02b26-e9be-46ee-be2a-9c0cdb537a47\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_counter_number\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-5pDzCL0Ha9nbkySRCIjCME2yqGDQ9k92GT8A1xqWU\";}s:2:\"id\";s:51:\"paragraph.ebt_counter_item.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:6:\"Number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:4:{s:3:\"min\";N;s:3:\"max\";N;s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"field_type\";s:7:\"integer\";}'),
('',	'field.field.paragraph.ebt_counter_item.field_ebt_counter_title',	'a:17:{s:4:\"uuid\";s:36:\"62ea8aa7-eadf-46fe-8360-d5a565d6e339\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ebt_counter_title\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CvlljFbOKRTlxFz1hVYtYJkEdk3S-0I9UmjjS41E7_U\";}s:2:\"id\";s:50:\"paragraph.ebt_counter_item.field_ebt_counter_title\";s:10:\"field_name\";s:23:\"field_ebt_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_counter_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_image',	'a:17:{s:4:\"uuid\";s:36:\"0ed191f1-4795-4501-9075-ad48a0ed7ef5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:52:\"field.storage.paragraph.field_ebt_slick_slider_image\";i:1;s:16:\"media.type.image\";i:2;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pYWtlYxsR5uP9TrVPzdvPyRiMgr6Lp75dE9QtVEyu3Q\";}s:2:\"id\";s:55:\"paragraph.ebt_slick_slider.field_ebt_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ebt_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_link',	'a:17:{s:4:\"uuid\";s:36:\"ae270a12-20ca-4ebe-a2f1-69ea8b4fe6e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ebt_slick_slider_link\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jk5t1dH13MfYx1LmuLzIlSTGOi3qFvAHr8Zj5vlyM2I\";}s:2:\"id\";s:54:\"paragraph.ebt_slick_slider.field_ebt_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_text',	'a:17:{s:4:\"uuid\";s:36:\"087b3c83-4e91-4f68-b458-96330c343db8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:51:\"field.storage.paragraph.field_ebt_slick_slider_text\";i:1;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ob6mfPaJJwePb80FfSWg_M2reWUeqydWDbjtcshe-Bw\";}s:2:\"id\";s:54:\"paragraph.ebt_slick_slider.field_ebt_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_link',	'a:17:{s:4:\"uuid\";s:36:\"f3fdd942-959d-4943-993f-2d7c52030728\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_slideshow_link\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_fFBiyKlJ3i_w71vNv_KlKPhYmEARkECK_6O5gU5skA\";}s:2:\"id\";s:48:\"paragraph.ebt_slideshow.field_ebt_slideshow_link\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:10:\"Slide Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_slide',	'a:17:{s:4:\"uuid\";s:36:\"b8c36a1d-4e00-47c8-8d3b-5f5c824c1c41\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:49:\"field.storage.paragraph.field_ebt_slideshow_slide\";i:1;s:16:\"media.type.image\";i:2;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZhjSOx4h5C-uQqS8wmCEX4R-expUAu-sQghZL7OK400\";}s:2:\"id\";s:49:\"paragraph.ebt_slideshow.field_ebt_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:11:\"Slide Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_text',	'a:17:{s:4:\"uuid\";s:36:\"db307a56-3f8e-4027-b5d1-28fe5edaa11e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_slideshow_text\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bZ0m2BBV-ldK-3Eh4BGp1MRAgA6rMqeGPulDsD9kdyg\";}s:2:\"id\";s:48:\"paragraph.ebt_slideshow.field_ebt_slideshow_text\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:10:\"Slide Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_slideshow.field_ebt_slideshow_title',	'a:17:{s:4:\"uuid\";s:36:\"cc62f49e-1354-4058-a151-c4c1e7e5994a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:49:\"field.storage.paragraph.field_ebt_slideshow_title\";i:1;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6qs_c-h6E-d-9pn4rWyP3VMtvPIx0dwfa_m8bl9Or4g\";}s:2:\"id\";s:49:\"paragraph.ebt_slideshow.field_ebt_slideshow_title\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:13:\"ebt_slideshow\";s:5:\"label\";s:11:\"Slide Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_image',	'a:17:{s:4:\"uuid\";s:36:\"e7dc4733-12c7-4748-975b-b7d57accd4ee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:46:\"field.storage.paragraph.field_stats_item_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1k1v70N6h-IQn541w0qMasOm8bEEp3XimOb7xSv8suk\";}s:2:\"id\";s:47:\"paragraph.ebt_stats_item.field_stats_item_image\";s:10:\"field_name\";s:22:\"field_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:16:\"Stats item image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_link',	'a:17:{s:4:\"uuid\";s:36:\"67b6c95b-30fa-471d-a031-e84ec26a1a54\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_stats_item_link\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"uExk2SWTCDuqJRmvyPPMsGBSMj4ilG_32ADqZm_jKZY\";}s:2:\"id\";s:46:\"paragraph.ebt_stats_item.field_stats_item_link\";s:10:\"field_name\";s:21:\"field_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:15:\"Stats item link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:2;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_number',	'a:17:{s:4:\"uuid\";s:36:\"4ae0f11b-4c4f-43c8-a58e-9413b992ad4d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_stats_item_number\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5OFR72Rn-pvsZTbp7LEkgUVp0q21QilFZMegsC5ICbo\";}s:2:\"id\";s:48:\"paragraph.ebt_stats_item.field_stats_item_number\";s:10:\"field_name\";s:23:\"field_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:17:\"Stats item number\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_stats_item.field_stats_item_text',	'a:17:{s:4:\"uuid\";s:36:\"2907b7cd-48be-4276-8c1a-ad20ca437cd4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_stats_item_text\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5YdkRFvRcJQuYp6xs1qhhjaUeyj1ysW93i6EPEh9dWU\";}s:2:\"id\";s:46:\"paragraph.ebt_stats_item.field_stats_item_text\";s:10:\"field_name\";s:21:\"field_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_stats_item\";s:5:\"label\";s:15:\"Stats item text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_block',	'a:17:{s:4:\"uuid\";s:36:\"6821e0ef-8080-428a-ac78-f51249bb5e2d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_block\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7dftnJ-QEc2wq727UtTNqtQGbbQis8Pwgykf0EPgU5U\";}s:2:\"id\";s:37:\"paragraph.ebt_tab.field_ebt_tab_block\";s:10:\"field_name\";s:19:\"field_ebt_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:9:\"Tab Block\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:9:\"selection\";s:6:\"blocks\";s:18:\"selection_settings\";a:1:{s:10:\"plugin_ids\";a:0:{}}}s:10:\"field_type\";s:11:\"block_field\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_content',	'a:17:{s:4:\"uuid\";s:36:\"9093a2e3-eafc-42f9-9d74-0c76cf2fa7e6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ebt_tab_content\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:7:\"options\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"as55Dml1Xd2yWFDU0vGxsQmoXaIr9fZ2lC4KG8TpvzA\";}s:2:\"id\";s:39:\"paragraph.ebt_tab.field_ebt_tab_content\";s:10:\"field_name\";s:21:\"field_ebt_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:11:\"Tab content\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:11:\"list_string\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_page',	'a:17:{s:4:\"uuid\";s:36:\"6b77acaf-9fab-4d2e-9843-cfe8180ce9fe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:42:\"field.storage.paragraph.field_ebt_tab_page\";i:1;s:14:\"node.type.page\";i:2;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t9WpCMZrY0hReO2jvRG2Rte22ZW2y4Dq_5kF4YVAWqo\";}s:2:\"id\";s:36:\"paragraph.ebt_tab.field_ebt_tab_page\";s:10:\"field_name\";s:18:\"field_ebt_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:8:\"Tab page\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:12:\"default:node\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:4:\"page\";s:4:\"page\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_text',	'a:17:{s:4:\"uuid\";s:36:\"0cb50bf8-21aa-4ea6-a7d0-90d454555f86\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:42:\"field.storage.paragraph.field_ebt_tab_text\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qDqTeXYS1CTWbjbJQUSmVXGsWThhwp_YLObjCrj-4wo\";}s:2:\"id\";s:36:\"paragraph.ebt_tab.field_ebt_tab_text\";s:10:\"field_name\";s:18:\"field_ebt_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:8:\"Tab text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_title',	'a:17:{s:4:\"uuid\";s:36:\"217d9d46-984c-450c-b218-1d58121ced68\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_title\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"axHae-sP24gbeAgLnxqUi-W0N6tnY4ImUB_wdC1bCiM\";}s:2:\"id\";s:37:\"paragraph.ebt_tab.field_ebt_tab_title\";s:10:\"field_name\";s:19:\"field_ebt_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:9:\"Tab title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:4:\"text\";}'),
('',	'field.field.paragraph.ebt_tab.field_ebt_tab_views',	'a:17:{s:4:\"uuid\";s:36:\"5c306dcf-d85c-424e-b5d0-a819386f6ecc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_views\";i:1;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}s:6:\"module\";a:1:{i:0;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Zc3r5Wx5CVuHBS5Fvv1jYRaHo4EnB7V2rhALuCxql_o\";}s:2:\"id\";s:37:\"paragraph.ebt_tab.field_ebt_tab_views\";s:10:\"field_name\";s:19:\"field_ebt_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:7:\"ebt_tab\";s:5:\"label\";s:9:\"Tab views\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:5:{s:7:\"handler\";s:12:\"default:view\";s:16:\"handler_settings\";a:2:{s:14:\"target_bundles\";N;s:11:\"auto_create\";i:0;}s:12:\"plugin_types\";a:5:{s:7:\"default\";s:7:\"default\";s:5:\"block\";s:5:\"block\";s:4:\"page\";i:0;s:4:\"feed\";i:0;s:5:\"embed\";i:0;}s:15:\"preselect_views\";a:14:{s:8:\"articles\";i:0;s:13:\"block_content\";i:0;s:7:\"comment\";i:0;s:15:\"comments_recent\";i:0;s:7:\"content\";i:0;s:14:\"content_recent\";i:0;s:5:\"files\";i:0;s:9:\"frontpage\";i:0;s:13:\"taxonomy_term\";i:0;s:17:\"user_admin_people\";i:0;s:8:\"watchdog\";i:0;s:19:\"webform_submissions\";i:0;s:9:\"who_s_new\";i:0;s:12:\"who_s_online\";i:0;}s:16:\"enabled_settings\";a:5:{s:5:\"pager\";i:0;s:5:\"limit\";i:0;s:6:\"offset\";i:0;s:5:\"title\";i:0;s:8:\"argument\";i:0;}}s:10:\"field_type\";s:14:\"viewsreference\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_clickable_tile',	'a:17:{s:4:\"uuid\";s:36:\"b6bcf941-67b4-43b7-9747-c95baf1b7bc4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_clickable_tile\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I8Bhnp9Mihk3DDEulISHIOOcN-avs5jkwzt9L0n-CcI\";}s:2:\"id\";s:49:\"paragraph.ebt_tiles_item.field_ebt_clickable_tile\";s:10:\"field_name\";s:24:\"field_ebt_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:14:\"Clickable Tile\";s:11:\"description\";s:66:\"Make entire tile clickable or display link separataly if unchecked\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:1;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_image',	'a:17:{s:4:\"uuid\";s:36:\"9d903341-553f-4311-8a83-c48130d410e0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:45:\"field.storage.paragraph.field_ebt_tiles_image\";i:1;s:16:\"media.type.image\";i:2;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lPf_h3aKofBH6XHQRhBmyVb1lV4Z8_w0oD6vY9JLcjM\";}s:2:\"id\";s:46:\"paragraph.ebt_tiles_item.field_ebt_tiles_image\";s:10:\"field_name\";s:21:\"field_ebt_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_link',	'a:17:{s:4:\"uuid\";s:36:\"3c7cd9d7-a4c3-49a9-9bbc-1ced5ab70209\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ebt_tiles_link\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pQ8lDL7PoSiLrK83cA8hSPIPNufbpw3j1qT4f1V9VUc\";}s:2:\"id\";s:45:\"paragraph.ebt_tiles_item.field_ebt_tiles_link\";s:10:\"field_name\";s:20:\"field_ebt_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:4:\"Link\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:5:\"title\";i:1;s:9:\"link_type\";i:17;}s:10:\"field_type\";s:4:\"link\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_text',	'a:17:{s:4:\"uuid\";s:36:\"5201e488-c9af-4ec2-867e-3b3dbe8c8b16\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:44:\"field.storage.paragraph.field_ebt_tiles_text\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yZYhpVfxBQEK7LOwoolFtOZY726XpjMHK5opPVJB4j4\";}s:2:\"id\";s:45:\"paragraph.ebt_tiles_item.field_ebt_tiles_text\";s:10:\"field_name\";s:20:\"field_ebt_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_tiles_item.field_ebt_tiles_title',	'a:17:{s:4:\"uuid\";s:36:\"1e88de7b-7c46-4562-a223-9ccf83779820\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:45:\"field.storage.paragraph.field_ebt_tiles_title\";i:1;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"V7UyIKTz-lufN2i-3921iDZVIjrM1K-GA3PPgZfgYTI\";}s:2:\"id\";s:46:\"paragraph.ebt_tiles_item.field_ebt_tiles_title\";s:10:\"field_name\";s:21:\"field_ebt_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_current',	'a:17:{s:4:\"uuid\";s:36:\"24fd2c38-f992-42ae-89ce-590dd574cb31\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:50:\"field.storage.paragraph.field_ebt_timeline_current\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Js3oBqyPFEjLEDUuAPzn29jLKcNg1wsB7M9uvAF8fwQ\";}s:2:\"id\";s:49:\"paragraph.ebt_timeline.field_ebt_timeline_current\";s:10:\"field_name\";s:26:\"field_ebt_timeline_current\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:7:\"Current\";s:11:\"description\";s:36:\"Highlight current stage in timeline.\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:8:\"on_label\";s:2:\"On\";s:9:\"off_label\";s:3:\"Off\";}s:10:\"field_type\";s:7:\"boolean\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_date',	'a:17:{s:4:\"uuid\";s:36:\"d1569baf-9302-4e38-9ed4-987caeafa2e4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ebt_timeline_date\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ajUABeEHsfvEoCEA1JJywutAhjakBjNSR6yymicgJcQ\";}s:2:\"id\";s:46:\"paragraph.ebt_timeline.field_ebt_timeline_date\";s:10:\"field_name\";s:23:\"field_ebt_timeline_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:4:\"Date\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_media_image',	'a:17:{s:4:\"uuid\";s:36:\"a0651ff8-3cb5-478f-acbe-120dd869e921\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:3:{i:0;s:54:\"field.storage.paragraph.field_ebt_timeline_media_image\";i:1;s:16:\"media.type.image\";i:2;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0WMqQDbMLHG-hJMnj9tohP4sS2B93Gy_jhhZoUJIA9I\";}s:2:\"id\";s:53:\"paragraph.ebt_timeline.field_ebt_timeline_media_image\";s:10:\"field_name\";s:30:\"field_ebt_timeline_media_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:1:{s:5:\"image\";s:5:\"image\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:0:\"\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_text',	'a:17:{s:4:\"uuid\";s:36:\"265711bf-cab4-450f-83c7-f401aa255ff1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:47:\"field.storage.paragraph.field_ebt_timeline_text\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5F87FeFRv4oMn7nyxCCJ3pjlpG-G5NBIfD-5o5No0t8\";}s:2:\"id\";s:46:\"paragraph.ebt_timeline.field_ebt_timeline_text\";s:10:\"field_name\";s:23:\"field_ebt_timeline_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:4:\"Text\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_timeline.field_ebt_timeline_title',	'a:17:{s:4:\"uuid\";s:36:\"ae101647-2196-429e-ba3e-cbb55e4e92f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:2:{i:0;s:48:\"field.storage.paragraph.field_ebt_timeline_title\";i:1;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_pET64Z-ylj-Ic4NyQ0BmUF4zGO8dZ-uVWadrNKQvyo\";}s:2:\"id\";s:47:\"paragraph.ebt_timeline.field_ebt_timeline_title\";s:10:\"field_name\";s:24:\"field_ebt_timeline_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:12:\"ebt_timeline\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:0:{}s:10:\"field_type\";s:6:\"string\";}'),
('',	'field.field.paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description',	'a:17:{s:4:\"uuid\";s:36:\"2c335583-7279-4b40-95b9-09d17b06fc4a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:54:\"field.storage.paragraph.field_gallery_item_description\";i:1;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}s:6:\"module\";a:1:{i:0;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lW3Ks0DIMaIjFKfbgrmmUXgP-Atqo_sKwWuBuvS3Rmg\";}s:2:\"id\";s:73:\"paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description\";s:10:\"field_name\";s:30:\"field_gallery_item_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:5:\"label\";s:24:\"Gallery item description\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}s:10:\"field_type\";s:9:\"text_long\";}'),
('',	'field.field.paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item',	'a:17:{s:4:\"uuid\";s:36:\"2d4456ac-0c7c-4f72-8624-a25a5d933b9b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"config\";a:4:{i:0;s:48:\"field.storage.paragraph.field_video_gallery_item\";i:1;s:16:\"media.type.image\";i:2;s:23:\"media.type.remote_video\";i:3;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JaxawDXWXvX-mf-HuaUiJYhh81uXGJm8rPPZGOoQze8\";}s:2:\"id\";s:67:\"paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item\";s:10:\"field_name\";s:24:\"field_video_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";s:32:\"ebt_video_and_image_gallery_item\";s:5:\"label\";s:12:\"Gallery Item\";s:11:\"description\";s:0:\"\";s:8:\"required\";b:0;s:12:\"translatable\";b:0;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:2:{s:7:\"handler\";s:13:\"default:media\";s:16:\"handler_settings\";a:4:{s:14:\"target_bundles\";a:2:{s:5:\"image\";s:5:\"image\";s:12:\"remote_video\";s:12:\"remote_video\";}s:4:\"sort\";a:2:{s:5:\"field\";s:5:\"_none\";s:9:\"direction\";s:3:\"ASC\";}s:11:\"auto_create\";b:0;s:18:\"auto_create_bundle\";s:5:\"image\";}}s:10:\"field_type\";s:16:\"entity_reference\";}'),
('',	'field.field.user.user.user_picture',	'a:17:{s:4:\"uuid\";s:36:\"a99bd180-01c5-4300-997c-47456c8ba004\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:31:\"field.storage.user.user_picture\";}s:6:\"module\";a:2:{i:0;s:5:\"image\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TE3gYVzd6g0deXqUl8SEu2azHwVG-SdXm3kwbrz0kHw\";}s:2:\"id\";s:22:\"user.user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:5:\"label\";s:7:\"Picture\";s:11:\"description\";s:29:\"Your virtual face or picture.\";s:8:\"required\";b:0;s:12:\"translatable\";b:1;s:13:\"default_value\";a:0:{}s:22:\"default_value_callback\";s:0:\"\";s:8:\"settings\";a:12:{s:7:\"handler\";s:12:\"default:file\";s:16:\"handler_settings\";a:0:{}s:14:\"file_directory\";s:40:\"pictures/[date:custom:Y]-[date:custom:m]\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:12:\"max_filesize\";s:0:\"\";s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:9:\"alt_field\";b:0;s:18:\"alt_field_required\";b:0;s:11:\"title_field\";b:0;s:20:\"title_field_required\";b:0;s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:10:\"field_type\";s:5:\"image\";}'),
('',	'field.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nJk0TAQBzlNo52ehiHI7bIEPLGi0BYqZvPdEn7Chfu0\";}s:16:\"purge_batch_size\";i:50;}'),
('',	'field.storage.block_content.body',	'a:17:{s:4:\"uuid\";s:36:\"3db51960-3062-400f-b922-f0a7373dacb5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:2:\"id\";s:18:\"block_content.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_accordion',	'a:17:{s:4:\"uuid\";s:36:\"510be1fe-456a-4a0f-8638-40b7764bd46a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-9lmszSGOf8FvJqERXt4Y75SqfNFnjrUmffe3mvm63E\";}s:2:\"id\";s:33:\"block_content.field_ebt_accordion\";s:10:\"field_name\";s:19:\"field_ebt_accordion\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_basic_button_link',	'a:17:{s:4:\"uuid\";s:36:\"227cb366-5e8c-44f6-bcc0-a4197c0060f2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BzBSGwNX6bKi7xiNAKiETrdJPbGYMNk27dC6VzdE2Z4\";}s:2:\"id\";s:41:\"block_content.field_ebt_basic_button_link\";s:10:\"field_name\";s:27:\"field_ebt_basic_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_block_block',	'a:17:{s:4:\"uuid\";s:36:\"93988320-9748-44ab-ac19-9ac1a6feaa9d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qUmxIKbmrhd1TnlvNUsQ24_IqgsilgfToL8gamHgjPk\";}s:2:\"id\";s:35:\"block_content.field_ebt_block_block\";s:10:\"field_name\";s:21:\"field_ebt_block_block\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_bootstrap_button_link',	'a:17:{s:4:\"uuid\";s:36:\"6848e7e6-6bb4-4d7b-bfe3-64cb965c8d83\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Mn_2tFUWa7Mu6w06yP9iFQ7KLLKr83YOpxoaTd3IDo\";}s:2:\"id\";s:45:\"block_content.field_ebt_bootstrap_button_link\";s:10:\"field_name\";s:31:\"field_ebt_bootstrap_button_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_carousel',	'a:17:{s:4:\"uuid\";s:36:\"c31eee89-5d35-4da4-a2f9-daca2ffd26b7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5RyRgQO2iOVZE4gIaH8pGJ4s3UZCNOm5nqfkFXWwVvE\";}s:2:\"id\";s:32:\"block_content.field_ebt_carousel\";s:10:\"field_name\";s:18:\"field_ebt_carousel\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_columns_blocks',	'a:17:{s:4:\"uuid\";s:36:\"007c60bc-7d54-4666-8065-f77200cca762\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:11:\"block_field\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8ubMRbdfnR4zPhu3EFrCWZOc2hr9_Dum6gPo01gA7OE\";}s:2:\"id\";s:38:\"block_content.field_ebt_columns_blocks\";s:10:\"field_name\";s:24:\"field_ebt_columns_blocks\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_countdown_date',	'a:17:{s:4:\"uuid\";s:36:\"18c467c8-f5f7-4380-a5b7-5d8dd1bd6891\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:8:\"datetime\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tfVOPr7E66mYxIOwRxWNsSw4nFQnztb5FQbxuKg7_Dg\";}s:2:\"id\";s:38:\"block_content.field_ebt_countdown_date\";s:10:\"field_name\";s:24:\"field_ebt_countdown_date\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:8:\"datetime\";s:8:\"settings\";a:1:{s:13:\"datetime_type\";s:8:\"datetime\";}s:6:\"module\";s:8:\"datetime\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"90f3734d-9d21-4723-8027-039393a502ef\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bYFfyXow5e24VR-vUVn5lG3PHuSyRBkkEZ_qOShiuk\";}s:2:\"id\";s:36:\"block_content.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_counter_items',	'a:17:{s:4:\"uuid\";s:36:\"fcff8171-e2db-44a5-9585-8b9fb7992b79\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n1DI17J39aMu-YkFmfdRmeqTQflyy2-_xOR8jw99LkE\";}s:2:\"id\";s:37:\"block_content.field_ebt_counter_items\";s:10:\"field_name\";s:23:\"field_ebt_counter_items\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"62a1a67b-d505-4c27-8636-6a9c35a21cf3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fzJ_kU3wKSQOA7gdcWs4erHYixRul2pFzixpKaUIEcs\";}s:2:\"id\";s:38:\"block_content.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:7:\"integer\";s:8:\"settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_column_image',	'a:17:{s:4:\"uuid\";s:36:\"1e11b0a4-9fbb-4f77-a027-2abe7c00a623\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cWseV862aJoW9_oVsbhZOp1F-1WgQGPaPWt4miaSdoM\";}s:2:\"id\";s:40:\"block_content.field_ebt_cta_column_image\";s:10:\"field_name\";s:26:\"field_ebt_cta_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_link',	'a:17:{s:4:\"uuid\";s:36:\"069a665c-1062-4320-b384-be548389f826\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rx7cMICk6v3oU3DQBozX_KkK6bXWe9gJNBM2H0aC6n4\";}s:2:\"id\";s:32:\"block_content.field_ebt_cta_link\";s:10:\"field_name\";s:18:\"field_ebt_cta_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_second_link',	'a:17:{s:4:\"uuid\";s:36:\"95a9a9f7-3de1-4e44-8f20-3d0f2dfe6baa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nldTu1l1Acs-EQQUI6pM7wxOCM_8L8QdevFiQDrvqdk\";}s:2:\"id\";s:39:\"block_content.field_ebt_cta_second_link\";s:10:\"field_name\";s:25:\"field_ebt_cta_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_cta_title',	'a:17:{s:4:\"uuid\";s:36:\"28d853cc-13c3-4be6-9b85-37001544855b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QzI1KYIZiUFHadsdJPmZk_6XW4wCrROvPpgDNWpBa8M\";}s:2:\"id\";s:33:\"block_content.field_ebt_cta_title\";s:10:\"field_name\";s:19:\"field_ebt_cta_title\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_column_image',	'a:17:{s:4:\"uuid\";s:36:\"ef778f49-5062-47e4-bca2-1b340272972f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qRkbr3wurZNCdoGUXFQbfo3Q8o-iJ-GBBGGEAY2iPYg\";}s:2:\"id\";s:41:\"block_content.field_ebt_hero_column_image\";s:10:\"field_name\";s:27:\"field_ebt_hero_column_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_link',	'a:17:{s:4:\"uuid\";s:36:\"27029cab-99df-44cd-891e-de41f3558b7c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u6S6Tua-DwnyB3sGdBXHub-aGYa1PeUoR9SfeJOlpYE\";}s:2:\"id\";s:33:\"block_content.field_ebt_hero_link\";s:10:\"field_name\";s:19:\"field_ebt_hero_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_second_link',	'a:17:{s:4:\"uuid\";s:36:\"535ff977-be0f-4fa5-8d38-7803ae8b9094\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zmAY3AWa6AyFxiDtFl2a9fy666r6LZkvLTF540UTBdE\";}s:2:\"id\";s:40:\"block_content.field_ebt_hero_second_link\";s:10:\"field_name\";s:26:\"field_ebt_hero_second_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_title',	'a:17:{s:4:\"uuid\";s:36:\"2807bb2f-4aff-460c-9cf6-46dd6ddcf653\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tz0LPZeke3wFWFFnRzkakjNgB9UGwLj1eCtzzQv6XSA\";}s:2:\"id\";s:34:\"block_content.field_ebt_hero_title\";s:10:\"field_name\";s:20:\"field_ebt_hero_title\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_hero_title_prefix',	'a:17:{s:4:\"uuid\";s:36:\"d972b731-9ab7-4ca0-8ee1-32320e00018b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yPT-fy4fwafnNJhdyQ0u1kFfPiRvtGiJ8-5FOUcKyaw\";}s:2:\"id\";s:41:\"block_content.field_ebt_hero_title_prefix\";s:10:\"field_name\";s:27:\"field_ebt_hero_title_prefix\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image',	'a:17:{s:4:\"uuid\";s:36:\"90e79693-e9f5-46f1-bb04-df225231b9a7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"glPjB_880Y127LFOondnNWS1FPhcaT_fJa11BR0P5BA\";}s:2:\"id\";s:29:\"block_content.field_ebt_image\";s:10:\"field_name\";s:15:\"field_ebt_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image_caption',	'a:17:{s:4:\"uuid\";s:36:\"d9f39667-4231-4f25-b5b5-7d6a627c0143\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LJgW5JIAhD9XCJuoflFRdy-F8SWYW2Cix0FvZz4SYiY\";}s:2:\"id\";s:37:\"block_content.field_ebt_image_caption\";s:10:\"field_name\";s:23:\"field_ebt_image_caption\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image_gallery',	'a:17:{s:4:\"uuid\";s:36:\"0ab015a1-cb97-4ec7-ad66-d236d2472cee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VTE6qLfHmQDITpk4f42HVWATR8Wgh7o2ygcj4yx3iNQ\";}s:2:\"id\";s:37:\"block_content.field_ebt_image_gallery\";s:10:\"field_name\";s:23:\"field_ebt_image_gallery\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_image_link',	'a:17:{s:4:\"uuid\";s:36:\"d53112b6-fda3-4a60-9140-a4f4d8c03704\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wLzveDC1XvIz7oYfIvN4OjokbzzjPzDc9Ik730ZY254\";}s:2:\"id\";s:34:\"block_content.field_ebt_image_link\";s:10:\"field_name\";s:20:\"field_ebt_image_link\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_micromodal_title',	'a:17:{s:4:\"uuid\";s:36:\"8889dde4-ff00-4644-8af5-1d22a85992bc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KxeGHZZZNOmgTH3mTuMpwjJqQoqqDIsVOiT05vaOjSQ\";}s:2:\"id\";s:40:\"block_content.field_ebt_micromodal_title\";s:10:\"field_name\";s:26:\"field_ebt_micromodal_title\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_quote_author',	'a:17:{s:4:\"uuid\";s:36:\"66105a0b-52fa-455d-9673-6bab401dd3d9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"un8UvEIKf-pPNdISDAwHz8cnHArBXUbFHb8rYis_-KU\";}s:2:\"id\";s:36:\"block_content.field_ebt_quote_author\";s:10:\"field_name\";s:22:\"field_ebt_quote_author\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_quote_image',	'a:17:{s:4:\"uuid\";s:36:\"c53a9a24-143b-4766-a552-e983659465b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"usPfnGqFjnh9WSQ4-5tqsU1G2FvbPHpJMyt4Omq2btU\";}s:2:\"id\";s:35:\"block_content.field_ebt_quote_image\";s:10:\"field_name\";s:21:\"field_ebt_quote_image\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_settings',	'a:17:{s:4:\"uuid\";s:36:\"37d2f916-06b4-418e-91ad-84a23f9fe7aa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:8:\"ebt_core\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ifyYbCOsv_c2p19zBnvPk39PxYWsMjVLhswFVxeoMEk\";}s:2:\"id\";s:32:\"block_content.field_ebt_settings\";s:10:\"field_name\";s:18:\"field_ebt_settings\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:12:\"ebt_settings\";s:8:\"settings\";a:0:{}s:6:\"module\";s:8:\"ebt_core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_slick_slider',	'a:17:{s:4:\"uuid\";s:36:\"4f31d892-e4c2-45d6-a14e-723ccc4c06f0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvQGqiPKTXqRaJpknm7I-jiTH0_2U95OADILQZQt5zA\";}s:2:\"id\";s:36:\"block_content.field_ebt_slick_slider\";s:10:\"field_name\";s:22:\"field_ebt_slick_slider\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_slideshow',	'a:17:{s:4:\"uuid\";s:36:\"aec7f7b6-b7a3-414f-8026-620c99e80fee\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pGo99IMeEAHZnIdMVP18pkNzYTjRT7opYqgiP2t4CzI\";}s:2:\"id\";s:33:\"block_content.field_ebt_slideshow\";s:10:\"field_name\";s:19:\"field_ebt_slideshow\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_stats',	'a:17:{s:4:\"uuid\";s:36:\"65f88f19-ba20-4a37-8258-22b4bbd0bed3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TCxq8NOVtHeT-j0H_fF1rrmP8AxlDhBMsOm8KSQlkrs\";}s:2:\"id\";s:29:\"block_content.field_ebt_stats\";s:10:\"field_name\";s:15:\"field_ebt_stats\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_tabs',	'a:17:{s:4:\"uuid\";s:36:\"8b001212-3460-4d07-af2d-efb8bed64599\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-l2aVtFab9PohqPfDUp_RU4Ji6kBJLDWSfB6L_rUZmo\";}s:2:\"id\";s:28:\"block_content.field_ebt_tabs\";s:10:\"field_name\";s:14:\"field_ebt_tabs\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_tiles',	'a:17:{s:4:\"uuid\";s:36:\"2fa60bf2-361b-4902-b836-53c11ea98d00\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xpk_uqKrbVXj3nCNx7pki4z-Cql8XOb4a0GLo-PxaDE\";}s:2:\"id\";s:29:\"block_content.field_ebt_tiles\";s:10:\"field_name\";s:15:\"field_ebt_tiles\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_timeline',	'a:17:{s:4:\"uuid\";s:36:\"34f357a7-4ec0-459d-9349-7c3b933ed9ca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"w5cvHJQa6dOxx4ke6vQ8dBNORP8_2BYC8XoDyNSh_ag\";}s:2:\"id\";s:32:\"block_content.field_ebt_timeline\";s:10:\"field_name\";s:18:\"field_ebt_timeline\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_video',	'a:17:{s:4:\"uuid\";s:36:\"cd7bca62-bdaa-494e-8d09-d0af7c881721\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yqpxggVM9qa9BsCQ0dK4C8x0wU_GrVyhYXeHKQe-IMI\";}s:2:\"id\";s:29:\"block_content.field_ebt_video\";s:10:\"field_name\";s:15:\"field_ebt_video\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_videos_and_images',	'a:17:{s:4:\"uuid\";s:36:\"51b55e7c-d254-49db-b70a-396cd9835bd2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gzA7OAqszgyne63vWHEzNQQzhp58wo4JD5jrt82tjk8\";}s:2:\"id\";s:41:\"block_content.field_ebt_videos_and_images\";s:10:\"field_name\";s:27:\"field_ebt_videos_and_images\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:26:\"entity_reference_revisions\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:6:\"module\";s:26:\"entity_reference_revisions\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_views_views',	'a:17:{s:4:\"uuid\";s:36:\"f11fd5af-293c-41e7-91eb-52f5c2b14f5a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"crklekBdziPXiKGCBhoUfqwhWUXAuyDEQHEw0J7NdQI\";}s:2:\"id\";s:35:\"block_content.field_ebt_views_views\";s:10:\"field_name\";s:21:\"field_ebt_views_views\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_webform_form',	'a:17:{s:4:\"uuid\";s:36:\"08365941-eddc-446f-8fc9-72a7728df65c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K4nKI1yvxZ4s40vKrpuBiz09L15lK0ygK9etUTwYVRw\";}s:2:\"id\";s:36:\"block_content.field_ebt_webform_form\";s:10:\"field_name\";s:22:\"field_ebt_webform_form\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.block_content.field_ebt_webform_popup_form',	'a:17:{s:4:\"uuid\";s:36:\"fb27b8eb-ae9d-44ec-8d20-6aa1287b8b5f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GlZwbpK_4w1bHHs_IAnr12BJmD-fvq2QCviVBXnfiRA\";}s:2:\"id\";s:42:\"block_content.field_ebt_webform_popup_form\";s:10:\"field_name\";s:28:\"field_ebt_webform_popup_form\";s:11:\"entity_type\";s:13:\"block_content\";s:4:\"type\";s:7:\"webform\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:6:\"module\";s:7:\"webform\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_audio_file',	'a:17:{s:4:\"uuid\";s:36:\"75a1e1d5-184d-4541-96b7-8957dddb2453\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JCHoh95CpUeBx9ch24Tmi6ru0nwmNz8xWVH4Qs7RnTg\";}s:2:\"id\";s:28:\"media.field_media_audio_file\";s:10:\"field_name\";s:22:\"field_media_audio_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_document',	'a:17:{s:4:\"uuid\";s:36:\"2c293a08-a63a-47a3-8b49-8e7650f47903\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BdkTx7IL59MCw5a_fOZprPTOGM_wcjz-Fm8g7HV3vFk\";}s:2:\"id\";s:26:\"media.field_media_document\";s:10:\"field_name\";s:20:\"field_media_document\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_image',	'a:17:{s:4:\"uuid\";s:36:\"379994ed-ae76-4656-ab52-4f8661d6efc4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0N0KSFk57p6qsq3qM4lYVGSuROvzXK-tSsdwByqUh3g\";}s:2:\"id\";s:23:\"media.field_media_image\";s:10:\"field_name\";s:17:\"field_media_image\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_oembed_video',	'a:17:{s:4:\"uuid\";s:36:\"eca9af3a-0023-4307-a38b-526dac079818\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cNf_852Dq-fNnSaMI4LxL-J6N7bLkHuDbD9EUqOn4_U\";}s:2:\"id\";s:30:\"media.field_media_oembed_video\";s:10:\"field_name\";s:24:\"field_media_oembed_video\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;s:8:\"is_ascii\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.media.field_media_video_file',	'a:17:{s:4:\"uuid\";s:36:\"4f8a6296-0295-4cc5-8e6a-c61c708a78ba\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z5mgbn1PIVZ5TNMByBmivqo_u3Rdk58UIzpyN4ypTeM\";}s:2:\"id\";s:28:\"media.field_media_video_file\";s:10:\"field_name\";s:22:\"field_media_video_file\";s:11:\"entity_type\";s:5:\"media\";s:4:\"type\";s:4:\"file\";s:8:\"settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:6:\"module\";s:4:\"file\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.body',	'a:17:{s:4:\"uuid\";s:36:\"27acecd6-ddfe-41ab-ad13-d09a77410226\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:2:\"id\";s:9:\"node.body\";s:10:\"field_name\";s:4:\"body\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:17:\"text_with_summary\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.field_image',	'a:17:{s:4:\"uuid\";s:36:\"0ce9563d-0108-4dd8-9768-e3f3f692efb8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:2:\"id\";s:16:\"node.field_image\";s:10:\"field_name\";s:11:\"field_image\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.field_metatags',	'a:16:{s:4:\"uuid\";s:36:\"3a56d56d-4fea-4e6d-abfd-6e9fd5799d1f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"metatag\";i:1;s:4:\"node\";}}s:2:\"id\";s:19:\"node.field_metatags\";s:10:\"field_name\";s:14:\"field_metatags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:7:\"metatag\";s:8:\"settings\";a:0:{}s:6:\"module\";s:7:\"metatag\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.field_tags',	'a:17:{s:4:\"uuid\";s:36:\"11256bc1-c4ef-404b-ae80-826c196dfc3c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:2:\"id\";s:15:\"node.field_tags\";s:10:\"field_name\";s:10:\"field_tags\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:-1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.node.layout_builder__layout',	'a:16:{s:4:\"uuid\";s:36:\"01dcf303-887c-48ba-8de3-a183f2dc164d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:14:\"layout_builder\";i:1;s:4:\"node\";}}s:2:\"id\";s:27:\"node.layout_builder__layout\";s:10:\"field_name\";s:22:\"layout_builder__layout\";s:11:\"entity_type\";s:4:\"node\";s:4:\"type\";s:14:\"layout_section\";s:8:\"settings\";a:0:{}s:6:\"module\";s:14:\"layout_builder\";s:6:\"locked\";b:1;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:0;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_accordion_text',	'a:17:{s:4:\"uuid\";s:36:\"c88354ca-8244-4d5a-8c63-2709d938c811\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dl3BMOx4hnrrl4qqLYkCtUssYQ_RkV9iIcbThUL8opE\";}s:2:\"id\";s:34:\"paragraph.field_ebt_accordion_text\";s:10:\"field_name\";s:24:\"field_ebt_accordion_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_accordion_title',	'a:17:{s:4:\"uuid\";s:36:\"7205b1e6-f387-4cb5-80f3-ea6e935096ea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xtdycMRMTk1-RbuIsXUkC8uoiTiAeIi8PtDCDuev5pM\";}s:2:\"id\";s:35:\"paragraph.field_ebt_accordion_title\";s:10:\"field_name\";s:25:\"field_ebt_accordion_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_carousel_caption',	'a:17:{s:4:\"uuid\";s:36:\"9950466c-7cf2-451c-a90c-6d94bc4223d2\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eH045cIw7DgTbyESpPO40c1yE4GkZSKAsRjv6wCv1cc\";}s:2:\"id\";s:36:\"paragraph.field_ebt_carousel_caption\";s:10:\"field_name\";s:26:\"field_ebt_carousel_caption\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_carousel_image',	'a:17:{s:4:\"uuid\";s:36:\"c9955fe0-9e81-4347-b5c8-b3a2813ea422\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sBBtSihKznwfoZE4RCUfKLyFx5JPJOKThpsezNspQUg\";}s:2:\"id\";s:34:\"paragraph.field_ebt_carousel_image\";s:10:\"field_name\";s:24:\"field_ebt_carousel_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_clickable_tile',	'a:17:{s:4:\"uuid\";s:36:\"4a6ac85b-3418-4331-8d82-82c365e01b2a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sqyvMHG_MfFRoRtp9QsU69-Hqibbf7-n0L6nXXuy-RY\";}s:2:\"id\";s:34:\"paragraph.field_ebt_clickable_tile\";s:10:\"field_name\";s:24:\"field_ebt_clickable_tile\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_description',	'a:17:{s:4:\"uuid\";s:36:\"474cb9c9-f18d-40c9-8bdc-2b263c5bf1bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T2aI_SC10fUAVAHAQ6YSjRx-RgZI16Y4DhBlcYV8xTY\";}s:2:\"id\";s:39:\"paragraph.field_ebt_counter_description\";s:10:\"field_name\";s:29:\"field_ebt_counter_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_icon',	'a:17:{s:4:\"uuid\";s:36:\"17ec174c-0286-4b9d-8d57-f5618c7d73b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A3xIcHA3Yh7nEExvOCO8fCJ2RKTLwO7PHRzSW91-6ag\";}s:2:\"id\";s:32:\"paragraph.field_ebt_counter_icon\";s:10:\"field_name\";s:22:\"field_ebt_counter_icon\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_number',	'a:17:{s:4:\"uuid\";s:36:\"fe9a8722-bb07-4268-815a-a4b9b20eb504\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"12yti1pJd8_55sJ_ipVJkKkOSBrqJNbIN1ScDohe8Ug\";}s:2:\"id\";s:34:\"paragraph.field_ebt_counter_number\";s:10:\"field_name\";s:24:\"field_ebt_counter_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"integer\";s:8:\"settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_counter_title',	'a:17:{s:4:\"uuid\";s:36:\"646af88e-2cb1-4e61-9b5a-1720fbe00d94\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8SSZniajg5zo9MscuowyDAxLHlUJhnpGgVXmpef2Qfc\";}s:2:\"id\";s:33:\"paragraph.field_ebt_counter_title\";s:10:\"field_name\";s:23:\"field_ebt_counter_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slick_slider_image',	'a:17:{s:4:\"uuid\";s:36:\"7b1e8d87-89a6-4d9c-b0ae-16292b52f88b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HwpmmxKvO4846yzGMxYlF27KAqxGN93LugyydI_mAQk\";}s:2:\"id\";s:38:\"paragraph.field_ebt_slick_slider_image\";s:10:\"field_name\";s:28:\"field_ebt_slick_slider_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slick_slider_link',	'a:17:{s:4:\"uuid\";s:36:\"ce8c8911-2694-45d2-b941-6c8f08c9a8fd\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2sX2ALM8UbHO085MTpnVsKr65w2_hTSuR1OGRh9yhnc\";}s:2:\"id\";s:37:\"paragraph.field_ebt_slick_slider_link\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slick_slider_text',	'a:17:{s:4:\"uuid\";s:36:\"fd3e2c50-dcff-4f84-bd3f-a28c9352ea81\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bw5ktsaCO3NIoI8s4_-sX-8nheZucWVVtes3gNa3nAM\";}s:2:\"id\";s:37:\"paragraph.field_ebt_slick_slider_text\";s:10:\"field_name\";s:27:\"field_ebt_slick_slider_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_link',	'a:17:{s:4:\"uuid\";s:36:\"99143ce8-61ee-4652-a122-2b74cf0353a8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYqrMKPAVBTFXGukNiO0LmsHSZLTwSIqlH0B12cWoSc\";}s:2:\"id\";s:34:\"paragraph.field_ebt_slideshow_link\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_slide',	'a:17:{s:4:\"uuid\";s:36:\"20a2702c-d0d9-491e-bc0d-48bd8f4e5479\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yvMPSQ3opDpO2Y7W2gLC_lfyYsUerg7quMuaUIXTG6Y\";}s:2:\"id\";s:35:\"paragraph.field_ebt_slideshow_slide\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_slide\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_text',	'a:17:{s:4:\"uuid\";s:36:\"5476f31f-53b6-41ea-919f-8ea57cf902fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l1sRS9qn9Xk0p6T25AqVsGWWAhp74-8ejyMC2cSICnA\";}s:2:\"id\";s:34:\"paragraph.field_ebt_slideshow_text\";s:10:\"field_name\";s:24:\"field_ebt_slideshow_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_slideshow_title',	'a:17:{s:4:\"uuid\";s:36:\"b514672e-03d7-4efa-81b8-0f04c6b94cd1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"56OfbIVnrkDV6Ei_ldSAYihwJbVyAJds03m4lf7fsqc\";}s:2:\"id\";s:35:\"paragraph.field_ebt_slideshow_title\";s:10:\"field_name\";s:25:\"field_ebt_slideshow_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_block',	'a:17:{s:4:\"uuid\";s:36:\"0fc30373-baea-48fd-8769-4b6c582ae3d8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AwzF4qJWahe58UULrqET0cwFen2kxLMygeAFj96-4Kk\";}s:2:\"id\";s:29:\"paragraph.field_ebt_tab_block\";s:10:\"field_name\";s:19:\"field_ebt_tab_block\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"block_field\";s:8:\"settings\";a:0:{}s:6:\"module\";s:11:\"block_field\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_content',	'a:17:{s:4:\"uuid\";s:36:\"d00f9fc0-b613-4eed-90b2-740af89205eb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"options\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7FvDDnDFUS9rxHT4MbM9RwHPArBckbhp09KzHNMtD10\";}s:2:\"id\";s:31:\"paragraph.field_ebt_tab_content\";s:10:\"field_name\";s:21:\"field_ebt_tab_content\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:11:\"list_string\";s:8:\"settings\";a:2:{s:14:\"allowed_values\";a:4:{i:0;a:2:{s:5:\"value\";s:4:\"text\";s:5:\"label\";s:4:\"Text\";}i:1;a:2:{s:5:\"value\";s:4:\"page\";s:5:\"label\";s:4:\"Page\";}i:2;a:2:{s:5:\"value\";s:5:\"block\";s:5:\"label\";s:5:\"Block\";}i:3;a:2:{s:5:\"value\";s:5:\"views\";s:5:\"label\";s:5:\"Views\";}}s:23:\"allowed_values_function\";s:0:\"\";}s:6:\"module\";s:7:\"options\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_page',	'a:17:{s:4:\"uuid\";s:36:\"527f69af-c7cb-450d-a95f-a0199f66a3fc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Lx2SQWOPiXsxTotbjz7VPPAu-QERRb10_IFn-ApZRDo\";}s:2:\"id\";s:28:\"paragraph.field_ebt_tab_page\";s:10:\"field_name\";s:18:\"field_ebt_tab_page\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"node\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_text',	'a:17:{s:4:\"uuid\";s:36:\"7492acc6-65ae-4f1f-b3c7-3e41a385e8cb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvq8PSEOBXAVYlGbuM_TA0t_zulyHA_Bkjc6MrrkLWY\";}s:2:\"id\";s:28:\"paragraph.field_ebt_tab_text\";s:10:\"field_name\";s:18:\"field_ebt_tab_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_title',	'a:17:{s:4:\"uuid\";s:36:\"0c03a11f-8242-48d7-ae98-2da2e80f3f2e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"chlF7z3GEcHoQnXo-49bdW3H_FSDPxAqWy0miEMc3AM\";}s:2:\"id\";s:29:\"paragraph.field_ebt_tab_title\";s:10:\"field_name\";s:19:\"field_ebt_tab_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"text\";s:8:\"settings\";a:1:{s:10:\"max_length\";i:1023;}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tab_views',	'a:17:{s:4:\"uuid\";s:36:\"3dc81a0a-ea91-4e72-af8b-18c1abffc08d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QmZGd58IuoXxDcUvh8hfNHnRLR71GZA3qzfZpuVSjH4\";}s:2:\"id\";s:29:\"paragraph.field_ebt_tab_views\";s:10:\"field_name\";s:19:\"field_ebt_tab_views\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:14:\"viewsreference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:6:\"module\";s:14:\"viewsreference\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_image',	'a:17:{s:4:\"uuid\";s:36:\"3988ff22-66ff-4325-be58-387a6451784f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3aeaxW3pHrK5yFagP66-FT7HXAGYacr2YhOcg-h70n0\";}s:2:\"id\";s:31:\"paragraph.field_ebt_tiles_image\";s:10:\"field_name\";s:21:\"field_ebt_tiles_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_link',	'a:17:{s:4:\"uuid\";s:36:\"f1992284-2903-4d4f-b4c2-4336abc56b45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mUN0Fv2hYJXOjWBr3fDMeZnblvk6m_qvnRncjAS5Jz0\";}s:2:\"id\";s:30:\"paragraph.field_ebt_tiles_link\";s:10:\"field_name\";s:20:\"field_ebt_tiles_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_text',	'a:17:{s:4:\"uuid\";s:36:\"6e677df8-5ee4-417d-be3a-d5036e605903\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SYBCp04_zUg3tqwrydEEBCSg6JWf7CR4f2Jym-jtu7Y\";}s:2:\"id\";s:30:\"paragraph.field_ebt_tiles_text\";s:10:\"field_name\";s:20:\"field_ebt_tiles_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_tiles_title',	'a:17:{s:4:\"uuid\";s:36:\"adfc8f4b-838d-40b5-956a-1f813f9dc592\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"__j2dIJmEb5SExuxv7f5bTbyHtFYlG0BqQD9owZgiFA\";}s:2:\"id\";s:31:\"paragraph.field_ebt_tiles_title\";s:10:\"field_name\";s:21:\"field_ebt_tiles_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_current',	'a:17:{s:4:\"uuid\";s:36:\"1043de86-9fe2-4436-8425-6f47521f1f00\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"io0Gxmv8qUwbnmMiTtgXlnMKWybAbO4f6d7W3yHn9vE\";}s:2:\"id\";s:36:\"paragraph.field_ebt_timeline_current\";s:10:\"field_name\";s:26:\"field_ebt_timeline_current\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_date',	'a:17:{s:4:\"uuid\";s:36:\"80c677f9-529e-499e-959c-dc9187ab7a49\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nmy2TG7m2qANlPD4kTWJk7016mawyxdzgYZ3omLSCVc\";}s:2:\"id\";s:33:\"paragraph.field_ebt_timeline_date\";s:10:\"field_name\";s:23:\"field_ebt_timeline_date\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_media_image',	'a:17:{s:4:\"uuid\";s:36:\"7089f45d-1e3c-4225-bba6-736084040e5b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yB2KT5oQDNzQfggkUQGHhoqlikRSVCE8a5MSV_5NvEo\";}s:2:\"id\";s:40:\"paragraph.field_ebt_timeline_media_image\";s:10:\"field_name\";s:30:\"field_ebt_timeline_media_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_text',	'a:17:{s:4:\"uuid\";s:36:\"fe035edd-b535-4ceb-bd54-a3c604fbae92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CFCHP9vAPguIB2d677v2iLm245zKg4MRxpfICMcUHo8\";}s:2:\"id\";s:33:\"paragraph.field_ebt_timeline_text\";s:10:\"field_name\";s:23:\"field_ebt_timeline_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_ebt_timeline_title',	'a:17:{s:4:\"uuid\";s:36:\"7b0677d8-0312-4994-b0a6-cd1c0852a050\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cM8ncQUeGNJamKPS5THMY_gIhCe_qsCwn4s-_6YPaq4\";}s:2:\"id\";s:34:\"paragraph.field_ebt_timeline_title\";s:10:\"field_name\";s:24:\"field_ebt_timeline_title\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:512;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_gallery_item_description',	'a:17:{s:4:\"uuid\";s:36:\"31c1cb14-3677-44d6-951e-3560a93c8f65\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jf90xTmsti89Pjc4bIjB0aBV5QshhjB0mhGkqONmGjU\";}s:2:\"id\";s:40:\"paragraph.field_gallery_item_description\";s:10:\"field_name\";s:30:\"field_gallery_item_description\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_image',	'a:17:{s:4:\"uuid\";s:36:\"233843a3-22c1-4376-a920-f894f695b87c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ml8f47_-t_lza9fvHT7YnpccMFPtmO5CC_TKle1QMr8\";}s:2:\"id\";s:32:\"paragraph.field_stats_item_image\";s:10:\"field_name\";s:22:\"field_stats_item_image\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_link',	'a:17:{s:4:\"uuid\";s:36:\"7003f50c-c76e-4efe-bfcc-67453daeb93c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6Xx4YNeE_zQDdDg8HySkyOGsBrl8RHNnsFsWYoC1GI4\";}s:2:\"id\";s:31:\"paragraph.field_stats_item_link\";s:10:\"field_name\";s:21:\"field_stats_item_link\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:4:\"link\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"link\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_number',	'a:17:{s:4:\"uuid\";s:36:\"f6763f4c-c4a6-4d80-ab1d-f0e2aca44f60\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YWL60ZrNzy_L7BYYe7ipJCC3__awGcG9ewUwecK82J4\";}s:2:\"id\";s:33:\"paragraph.field_stats_item_number\";s:10:\"field_name\";s:23:\"field_stats_item_number\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_stats_item_text',	'a:17:{s:4:\"uuid\";s:36:\"0d6fd00f-5382-443f-ae8a-996e1552af22\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7R83PXXuAu39Em7tMg3vXyaerbWjilK3AuSi3IXVRYc\";}s:2:\"id\";s:31:\"paragraph.field_stats_item_text\";s:10:\"field_name\";s:21:\"field_stats_item_text\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:9:\"text_long\";s:8:\"settings\";a:0:{}s:6:\"module\";s:4:\"text\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.paragraph.field_video_gallery_item',	'a:17:{s:4:\"uuid\";s:36:\"5c6f70cc-17fc-4f18-bcfb-4c0d8a66500e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qNGEoWbTX-CnhncjUmfOTlH2eL2GnzBZckwY_yzsHfM\";}s:2:\"id\";s:34:\"paragraph.field_video_gallery_item\";s:10:\"field_name\";s:24:\"field_video_gallery_item\";s:11:\"entity_type\";s:9:\"paragraph\";s:4:\"type\";s:16:\"entity_reference\";s:8:\"settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:6:\"module\";s:4:\"core\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:0:{}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field.storage.user.user_picture',	'a:17:{s:4:\"uuid\";s:36:\"13a3c6c5-6417-4477-8a58-0b066b2141c3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:2:\"id\";s:17:\"user.user_picture\";s:10:\"field_name\";s:12:\"user_picture\";s:11:\"entity_type\";s:4:\"user\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:6:\"module\";s:5:\"image\";s:6:\"locked\";b:0;s:11:\"cardinality\";i:1;s:12:\"translatable\";b:1;s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:22:\"persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;}'),
('',	'field_ui.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q1nMi90W6YQxKzZAgJQw7Ag9U4JrsEUwkomF0lhvbIM\";}s:12:\"field_prefix\";s:6:\"field_\";}'),
('',	'file.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bwjZB1IjEYbppgZT3g7YW_5h_LDZYNa3DaDEfWX82U\";}s:11:\"description\";a:2:{s:4:\"type\";s:9:\"textfield\";s:6:\"length\";i:128;}s:4:\"icon\";a:1:{s:9:\"directory\";s:23:\"core/modules/file/icons\";}s:35:\"make_unused_managed_files_temporary\";b:0;s:21:\"filename_sanitization\";a:6:{s:13:\"transliterate\";b:1;s:18:\"replace_whitespace\";b:1;s:24:\"replace_non_alphanumeric\";b:1;s:22:\"deduplicate_separators\";b:1;s:9:\"lowercase\";b:1;s:21:\"replacement_character\";s:1:\"-\";}}'),
('',	'filter.format.basic_html',	'a:9:{s:4:\"uuid\";s:36:\"5d0c18fb-1e15-4eac-9e4b-1484b52ff943\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:6:\"editor\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mclCbTlJwWJORez4Y1eX2MqA0aGjSMAoJb3TaBABcK8\";}s:4:\"name\";s:10:\"Basic HTML\";s:6:\"format\";s:10:\"basic_html\";s:6:\"weight\";i:0;s:7:\"filters\";a:6:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:7;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:243:\"<br> <p> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id> <cite> <dl> <dt> <dd> <a hreflang href> <blockquote cite> <ul type> <ol start type> <strong> <em> <code> <li> <img src alt data-entity-uuid data-entity-type height width data-caption data-align>\";s:16:\"filter_html_help\";b:0;s:20:\"filter_html_nofollow\";b:0;}}s:24:\"filter_html_image_secure\";a:5:{s:2:\"id\";s:24:\"filter_html_image_secure\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}}}'),
('',	'filter.format.full_html',	'a:9:{s:4:\"uuid\";s:36:\"e00030fb-b30d-42df-a35b-b9dca992742e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:6:\"editor\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vpZysv3RHJjhYzq7O_q5q8mVlHdrSzKELmXyiX6RtV0\";}s:4:\"name\";s:9:\"Full HTML\";s:6:\"format\";s:9:\"full_html\";s:6:\"weight\";i:2;s:7:\"filters\";a:5:{s:21:\"editor_file_reference\";a:5:{s:2:\"id\";s:21:\"editor_file_reference\";s:8:\"provider\";s:6:\"editor\";s:6:\"status\";b:1;s:6:\"weight\";i:11;s:8:\"settings\";a:0:{}}s:12:\"filter_align\";a:5:{s:2:\"id\";s:12:\"filter_align\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:8;s:8:\"settings\";a:0:{}}s:14:\"filter_caption\";a:5:{s:2:\"id\";s:14:\"filter_caption\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:9;s:8:\"settings\";a:0:{}}s:20:\"filter_htmlcorrector\";a:5:{s:2:\"id\";s:20:\"filter_htmlcorrector\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:10;s:8:\"settings\";a:0:{}}s:22:\"filter_image_lazy_load\";a:5:{s:2:\"id\";s:22:\"filter_image_lazy_load\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:15;s:8:\"settings\";a:0:{}}}}'),
('',	'filter.format.plain_text',	'a:9:{s:4:\"uuid\";s:36:\"98975409-6030-4f9b-8f64-18610166736a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JLMwODO0epnA_H-jFlH9ezVfa5YBJniRv3MmLqYNl_Q\";}s:4:\"name\";s:10:\"Plain text\";s:6:\"format\";s:10:\"plain_text\";s:6:\"weight\";i:10;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:18:\"filter_html_escape\";a:5:{s:2:\"id\";s:18:\"filter_html_escape\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:0:{}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),
('',	'filter.format.restricted_html',	'a:9:{s:4:\"uuid\";s:36:\"8ca43f73-d620-4c03-bbd7-8221d546124f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QiKqQS_YGAT3Qr4vaAgZICJknm-MGCzt_xBAMqg-tRM\";}s:4:\"name\";s:15:\"Restricted HTML\";s:6:\"format\";s:15:\"restricted_html\";s:6:\"weight\";i:1;s:7:\"filters\";a:3:{s:12:\"filter_autop\";a:5:{s:2:\"id\";s:12:\"filter_autop\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:0:{}}s:11:\"filter_html\";a:5:{s:2:\"id\";s:11:\"filter_html\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:-10;s:8:\"settings\";a:3:{s:12:\"allowed_html\";s:149:\"<a href hreflang> <em> <strong> <cite> <blockquote cite> <code> <ul type> <ol start type> <li> <dl> <dt> <dd> <h2 id> <h3 id> <h4 id> <h5 id> <h6 id>\";s:16:\"filter_html_help\";b:1;s:20:\"filter_html_nofollow\";b:0;}}s:10:\"filter_url\";a:5:{s:2:\"id\";s:10:\"filter_url\";s:8:\"provider\";s:6:\"filter\";s:6:\"status\";b:1;s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:17:\"filter_url_length\";i:72;}}}}'),
('',	'filter.format.webform_default',	'a:9:{s:4:\"uuid\";s:36:\"cf32d962-2f58-41c9-989d-a8f82367e8e1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EeKp_M4Oid3erARiAam9rsgBKR91uEnFkEP3aZS2ol8\";}s:4:\"name\";s:31:\"Webform (Default) - DO NOT EDIT\";s:6:\"format\";s:15:\"webform_default\";s:6:\"weight\";i:100;s:7:\"filters\";a:0:{}}'),
('',	'filter.settings',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FiPjM3WdB__ruFA7B6TLwni_UcZbmek5G4b2dxQItxA\";}s:15:\"fallback_format\";s:10:\"plain_text\";s:27:\"always_show_fallback_choice\";b:0;}'),
('',	'glightbox.settings',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5G059LQS_7DV7oGUpxVTPM0aWtunW7bvDpRkgeb0KtE\";}s:6:\"custom\";a:17:{s:8:\"activate\";i:0;s:11:\"open_effect\";s:4:\"zoom\";s:12:\"close_effect\";s:4:\"zoom\";s:12:\"slide_effect\";s:5:\"slide\";s:5:\"width\";s:3:\"98%\";s:6:\"height\";s:3:\"98%\";s:11:\"videosWidth\";s:5:\"960px\";s:22:\"close_on_outside_click\";b:1;s:9:\"more_text\";s:8:\"See more\";s:11:\"more_length\";i:60;s:13:\"desc_position\";s:6:\"bottom\";s:4:\"loop\";b:0;s:8:\"zoomable\";b:1;s:9:\"draggable\";b:1;s:7:\"preload\";b:1;s:15:\"autoplay_videos\";b:1;s:16:\"autofocus_videos\";b:0;}s:8:\"advanced\";a:2:{s:12:\"unique_token\";i:0;s:16:\"compression_type\";s:8:\"minified\";}}'),
('',	'google_analytics.settings',	'a:12:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dwMYPgAnj9KBO77SLEv9Z42NDJAbuxe0uU9eGC8qw3M\";}s:7:\"account\";s:0:\"\";s:11:\"domain_mode\";i:0;s:13:\"cross_domains\";s:0:\"\";s:10:\"visibility\";a:5:{s:17:\"request_path_mode\";i:0;s:18:\"request_path_pages\";s:53:\"/admin\n/admin/*\n/batch\n/node/add*\n/node/*/*\n/user/*/*\";s:14:\"user_role_mode\";i:0;s:15:\"user_role_roles\";a:0:{}s:17:\"user_account_mode\";i:1;}s:5:\"track\";a:13:{s:8:\"outbound\";b:1;s:6:\"mailto\";b:1;s:3:\"tel\";b:1;s:5:\"files\";b:1;s:16:\"files_extensions\";s:279:\"7z|aac|arc|arj|asf|asx|avi|bin|csv|doc(x|m)?|dot(x|m)?|exe|flv|gif|gz|gzip|hqx|jar|jpe?g|js|mp(2|3|4|e?g)|mov(ie)?|msi|msp|pdf|phps|png|ppt(x|m)?|pot(x|m)?|pps(x|m)?|ppam|sld(x|m)?|thmx|qtm?|ra(m|r)?|sea|sit|tar|tgz|torrent|txt|wav|wma|wmv|wpd|xls(x|m|b)?|xlt(x|m)|xlam|xml|z|zip\";s:8:\"colorbox\";b:1;s:6:\"linkid\";b:0;s:12:\"urlfragments\";b:0;s:6:\"userid\";b:0;s:8:\"messages\";a:0:{}s:11:\"site_search\";b:0;s:7:\"adsense\";b:0;s:15:\"displayfeatures\";b:1;}s:7:\"privacy\";a:1:{s:11:\"anonymizeip\";b:1;}s:6:\"custom\";a:1:{s:10:\"parameters\";a:0:{}}s:11:\"codesnippet\";a:3:{s:6:\"create\";a:0:{}s:6:\"before\";s:0:\"\";s:5:\"after\";s:0:\"\";}s:15:\"translation_set\";b:0;s:5:\"cache\";b:0;s:5:\"debug\";b:0;}'),
('',	'image.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k-yDFHbqNfpe-Srg4sdCSqaosCl2D8uwyEY5esF8gEw\";}s:13:\"preview_image\";s:29:\"core/modules/image/sample.png\";s:26:\"allow_insecure_derivatives\";b:0;s:20:\"suppress_itok_output\";b:0;}'),
('',	'image.style.ebt_gallery_image',	'a:8:{s:4:\"uuid\";s:36:\"3387ae71-e231-4ddd-9e5f-664ca37b095b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Et29BhgBeTqvhgY2GYsCViL4QGjZRI0vsbEe5O1VON4\";}s:4:\"name\";s:17:\"ebt_gallery_image\";s:5:\"label\";s:17:\"EBT Gallery Image\";s:7:\"effects\";a:1:{s:36:\"6ab4544c-7611-414c-aaa8-4eed96b10c84\";a:4:{s:4:\"uuid\";s:36:\"6ab4544c-7611-414c-aaa8-4eed96b10c84\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:365;s:6:\"height\";i:265;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.ebt_video_and_image_gallery',	'a:8:{s:4:\"uuid\";s:36:\"c4e70146-66c8-4f81-9049-d4e41b4c5305\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9px7Sz4srt9t5bnyp1lHoLhxTyuSbHKBR0pbE7rMPJ4\";}s:4:\"name\";s:27:\"ebt_video_and_image_gallery\";s:5:\"label\";s:27:\"EBT Video and Image gallery\";s:7:\"effects\";a:1:{s:36:\"de12b6ed-b5ac-4ec8-9cf1-0df6cb6c8d32\";a:4:{s:4:\"uuid\";s:36:\"de12b6ed-b5ac-4ec8-9cf1-0df6cb6c8d32\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:360;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.large',	'a:8:{s:4:\"uuid\";s:36:\"527e81f9-fafb-4f3e-aad6-f169b5885095\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rDR2BOewa2UFH9yG4tVvrGxEVv8U7LQo-RLkJhFpERs\";}s:4:\"name\";s:5:\"large\";s:5:\"label\";s:16:\"Large (480×480)\";s:7:\"effects\";a:2:{s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";a:4:{s:4:\"uuid\";s:36:\"ddd73aa7-4bd6-4c85-b600-bdf2b1628d1d\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:480;s:6:\"height\";i:480;s:7:\"upscale\";b:0;}}s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";a:4:{s:4:\"uuid\";s:36:\"6e8fe467-84c1-4ef0-a73b-7eccf1cc20e8\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.linkit_result_thumbnail',	'a:8:{s:4:\"uuid\";s:36:\"7751cf12-1253-4c81-bcd8-bc001066b67b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PY0kMp7KIxvU4kBi5mcnD_DHTKUc1OkYCfaPliXjpa8\";}s:4:\"name\";s:23:\"linkit_result_thumbnail\";s:5:\"label\";s:23:\"Linkit result thumbnail\";s:7:\"effects\";a:1:{s:36:\"2943df29-38ea-459c-ba1d-290489bb1807\";a:4:{s:4:\"uuid\";s:36:\"2943df29-38ea-459c-ba1d-290489bb1807\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:50;s:6:\"height\";i:50;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.media_library',	'a:8:{s:4:\"uuid\";s:36:\"9fcd2b87-5cd2-4214-90f8-d2a1c4229d26\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FxMdscEA4aDH0KPM73HIZtVn3zIAgC1kQ3CkBw26HYs\";}s:4:\"name\";s:13:\"media_library\";s:5:\"label\";s:34:\"Media Library thumbnail (220×220)\";s:7:\"effects\";a:2:{s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";a:4:{s:4:\"uuid\";s:36:\"75b076a8-1234-4b42-85db-bf377c4d8d5f\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";a:4:{s:4:\"uuid\";s:36:\"1021da71-fc2a-43d0-be5d-efaf1c79e2ea\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.medium',	'a:8:{s:4:\"uuid\";s:36:\"c8b8fa24-4235-4e63-abae-72f30beb637e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dlar76VBuGj5iMGTruB_uMZX8VbivXt9_QLemaG2q4E\";}s:4:\"name\";s:6:\"medium\";s:5:\"label\";s:17:\"Medium (220×220)\";s:7:\"effects\";a:2:{s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";a:4:{s:4:\"uuid\";s:36:\"bddf0d06-42f9-4c75-a700-a33cafa25ea0\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:220;s:6:\"height\";i:220;s:7:\"upscale\";b:0;}}s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";a:4:{s:4:\"uuid\";s:36:\"c410ed2f-aa30-4d9c-a224-d2865d9188cd\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.quote_image',	'a:8:{s:4:\"uuid\";s:36:\"60fb949e-3206-43f8-8a85-d75fa8ec9bf5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xlTbw2rsxfnXJ7Hv3VCpxLp5Ekaa0jutCubC0YpGcbw\";}s:4:\"name\";s:11:\"quote_image\";s:5:\"label\";s:11:\"Quote Image\";s:7:\"effects\";a:1:{s:36:\"d8117768-053a-4efa-87bf-a1e49600d865\";a:4:{s:4:\"uuid\";s:36:\"d8117768-053a-4efa-87bf-a1e49600d865\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:2;s:4:\"data\";a:3:{s:5:\"width\";i:530;s:6:\"height\";N;s:7:\"upscale\";b:0;}}}}'),
('',	'image.style.slick_slider_card',	'a:8:{s:4:\"uuid\";s:36:\"a7519911-04cf-4e32-8dd4-55d8d342ddfc\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2zkdfRMnFwX0N2JCd1N-mTn2NTGgTRwRkfqW4Uiit8c\";}s:4:\"name\";s:17:\"slick_slider_card\";s:5:\"label\";s:17:\"Slick Slider card\";s:7:\"effects\";a:1:{s:36:\"c770ae08-739c-4196-a069-6d5becc97113\";a:4:{s:4:\"uuid\";s:36:\"c770ae08-739c-4196-a069-6d5becc97113\";s:2:\"id\";s:20:\"image_scale_and_crop\";s:6:\"weight\";i:2;s:4:\"data\";a:3:{s:5:\"width\";i:400;s:6:\"height\";i:300;s:6:\"anchor\";s:13:\"center-center\";}}}}'),
('',	'image.style.thumbnail',	'a:8:{s:4:\"uuid\";s:36:\"7e8ff02c-5435-43f6-8dc3-916788ea8d9f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BgeBV-xOFINMsz-y2thm45EGesj6bRM6DTLZ6ce3V9I\";}s:4:\"name\";s:9:\"thumbnail\";s:5:\"label\";s:20:\"Thumbnail (100×100)\";s:7:\"effects\";a:2:{s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";a:4:{s:4:\"uuid\";s:36:\"1cfec298-8620-4749-b100-ccb6c4500779\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:0;s:4:\"data\";a:3:{s:5:\"width\";i:100;s:6:\"height\";i:100;s:7:\"upscale\";b:0;}}s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";a:4:{s:4:\"uuid\";s:36:\"c4eb9942-2c9e-4a81-949f-6161a44b6559\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'image.style.wide',	'a:8:{s:4:\"uuid\";s:36:\"cf4a237b-4886-4db6-90a2-e2f1348070b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"XHh3ATMH7z4ljwmzdndM47qNMkgLnoYsP98rGxVgCOw\";}s:4:\"name\";s:4:\"wide\";s:5:\"label\";s:11:\"Wide (1090)\";s:7:\"effects\";a:2:{s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";a:4:{s:4:\"uuid\";s:36:\"09959c15-59ce-4f6d-90df-e2d7cf32bce5\";s:2:\"id\";s:11:\"image_scale\";s:6:\"weight\";i:1;s:4:\"data\";a:3:{s:5:\"width\";i:1090;s:6:\"height\";N;s:7:\"upscale\";b:0;}}s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";a:4:{s:4:\"uuid\";s:36:\"294c5f76-42a4-43ce-82c2-81c2f4723da0\";s:2:\"id\";s:13:\"image_convert\";s:6:\"weight\";i:2;s:4:\"data\";a:1:{s:9:\"extension\";s:4:\"webp\";}}}}'),
('',	'linkit.linkit_profile.default',	'a:9:{s:4:\"uuid\";s:36:\"655a70f6-77d9-4568-ad74-866e455f296a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0Jw_BFJCCtWk187tIYvME58VFpYwPaAdrc4eRtAyHH0\";}s:5:\"label\";s:7:\"Default\";s:2:\"id\";s:7:\"default\";s:11:\"description\";s:24:\"A default Linkit profile\";s:8:\"matchers\";a:1:{s:36:\"556010a3-e317-48b3-b4ed-854c10f4b950\";a:4:{s:2:\"id\";s:11:\"entity:node\";s:4:\"uuid\";s:36:\"556010a3-e317-48b3-b4ed-854c10f4b950\";s:8:\"settings\";a:6:{s:8:\"metadata\";s:77:\"[node:content-type:name] #[node:nid] | [node:created:medium] by [node:author]\";s:7:\"bundles\";a:0:{}s:15:\"group_by_bundle\";b:0;s:19:\"include_unpublished\";b:0;s:17:\"substitution_type\";s:9:\"canonical\";s:5:\"limit\";i:100;}s:6:\"weight\";i:0;}}}'),
('',	'media.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WCFqLQAxMw1weToDJEhfnW1Z-iOF7cqMdL8X7YTFxBA\";}s:13:\"icon_base_uri\";s:28:\"public://media-icons/generic\";s:13:\"iframe_domain\";N;s:20:\"oembed_providers_url\";s:33:\"https://oembed.com/providers.json\";s:14:\"standalone_url\";b:0;}'),
('',	'media.type.audio',	'a:13:{s:4:\"uuid\";s:36:\"5b9f8640-5def-4f1f-8cbb-9a34ee0d322b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJw8n6Tk2tO3ZysuEeGR1gZa1yRffaZzR4t0Q7iNurs\";}s:2:\"id\";s:5:\"audio\";s:5:\"label\";s:5:\"Audio\";s:11:\"description\";s:28:\"A locally hosted audio file.\";s:6:\"source\";s:10:\"audio_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_audio_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media.type.document',	'a:13:{s:4:\"uuid\";s:36:\"474a8161-6e84-4c54-8d09-7cd6cf51ca6f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_D9q3XSnP6ik9we9UuoTvZsQKPuYNp_G9PfwVtWzgnQ\";}s:2:\"id\";s:8:\"document\";s:5:\"label\";s:8:\"Document\";s:11:\"description\";s:44:\"An uploaded file or document, such as a PDF.\";s:6:\"source\";s:4:\"file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:20:\"field_media_document\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media.type.image',	'a:13:{s:4:\"uuid\";s:36:\"d02792ed-7ab7-466f-94e2-1bc1eb7fc178\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6Qope5wG7HUpV0tPOBMtDI_GZkHFcF1Xj4hgD9Cu_hM\";}s:2:\"id\";s:5:\"image\";s:5:\"label\";s:5:\"Image\";s:11:\"description\";s:36:\"Use local images for reusable media.\";s:6:\"source\";s:5:\"image\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:17:\"field_media_image\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media.type.remote_video',	'a:13:{s:4:\"uuid\";s:36:\"59bb7b69-536f-47d7-b202-4c65a9b02036\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hIBTnDGgDKnCiP6HUZm1m7600DHUEpC6FN3LQ4sUgZ4\";}s:2:\"id\";s:12:\"remote_video\";s:5:\"label\";s:12:\"Remote video\";s:11:\"description\";s:46:\"A remotely hosted video from YouTube or Vimeo.\";s:6:\"source\";s:12:\"oembed:video\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:3:{s:12:\"source_field\";s:24:\"field_media_oembed_video\";s:20:\"thumbnails_directory\";s:44:\"public://oembed_thumbnails/[date:custom:Y-m]\";s:9:\"providers\";a:2:{i:0;s:7:\"YouTube\";i:1;s:5:\"Vimeo\";}}s:9:\"field_map\";a:1:{s:5:\"title\";s:4:\"name\";}}'),
('',	'media.type.video',	'a:13:{s:4:\"uuid\";s:36:\"47a446d2-2250-4e11-98eb-8a4c51117635\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hzgvcRgZHltqWf8hBmttoWh95tCJoPL25lPq9YSIRsY\";}s:2:\"id\";s:5:\"video\";s:5:\"label\";s:5:\"Video\";s:11:\"description\";s:28:\"A locally hosted video file.\";s:6:\"source\";s:10:\"video_file\";s:25:\"queue_thumbnail_downloads\";b:0;s:12:\"new_revision\";b:1;s:20:\"source_configuration\";a:1:{s:12:\"source_field\";s:22:\"field_media_video_file\";}s:9:\"field_map\";a:1:{s:4:\"name\";s:4:\"name\";}}'),
('',	'media_library.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_3gQsCnZELUjUUqHk8SSh8bXnx7TZwN95vctAeVJG60\";}s:11:\"advanced_ui\";b:0;}'),
('',	'menu_ui.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SqMarzIjxC3F8dZo9FEOxfqDKD_sdW1tbcFTV1BA2zU\";}s:24:\"override_parent_selector\";b:0;}'),
('',	'metatag.metatag_defaults.403',	'a:8:{s:4:\"uuid\";s:36:\"32de19c3-215d-4985-a7d7-d588a90d7f0d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RDCkFL0NDt75Gwioooxo1iuA1S50xTVsBOgX__c6wTw\";}s:2:\"id\";s:3:\"403\";s:5:\"label\";s:17:\"403 access denied\";s:4:\"tags\";a:3:{s:6:\"robots\";s:7:\"noindex\";s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),
('',	'metatag.metatag_defaults.404',	'a:8:{s:4:\"uuid\";s:36:\"1131c9da-259d-4688-af2b-8cd70c4d304f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"puBstSLDz8mbaWU357zaqQDBGMGsJzG0j-TQNQkjg20\";}s:2:\"id\";s:3:\"404\";s:5:\"label\";s:18:\"404 page not found\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),
('',	'metatag.metatag_defaults.front',	'a:8:{s:4:\"uuid\";s:36:\"14e6bd6a-5fd4-4abb-b304-231e944ee914\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1noCXlegCr5HFehQRF1ViXy1jhU1jZ_sNN99a8Sj5jo\";}s:2:\"id\";s:5:\"front\";s:5:\"label\";s:10:\"Front page\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:10:\"[site:url]\";s:9:\"shortlink\";s:10:\"[site:url]\";}}'),
('',	'metatag.metatag_defaults.global',	'a:8:{s:4:\"uuid\";s:36:\"c377ec68-aa9d-4ed0-8e17-b44da3051c14\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sL588ui1E_8-2c_UupwyYxcqX2OVyMFp3HTLbbFqvPc\";}s:2:\"id\";s:6:\"global\";s:5:\"label\";s:6:\"Global\";s:4:\"tags\";a:2:{s:13:\"canonical_url\";s:18:\"[current-page:url]\";s:5:\"title\";s:34:\"[current-page:title] | [site:name]\";}}'),
('',	'metatag.metatag_defaults.node',	'a:8:{s:4:\"uuid\";s:36:\"3950fa9e-d155-4064-8913-f7928e563aa1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rpwvgyEURXLz_JjgMCrkS1rUv-0k3L79BpO-ReN7fDI\";}s:2:\"id\";s:4:\"node\";s:5:\"label\";s:7:\"Content\";s:4:\"tags\";a:3:{s:5:\"title\";s:26:\"[node:title] | [site:name]\";s:11:\"description\";s:14:\"[node:summary]\";s:13:\"canonical_url\";s:10:\"[node:url]\";}}'),
('',	'metatag.metatag_defaults.taxonomy_term',	'a:8:{s:4:\"uuid\";s:36:\"7175fa40-e959-4cb9-a9af-08b0acf53b23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"92bXZdyYJ5xqukdfmGRr_CYcwm1vfuS8b8aJ7X_G7E0\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:4:\"tags\";a:3:{s:13:\"canonical_url\";s:10:\"[term:url]\";s:11:\"description\";s:18:\"[term:description]\";s:5:\"title\";s:25:\"[term:name] | [site:name]\";}}'),
('',	'metatag.metatag_defaults.user',	'a:8:{s:4:\"uuid\";s:36:\"2ce7b5a6-e273-4808-988d-bd51796041d7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MvQPTbQx0Vxwy0ordSHyixdZmLCMpvMdLD69dlwkrKc\";}s:2:\"id\";s:4:\"user\";s:5:\"label\";s:4:\"User\";s:4:\"tags\";a:3:{s:13:\"canonical_url\";s:10:\"[user:url]\";s:11:\"description\";s:11:\"[site:name]\";s:5:\"title\";s:33:\"[user:display-name] | [site:name]\";}}'),
('',	'metatag.settings',	'a:7:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tKLBW2GXZVLFXqS9QgLyfTuxCLc1u_quKPQLtCia-Bw\";}s:18:\"entity_type_groups\";a:0:{}s:9:\"separator\";s:0:\"\";s:15:\"tag_trim_method\";s:11:\"beforeValue\";s:18:\"tag_trim_maxlength\";a:0:{}s:21:\"tag_scroll_max_height\";s:0:\"\";s:13:\"use_maxlength\";b:1;}'),
('',	'node.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W0cgFPhPJ3gAdqm06-az48BLf5MVcoZVS0HdByoofi0\";}s:15:\"use_admin_theme\";b:1;}'),
('',	'node.type.article',	'a:12:{s:4:\"uuid\";s:36:\"23740c9e-4bc8-422a-a456-7efd997502e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Fe3N1uqaAyyKJbVkqT-btXy3t98puW8GCRD822xjl10\";}s:4:\"name\";s:7:\"Article\";s:4:\"type\";s:7:\"article\";s:11:\"description\";s:89:\"Use <em>articles</em> for time-sensitive content like news, press releases or blog posts.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:1;}'),
('',	'node.type.page',	'a:12:{s:4:\"uuid\";s:36:\"1edca201-7650-4af0-af2a-47c5a971bfde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"i0snV8Wj--OkRW12UdachUiYiz3FbeMwHu_pZYfzKLc\";}s:4:\"name\";s:10:\"Basic page\";s:4:\"type\";s:4:\"page\";s:11:\"description\";s:77:\"Use <em>basic pages</em> for your static content, such as an \'About us\' page.\";s:4:\"help\";N;s:12:\"new_revision\";b:1;s:12:\"preview_mode\";i:1;s:17:\"display_submitted\";b:0;}'),
('',	'olivero.settings',	'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1TswGK46jyu77aIM7Z-0JVQs5bxHmo-gtgrvrQGMXxc\";}s:7:\"favicon\";a:1:{s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:0;}s:4:\"logo\";a:1:{s:11:\"use_default\";b:0;}s:20:\"third_party_settings\";a:1:{s:8:\"shortcut\";a:1:{s:11:\"module_link\";b:1;}}s:22:\"mobile_menu_all_widths\";i:0;s:22:\"site_branding_bg_color\";s:7:\"default\";s:18:\"base_primary_color\";s:7:\"#1b9ae4\";}'),
('',	'paragraphs.paragraphs_type.ebt_accordion',	'a:11:{s:4:\"uuid\";s:36:\"5071ad52-b6e8-4a13-88ad-a0e644e823f9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"a7oBJmAAPescdOPyZ2zkmnxQR_-MkKei1Cs600-7sxM\";}s:2:\"id\";s:13:\"ebt_accordion\";s:5:\"label\";s:35:\"EBT Accordion section / FAQ section\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:46:\"Accordion or FAQ section for EBT Accordion/FAQ\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_carousel',	'a:11:{s:4:\"uuid\";s:36:\"eae57e5f-f332-4203-be4f-1ead1a6c1ebf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"F5G5bjObjmi_ofKoiKAxY1BXGoLKFMVsBTNd7Z39OuI\";}s:2:\"id\";s:12:\"ebt_carousel\";s:5:\"label\";s:17:\"EBT Carousel item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Carousel section for EBT Carousel\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_counter_item',	'a:11:{s:4:\"uuid\";s:36:\"8a0e0b99-a544-4c46-8cb3-534e418ac0e9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ycgzZPt9EhNziX0konZumLTJ6y69olJaVnLJ2dtyKnI\";}s:2:\"id\";s:16:\"ebt_counter_item\";s:5:\"label\";s:16:\"EBT Counter Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:60:\"Counter Items to be used inside of Block Type: \"EBT Counter\"\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_slick_slider',	'a:11:{s:4:\"uuid\";s:36:\"70607742-51bf-4b77-8d46-c07397b718e6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7IpvZPMN9T939ox72-gNDYNrZIVrXQ7nlF-Pxkzq_7M\";}s:2:\"id\";s:16:\"ebt_slick_slider\";s:5:\"label\";s:15:\"EBT Slick Slide\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:26:\"Slide for EBT Slick Slider\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_slideshow',	'a:11:{s:4:\"uuid\";s:36:\"68f7444a-b28e-4ac9-abc5-57a62d63fe7f\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HQnVagG9vsLrOtO1nF5ggZaNQ0tRGZZhiOW1-8nLOMM\";}s:2:\"id\";s:13:\"ebt_slideshow\";s:5:\"label\";s:9:\"EBT Slide\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:35:\"Slideshow section for EBT Slideshow\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_stats_item',	'a:11:{s:4:\"uuid\";s:36:\"210023af-0ce2-4183-bbba-6adbe094a405\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mXP3gCAYTFLXux_oLacqKfa_b0MprpWFhqxO39VWGl8\";}s:2:\"id\";s:14:\"ebt_stats_item\";s:5:\"label\";s:14:\"EBT Stats Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:30:\"Stats Item for EBT Stats block\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_tab',	'a:11:{s:4:\"uuid\";s:36:\"d24c7342-50a5-4bba-a2ca-23838ec42c25\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nzTVRmvjb6HJiVMoRzf0HR02L3_n5N9VxatQ_IQQCmc\";}s:2:\"id\";s:7:\"ebt_tab\";s:5:\"label\";s:7:\"EBT Tab\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:32:\"Tab paragraph for EBT Tabs block\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_tiles_item',	'a:11:{s:4:\"uuid\";s:36:\"332e9a66-40d4-4d0f-a252-bacb76456f61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OXCYSO_8vGgFySd4voU9Be7Av6Oqe56G4XnMO_fX4EE\";}s:2:\"id\";s:14:\"ebt_tiles_item\";s:5:\"label\";s:14:\"EBT Tiles Item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:21:\"Section for EBT Tiles\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_timeline',	'a:11:{s:4:\"uuid\";s:36:\"0700c7f4-0990-4033-a96a-7eac220fe625\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"giGGVKGIGi_PVlgEPMjzx78I9q-gtwP8qRWwp4goOaE\";}s:2:\"id\";s:12:\"ebt_timeline\";s:5:\"label\";s:18:\"EBT Timeline Event\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:33:\"Timeline section for EBT Timeline\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.paragraphs_type.ebt_video_and_image_gallery_item',	'a:11:{s:4:\"uuid\";s:36:\"69becd39-ca29-4229-a5e0-b50dda5e664e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ASm3yV1er7y-WJqAsPm4lUKhLJEK2A1QYjC-_eJJFIA\";}s:2:\"id\";s:32:\"ebt_video_and_image_gallery_item\";s:5:\"label\";s:32:\"EBT Video and Image gallery item\";s:9:\"icon_uuid\";N;s:12:\"icon_default\";N;s:11:\"description\";s:58:\"Video and Image item for EBT Video and Image Gallery block\";s:16:\"behavior_plugins\";a:0:{}}'),
('',	'paragraphs.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7eR0sk71Eol86r_A7BMqn5_46wzenh5J1O5vZRCGKv8\";}s:16:\"show_unpublished\";b:1;}'),
('',	'pathauto.settings',	'a:13:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SwvLp8snyPEExF41CaJJYdPUVomofLqtXvwciHc4cPg\";}s:20:\"enabled_entity_types\";a:1:{i:0;s:4:\"user\";}s:11:\"punctuation\";a:1:{s:6:\"hyphen\";i:1;}s:7:\"verbose\";b:0;s:9:\"separator\";s:1:\"-\";s:10:\"max_length\";i:100;s:20:\"max_component_length\";i:100;s:13:\"transliterate\";b:1;s:12:\"reduce_ascii\";b:0;s:4:\"case\";b:1;s:12:\"ignore_words\";s:134:\"a, an, as, at, before, but, by, for, from, is, in, into, like, of, off, on, onto, per, since, than, the, this, that, to, up, via, with\";s:13:\"update_action\";i:2;s:11:\"safe_tokens\";a:6:{i:0;s:5:\"alias\";i:1;s:4:\"path\";i:2;s:9:\"join-path\";i:3;s:9:\"login-url\";i:4;s:3:\"url\";i:5;s:9:\"url-brief\";}}'),
('',	'redirect.settings',	'a:8:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FEwQLW1wXW7fiJdG1B2bxW1c_-k6w-r-3V3bSsW6PqM\";}s:13:\"auto_redirect\";b:1;s:19:\"default_status_code\";i:301;s:23:\"passthrough_querystring\";b:1;s:7:\"warning\";b:0;s:17:\"ignore_admin_path\";b:0;s:12:\"access_check\";b:0;s:24:\"route_normalizer_enabled\";b:1;}'),
('',	'search.page.help_search',	'a:11:{s:4:\"uuid\";s:36:\"fec10881-499f-4858-a42b-9b60cee45abe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"help\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RZ-bcSekNSsAbIPLW7Gmyd3uUjIOSrPvnb8RCCZYJm8\";}s:2:\"id\";s:11:\"help_search\";s:5:\"label\";s:4:\"Help\";s:4:\"path\";s:4:\"help\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"help_search\";s:13:\"configuration\";a:0:{}}'),
('',	'search.page.node_search',	'a:11:{s:4:\"uuid\";s:36:\"72642a28-df7e-4618-aa8c-3f52bf7d9f97\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"97tvtzGOa8_flb22CzSjgtm_YkiGMHvEBO-6q2K9V_U\";}s:2:\"id\";s:11:\"node_search\";s:5:\"label\";s:7:\"Content\";s:4:\"path\";s:4:\"node\";s:6:\"weight\";i:-10;s:6:\"plugin\";s:11:\"node_search\";s:13:\"configuration\";a:1:{s:8:\"rankings\";a:0:{}}}'),
('',	'search.page.user_search',	'a:11:{s:4:\"uuid\";s:36:\"294f8603-9cb9-4c47-91cb-def8653638f4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"k3aUaZXGDuhkek2TZIee0PApOPTvYZLadziekdyHA5A\";}s:2:\"id\";s:11:\"user_search\";s:5:\"label\";s:5:\"Users\";s:4:\"path\";s:4:\"user\";s:6:\"weight\";i:0;s:6:\"plugin\";s:11:\"user_search\";s:13:\"configuration\";a:0:{}}'),
('',	'search.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"hvVxL1G-ZCxaq32IZws0YsfuhvaDiQE_np-0g35KjUk\";}s:12:\"and_or_limit\";i:7;s:12:\"default_page\";s:11:\"node_search\";s:5:\"index\";a:4:{s:10:\"cron_limit\";i:100;s:11:\"overlap_cjk\";b:1;s:17:\"minimum_word_size\";i:3;s:11:\"tag_weights\";a:12:{s:2:\"h1\";i:25;s:2:\"h2\";i:18;s:2:\"h3\";i:15;s:2:\"h4\";i:14;s:2:\"h5\";i:9;s:2:\"h6\";i:6;s:1:\"u\";i:3;s:1:\"b\";i:3;s:1:\"i\";i:3;s:6:\"strong\";i:3;s:2:\"em\";i:3;s:1:\"a\";i:10;}}s:7:\"logging\";b:0;}'),
('',	'shortcut.set.default',	'a:7:{s:4:\"uuid\";s:36:\"bc9830ea-c02f-4ef4-a17e-f3539c02304b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"U5VlGjd_SfV0Qm_EfnaynOfc549cNscFAx48JfYoMRI\";}s:2:\"id\";s:7:\"default\";s:5:\"label\";s:7:\"Default\";}'),
('',	'system.action.media_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"62205804-910a-4719-bbcb-1c8ef9179e61\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FrZy1tmuXJcOxhXlBoI1Hsnen5TT-9OCC1iolWH84go\";}s:2:\"id\";s:19:\"media_delete_action\";s:5:\"label\";s:12:\"Delete media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:26:\"entity:delete_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.media_publish_action',	'a:10:{s:4:\"uuid\";s:36:\"74ae1caf-547b-4f5b-b2c5-344fbdfc9454\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nh83qNNrmWE-CDdHz2MdFOAk60T9mzv3R-MaKfZR2jw\";}s:2:\"id\";s:20:\"media_publish_action\";s:5:\"label\";s:13:\"Publish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:27:\"entity:publish_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.media_save_action',	'a:10:{s:4:\"uuid\";s:36:\"15843e3d-3327-4414-a048-e956e137183d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VVyUA6PIaVeGtcIbgEWqJ6SYDiJdReBeojFswURFpKs\";}s:2:\"id\";s:17:\"media_save_action\";s:5:\"label\";s:10:\"Save media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:24:\"entity:save_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.media_unpublish_action',	'a:10:{s:4:\"uuid\";s:36:\"9d24595c-700e-4798-9d98-3f086528cbd9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CsK6TseQ2DatEbZgbd30swOlZ28_HHwAESU2LvEnWq0\";}s:2:\"id\";s:22:\"media_unpublish_action\";s:5:\"label\";s:15:\"Unpublish media\";s:4:\"type\";s:5:\"media\";s:6:\"plugin\";s:29:\"entity:unpublish_action:media\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"8ff0ec2c-b155-4314-9b5d-65aef57e6ed9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"t43OqwzP3CTbcAagSsWKNy6KwMm_zShXo3c4-So6rQg\";}s:2:\"id\";s:18:\"node_delete_action\";s:5:\"label\";s:14:\"Delete content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"entity:delete_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_make_sticky_action',	'a:10:{s:4:\"uuid\";s:36:\"d5b780e9-4002-48fb-9961-4890d2e18a4e\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sOb26JSy3fGpWkvR0WYN6_hMqj_6d1rvbvrkzp1yya0\";}s:2:\"id\";s:23:\"node_make_sticky_action\";s:5:\"label\";s:19:\"Make content sticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"node_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_make_unsticky_action',	'a:10:{s:4:\"uuid\";s:36:\"79cd458d-4e0f-42fc-8713-cf8324d4116c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lDM9mvIGAu8Sw8rt-uCO4Sr7yX5VPrDPxYcawkbKd6k\";}s:2:\"id\";s:25:\"node_make_unsticky_action\";s:5:\"label\";s:21:\"Make content unsticky\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:25:\"node_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_promote_action',	'a:10:{s:4:\"uuid\";s:36:\"80e483ef-5cef-449b-b6eb-338611cedfbf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"N0RDBTqiK4dKoN4p4oW2j0SGWycdHyALUe9M-Ofp89U\";}s:2:\"id\";s:19:\"node_promote_action\";s:5:\"label\";s:29:\"Promote content to front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:19:\"node_promote_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_publish_action',	'a:10:{s:4:\"uuid\";s:36:\"638ab18d-e126-4bf0-934b-ca0f8e76d21a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2B9uF8NL5gutNKSdPRAhhAsDWFZZG1PJOBmx0aBGd_0\";}s:2:\"id\";s:19:\"node_publish_action\";s:5:\"label\";s:15:\"Publish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:26:\"entity:publish_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_save_action',	'a:10:{s:4:\"uuid\";s:36:\"e656d6be-7229-49e2-a65a-513fbe566776\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LhdsoZPL_pFas2fjaAWue4zvrQ_tEVofLYtcNec-JGM\";}s:2:\"id\";s:16:\"node_save_action\";s:5:\"label\";s:12:\"Save content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:23:\"entity:save_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_unpromote_action',	'a:10:{s:4:\"uuid\";s:36:\"1dc10e26-9e52-406f-aa64-78f6f7ff20b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JBptjnfuOMtsdKygklXxoOgeOCTMtQxlkymjnnj-cC0\";}s:2:\"id\";s:21:\"node_unpromote_action\";s:5:\"label\";s:30:\"Remove content from front page\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"node_unpromote_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.node_unpublish_action',	'a:10:{s:4:\"uuid\";s:36:\"12dedc3c-a189-49b8-bfa3-3925d1475a53\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"C7X8h9FWlwkQ9y5mnU2JzgaZICAdc6HFbPVbhvjlAYE\";}s:2:\"id\";s:21:\"node_unpublish_action\";s:5:\"label\";s:17:\"Unpublish content\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:28:\"entity:unpublish_action:node\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.pathauto_update_alias_node',	'a:10:{s:4:\"uuid\";s:36:\"49be4fb0-6832-463d-8bbe-69dd46552e18\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"pathauto\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"node\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"lno8QThS348UX-kaUsagJtCnuPHKLXYnTQiF_9HSDWA\";}s:2:\"id\";s:26:\"pathauto_update_alias_node\";s:5:\"label\";s:16:\"Update URL alias\";s:4:\"type\";s:4:\"node\";s:6:\"plugin\";s:21:\"pathauto_update_alias\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.pathauto_update_alias_user',	'a:10:{s:4:\"uuid\";s:36:\"acf6f444-fa28-4103-ae56-96da6d7abcc5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"pathauto\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x_ok_ZsfA4Xk4B_hVW3O4-3PcNoK57nXLz_Dlletidg\";}s:2:\"id\";s:26:\"pathauto_update_alias_user\";s:5:\"label\";s:16:\"Update URL alias\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:21:\"pathauto_update_alias\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.redirect_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"8c900910-1bd8-48a7-abea-4493a2f89f45\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"redirect\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"vcnRZRvBqTbK3nZ2M4_lKPlEGc8GjPzgaqapYUfyX8M\";}s:2:\"id\";s:22:\"redirect_delete_action\";s:5:\"label\";s:15:\"Delete redirect\";s:4:\"type\";s:8:\"redirect\";s:6:\"plugin\";s:22:\"redirect_delete_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.taxonomy_term_publish_action',	'a:10:{s:4:\"uuid\";s:36:\"98441d8b-cb2a-44eb-863f-f500933dc072\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DoVt_VGgVLcDD4XmVbSFzr0K17SJy9imFiYusKkJBgY\";}s:2:\"id\";s:28:\"taxonomy_term_publish_action\";s:5:\"label\";s:21:\"Publish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:35:\"entity:publish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.taxonomy_term_unpublish_action',	'a:10:{s:4:\"uuid\";s:36:\"c50e2e3d-3fd4-474f-b4c3-6e9deb3aa4ec\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:8:\"taxonomy\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z2sNRM3ECa7FPCGnSNje_9SmZJQgwhD_6fG_L4Mr8zI\";}s:2:\"id\";s:30:\"taxonomy_term_unpublish_action\";s:5:\"label\";s:23:\"Unpublish taxonomy term\";s:4:\"type\";s:13:\"taxonomy_term\";s:6:\"plugin\";s:37:\"entity:unpublish_action:taxonomy_term\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.user_add_role_action.administrator',	'a:9:{s:4:\"uuid\";s:36:\"e9cdc7cd-560d-4c6e-b18d-4086edd12442\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:34:\"user_add_role_action.administrator\";s:5:\"label\";s:50:\"Add the Administrator role to the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:20:\"user_add_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),
('',	'system.action.user_block_user_action',	'a:10:{s:4:\"uuid\";s:36:\"e33d4c27-1cb5-4a82-a343-178013992c5b\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DyypzTfThX10FFQw-399qPfEbLLyrhXgQrKPVsmAoJ4\";}s:2:\"id\";s:22:\"user_block_user_action\";s:5:\"label\";s:26:\"Block the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:22:\"user_block_user_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.user_cancel_user_action',	'a:10:{s:4:\"uuid\";s:36:\"47b35c2c-ef80-4dbb-9bc2-87e5467e802a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nvrL9bFilzBvm2bjO9rQnFDpBA7dBBUjShSSt6NS-DU\";}s:2:\"id\";s:23:\"user_cancel_user_action\";s:5:\"label\";s:35:\"Cancel the selected user account(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_cancel_user_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.user_remove_role_action.administrator',	'a:9:{s:4:\"uuid\";s:36:\"3a610953-8310-41e6-916e-67a38ded8605\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:23:\"user.role.administrator\";}s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:2:\"id\";s:37:\"user_remove_role_action.administrator\";s:5:\"label\";s:55:\"Remove the Administrator role from the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:23:\"user_remove_role_action\";s:13:\"configuration\";a:1:{s:3:\"rid\";s:13:\"administrator\";}}'),
('',	'system.action.user_unblock_user_action',	'a:10:{s:4:\"uuid\";s:36:\"f372b8db-b95d-43f7-8c2b-b99a92076084\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SPsUXsR3Rc8d1y3gewzaAKWa1ncea_ywXX3f7LTn7k0\";}s:2:\"id\";s:24:\"user_unblock_user_action\";s:5:\"label\";s:28:\"Unblock the selected user(s)\";s:4:\"type\";s:4:\"user\";s:6:\"plugin\";s:24:\"user_unblock_user_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_archive_action',	'a:10:{s:4:\"uuid\";s:36:\"6125548a-6827-4acb-a08b-eda4e1b25de1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OmnschvBLb9ZJn0iVyBd2odf8U8Nt0INjRbRMixZw9U\";}s:2:\"id\";s:22:\"webform_archive_action\";s:5:\"label\";s:15:\"Archive webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:22:\"webform_archive_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_close_action',	'a:10:{s:4:\"uuid\";s:36:\"9a449986-702c-4f26-a07f-3cbbae693dde\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Dl-1T9PDkraB7MyMUjTJAioPEx6UNvIB9gqmnB1CRkk\";}s:2:\"id\";s:20:\"webform_close_action\";s:5:\"label\";s:13:\"Close webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:20:\"webform_close_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"d93c6987-507f-40ab-8f7a-1166f768bc12\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e1bCTp0ryXZZtnS9nlVAbtoWz3-8fmbNlqKY3GHzbsM\";}s:2:\"id\";s:21:\"webform_delete_action\";s:5:\"label\";s:14:\"Delete webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:21:\"webform_delete_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_open_action',	'a:10:{s:4:\"uuid\";s:36:\"b9252337-7eb0-41ce-b704-8142809ba069\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AK83C-dOZEPruvi6GbkuhihWLnO4VtrbesqSC6izf4o\";}s:2:\"id\";s:19:\"webform_open_action\";s:5:\"label\";s:12:\"Open webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:19:\"webform_open_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_delete_action',	'a:10:{s:4:\"uuid\";s:36:\"9caf9021-aacc-4038-827b-c7fe7712e0ed\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TBnl4vapW7sy5bRi7TcF-ueJnvz7aZNLif95ifvhfTQ\";}s:2:\"id\";s:32:\"webform_submission_delete_action\";s:5:\"label\";s:17:\"Delete submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:32:\"webform_submission_delete_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_lock_action',	'a:10:{s:4:\"uuid\";s:36:\"5e4d1084-e98f-408d-9529-89567e88b624\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MKmZlPRk3OJKNcYdYxSeZGQUh7LMah6MRShfkzch4bk\";}s:2:\"id\";s:35:\"webform_submission_make_lock_action\";s:5:\"label\";s:15:\"Lock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:35:\"webform_submission_make_lock_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_sticky_action',	'a:10:{s:4:\"uuid\";s:36:\"71eff68f-3ada-438a-93f8-5554a79cb737\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mPWBT52fKHyINRl9S3cCWFxY3rKbwkIRxaK6sIA26oo\";}s:2:\"id\";s:37:\"webform_submission_make_sticky_action\";s:5:\"label\";s:20:\"Star/flag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_sticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_unlock_action',	'a:10:{s:4:\"uuid\";s:36:\"f6b34ab3-4ded-41c8-8a32-ba4e032881fb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"begZ0-RmTzO_zDAwEKA2lKvtGYw1vbFOzbQOJzUbZX0\";}s:2:\"id\";s:37:\"webform_submission_make_unlock_action\";s:5:\"label\";s:17:\"Unlock submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:37:\"webform_submission_make_unlock_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_submission_make_unsticky_action',	'a:10:{s:4:\"uuid\";s:36:\"326c9843-f7a5-4f11-a105-e093bfdaae75\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n4gTFiUsdp7gw6yWUlDbKFEasZLCgXWWCmm7eJejay0\";}s:2:\"id\";s:39:\"webform_submission_make_unsticky_action\";s:5:\"label\";s:24:\"Unstar/unflag submission\";s:4:\"type\";s:18:\"webform_submission\";s:6:\"plugin\";s:39:\"webform_submission_make_unsticky_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.action.webform_unarchive_action',	'a:10:{s:4:\"uuid\";s:36:\"30b42137-73bc-48ad-bd3d-7b1492d2645a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aqi5Ftlnhe9KyOowpK7CanEvJMBBo8xAR1dA99bKOuc\";}s:2:\"id\";s:24:\"webform_unarchive_action\";s:5:\"label\";s:15:\"Restore webform\";s:4:\"type\";s:7:\"webform\";s:6:\"plugin\";s:24:\"webform_unarchive_action\";s:13:\"configuration\";a:0:{}}'),
('',	'system.advisories',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"x0FuQ_7Cg81mSDQwG028_Z0CjH3R9ib5IDlHeV2BbAo\";}s:7:\"enabled\";b:1;s:14:\"interval_hours\";i:6;}'),
('',	'system.cron',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"f3yToH8v8EaBZU0NFFw2qR8ogSCuWVmQaN0hpYR1BD8\";}s:9:\"threshold\";a:2:{s:20:\"requirements_warning\";i:172800;s:18:\"requirements_error\";i:1209600;}s:7:\"logging\";b:1;}'),
('',	'system.date',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"IVsFTD1mvR2NGBP_1myt9kFIFmGepH4PyaN5aQBYpno\";}s:9:\"first_day\";i:0;s:7:\"country\";a:1:{s:7:\"default\";N;}s:8:\"timezone\";a:2:{s:7:\"default\";s:15:\"Europe/Belgrade\";s:4:\"user\";a:3:{s:12:\"configurable\";b:1;s:7:\"default\";i:0;s:4:\"warn\";b:0;}}}'),
('',	'system.diff',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1WanmaEhxW_vM8_5Ktsdntj8MaO9UBHXg0lN603PsWM\";}s:7:\"context\";a:2:{s:13:\"lines_leading\";i:2;s:14:\"lines_trailing\";i:2;}}'),
('',	'system.feature_flags',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYyVj1FtPGV40Cf65YDVTUIc7YgLH6trXlotuevfs2I\";}s:16:\"linkset_endpoint\";b:0;}'),
('',	'system.file',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mguGHCYb9Dw5EcpfjwoShGV1Vjkbz3QuPRCLfxiye-g\";}s:22:\"allow_insecure_uploads\";b:0;s:14:\"default_scheme\";s:6:\"public\";s:21:\"temporary_maximum_age\";i:21600;}'),
('',	'system.image',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"durWHaKeBaq4d9Wpi4RqwADj1OufDepcnJuhVLmKN24\";}s:7:\"toolkit\";s:2:\"gd\";}'),
('',	'system.image.gd',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eNXaHfkJJUThHeF0nvkoXyPLRrKYGxgHRjORvT4F5rQ\";}s:12:\"jpeg_quality\";i:75;}'),
('',	'system.logging',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u3-njszl92FaxjrCMiq0yDcjAfcdx72w1zT1O9dx6aA\";}s:11:\"error_level\";s:4:\"hide\";}'),
('',	'system.mail',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5PvD9swkqWUeHkabdvbJ2SQqdhrzjkCT21wtD4BLfk4\";}s:9:\"interface\";a:2:{s:7:\"default\";s:8:\"php_mail\";s:7:\"webform\";s:16:\"webform_php_mail\";}s:10:\"mailer_dsn\";a:6:{s:6:\"scheme\";s:8:\"sendmail\";s:4:\"host\";s:7:\"default\";s:4:\"user\";N;s:8:\"password\";N;s:4:\"port\";N;s:7:\"options\";a:0:{}}}'),
('',	'system.maintenance',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"1SNdA25INsV5YjlgAJtfC-6AM8VcWe_00xneMLb2yFg\";}s:8:\"langcode\";s:2:\"en\";s:7:\"message\";s:93:\"@site is currently under maintenance. We should be back shortly. Thank you for your patience.\";}'),
('',	'system.menu.account',	'a:9:{s:4:\"uuid\";s:36:\"c0346b12-c5cd-40d6-886c-cf0888f426ac\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"M_Bh81osDyUQ4wV0GgU_NdBNqkzM87sLxjaCdFj9mnw\";}s:2:\"id\";s:7:\"account\";s:5:\"label\";s:17:\"User account menu\";s:11:\"description\";s:40:\"Links related to the active user account\";s:6:\"locked\";b:1;}'),
('',	'system.menu.admin',	'a:9:{s:4:\"uuid\";s:36:\"90616064-32be-41e1-baa8-be78784e75f1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sapEi2YDGoI9yQIT_WgIV2vUdQ6DScH0V3fAyTadAL0\";}s:2:\"id\";s:5:\"admin\";s:5:\"label\";s:14:\"Administration\";s:11:\"description\";s:25:\"Administrative task links\";s:6:\"locked\";b:1;}'),
('',	'system.menu.footer',	'a:9:{s:4:\"uuid\";s:36:\"ba5622c9-4800-414f-8f65-c096cf34841d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7yrlW5z9zdg2eBucB2GPqXKSMQfH9lSRSO4DbWF7AFc\";}s:2:\"id\";s:6:\"footer\";s:5:\"label\";s:6:\"Footer\";s:11:\"description\";s:22:\"Site information links\";s:6:\"locked\";b:1;}'),
('',	'system.menu.main',	'a:9:{s:4:\"uuid\";s:36:\"7f6e64bf-0677-4eaf-82ae-a29df89f11b9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Q2Ra3jfoIVk0f3SjxJX61byRQFVBAbpzYDQOiY-kno8\";}s:2:\"id\";s:4:\"main\";s:5:\"label\";s:15:\"Main navigation\";s:11:\"description\";s:18:\"Site section links\";s:6:\"locked\";b:1;}'),
('',	'system.menu.tools',	'a:9:{s:4:\"uuid\";s:36:\"a2a145f9-0c16-431e-975e-9af61b72ef36\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BCM-vV1zzRaLHN18dqAR_CuGOj8AFJvTx7BKl_8Gcxc\";}s:2:\"id\";s:5:\"tools\";s:5:\"label\";s:5:\"Tools\";s:11:\"description\";s:39:\"User tool links, often added by modules\";s:6:\"locked\";b:1;}'),
('',	'system.performance',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jtno5biznHZbrIgKwzq-ze-7XaQxLCGe6PeUOR7bRiQ\";}s:5:\"cache\";a:1:{s:4:\"page\";a:1:{s:7:\"max_age\";i:0;}}s:3:\"css\";a:2:{s:10:\"preprocess\";b:1;s:4:\"gzip\";b:1;}s:8:\"fast_404\";a:4:{s:7:\"enabled\";b:1;s:5:\"paths\";s:69:\"/\\.(?:txt|png|gif|jpe?g|css|js|ico|swf|flv|cgi|bat|pl|dll|exe|asp)$/i\";s:13:\"exclude_paths\";s:27:\"/\\/(?:styles|imagecache)\\//\";s:4:\"html\";s:162:\"<!DOCTYPE html><html><head><title>404 Not Found</title></head><body><h1>Not Found</h1><p>The requested URL \"@path\" was not found on this server.</p></body></html>\";}s:2:\"js\";a:2:{s:10:\"preprocess\";b:1;s:4:\"gzip\";b:1;}}'),
('',	'system.rss',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"MIpNzlG4gPunfS7vTCwUPum6QH3GUsEBMj-qS631Jw0\";}s:5:\"items\";a:1:{s:9:\"view_mode\";s:3:\"rss\";}}'),
('',	'system.site',	'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ijfbzDTN4CbE7Sr-6ubWzy_t1vH4OtU1doNCLssVz-4\";}s:8:\"langcode\";s:2:\"en\";s:4:\"uuid\";s:36:\"81f69bca-c1ec-48e0-bfde-2d9c7e27ddda\";s:4:\"name\";s:18:\"EBT Builder Source\";s:4:\"mail\";s:17:\"admin@example.com\";s:6:\"slogan\";s:0:\"\";s:4:\"page\";a:3:{i:403;s:0:\"\";i:404;s:0:\"\";s:5:\"front\";s:5:\"/node\";}s:18:\"admin_compact_mode\";b:0;s:17:\"weight_select_max\";i:100;s:16:\"default_langcode\";s:2:\"en\";s:17:\"mail_notification\";N;}'),
('',	'system.theme',	'a:3:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eJ529VM1gSIA_vgTy2PdiDvJuG0xhSxfQjCyl5WKlv4\";}s:5:\"admin\";s:5:\"claro\";s:7:\"default\";s:7:\"olivero\";}'),
('',	'system.theme.global',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KZiV2LB312xgJBphfq5BTjmp16xiR5KM8InBJ-pff7Y\";}s:7:\"favicon\";a:4:{s:8:\"mimetype\";s:24:\"image/vnd.microsoft.icon\";s:4:\"path\";s:0:\"\";s:3:\"url\";s:0:\"\";s:11:\"use_default\";b:1;}s:8:\"features\";a:4:{s:20:\"comment_user_picture\";b:1;s:25:\"comment_user_verification\";b:1;s:7:\"favicon\";b:1;s:17:\"node_user_picture\";b:1;}s:4:\"logo\";a:3:{s:4:\"path\";s:0:\"\";s:3:\"url\";N;s:11:\"use_default\";b:1;}}'),
('',	'taxonomy.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zKpaWT6cJc1tVQQaTqatGELaCqU_oyRym6zTl27Yias\";}s:20:\"maintain_index_table\";b:1;s:17:\"override_selector\";b:0;s:20:\"terms_per_page_admin\";i:100;}'),
('',	'taxonomy.vocabulary.tags',	'a:10:{s:4:\"uuid\";s:36:\"bae62ed0-d39a-4ca0-a737-86bf6ae374a6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"iTEzwrEQ_4JIb-OYGiqzyF2TmMgWyWayresXcWgwGWM\";}s:4:\"name\";s:4:\"Tags\";s:3:\"vid\";s:4:\"tags\";s:11:\"description\";s:61:\"Use tags to group articles on similar topics into categories.\";s:6:\"weight\";i:0;s:12:\"new_revision\";b:0;}'),
('',	'text.settings',	'a:2:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Bkewb77RBOK3_aXMPsp8p87gbc03NvmC5gBLzPl7hVA\";}s:22:\"default_summary_length\";i:600;}'),
('',	'update.settings',	'a:4:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xbYr66-g0FjNgVBkGypCuN46vBI2XHntXN1URawq1s4\";}s:5:\"check\";a:2:{s:19:\"disabled_extensions\";b:0;s:13:\"interval_days\";i:1;}s:5:\"fetch\";a:3:{s:3:\"url\";N;s:12:\"max_attempts\";i:2;s:7:\"timeout\";i:30;}s:12:\"notification\";a:2:{s:6:\"emails\";a:1:{i:0;s:17:\"admin@example.com\";}s:9:\"threshold\";s:3:\"all\";}}'),
('',	'user.flood',	'a:6:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"UYfMzeP1S8jKm9PSvxf7nQNe8DsNS-3bc2WSNNXBQWs\";}s:8:\"uid_only\";b:0;s:8:\"ip_limit\";i:50;s:9:\"ip_window\";i:3600;s:10:\"user_limit\";i:5;s:11:\"user_window\";i:21600;}'),
('',	'user.mail',	'a:11:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6CZIzFifRq3qbdq3n3nDpEOO4hWIQtKOAQNPvGNGKeM\";}s:8:\"langcode\";s:2:\"en\";s:14:\"cancel_confirm\";a:2:{s:7:\"subject\";s:67:\"Account cancellation request for [user:display-name] at [site:name]\";s:4:\"body\";s:376:\"[user:display-name]\n\nA request to cancel your account has been made at [site:name].\n\nYou may now cancel your account on [site:url-brief] by clicking this link or copying and pasting it into your browser:\n\n[user:cancel-url]\n\nNOTE: The cancellation of your account is not reversible.\n\nThis link expires in one day and nothing will happen if it is not used.\n\n--  [site:name] team\";}s:14:\"password_reset\";a:2:{s:7:\"subject\";s:68:\"Replacement login information for [user:display-name] at [site:name]\";s:4:\"body\";s:407:\"[user:display-name],\n\nA request to reset the password for your account has been made at [site:name].\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password. It expires after one day and nothing will happen if it\'s not used.\n\n--  [site:name] team\";}s:22:\"register_admin_created\";a:2:{s:7:\"subject\";s:58:\"An administrator created an account for you at [site:name]\";s:4:\"body\";s:473:\"[user:display-name],\n\nA site administrator at [site:name] has created an account for you. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:29:\"register_no_approval_required\";a:2:{s:7:\"subject\";s:54:\"Account details for [user:display-name] at [site:name]\";s:4:\"body\";s:447:\"[user:display-name],\n\nThank you for registering at [site:name]. You may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:name]\npassword: Your password\n\n--  [site:name] team\";}s:25:\"register_pending_approval\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:288:\"[user:display-name],\n\nThank you for registering at [site:name]. Your application for an account is currently pending approval. Once it has been approved, you will receive another email containing information about how to log in, set your password, and other details.\n\n--  [site:name] team\";}s:31:\"register_pending_approval_admin\";a:2:{s:7:\"subject\";s:79:\"Account details for [user:display-name] at [site:name] (pending admin approval)\";s:4:\"body\";s:64:\"[user:display-name] has applied for an account.\n\n[user:edit-url]\";}s:16:\"status_activated\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (approved)\";s:4:\"body\";s:462:\"[user:display-name],\n\nYour account at [site:name] has been activated.\n\nYou may now log in by clicking this link or copying and pasting it into your browser:\n\n[user:one-time-login-url]\n\nThis link can only be used once to log in and will lead you to a page where you can set your password.\n\nAfter setting your password, you will be able to log in at [site:login-url] in the future using:\n\nusername: [user:account-name]\npassword: Your password\n\n--  [site:name] team\";}s:14:\"status_blocked\";a:2:{s:7:\"subject\";s:64:\"Account details for [user:display-name] at [site:name] (blocked)\";s:4:\"body\";s:89:\"[user:display-name],\n\nYour account on [site:name] has been blocked.\n\n--  [site:name] team\";}s:15:\"status_canceled\";a:2:{s:7:\"subject\";s:65:\"Account details for [user:display-name] at [site:name] (canceled)\";s:4:\"body\";s:90:\"[user:display-name],\n\nYour account on [site:name] has been canceled.\n\n--  [site:name] team\";}}'),
('',	'user.role.administrator',	'a:10:{s:4:\"uuid\";s:36:\"55c650b9-b5a7-4ff4-bc0f-f89243b36175\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:0:{}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OeKGIkmZA_c-t6QLH81WNQx8gDCc1MRmxaTuQgxBByU\";}s:2:\"id\";s:13:\"administrator\";s:5:\"label\";s:13:\"Administrator\";s:6:\"weight\";i:3;s:8:\"is_admin\";b:1;s:11:\"permissions\";a:0:{}}'),
('',	'user.role.anonymous',	'a:10:{s:4:\"uuid\";s:36:\"8ae6303e-51a9-461e-9cd1-3548f02fd2f7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:29:\"filter.format.restricted_html\";}s:6:\"module\";a:5:{i:0;s:7:\"contact\";i:1;s:6:\"filter\";i:2;s:5:\"media\";i:3;s:6:\"search\";i:4;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6WavjUYXIegP9AAg2zXGx54MWIVoomC3SZhNiqe-Dyk\";}s:2:\"id\";s:9:\"anonymous\";s:5:\"label\";s:14:\"Anonymous user\";s:6:\"weight\";i:0;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:5:{i:0;s:14:\"access content\";i:1;s:29:\"access site-wide contact form\";i:2;s:14:\"search content\";i:3;s:31:\"use text format restricted_html\";i:4;s:10:\"view media\";}}'),
('',	'user.role.authenticated',	'a:10:{s:4:\"uuid\";s:36:\"a817234d-3eaa-4c9f-a2ec-0f6cada70063\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:24:\"filter.format.basic_html\";i:1;s:29:\"filter.format.webform_default\";}s:6:\"module\";a:8:{i:0;s:7:\"contact\";i:1;s:4:\"file\";i:2;s:6:\"filter\";i:3;s:16:\"google_analytics\";i:4;s:5:\"media\";i:5;s:6:\"search\";i:6;s:8:\"shortcut\";i:7;s:6:\"system\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cFrlqjtkTfvY3RGccjJkPf1SGIfJ942IrxTLWAO4mgA\";}s:2:\"id\";s:13:\"authenticated\";s:5:\"label\";s:18:\"Authenticated user\";s:6:\"weight\";i:1;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:9:{i:0;s:14:\"access content\";i:1;s:16:\"access shortcuts\";i:2;s:29:\"access site-wide contact form\";i:3;s:16:\"delete own files\";i:4;s:42:\"opt-in or out of google analytics tracking\";i:5;s:14:\"search content\";i:6;s:26:\"use text format basic_html\";i:7;s:31:\"use text format webform_default\";i:8;s:10:\"view media\";}}'),
('',	'user.role.content_editor',	'a:10:{s:4:\"uuid\";s:36:\"d6e980dc-d5d4-42cf-8308-888d9c255fa0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:3:{i:0;s:17:\"node.type.article\";i:1;s:14:\"node.type.page\";i:2;s:24:\"taxonomy.vocabulary.tags\";}s:6:\"module\";a:7:{i:0;s:10:\"contextual\";i:1;s:4:\"file\";i:2;s:4:\"node\";i:3;s:4:\"path\";i:4;s:6:\"system\";i:5;s:8:\"taxonomy\";i:6;s:7:\"toolbar\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"e_wG1u7SrGaJbY2-Szgbgl-c8T3kdirU3uTNq2c_QJQ\";}s:2:\"id\";s:14:\"content_editor\";s:5:\"label\";s:14:\"Content editor\";s:6:\"weight\";i:2;s:8:\"is_admin\";b:0;s:11:\"permissions\";a:22:{i:0;s:27:\"access administration pages\";i:1;s:23:\"access content overview\";i:2;s:23:\"access contextual links\";i:3;s:21:\"access files overview\";i:4;s:14:\"access toolbar\";i:5;s:22:\"administer url aliases\";i:6;s:22:\"create article content\";i:7;s:19:\"create page content\";i:8;s:20:\"create terms in tags\";i:9;s:18:\"create url aliases\";i:10;s:24:\"delete article revisions\";i:11;s:26:\"delete own article content\";i:12;s:16:\"delete own files\";i:13;s:23:\"delete own page content\";i:14;s:21:\"delete page revisions\";i:15;s:24:\"edit own article content\";i:16;s:21:\"edit own page content\";i:17;s:18:\"edit terms in tags\";i:18;s:20:\"revert all revisions\";i:19;s:18:\"view all revisions\";i:20;s:28:\"view own unpublished content\";i:21;s:29:\"view the administration theme\";}}'),
('',	'user.settings',	'a:9:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-htDFWUv1S4OlJMzta2nhFl4QbhJvu0D9xsJ-clxo-M\";}s:8:\"langcode\";s:2:\"en\";s:9:\"anonymous\";s:9:\"Anonymous\";s:11:\"verify_mail\";b:1;s:6:\"notify\";a:8:{s:14:\"cancel_confirm\";b:1;s:14:\"password_reset\";b:1;s:16:\"status_activated\";b:1;s:14:\"status_blocked\";b:0;s:15:\"status_canceled\";b:0;s:22:\"register_admin_created\";b:1;s:29:\"register_no_approval_required\";b:1;s:25:\"register_pending_approval\";b:1;}s:8:\"register\";s:23:\"visitors_admin_approval\";s:13:\"cancel_method\";s:17:\"user_cancel_block\";s:22:\"password_reset_timeout\";i:86400;s:17:\"password_strength\";b:1;}'),
('',	'views.settings',	'a:5:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8oDr9oPVb_ostrNnVV6V7VdphwoH_u-NqTS0u7SE7qc\";}s:17:\"display_extenders\";a:0:{}s:13:\"sql_signature\";b:0;s:2:\"ui\";a:3:{s:4:\"show\";a:7:{s:18:\"additional_queries\";b:0;s:15:\"advanced_column\";b:0;s:15:\"default_display\";b:0;s:22:\"performance_statistics\";b:0;s:19:\"preview_information\";b:1;s:9:\"sql_query\";a:2:{s:7:\"enabled\";b:0;s:5:\"where\";s:5:\"above\";}s:13:\"display_embed\";b:0;}s:19:\"always_live_preview\";b:1;s:24:\"exposed_filter_any_label\";s:7:\"old_any\";}s:22:\"field_rewrite_elements\";a:29:{s:3:\"div\";s:3:\"DIV\";s:4:\"span\";s:4:\"SPAN\";s:2:\"h1\";s:2:\"H1\";s:2:\"h2\";s:2:\"H2\";s:2:\"h3\";s:2:\"H3\";s:2:\"h4\";s:2:\"H4\";s:2:\"h5\";s:2:\"H5\";s:2:\"h6\";s:2:\"H6\";s:1:\"p\";s:1:\"P\";s:6:\"header\";s:6:\"HEADER\";s:6:\"footer\";s:6:\"FOOTER\";s:7:\"article\";s:7:\"ARTICLE\";s:7:\"section\";s:7:\"SECTION\";s:5:\"aside\";s:5:\"ASIDE\";s:7:\"details\";s:7:\"DETAILS\";s:10:\"blockquote\";s:10:\"BLOCKQUOTE\";s:6:\"figure\";s:6:\"FIGURE\";s:7:\"address\";s:7:\"ADDRESS\";s:4:\"code\";s:4:\"CODE\";s:3:\"pre\";s:3:\"PRE\";s:3:\"var\";s:3:\"VAR\";s:4:\"samp\";s:4:\"SAMP\";s:3:\"kbd\";s:3:\"KBD\";s:6:\"strong\";s:6:\"STRONG\";s:2:\"em\";s:2:\"EM\";s:3:\"del\";s:3:\"DEL\";s:3:\"ins\";s:3:\"INS\";s:1:\"q\";s:1:\"Q\";s:1:\"s\";s:1:\"S\";}}'),
('',	'views.view.archive',	'a:13:{s:4:\"uuid\";s:36:\"869573d7-3210-47a6-a85b-2b4f70595558\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"exIF08PTvYSK6tJCsAzBqMEKUBKIptPorMn74SVhevc\";}s:2:\"id\";s:7:\"archive\";s:5:\"label\";s:7:\"Archive\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:22:\"All content, by month.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:15:\"Monthly archive\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:2:{s:8:\"override\";b:1;s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:2:{s:10:\"sort_order\";s:4:\"desc\";s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:0;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:9:\"arguments\";a:1:{s:18:\"created_year_month\";a:13:{s:2:\"id\";s:18:\"created_year_month\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:18:\"created_year_month\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:15:\"date_year_month\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:1;s:5:\"title\";s:34:\"{{ arguments.created_year_month }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:15:\"summary_options\";a:1:{s:14:\"items_per_page\";i:30;}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"archive\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.block_content',	'a:13:{s:4:\"uuid\";s:36:\"2b2425c7-ad13-4164-afc2-8d66592f2a30\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HfvTcWhiVuvxchoh4DjIkXhKkj9ow2TGgHkLHSvRLq8\";}s:2:\"id\";s:13:\"block_content\";s:5:\"label\";s:14:\"Content blocks\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:31:\"Find and manage content blocks.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:24:\"block_content_field_data\";s:10:\"base_field\";s:2:\"id\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:14:\"Content blocks\";s:6:\"fields\";a:4:{s:4:\"info\";a:37:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";N;s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:17:\"Block description\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Block type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access block library\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:2:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:38:\"There are no content blocks available.\";s:8:\"tokenize\";b:0;}s:27:\"block_content_listing_empty\";a:10:{s:2:\"id\";s:27:\"block_content_listing_empty\";s:5:\"table\";s:13:\"block_content\";s:5:\"field\";s:27:\"block_content_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:9:\"plugin_id\";s:27:\"block_content_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:4:\"info\";a:16:{s:2:\"id\";s:4:\"info\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"info\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"info\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"info_op\";s:5:\"label\";s:17:\"Block description\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"info_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"info\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:10:\"Block type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"reusable\";a:16:{s:2:\"id\";s:8:\"reusable\";s:5:\"table\";s:24:\"block_content_field_data\";s:5:\"field\";s:8:\"reusable\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:13:\"block_content\";s:12:\"entity_field\";s:8:\"reusable\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:4:\"info\";s:4:\"info\";s:4:\"type\";s:4:\"type\";s:7:\"changed\";s:7:\"changed\";s:10:\"operations\";s:10:\"operations\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:4:{s:4:\"info\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/block\";s:4:\"menu\";a:7:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:6:\"Blocks\";s:11:\"description\";s:31:\"Create and edit content blocks.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:6:\"parent\";s:20:\"system.admin_content\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.content',	'a:13:{s:4:\"uuid\";s:36:\"53b483f4-38d1-4359-99b2-b24e9f23a505\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"whBYBAcXQuQblGEdvQ9QfGuuW3zC49F2-5vXSm1slFM\";}s:2:\"id\";s:7:\"content\";s:5:\"label\";s:7:\"Content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:24:\"Find and manage content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:7:\"Content\";s:6:\"fields\";a:8:{s:14:\"node_bulk_form\";a:14:{s:2:\"id\";s:14:\"node_bulk_form\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:14:\"node_bulk_form\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:14:\"node_bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"title\";a:17:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:4:\"type\";a:37:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Content type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:17:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:17:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}}s:7:\"changed\";a:17:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:1:{s:10:\"alter_text\";b:0;}s:13:\"element_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:8:\"langcode\";a:37:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Language\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:8:\"language\";s:8:\"settings\";a:2:{s:14:\"link_to_entity\";b:0;s:15:\"native_language\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:23:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:3:{s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:23:\"access content overview\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:5:\"title\";a:16:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:8:\"title_op\";s:5:\"label\";s:5:\"Title\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:8:\"title_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:5:\"title\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"type\";a:16:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:4:\"type\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:12:\"Content type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:12:\"status_extra\";a:9:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:6:\"expose\";a:2:{s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:10:{s:14:\"node_bulk_form\";s:14:\"node_bulk_form\";s:5:\"title\";s:5:\"title\";s:4:\"type\";s:4:\"type\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:7:\"changed\";s:7:\"changed\";s:9:\"edit_node\";s:9:\"edit_node\";s:11:\"delete_node\";s:11:\"delete_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";s:9:\"timestamp\";s:5:\"title\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:10:{s:14:\"node_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"title\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"delete_node\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:1;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:1:{s:4:\"type\";s:11:\"views_query\";}s:13:\"relationships\";a:1:{s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:18:\"admin/content/node\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:7:\"Content\";s:11:\"description\";s:23:\"Find and manage content\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:21:\"user.node_grants:view\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.content_recent',	'a:13:{s:4:\"uuid\";s:36:\"0aadfe89-23e4-4ec3-a50a-3c76c79be76a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YqZN5rc7XDQcFcInc8wkzuaHJmC5YvirhTmDcrarT6M\";}s:2:\"id\";s:14:\"content_recent\";s:5:\"label\";s:14:\"Recent content\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:15:\"Recent content.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:22:{s:5:\"title\";s:14:\"Recent content\";s:6:\"fields\";a:2:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:21:\"No content available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"changed\";a:13:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"changed\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:11:\"node_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";b:0;s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:1;}}s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"More\";s:12:\"link_display\";s:1:\"0\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:5:\"Block\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:1:{s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:4:\"user\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.files',	'a:13:{s:4:\"uuid\";s:36:\"534a8e69-2ee4-4c66-98d4-040cedf2dcd1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"blP1XdpU4RqVoA_8po7qnIokIbHB6DJt0lpilgY5ovM\";}s:2:\"id\";s:5:\"files\";s:5:\"label\";s:5:\"Files\";s:6:\"module\";s:4:\"file\";s:11:\"description\";s:22:\"Find and manage files.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:12:\"file_managed\";s:10:\"base_field\";s:3:\"fid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:5:\"Files\";s:6:\"fields\";a:9:{s:3:\"fid\";a:24:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:3:\"Fid\";s:7:\"exclude\";b:1;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"filename\";a:36:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"file_link\";s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:8:\"filemime\";a:25:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"MIME type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"file_filemime\";}s:8:\"filesize\";a:25:{s:2:\"id\";s:8:\"filesize\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filesize\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filesize\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Size\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"file_size\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:9:\"Temporary\";s:18:\"format_custom_true\";s:9:\"Permanent\";}}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Upload date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:12:\"Changed date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:3:\"fid\";s:10:\"group_type\";s:3:\"sum\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:7:\"Used in\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/content/files/usage/{{ fid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:1;s:20:\"format_plural_string\";s:21:\"1 place@count places\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access files overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:6:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No files available.\";}}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:8:\"filename\";a:16:{s:2:\"id\";s:8:\"filename\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filename\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filename\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:8:\"Filename\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filename_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filename\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"filemime\";a:16:{s:2:\"id\";s:8:\"filemime\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:8:\"filemime\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:8:\"filemime\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:4:\"word\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:11:\"filemime_op\";s:5:\"label\";s:9:\"MIME type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"filemime_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"filemime\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:11:\"file_status\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"status_op\";s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:3:\"fid\";s:3:\"fid\";s:8:\"filename\";s:8:\"filename\";s:8:\"filemime\";s:8:\"filemime\";s:8:\"filesize\";s:8:\"filesize\";s:6:\"status\";s:6:\"status\";s:7:\"created\";s:7:\"created\";s:7:\"changed\";s:7:\"changed\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:8:{s:3:\"fid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filename\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"filemime\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:8:\"filesize\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:1;s:16:\"show_admin_links\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:14:\"Files overview\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:2:{s:5:\"pager\";b:1;s:13:\"relationships\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:0;}}s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/files\";s:4:\"menu\";a:6:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Files\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_2\";a:6:{s:2:\"id\";s:6:\"page_2\";s:13:\"display_title\";s:10:\"File usage\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:15:{s:5:\"title\";s:10:\"File usage\";s:6:\"fields\";a:4:{s:12:\"entity_label\";a:23:{s:2:\"id\";s:12:\"entity_label\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:12:\"entity_label\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"entity_label\";s:5:\"label\";s:6:\"Entity\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:14:\"link_to_entity\";b:1;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:11:\"Entity type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:6:\"module\";a:22:{s:2:\"id\";s:6:\"module\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:6:\"module\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:18:\"Registering module\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:5:\"count\";a:30:{s:2:\"id\";s:5:\"count\";s:5:\"table\";s:10:\"file_usage\";s:5:\"field\";s:5:\"count\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"numeric\";s:5:\"label\";s:9:\"Use count\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:13:\"set_precision\";b:0;s:9:\"precision\";i:0;s:7:\"decimal\";s:1:\".\";s:9:\"separator\";s:1:\",\";s:13:\"format_plural\";b:0;s:20:\"format_plural_string\";s:8:\"1@count\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:5:\"empty\";a:0:{}s:9:\"arguments\";a:1:{s:3:\"fid\";a:22:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"file\";s:12:\"entity_field\";s:3:\"fid\";s:9:\"plugin_id\";s:8:\"file_fid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:46:\"File usage information for {{ arguments.fid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;}}s:7:\"filters\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:4:{s:12:\"entity_label\";s:12:\"entity_label\";s:4:\"type\";s:4:\"type\";s:6:\"module\";s:6:\"module\";s:5:\"count\";s:5:\"count\";}s:7:\"default\";s:12:\"entity_label\";s:4:\"info\";a:4:{s:12:\"entity_label\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:6:\"module\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:5:\"count\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:11:{s:5:\"empty\";b:0;s:5:\"title\";b:0;s:5:\"pager\";b:0;s:8:\"group_by\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:13:\"relationships\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:13:\"relationships\";a:1:{s:3:\"fid\";a:7:{s:2:\"id\";s:3:\"fid\";s:5:\"table\";s:12:\"file_managed\";s:5:\"field\";s:3:\"fid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:10:\"File usage\";s:8:\"required\";b:1;}}s:8:\"group_by\";b:0;s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:27:\"admin/content/files/usage/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.frontpage',	'a:13:{s:4:\"uuid\";s:36:\"697fbe61-72f2-4f36-9ef0-93f40a5476d1\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:2:{i:0;s:30:\"core.entity_view_mode.node.rss\";i:1;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"OEEnRQIjfIaCFRsz8U3VqDrE82ltQKlo8wNbQJRZXu0\";}s:2:\"id\";s:9:\"frontpage\";s:5:\"label\";s:9:\"Frontpage\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:39:\"All content promoted to the front page.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:0:\"\";s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:3:{s:16:\"area_text_custom\";a:11:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:7:\"content\";s:181:\"No front page content has been created yet.<br/>Follow the <a target=\"_blank\" href=\"https://www.drupal.org/docs/user_guide/en/index.html\">User Guide</a> to start building your site.\";s:8:\"tokenize\";b:0;}s:18:\"node_listing_empty\";a:10:{s:2:\"id\";s:18:\"node_listing_empty\";s:5:\"table\";s:4:\"node\";s:5:\"field\";s:18:\"node_listing_empty\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:9:\"plugin_id\";s:18:\"node_listing_empty\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;}s:5:\"title\";a:10:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:5:\"title\";s:5:\"label\";s:0:\"\";s:5:\"empty\";b:1;s:5:\"title\";s:8:\"Welcome!\";}}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:12:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:3:{s:7:\"promote\";a:16:{s:2:\"id\";s:7:\"promote\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"promote\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"promote\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:3:\"rss\";}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:7:\"rss.xml\";s:14:\"sitename_title\";b:1;s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:28:\"languages:language_interface\";i:1;s:21:\"user.node_grants:view\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:4:\"node\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:14:\"url.query_args\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.glossary',	'a:13:{s:4:\"uuid\";s:36:\"4b34ee05-e652-40b7-8ec4-c522b22c6013\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:0;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:16:\"system.menu.main\";}s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"r-klgGeO4haVHqAwxW1HXZLzdzLSMUVC08OuTBrRh58\";}s:2:\"id\";s:8:\"glossary\";s:5:\"label\";s:8:\"Glossary\";s:6:\"module\";s:4:\"node\";s:11:\"description\";s:23:\"All content, by letter.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:6:\"fields\";a:3:{s:5:\"title\";a:24:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:5:\"Title\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:7:\"changed\";a:26:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:36;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:0:{}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"default\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:0:{}s:7:\"summary\";a:1:{s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;s:7:\"columns\";a:3:{s:5:\"title\";s:5:\"title\";s:4:\"name\";s:4:\"name\";s:7:\"changed\";s:7:\"changed\";}s:7:\"default\";s:5:\"title\";s:4:\"info\";a:3:{s:5:\"title\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:4:\"name\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}s:7:\"changed\";a:2:{s:8:\"sortable\";b:1;s:9:\"separator\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:5:\"order\";s:3:\"asc\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:6:\"author\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"attachment_1\";a:6:{s:2:\"id\";s:12:\"attachment_1\";s:13:\"display_title\";s:10:\"Attachment\";s:14:\"display_plugin\";s:10:\"attachment\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:0;}}s:9:\"arguments\";a:1:{s:5:\"title\";a:26:{s:2:\"id\";s:5:\"title\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:5:\"title\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:5:\"title\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:7:\"summary\";s:9:\"exception\";a:1:{s:12:\"title_enable\";b:1;}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:1:\"a\";}s:15:\"summary_options\";a:3:{s:14:\"items_per_page\";i:25;s:6:\"inline\";b:1;s:9:\"separator\";s:3:\" | \";}s:7:\"summary\";a:1:{s:6:\"format\";s:19:\"unformatted_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:1;s:5:\"limit\";i:1;s:4:\"case\";s:5:\"upper\";s:9:\"path_case\";s:5:\"lower\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:8:\"defaults\";a:1:{s:9:\"arguments\";b:0;}s:17:\"display_extenders\";a:0:{}s:8:\"displays\";a:2:{s:7:\"default\";s:7:\"default\";s:6:\"page_1\";s:6:\"page_1\";}s:17:\"inherit_arguments\";b:0;}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:8:\"glossary\";s:4:\"menu\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:8:\"Glossary\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:21:\"user.node_grants:view\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.media',	'a:13:{s:4:\"uuid\";s:36:\"36a349da-87e8-43e4-89c5-350096634510\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:21:\"image.style.thumbnail\";}s:6:\"module\";a:3:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"kOTUk5XWeupgBOJuRRarCiDcFKVZcvaW-FT5MTzrML8\";}s:2:\"id\";s:5:\"media\";s:5:\"label\";s:5:\"Media\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:8:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:20:\"thumbnail__target_id\";a:37:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:9:\"thumbnail\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:4:\"lazy\";}}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:5:\"media\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Media name\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"bundle\";a:37:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:0;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:3:\"uid\";a:37:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:9:\"target_id\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}s:12:\"group_column\";s:9:\"target_id\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:6:\"status\";a:37:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:11:\"Unpublished\";s:18:\"format_custom_true\";s:9:\"Published\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:7:\"changed\";a:37:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:5:{s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:10:\"Media name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:4:\"True\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:16:\"Published status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:6:{s:4:\"name\";s:4:\"name\";s:6:\"bundle\";s:6:\"bundle\";s:7:\"changed\";s:7:\"changed\";s:3:\"uid\";s:3:\"uid\";s:6:\"status\";s:6:\"status\";s:20:\"thumbnail__target_id\";s:20:\"thumbnail__target_id\";}s:7:\"default\";s:7:\"changed\";s:4:\"info\";a:6:{s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"bundle\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"changed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"uid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:15:\"media_page_list\";a:6:{s:2:\"id\";s:15:\"media_page_list\";s:13:\"display_title\";s:5:\"Media\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:0:\"\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/content/media\";s:4:\"menu\";a:8:{s:4:\"type\";s:3:\"tab\";s:5:\"title\";s:5:\"Media\";s:11:\"description\";s:0:\"\";s:6:\"weight\";i:0;s:8:\"expanded\";b:0;s:9:\"menu_name\";s:4:\"main\";s:6:\"parent\";s:0:\"\";s:7:\"context\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.media_library',	'a:13:{s:4:\"uuid\";s:36:\"bc9a8070-9681-4b94-8d52-549af33d0dbe\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:3:{s:6:\"config\";a:2:{i:0;s:41:\"core.entity_view_mode.media.media_library\";i:1;s:25:\"image.style.media_library\";}s:6:\"module\";a:4:{i:0;s:5:\"image\";i:1;s:5:\"media\";i:2;s:13:\"media_library\";i:3;s:4:\"user\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"media_library\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9u9hwW-Q0-uQJz1vgenJTQhZGYN0FBZoOogwPD6kgkQ\";}s:2:\"id\";s:13:\"media_library\";s:5:\"label\";s:13:\"Media library\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:22:\"Find and manage media.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:16:\"media_field_data\";s:10:\"base_field\";s:3:\"mid\";s:7:\"display\";a:4:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:5:\"title\";s:5:\"Media\";s:6:\"fields\";a:2:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:24;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"6, 12, 24, 48\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:13:\"Apply filters\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:21:\"access media overview\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:19:\"No media available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:3:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:12:\"Newest first\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:1;s:11:\"granularity\";s:6:\"second\";}s:4:\"name\";a:12:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:3:\"ASC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (A-Z)\";s:16:\"field_identifier\";s:4:\"name\";}s:7:\"exposed\";b:1;}s:6:\"name_1\";a:12:{s:2:\"id\";s:6:\"name_1\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:10:\"Name (Z-A)\";s:16:\"field_identifier\";s:6:\"name_1\";}s:7:\"exposed\";b:1;}}s:7:\"filters\";a:5:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:17:\"Publishing status\";s:11:\"description\";N;s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:1;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:9:\"Published\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:9:\"Published\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:11:\"Unpublished\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"bundle\";a:16:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"bundle\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:9:\"bundle_op\";s:5:\"label\";s:10:\"Media type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"bundle_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:10:\"Media type\";s:11:\"description\";N;s:10:\"identifier\";s:6:\"bundle\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:3:{i:1;a:0:{}i:2;a:0:{}i:3;a:0:{}}}}s:12:\"status_extra\";a:15:{s:2:\"id\";s:12:\"status_extra\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:12:\"status_extra\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:12:\"media_status\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"langcode_op\";s:5:\"label\";s:8:\"Language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"langcode_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"langcode\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:22:\"default_field_elements\";b:1;s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:1;s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:6:\"fields\";a:5:{s:15:\"media_bulk_form\";a:26:{s:2:\"id\";s:15:\"media_bulk_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"media_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:9:\"bulk_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:10:\"edit_media\";a:26:{s:2:\"id\";s:10:\"edit_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:10:\"edit_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:15:\"Edit {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:15:\"Edit {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"Edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:12:\"delete_media\";a:26:{s:2:\"id\";s:12:\"delete_media\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:12:\"delete_media\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:18:\"entity_link_delete\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:17:\"Delete {{ name }}\";s:9:\"make_link\";b:1;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:17:\"Delete {{ name }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:1:\"0\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:6:\"Delete\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:8:\"defaults\";a:1:{s:6:\"fields\";b:0;}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:24:\"admin/content/media-grid\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:7:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:22:\"url.query_args:sort_by\";i:5;s:4:\"user\";i:6;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"widget\";a:6:{s:2:\"id\";s:6:\"widget\";s:13:\"display_title\";s:6:\"Widget\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:2;s:15:\"display_options\";a:12:{s:6:\"fields\";a:2:{s:25:\"media_library_select_form\";a:23:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:15:\"rendered_entity\";a:24:{s:2:\"id\";s:15:\"rendered_entity\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:15:\"rendered_entity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:15:\"rendered_entity\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:9:\"view_mode\";s:13:\"media_library\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:8:\"defaults\";a:7:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:19:\"display_description\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:26:\"admin/content/media-widget\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"widget_table\";a:6:{s:2:\"id\";s:12:\"widget_table\";s:13:\"display_title\";s:14:\"Widget (table)\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:3;s:15:\"display_options\";a:13:{s:6:\"fields\";a:5:{s:25:\"media_library_select_form\";a:9:{s:2:\"id\";s:25:\"media_library_select_form\";s:5:\"table\";s:5:\"media\";s:5:\"field\";s:25:\"media_library_select_form\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:9:\"plugin_id\";s:25:\"media_library_select_form\";s:5:\"label\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";}s:20:\"thumbnail__target_id\";a:10:{s:2:\"id\";s:20:\"thumbnail__target_id\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:20:\"thumbnail__target_id\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:9:\"thumbnail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:9:\"Thumbnail\";s:4:\"type\";s:5:\"image\";s:8:\"settings\";a:3:{s:10:\"image_link\";s:0:\"\";s:11:\"image_style\";s:13:\"media_library\";s:13:\"image_loading\";a:1:{s:9:\"attribute\";s:5:\"eager\";}}}s:4:\"name\";a:10:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"Name\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}}s:3:\"uid\";a:10:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:20:\"media_field_revision\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Author\";s:4:\"type\";s:22:\"entity_reference_label\";s:8:\"settings\";a:1:{s:4:\"link\";b:1;}}s:7:\"changed\";a:10:{s:2:\"id\";s:7:\"changed\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:7:\"changed\";s:12:\"relationship\";s:4:\"none\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:7:\"changed\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:7:\"Updated\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:4:\"long\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:10:\"view media\";}}s:9:\"arguments\";a:1:{s:6:\"bundle\";a:26:{s:2:\"id\";s:6:\"bundle\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"bundle\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"bundle\";s:9:\"plugin_id\";s:6:\"string\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:24;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:8:\"glossary\";b:0;s:5:\"limit\";i:0;s:4:\"case\";s:4:\"none\";s:9:\"path_case\";s:4:\"none\";s:14:\"transform_dash\";b:0;s:12:\"break_phrase\";b:0;}}s:7:\"filters\";a:3:{s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:4:\"name\";a:16:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:6:\"string\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:7:\"name_op\";s:5:\"label\";s:4:\"Name\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"name_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"name\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"media_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:5:\"media\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:2:{s:9:\"row_class\";s:85:\"media-library-item media-library-item--table js-media-library-item js-click-to-select\";s:17:\"default_row_class\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:8:\"defaults\";a:9:{s:6:\"access\";b:0;s:9:\"css_class\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"fields\";b:0;s:9:\"arguments\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;s:6:\"header\";b:0;}s:9:\"css_class\";s:0:\"\";s:6:\"header\";a:2:{s:17:\"display_link_grid\";a:7:{s:2:\"id\";s:17:\"display_link_grid\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:4:\"Grid\";s:5:\"empty\";b:1;s:10:\"display_id\";s:6:\"widget\";}s:18:\"display_link_table\";a:7:{s:2:\"id\";s:18:\"display_link_table\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:12:\"display_link\";s:9:\"plugin_id\";s:12:\"display_link\";s:5:\"label\";s:5:\"Table\";s:5:\"empty\";b:1;s:10:\"display_id\";s:12:\"widget_table\";}}s:18:\"rendering_language\";s:33:\"***LANGUAGE_language_interface***\";s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:32:\"admin/content/media-widget-table\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:22:\"url.query_args:sort_by\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.redirect',	'a:13:{s:4:\"uuid\";s:36:\"cb66f7a4-4661-4051-8a2d-40c096d4f55d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"link\";i:1;s:8:\"redirect\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"I9VqfbwK5ZyKzL7810d0fswaadU6riFT3kPL0yxcpLs\";}s:2:\"id\";s:8:\"redirect\";s:5:\"label\";s:8:\"Redirect\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:17:\"List of redirects\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"redirect\";s:10:\"base_field\";s:3:\"rid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"administer redirects\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:14:\"items_per_page\";i:50;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:12:\"‹ previous\";s:4:\"next\";s:8:\"next ›\";s:5:\"first\";s:8:\"« first\";s:4:\"last\";s:7:\"last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;s:24:\"pagination_heading_level\";s:2:\"h4\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:6:{s:21:\"redirect_source__path\";s:21:\"redirect_source__path\";s:22:\"redirect_redirect__uri\";s:22:\"redirect_redirect__uri\";s:11:\"status_code\";s:11:\"status_code\";s:8:\"language\";s:8:\"language\";s:7:\"created\";s:7:\"created\";s:10:\"operations\";s:10:\"operations\";}s:4:\"info\";a:6:{s:21:\"redirect_source__path\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:22:\"redirect_redirect__uri\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"status_code\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"language\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:10:\"operations\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:6:\"fields\";a:7:{s:18:\"redirect_bulk_form\";a:26:{s:2:\"id\";s:18:\"redirect_bulk_form\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:18:\"redirect_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:14:\"With selection\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:8:\"redirect\";s:9:\"plugin_id\";s:18:\"redirect_bulk_form\";}s:21:\"redirect_source__path\";a:37:{s:2:\"id\";s:21:\"redirect_source__path\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:21:\"redirect_source__path\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:4:\"From\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:4:\"path\";s:4:\"type\";s:15:\"redirect_source\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:0:\"\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:15:\"redirect_source\";s:9:\"plugin_id\";s:5:\"field\";}s:22:\"redirect_redirect__uri\";a:6:{s:2:\"id\";s:22:\"redirect_redirect__uri\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:22:\"redirect_redirect__uri\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:17:\"redirect_redirect\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"status_code\";a:6:{s:2:\"id\";s:11:\"status_code\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:11:\"status_code\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:11:\"status_code\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"language\";a:6:{s:2:\"id\";s:8:\"language\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:8:\"language\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:8:\"language\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:27:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:8:\"fallback\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";}s:10:\"operations\";a:5:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:10:\"operations\";s:11:\"entity_type\";s:8:\"redirect\";s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:4:{s:21:\"redirect_source__path\";a:16:{s:2:\"id\";s:21:\"redirect_source__path\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:21:\"redirect_source__path\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:24:\"redirect_source__path_op\";s:5:\"label\";s:4:\"From\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:24:\"redirect_source__path_op\";s:10:\"identifier\";s:21:\"redirect_source__path\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:15:\"redirect_source\";s:9:\"plugin_id\";s:6:\"string\";}s:22:\"redirect_redirect__uri\";a:16:{s:2:\"id\";s:22:\"redirect_redirect__uri\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:22:\"redirect_redirect__uri\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:25:\"redirect_redirect__uri_op\";s:5:\"label\";s:2:\"To\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:25:\"redirect_redirect__uri_op\";s:10:\"identifier\";s:22:\"redirect_redirect__uri\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:17:\"redirect_redirect\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"status_code\";a:16:{s:2:\"id\";s:11:\"status_code\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:11:\"status_code\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:0:\"\";}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:14:\"status_code_op\";s:5:\"label\";s:11:\"Status code\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:14:\"status_code_op\";s:10:\"identifier\";s:11:\"status_code\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:11:\"Status code\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:11:\"status_code\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:7:{i:1;a:3:{s:5:\"title\";s:20:\"300 Multiple Choices\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"300\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:2;a:3:{s:5:\"title\";s:21:\"301 Moved Permanently\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"301\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:3;a:3:{s:5:\"title\";s:9:\"302 Found\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"302\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:4;a:3:{s:5:\"title\";s:13:\"303 See Other\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"303\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:5;a:3:{s:5:\"title\";s:16:\"304 Not Modified\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"304\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:6;a:3:{s:5:\"title\";s:13:\"305 Use Proxy\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"305\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}i:7;a:3:{s:5:\"title\";s:22:\"307 Temporary Redirect\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";a:3:{s:5:\"value\";s:3:\"307\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";}}}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:11:\"status_code\";s:9:\"plugin_id\";s:7:\"numeric\";}s:8:\"language\";a:16:{s:2:\"id\";s:8:\"language\";s:5:\"table\";s:8:\"redirect\";s:5:\"field\";s:8:\"language\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"language_op\";s:5:\"label\";s:17:\"Original language\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"language_op\";s:10:\"identifier\";s:8:\"language\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:8:\"redirect\";s:12:\"entity_field\";s:8:\"language\";s:9:\"plugin_id\";s:8:\"language\";}}s:5:\"sorts\";a:0:{}s:5:\"title\";s:8:\"Redirect\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"There is no redirect yet.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:0:{}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:4:{s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:9:\"cacheable\";b:0;s:7:\"max-age\";i:0;s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:14:\"display_plugin\";s:4:\"page\";s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:28:\"admin/config/search/redirect\";}s:14:\"cache_metadata\";a:4:{s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:9:\"cacheable\";b:0;s:7:\"max-age\";i:0;s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.taxonomy_term',	'a:13:{s:4:\"uuid\";s:36:\"d74333b1-feb4-4d77-9bb9-7230d2bc1f92\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"config\";a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}s:6:\"module\";a:3:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";i:2;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KejdxDJQmx8SaO-t83OVekLw6ar4ldjmsJMGcotGxnQ\";}s:2:\"id\";s:13:\"taxonomy_term\";s:5:\"label\";s:13:\"Taxonomy term\";s:6:\"module\";s:8:\"taxonomy\";s:11:\"description\";s:45:\"Content belonging to a certain taxonomy term.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:15:\"node_field_data\";s:10:\"base_field\";s:3:\"nid\";s:7:\"display\";a:3:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"fields\";a:0:{}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:10;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:2:{s:6:\"sticky\";a:10:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"sticky\";}s:7:\"exposed\";b:0;}s:7:\"created\";a:11:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:1:{s:3:\"tid\";a:22:{s:2:\"id\";s:3:\"tid\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:3:\"tid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:18:\"taxonomy_index_tid\";s:14:\"default_action\";s:9:\"not found\";s:9:\"exception\";a:3:{s:5:\"value\";s:0:\"\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:1;s:5:\"title\";s:19:\"{{ arguments.tid }}\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:8:\"override\";b:0;s:14:\"items_per_page\";i:25;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:1;s:8:\"validate\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:4:{s:7:\"bundles\";a:0:{}s:6:\"access\";b:1;s:9:\"operation\";s:4:\"view\";s:8:\"multiple\";i:0;}s:12:\"break_phrase\";b:0;s:9:\"add_table\";b:0;s:13:\"require_value\";b:0;s:17:\"reduce_duplicates\";b:0;}}s:7:\"filters\";a:2:{s:8:\"langcode\";a:16:{s:2:\"id\";s:8:\"langcode\";s:5:\"table\";s:15:\"node_field_data\";s:5:\"field\";s:8:\"langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"node\";s:12:\"entity_field\";s:8:\"langcode\";s:9:\"plugin_id\";s:8:\"language\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:1:{s:31:\"***LANGUAGE_language_content***\";s:31:\"***LANGUAGE_language_content***\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:6:\"status\";a:14:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:14:\"taxonomy_index\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:7:\"default\";s:7:\"options\";a:4:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:11:\"uses_fields\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:7:\"options\";a:1:{s:9:\"view_mode\";s:6:\"teaser\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:6:\"header\";a:1:{s:20:\"entity_taxonomy_term\";a:12:{s:2:\"id\";s:20:\"entity_taxonomy_term\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:20:\"entity_taxonomy_term\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"entity\";s:5:\"empty\";b:1;s:6:\"target\";s:23:\"{{ raw_arguments.tid }}\";s:9:\"view_mode\";s:4:\"full\";s:8:\"tokenize\";b:1;s:13:\"bypass_access\";b:0;}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"feed_1\";a:6:{s:2:\"id\";s:6:\"feed_1\";s:13:\"display_title\";s:4:\"Feed\";s:14:\"display_plugin\";s:4:\"feed\";s:8:\"position\";i:2;s:15:\"display_options\";a:7:{s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:5:\"style\";a:2:{s:4:\"type\";s:3:\"rss\";s:7:\"options\";a:3:{s:8:\"grouping\";a:0:{}s:11:\"uses_fields\";b:0;s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:2:{s:4:\"type\";s:8:\"node_rss\";s:7:\"options\";a:2:{s:12:\"relationship\";s:4:\"none\";s:9:\"view_mode\";s:7:\"default\";}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:20:\"taxonomy/term/%/feed\";s:8:\"displays\";a:2:{s:6:\"page_1\";s:6:\"page_1\";s:7:\"default\";s:1:\"0\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:4:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:21:\"user.node_grants:view\";i:3;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:0:{}}s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:15:\"taxonomy/term/%\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:28:\"languages:language_interface\";i:1;s:3:\"url\";i:2;s:14:\"url.query_args\";i:3;s:21:\"user.node_grants:view\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.user_admin_people',	'a:13:{s:4:\"uuid\";s:36:\"dd75f214-13a9-43b5-af70-9953d491803c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"FFLg74mnzRE10lgg5fspPCZWLnIEcvCnJMlNzj8OEtw\";}s:2:\"id\";s:17:\"user_admin_people\";s:5:\"label\";s:6:\"People\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:25:{s:5:\"title\";s:6:\"People\";s:6:\"fields\";a:8:{s:14:\"user_bulk_form\";a:23:{s:2:\"id\";s:14:\"user_bulk_form\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:14:\"user_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:14:\"user_bulk_form\";s:5:\"label\";s:11:\"Bulk update\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:8:\"Username\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}s:6:\"status\";a:26:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:6:\"Status\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"custom\";s:19:\"format_custom_false\";s:7:\"Blocked\";s:18:\"format_custom_true\";s:6:\"Active\";}}s:15:\"roles_target_id\";a:24:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:5:\"label\";s:5:\"Roles\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:2:\"ul\";s:9:\"separator\";s:2:\", \";}s:7:\"created\";a:26:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:10:\"Member for\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:9:\"@interval\";s:11:\"past_format\";s:9:\"@interval\";s:11:\"granularity\";i:2;}}s:6:\"access\";a:26:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:11:\"Last access\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:13:\"timestamp_ago\";s:8:\"settings\";a:3:{s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;}}s:10:\"operations\";a:24:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:5:\"users\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:17:\"entity_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;}s:4:\"mail\";a:37:{s:2:\"id\";s:4:\"mail\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"mail\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"mail\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:12:\"basic_string\";s:8:\"settings\";a:0:{}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";i:0;s:2:\"id\";i:0;s:4:\"tags\";a:4:{s:4:\"next\";s:8:\"Next ›\";s:8:\"previous\";s:12:\"‹ Previous\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:16:\"administer users\";}}s:5:\"cache\";a:1:{s:4:\"type\";s:3:\"tag\";}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:20:\"No people available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:7:\"filters\";a:6:{s:7:\"combine\";a:15:{s:2:\"id\";s:7:\"combine\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"combine\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:7:\"combine\";s:8:\"operator\";s:8:\"contains\";s:5:\"value\";s:0:\"\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:10:\"combine_op\";s:5:\"label\";s:22:\"Name or email contains\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:10:\"combine_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"user\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:6:\"fields\";a:2:{s:4:\"name\";s:4:\"name\";s:4:\"mail\";s:4:\"mail\";}}s:6:\"status\";a:16:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"status_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"status\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:1;s:10:\"group_info\";a:10:{s:5:\"label\";s:6:\"Status\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:6:\"status\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:2:{i:1;a:3:{s:5:\"title\";s:6:\"Active\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";}i:2;a:3:{s:5:\"title\";s:7:\"Blocked\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"0\";}}}}s:15:\"roles_target_id\";a:15:{s:2:\"id\";s:15:\"roles_target_id\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:15:\"roles_target_id\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:10:\"user_roles\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:18:\"roles_target_id_op\";s:5:\"label\";s:4:\"Role\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:18:\"roles_target_id_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"role\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:10:\"permission\";a:15:{s:2:\"id\";s:10:\"permission\";s:5:\"table\";s:11:\"user__roles\";s:5:\"field\";s:10:\"permission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"user_permissions\";s:8:\"operator\";s:2:\"or\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:13:\"permission_op\";s:5:\"label\";s:10:\"Permission\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:13:\"permission_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:10:\"permission\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:17:\"reduce_duplicates\";b:0;}s:16:\"default_langcode\";a:16:{s:2:\"id\";s:16:\"default_langcode\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:16:\"default_langcode\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:16:\"default_langcode\";s:9:\"plugin_id\";s:7:\"boolean\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:7:\"uid_raw\";a:15:{s:2:\"id\";s:7:\"uid_raw\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"uid_raw\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:9:\"plugin_id\";s:7:\"numeric\";s:8:\"operator\";s:2:\"!=\";s:5:\"value\";a:3:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:1:\"0\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:10:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:14:\"user_bulk_form\";s:14:\"user_bulk_form\";s:4:\"name\";s:4:\"name\";s:6:\"status\";s:6:\"status\";s:3:\"rid\";s:3:\"rid\";s:7:\"created\";s:7:\"created\";s:6:\"access\";s:6:\"access\";s:9:\"edit_node\";s:9:\"edit_node\";s:10:\"dropbutton\";s:10:\"dropbutton\";}s:7:\"default\";s:7:\"created\";s:4:\"info\";a:8:{s:14:\"user_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"status\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:3:\"rid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:6:\"access\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:9:\"edit_node\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:10:\"dropbutton\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:1;}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:9:\"css_class\";s:0:\"\";s:8:\"use_ajax\";b:0;s:8:\"group_by\";b:0;s:16:\"show_admin_links\";b:1;s:8:\"use_more\";b:0;s:15:\"use_more_always\";b:0;s:13:\"use_more_text\";s:4:\"more\";s:12:\"link_display\";s:6:\"page_1\";s:8:\"link_url\";s:0:\"\";s:15:\"display_comment\";s:0:\"\";s:23:\"hide_attachment_summary\";b:0;s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:6:\"page_1\";a:6:{s:2:\"id\";s:6:\"page_1\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:6:{s:8:\"defaults\";a:1:{s:16:\"show_admin_links\";b:0;}s:16:\"show_admin_links\";b:0;s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:17:\"admin/people/list\";s:4:\"menu\";a:6:{s:4:\"type\";s:11:\"default tab\";s:5:\"title\";s:4:\"List\";s:11:\"description\";s:50:\"Find and manage people interacting with your site.\";s:6:\"weight\";i:-10;s:9:\"menu_name\";s:5:\"admin\";s:7:\"context\";s:0:\"\";}s:11:\"tab_options\";a:5:{s:4:\"type\";s:6:\"normal\";s:5:\"title\";s:6:\"People\";s:11:\"description\";s:45:\"Manage user accounts, roles, and permissions.\";s:6:\"weight\";i:0;s:9:\"menu_name\";s:5:\"admin\";}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.watchdog',	'a:13:{s:4:\"uuid\";s:36:\"1d71a232-99d5-4253-868e-76836877a513\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"dblog\";i:1;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SR5P89f0vUTPC7WY2YpLAffkDx8-Ar8LKFfowVXeqNU\";}s:2:\"id\";s:8:\"watchdog\";s:5:\"label\";s:8:\"Watchdog\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:19:\"Recent log messages\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:8:\"watchdog\";s:10:\"base_field\";s:3:\"wid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:19:{s:5:\"title\";s:19:\"Recent log messages\";s:6:\"fields\";a:8:{s:7:\"nothing\";a:22:{s:2:\"id\";s:7:\"nothing\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:7:\"nothing\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"Icon\";s:9:\"plugin_id\";s:6:\"custom\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:1;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:4:\"icon\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:0;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:0;}s:3:\"wid\";a:22:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:3:\"WID\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:8:\"severity\";a:23:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:12:\"machine_name\";s:5:\"label\";s:8:\"Severity\";s:7:\"exclude\";b:1;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"machine_name\";b:0;}s:4:\"type\";a:22:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"label\";s:4:\"Type\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}s:9:\"timestamp\";a:25:{s:2:\"id\";s:9:\"timestamp\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:9:\"timestamp\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"label\";s:4:\"Date\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"date_format\";s:5:\"short\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";}s:7:\"message\";a:23:{s:2:\"id\";s:7:\"message\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:7:\"message\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:13:\"dblog_message\";s:5:\"label\";s:7:\"Message\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:1;s:4:\"path\";s:35:\"admin/reports/dblog/event/{{ wid }}\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:13:\"{{ message }}\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:56;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:1;s:4:\"trim\";b:1;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:1;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"replace_variables\";b:1;}s:4:\"name\";a:37:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:3:\"uid\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:4:\"User\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"user_name\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;}s:4:\"link\";a:22:{s:2:\"id\";s:4:\"link\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"link\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:16:\"dblog_operations\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"mini\";s:7:\"options\";a:7:{s:6:\"offset\";i:0;s:24:\"pagination_heading_level\";s:2:\"h4\";s:14:\"items_per_page\";i:50;s:11:\"total_pages\";N;s:2:\"id\";i:0;s:4:\"tags\";a:2:{s:4:\"next\";s:6:\"››\";s:8:\"previous\";s:6:\"‹‹\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:13:\"5, 10, 25, 50\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:6:\"Filter\";s:12:\"reset_button\";b:1;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:0;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:19:\"access site reports\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:4:\"area\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:26:\"No log messages available.\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:26:\"No log messages available.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:3:\"wid\";a:10:{s:2:\"id\";s:3:\"wid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"wid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:8:\"standard\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:3:\"wid\";}s:7:\"exposed\";b:0;}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:4:\"type\";a:14:{s:2:\"id\";s:4:\"type\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:4:\"type\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"dblog_types\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:7:\"type_op\";s:5:\"label\";s:4:\"Type\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:7:\"type_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:4:\"type\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}s:8:\"severity\";a:14:{s:2:\"id\";s:8:\"severity\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:8:\"severity\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"in_operator\";s:8:\"operator\";s:2:\"in\";s:5:\"value\";a:0:{}s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:13:{s:11:\"operator_id\";s:11:\"severity_op\";s:5:\"label\";s:8:\"Severity\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"severity_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:8:\"severity\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:1;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:6:\"reduce\";b:0;}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:25:\"{{ type }} {{ severity }}\";s:17:\"default_row_class\";b:1;s:7:\"columns\";a:8:{s:7:\"nothing\";s:7:\"nothing\";s:3:\"wid\";s:3:\"wid\";s:8:\"severity\";s:8:\"severity\";s:4:\"type\";s:4:\"type\";s:9:\"timestamp\";s:9:\"timestamp\";s:7:\"message\";s:7:\"message\";s:4:\"name\";s:4:\"name\";s:4:\"link\";s:4:\"link\";}s:7:\"default\";s:3:\"wid\";s:4:\"info\";a:8:{s:7:\"nothing\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:3:\"wid\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:8:\"severity\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:4:\"type\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:9:\"timestamp\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}s:7:\"message\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:4:\"name\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:15:\"priority-medium\";}s:4:\"link\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:12:\"priority-low\";}}s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"summary\";s:0:\"\";s:11:\"empty_table\";b:0;s:7:\"caption\";s:0:\"\";s:11:\"description\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:1:{s:3:\"uid\";a:8:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:8:\"watchdog\";s:5:\"field\";s:3:\"uid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:4:\"User\";s:9:\"plugin_id\";s:8:\"standard\";s:8:\"required\";b:0;}}s:9:\"css_class\";s:11:\"admin-dblog\";s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:4:\"page\";a:6:{s:2:\"id\";s:4:\"page\";s:13:\"display_title\";s:4:\"Page\";s:14:\"display_plugin\";s:4:\"page\";s:8:\"position\";i:1;s:15:\"display_options\";a:2:{s:17:\"display_extenders\";a:0:{}s:4:\"path\";s:19:\"admin/reports/dblog\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.webform_submissions',	'a:13:{s:4:\"uuid\";s:36:\"5c298710-8d19-4662-a5cc-dcd249b03b1d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"user\";i:1;s:7:\"webform\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ndr5pjyhumlySBPBZtyaztiGbMUclmN32B3nTQ-FRqE\";}s:2:\"id\";s:19:\"webform_submissions\";s:5:\"label\";s:19:\"Webform submissions\";s:6:\"module\";s:5:\"views\";s:11:\"description\";s:34:\"Default webform submissions views.\";s:3:\"tag\";s:0:\"\";s:10:\"base_table\";s:18:\"webform_submission\";s:10:\"base_field\";s:3:\"sid\";s:7:\"display\";a:5:{s:7:\"default\";a:6:{s:14:\"display_plugin\";s:7:\"default\";s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:6:\"Master\";s:8:\"position\";i:0;s:15:\"display_options\";a:18:{s:6:\"access\";a:2:{s:4:\"type\";s:4:\"none\";s:7:\"options\";a:0:{}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:13:\"query_comment\";s:0:\"\";s:10:\"query_tags\";a:0:{}}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"full\";s:7:\"options\";a:8:{s:14:\"items_per_page\";i:25;s:6:\"offset\";i:0;s:2:\"id\";i:0;s:11:\"total_pages\";N;s:4:\"tags\";a:4:{s:8:\"previous\";s:6:\"‹‹\";s:4:\"next\";s:6:\"››\";s:5:\"first\";s:8:\"« First\";s:4:\"last\";s:7:\"Last »\";}s:6:\"expose\";a:7:{s:14:\"items_per_page\";b:0;s:20:\"items_per_page_label\";s:14:\"Items per page\";s:22:\"items_per_page_options\";s:23:\"5, 10, 25, 50, 100, 200\";s:26:\"items_per_page_options_all\";b:0;s:32:\"items_per_page_options_all_label\";s:7:\"- All -\";s:6:\"offset\";b:0;s:12:\"offset_label\";s:6:\"Offset\";}s:8:\"quantity\";i:9;s:24:\"pagination_heading_level\";s:2:\"h4\";}}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"fields\";a:5:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:7:\"filters\";a:0:{}s:5:\"sorts\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:0;s:7:\"content\";s:34:\"Displaying @start - @end of @total\";s:9:\"plugin_id\";s:6:\"result\";}}s:6:\"footer\";a:0:{}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"empty\";b:1;s:8:\"tokenize\";b:0;s:7:\"content\";s:25:\"No submissions available.\";s:9:\"plugin_id\";s:11:\"text_custom\";}}s:13:\"relationships\";a:0:{}s:9:\"arguments\";a:5:{s:10:\"webform_id\";a:6:{s:2:\"id\";s:10:\"webform_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"webform_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:10:\"webform_id\";s:9:\"plugin_id\";s:6:\"string\";}s:11:\"entity_type\";a:6:{s:2:\"id\";s:11:\"entity_type\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"entity_type\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"entity_type\";s:9:\"plugin_id\";s:6:\"string\";}s:9:\"entity_id\";a:6:{s:2:\"id\";s:9:\"entity_id\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"entity_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"entity_id\";s:9:\"plugin_id\";s:6:\"string\";}s:3:\"uid\";a:6:{s:2:\"id\";s:3:\"uid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"uid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"uid\";s:9:\"plugin_id\";s:7:\"numeric\";}s:8:\"in_draft\";a:22:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:14:\"default_action\";s:6:\"ignore\";s:9:\"exception\";a:3:{s:5:\"value\";s:3:\"all\";s:12:\"title_enable\";b:0;s:5:\"title\";s:3:\"All\";}s:12:\"title_enable\";b:0;s:5:\"title\";s:0:\"\";s:21:\"default_argument_type\";s:5:\"fixed\";s:24:\"default_argument_options\";a:1:{s:8:\"argument\";s:0:\"\";}s:15:\"summary_options\";a:4:{s:9:\"base_path\";s:0:\"\";s:5:\"count\";b:1;s:14:\"items_per_page\";i:25;s:8:\"override\";b:0;}s:7:\"summary\";a:3:{s:10:\"sort_order\";s:3:\"asc\";s:17:\"number_of_records\";i:0;s:6:\"format\";s:15:\"default_summary\";}s:18:\"specify_validation\";b:0;s:8:\"validate\";a:2:{s:4:\"type\";s:4:\"none\";s:4:\"fail\";s:9:\"not found\";}s:16:\"validate_options\";a:0:{}s:12:\"break_phrase\";b:0;s:3:\"not\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"numeric\";}}s:17:\"display_extenders\";a:0:{}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:0:{}}s:5:\"title\";s:19:\"Webform submissions\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:16:\"embed_administer\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:16:\"embed_administer\";s:13:\"display_title\";s:17:\"Embed: Administer\";s:8:\"position\";i:2;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:23:\"Administer submissions.\";s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:8:\"defaults\";a:6:{s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:6:\"fields\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:29:\"administer webform submission\";}}s:6:\"fields\";a:9:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"exclude\";s:16:\"selected_actions\";a:0:{}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:10:\"operations\";a:25:{s:2:\"id\";s:10:\"operations\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:10:\"operations\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:11:\"destination\";b:1;s:11:\"entity_type\";N;s:12:\"entity_field\";N;s:9:\"plugin_id\";s:17:\"entity_operations\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:13:\"embed_default\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:13:\"embed_default\";s:13:\"display_title\";s:14:\"Embed: Default\";s:8:\"position\";i:1;s:15:\"display_options\";a:5:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:20:\"Display submissions.\";s:8:\"defaults\";a:5:{s:6:\"fields\";b:1;s:5:\"style\";b:0;s:3:\"row\";b:0;s:7:\"filters\";b:1;s:13:\"filter_groups\";b:1;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:5:{s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:7:\"created\";s:7:\"created\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:5:{s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:5:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_manage\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_manage\";s:13:\"display_title\";s:13:\"Embed: Manage\";s:8:\"position\";i:3;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Manage submissions.\";s:6:\"fields\";a:10:{s:28:\"webform_submission_bulk_form\";a:26:{s:2:\"id\";s:28:\"webform_submission_bulk_form\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:28:\"webform_submission_bulk_form\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:39:\"Webform submission operations bulk form\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:12:\"action_title\";s:6:\"Action\";s:15:\"include_exclude\";s:7:\"include\";s:16:\"selected_actions\";a:4:{i:0;s:35:\"webform_submission_make_lock_action\";i:1;s:37:\"webform_submission_make_sticky_action\";i:2;s:37:\"webform_submission_make_unlock_action\";i:3;s:39:\"webform_submission_make_unsticky_action\";}s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:28:\"webform_submission_bulk_form\";}s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}s:23:\"edit_webform_submission\";a:26:{s:2:\"id\";s:23:\"edit_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"edit_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"edit\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:16:\"entity_link_edit\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"edit any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:0;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:12:\"embed_review\";a:6:{s:14:\"display_plugin\";s:5:\"embed\";s:2:\"id\";s:12:\"embed_review\";s:13:\"display_title\";s:13:\"Embed: Review\";s:8:\"position\";i:4;s:15:\"display_options\";a:9:{s:17:\"display_extenders\";a:0:{}s:19:\"display_description\";s:19:\"Review submissions.\";s:6:\"fields\";a:8:{s:3:\"sid\";a:37:{s:2:\"id\";s:3:\"sid\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:3:\"sid\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:1:\"#\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:14:\"number_integer\";s:8:\"settings\";a:2:{s:18:\"thousand_separator\";s:0:\"\";s:13:\"prefix_suffix\";b:1;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:3:\"sid\";s:9:\"plugin_id\";s:5:\"field\";}s:8:\"in_draft\";a:37:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:5:\"Draft\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"sticky\";a:37:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:5:\"field\";}s:6:\"locked\";a:37:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:7:\"boolean\";s:8:\"settings\";a:3:{s:6:\"format\";s:6:\"yes-no\";s:18:\"format_custom_true\";s:0:\"\";s:19:\"format_custom_false\";s:0:\"\";}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:5:\"field\";}s:7:\"created\";a:37:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:7:\"Created\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:0;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:5:\"field\";}s:9:\"completed\";a:37:{s:2:\"id\";s:9:\"completed\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:9:\"completed\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:9:\"Completed\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:9:\"timestamp\";s:8:\"settings\";a:5:{s:11:\"date_format\";s:6:\"medium\";s:18:\"custom_date_format\";s:0:\"\";s:8:\"timezone\";s:0:\"\";s:7:\"tooltip\";a:2:{s:11:\"date_format\";s:0:\"\";s:18:\"custom_date_format\";s:0:\"\";}s:9:\"time_diff\";a:5:{s:7:\"enabled\";b:0;s:13:\"future_format\";s:15:\"@interval hence\";s:11:\"past_format\";s:13:\"@interval ago\";s:11:\"granularity\";i:2;s:7:\"refresh\";i:60;}}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:9:\"completed\";s:9:\"plugin_id\";s:5:\"field\";}s:11:\"remote_addr\";a:37:{s:2:\"id\";s:11:\"remote_addr\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:11:\"remote_addr\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"IP address\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:17:\"click_sort_column\";s:5:\"value\";s:4:\"type\";s:6:\"string\";s:8:\"settings\";a:1:{s:14:\"link_to_entity\";b:0;}s:12:\"group_column\";s:5:\"value\";s:13:\"group_columns\";a:0:{}s:10:\"group_rows\";b:1;s:11:\"delta_limit\";i:0;s:12:\"delta_offset\";i:0;s:14:\"delta_reversed\";b:0;s:16:\"delta_first_last\";b:0;s:10:\"multi_type\";s:9:\"separator\";s:9:\"separator\";s:2:\", \";s:17:\"field_api_classes\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:11:\"remote_addr\";s:9:\"plugin_id\";s:5:\"field\";}s:23:\"view_webform_submission\";a:26:{s:2:\"id\";s:23:\"view_webform_submission\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:23:\"view_webform_submission\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:5:\"label\";s:10:\"Operations\";s:7:\"exclude\";b:0;s:5:\"alter\";a:26:{s:10:\"alter_text\";b:0;s:4:\"text\";s:0:\"\";s:9:\"make_link\";b:0;s:4:\"path\";s:0:\"\";s:8:\"absolute\";b:0;s:8:\"external\";b:0;s:14:\"replace_spaces\";b:0;s:9:\"path_case\";s:4:\"none\";s:15:\"trim_whitespace\";b:0;s:3:\"alt\";s:0:\"\";s:3:\"rel\";s:0:\"\";s:10:\"link_class\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";s:6:\"target\";s:0:\"\";s:5:\"nl2br\";b:0;s:10:\"max_length\";i:0;s:13:\"word_boundary\";b:1;s:8:\"ellipsis\";b:1;s:9:\"more_link\";b:0;s:14:\"more_link_text\";s:0:\"\";s:14:\"more_link_path\";s:0:\"\";s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:13:\"preserve_tags\";s:0:\"\";s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"text\";s:4:\"view\";s:18:\"output_url_as_text\";b:0;s:8:\"absolute\";b:0;s:11:\"entity_type\";s:18:\"webform_submission\";s:9:\"plugin_id\";s:11:\"entity_link\";}}s:8:\"defaults\";a:6:{s:6:\"fields\";b:0;s:5:\"style\";b:0;s:3:\"row\";b:0;s:6:\"access\";b:0;s:7:\"filters\";b:0;s:13:\"filter_groups\";b:0;}s:5:\"style\";a:2:{s:4:\"type\";s:5:\"table\";s:7:\"options\";a:12:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:8:\"override\";b:1;s:6:\"sticky\";b:0;s:7:\"caption\";s:0:\"\";s:7:\"summary\";s:0:\"\";s:11:\"description\";s:0:\"\";s:7:\"columns\";a:10:{s:28:\"webform_submission_bulk_form\";s:28:\"webform_submission_bulk_form\";s:3:\"sid\";s:3:\"sid\";s:8:\"in_draft\";s:8:\"in_draft\";s:6:\"sticky\";s:6:\"sticky\";s:6:\"locked\";s:6:\"locked\";s:7:\"created\";s:7:\"created\";s:9:\"completed\";s:9:\"completed\";s:11:\"remote_addr\";s:11:\"remote_addr\";s:23:\"view_webform_submission\";s:23:\"view_webform_submission\";s:23:\"edit_webform_submission\";s:23:\"view_webform_submission\";}s:4:\"info\";a:10:{s:28:\"webform_submission_bulk_form\";a:4:{s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:3:\"sid\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:8:\"in_draft\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"sticky\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:6:\"locked\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:7:\"created\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:4:\"desc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:9:\"completed\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:11:\"remote_addr\";a:6:{s:8:\"sortable\";b:1;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"view_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:1:\" \";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}s:23:\"edit_webform_submission\";a:6:{s:8:\"sortable\";b:0;s:18:\"default_sort_order\";s:3:\"asc\";s:5:\"align\";s:0:\"\";s:9:\"separator\";s:0:\"\";s:12:\"empty_column\";b:0;s:10:\"responsive\";s:0:\"\";}}s:7:\"default\";s:7:\"created\";s:11:\"empty_table\";b:0;}}s:3:\"row\";a:2:{s:4:\"type\";s:6:\"fields\";s:7:\"options\";a:4:{s:6:\"inline\";a:0:{}s:9:\"separator\";s:0:\"\";s:10:\"hide_empty\";b:0;s:22:\"default_field_elements\";b:1;}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:27:\"view any webform submission\";}}s:7:\"filters\";a:3:{s:8:\"in_draft\";a:16:{s:2:\"id\";s:8:\"in_draft\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:8:\"in_draft\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:8:\"Is draft\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:11:\"in_draft_op\";s:10:\"identifier\";s:8:\"in_draft\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:8:\"in_draft\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"sticky\";a:16:{s:2:\"id\";s:6:\"sticky\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"sticky\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Sticky\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"sticky_op\";s:10:\"identifier\";s:6:\"sticky\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"sticky\";s:9:\"plugin_id\";s:7:\"boolean\";}s:6:\"locked\";a:16:{s:2:\"id\";s:6:\"locked\";s:5:\"table\";s:18:\"webform_submission\";s:5:\"field\";s:6:\"locked\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:8:\"operator\";s:1:\"=\";s:5:\"value\";s:3:\"All\";s:5:\"group\";i:1;s:7:\"exposed\";b:1;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:0:\"\";s:5:\"label\";s:6:\"Locked\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"locked_op\";s:10:\"identifier\";s:6:\"locked\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:4:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";s:11:\"demo_region\";s:1:\"0\";}s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}s:11:\"entity_type\";s:18:\"webform_submission\";s:12:\"entity_field\";s:6:\"locked\";s:9:\"plugin_id\";s:7:\"boolean\";}}s:13:\"filter_groups\";a:2:{s:8:\"operator\";s:3:\"AND\";s:6:\"groups\";a:1:{i:1;s:3:\"AND\";}}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:6:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:3:\"url\";i:3;s:14:\"url.query_args\";i:4;s:4:\"user\";i:5;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.who_s_new',	'a:13:{s:4:\"uuid\";s:36:\"a7f5e956-bb75-4caf-908d-26f2bf0d1ceb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zji0_13MyVGK7Bn1lUMDeZyyOIZedWvqpYUeM_SioPI\";}s:2:\"id\";s:9:\"who_s_new\";s:5:\"label\";s:9:\"Who\'s new\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:53:\"Shows a list of the newest user accounts on the site.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:9:\"Who\'s new\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:5;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:14:\"access content\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:0:{}s:5:\"sorts\";a:1:{s:7:\"created\";a:13:{s:2:\"id\";s:7:\"created\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:7:\"created\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:7:\"created\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:7:\"created\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:1:\">\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:10:\"1970-01-01\";s:4:\"type\";s:4:\"date\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:1:\"0\";s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:0:\"\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:0:\"\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:1:{s:13:\"authenticated\";s:13:\"authenticated\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:1:{s:4:\"type\";s:9:\"html_list\";}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:0:{}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:7:\"block_1\";a:6:{s:2:\"id\";s:7:\"block_1\";s:13:\"display_title\";s:9:\"Who\'s new\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:4:{s:19:\"display_description\";s:19:\"A list of new users\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:9:\"Who\'s new\";s:14:\"block_category\";s:4:\"User\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'views.view.who_s_online',	'a:13:{s:4:\"uuid\";s:36:\"c473d286-cede-440e-97e5-6d2909d58b05\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:4:\"user\";}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"suDsVMgawXoQt4rfmdfpr05EVX3z3KyfDDTYgeSM898\";}s:2:\"id\";s:12:\"who_s_online\";s:5:\"label\";s:18:\"Who\'s online block\";s:6:\"module\";s:4:\"user\";s:11:\"description\";s:93:\"Shows the user names of the most recently active users, and the total number of active users.\";s:3:\"tag\";s:7:\"default\";s:10:\"base_table\";s:16:\"users_field_data\";s:10:\"base_field\";s:3:\"uid\";s:7:\"display\";a:2:{s:7:\"default\";a:6:{s:2:\"id\";s:7:\"default\";s:13:\"display_title\";s:7:\"Default\";s:14:\"display_plugin\";s:7:\"default\";s:8:\"position\";i:0;s:15:\"display_options\";a:17:{s:5:\"title\";s:12:\"Who\'s online\";s:6:\"fields\";a:1:{s:4:\"name\";a:25:{s:2:\"id\";s:4:\"name\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:4:\"name\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:4:\"name\";s:9:\"plugin_id\";s:5:\"field\";s:5:\"label\";s:0:\"\";s:7:\"exclude\";b:0;s:5:\"alter\";a:8:{s:10:\"alter_text\";b:0;s:9:\"make_link\";b:0;s:8:\"absolute\";b:0;s:13:\"word_boundary\";b:0;s:8:\"ellipsis\";b:0;s:10:\"strip_tags\";b:0;s:4:\"trim\";b:0;s:4:\"html\";b:0;}s:12:\"element_type\";s:0:\"\";s:13:\"element_class\";s:0:\"\";s:18:\"element_label_type\";s:0:\"\";s:19:\"element_label_class\";s:0:\"\";s:19:\"element_label_colon\";b:1;s:20:\"element_wrapper_type\";s:0:\"\";s:21:\"element_wrapper_class\";s:0:\"\";s:23:\"element_default_classes\";b:1;s:5:\"empty\";s:0:\"\";s:10:\"hide_empty\";b:0;s:10:\"empty_zero\";b:0;s:16:\"hide_alter_empty\";b:1;s:4:\"type\";s:9:\"user_name\";}}s:5:\"pager\";a:2:{s:4:\"type\";s:4:\"some\";s:7:\"options\";a:2:{s:6:\"offset\";i:0;s:14:\"items_per_page\";i:10;}}s:12:\"exposed_form\";a:2:{s:4:\"type\";s:5:\"basic\";s:7:\"options\";a:7:{s:13:\"submit_button\";s:5:\"Apply\";s:12:\"reset_button\";b:0;s:18:\"reset_button_label\";s:5:\"Reset\";s:19:\"exposed_sorts_label\";s:7:\"Sort by\";s:17:\"expose_sort_order\";b:1;s:14:\"sort_asc_label\";s:3:\"Asc\";s:15:\"sort_desc_label\";s:4:\"Desc\";}}s:6:\"access\";a:2:{s:4:\"type\";s:4:\"perm\";s:7:\"options\";a:1:{s:4:\"perm\";s:20:\"access user profiles\";}}s:5:\"cache\";a:2:{s:4:\"type\";s:3:\"tag\";s:7:\"options\";a:0:{}}s:5:\"empty\";a:1:{s:16:\"area_text_custom\";a:10:{s:2:\"id\";s:16:\"area_text_custom\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:16:\"area_text_custom\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:11:\"text_custom\";s:5:\"empty\";b:1;s:7:\"content\";s:35:\"There are currently 0 users online.\";s:8:\"tokenize\";b:0;}}s:5:\"sorts\";a:1:{s:6:\"access\";a:13:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:5:\"order\";s:4:\"DESC\";s:6:\"expose\";a:2:{s:5:\"label\";s:0:\"\";s:16:\"field_identifier\";s:6:\"access\";}s:7:\"exposed\";b:0;s:11:\"granularity\";s:6:\"second\";}}s:9:\"arguments\";a:0:{}s:7:\"filters\";a:2:{s:6:\"status\";a:9:{s:2:\"id\";s:6:\"status\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"status\";s:9:\"plugin_id\";s:7:\"boolean\";s:5:\"value\";s:1:\"1\";s:5:\"group\";i:1;s:6:\"expose\";a:3:{s:8:\"operator\";s:1:\"0\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}}}s:6:\"access\";a:16:{s:2:\"id\";s:6:\"access\";s:5:\"table\";s:16:\"users_field_data\";s:5:\"field\";s:6:\"access\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:11:\"entity_type\";s:4:\"user\";s:12:\"entity_field\";s:6:\"access\";s:9:\"plugin_id\";s:4:\"date\";s:8:\"operator\";s:2:\">=\";s:5:\"value\";a:4:{s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:5:\"value\";s:11:\"-15 minutes\";s:4:\"type\";s:6:\"offset\";}s:5:\"group\";i:1;s:7:\"exposed\";b:0;s:6:\"expose\";a:12:{s:11:\"operator_id\";s:9:\"access_op\";s:5:\"label\";s:11:\"Last access\";s:11:\"description\";s:77:\"A user is considered online for this long after they have last viewed a page.\";s:12:\"use_operator\";b:0;s:8:\"operator\";s:9:\"access_op\";s:24:\"operator_limit_selection\";b:0;s:13:\"operator_list\";a:0:{}s:10:\"identifier\";s:6:\"access\";s:8:\"required\";b:0;s:8:\"remember\";b:0;s:8:\"multiple\";b:0;s:14:\"remember_roles\";a:3:{s:13:\"authenticated\";s:13:\"authenticated\";s:9:\"anonymous\";s:1:\"0\";s:13:\"administrator\";s:1:\"0\";}}s:10:\"is_grouped\";b:0;s:10:\"group_info\";a:10:{s:5:\"label\";s:0:\"\";s:11:\"description\";s:0:\"\";s:10:\"identifier\";s:0:\"\";s:8:\"optional\";b:1;s:6:\"widget\";s:6:\"select\";s:8:\"multiple\";b:0;s:8:\"remember\";b:0;s:13:\"default_group\";s:3:\"All\";s:22:\"default_group_multiple\";a:0:{}s:11:\"group_items\";a:0:{}}}}s:5:\"style\";a:2:{s:4:\"type\";s:9:\"html_list\";s:7:\"options\";a:6:{s:8:\"grouping\";a:0:{}s:9:\"row_class\";s:0:\"\";s:17:\"default_row_class\";b:1;s:4:\"type\";s:2:\"ul\";s:13:\"wrapper_class\";s:9:\"item-list\";s:5:\"class\";s:0:\"\";}}s:3:\"row\";a:1:{s:4:\"type\";s:6:\"fields\";}s:5:\"query\";a:2:{s:4:\"type\";s:11:\"views_query\";s:7:\"options\";a:5:{s:13:\"query_comment\";s:0:\"\";s:19:\"disable_sql_rewrite\";b:0;s:8:\"distinct\";b:0;s:7:\"replica\";b:0;s:10:\"query_tags\";a:0:{}}}s:13:\"relationships\";a:0:{}s:6:\"header\";a:1:{s:6:\"result\";a:9:{s:2:\"id\";s:6:\"result\";s:5:\"table\";s:5:\"views\";s:5:\"field\";s:6:\"result\";s:12:\"relationship\";s:4:\"none\";s:10:\"group_type\";s:5:\"group\";s:11:\"admin_label\";s:0:\"\";s:9:\"plugin_id\";s:6:\"result\";s:5:\"empty\";b:0;s:7:\"content\";s:40:\"There are currently @total users online.\";}}s:6:\"footer\";a:0:{}s:17:\"display_extenders\";a:0:{}}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}s:18:\"who_s_online_block\";a:6:{s:2:\"id\";s:18:\"who_s_online_block\";s:13:\"display_title\";s:12:\"Who\'s online\";s:14:\"display_plugin\";s:5:\"block\";s:8:\"position\";i:1;s:15:\"display_options\";a:3:{s:19:\"display_description\";s:45:\"A list of users that are currently logged in.\";s:17:\"display_extenders\";a:0:{}s:17:\"block_description\";s:12:\"Who\'s online\";}s:14:\"cache_metadata\";a:3:{s:7:\"max-age\";i:-1;s:8:\"contexts\";a:3:{i:0;s:26:\"languages:language_content\";i:1;s:28:\"languages:language_interface\";i:2;s:16:\"user.permissions\";}s:4:\"tags\";a:0:{}}}}}'),
('',	'webform.settings',	'a:20:{s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eZgcriT-utjDI1pjl-24jYFW2DmCxMXaFSnJd0XoU-0\";}s:8:\"settings\";a:73:{s:14:\"default_status\";s:4:\"open\";s:18:\"default_categories\";a:0:{}s:12:\"default_page\";b:1;s:22:\"default_page_base_path\";s:5:\"/form\";s:12:\"default_ajax\";b:0;s:19:\"default_ajax_effect\";s:4:\"fade\";s:18:\"default_ajax_speed\";i:500;s:26:\"default_ajax_progress_type\";s:8:\"throbber\";s:25:\"default_form_open_message\";s:49:\"This form has not yet been opened to submissions.\";s:26:\"default_form_close_message\";s:48:\"Sorry… This form is closed to new submissions.\";s:30:\"default_form_exception_message\";s:70:\"Unable to display this webform. Please contact the site administrator.\";s:27:\"default_submit_button_label\";s:6:\"Submit\";s:26:\"default_reset_button_label\";s:5:\"Reset\";s:27:\"default_delete_button_label\";s:6:\"Delete\";s:24:\"default_form_submit_once\";b:0;s:33:\"default_form_confidential_message\";s:135:\"This form is confidential. You must <a href=\"[site:login-url]/logout?destination=[current-page:url:relative]\">Log out</a> to submit it.\";s:34:\"default_form_access_denied_message\";s:34:\"Please log in to access this form.\";s:25:\"default_form_disable_back\";b:0;s:24:\"default_form_submit_back\";b:0;s:20:\"default_form_unsaved\";b:0;s:32:\"default_form_disable_remote_addr\";b:0;s:23:\"default_form_novalidate\";b:0;s:34:\"default_form_disable_inline_errors\";b:0;s:21:\"default_form_required\";b:0;s:27:\"default_form_required_label\";s:24:\"Indicates required field\";s:27:\"default_form_details_toggle\";b:1;s:23:\"default_form_file_limit\";s:0:\"\";s:12:\"form_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:14:\"button_classes\";s:0:\"\";s:32:\"default_wizard_prev_button_label\";s:10:\"< Previous\";s:32:\"default_wizard_next_button_label\";s:6:\"Next >\";s:26:\"default_wizard_start_label\";s:5:\"Start\";s:33:\"default_wizard_confirmation_label\";s:8:\"Complete\";s:32:\"default_wizard_toggle_show_label\";s:8:\"Show all\";s:32:\"default_wizard_toggle_hide_label\";s:8:\"Hide all\";s:33:\"default_preview_next_button_label\";s:7:\"Preview\";s:33:\"default_preview_prev_button_label\";s:10:\"< Previous\";s:21:\"default_preview_label\";s:7:\"Preview\";s:21:\"default_preview_title\";s:24:\"[webform:title]: Preview\";s:23:\"default_preview_message\";s:99:\"Please review your submission. Your submission is not complete until you press the \"Submit\" button!\";s:26:\"default_draft_button_label\";s:10:\"Save Draft\";s:27:\"default_draft_saved_message\";s:91:\"Submission saved. You may return to this form later and it will restore the current values.\";s:28:\"default_draft_loaded_message\";s:77:\"A partially-completed form was found. Please complete the remaining portions.\";s:36:\"default_draft_pending_single_message\";s:83:\"You have a pending draft for this webform. <a href=\"#\">Load your pending draft</a>.\";s:38:\"default_draft_pending_multiple_message\";s:83:\"You have pending drafts for this webform. <a href=\"#\">View your pending drafts</a>.\";s:28:\"default_confirmation_message\";s:40:\"New submission added to [webform:title].\";s:31:\"default_confirmation_back_label\";s:12:\"Back to form\";s:28:\"default_confirmation_noindex\";b:1;s:24:\"default_submission_label\";s:74:\"[webform_submission:submitted-to]: Submission #[webform_submission:serial]\";s:40:\"default_submission_access_denied_message\";s:40:\"Please log in to access this submission.\";s:36:\"default_submission_exception_message\";s:73:\"Unable to process this submission. Please contact the site administrator.\";s:33:\"default_submission_locked_message\";s:32:\"This submission has been locked.\";s:22:\"default_submission_log\";b:0;s:24:\"default_submission_views\";a:0:{}s:32:\"default_submission_views_replace\";a:3:{s:13:\"global_routes\";a:2:{i:0;s:36:\"entity.webform_submission.collection\";i:1;s:30:\"entity.webform_submission.user\";}s:14:\"webform_routes\";a:3:{i:0;s:34:\"entity.webform.results_submissions\";i:1;s:26:\"entity.webform.user.drafts\";i:2;s:31:\"entity.webform.user.submissions\";}s:11:\"node_routes\";a:3:{i:0;s:39:\"entity.node.webform.results_submissions\";i:1;s:31:\"entity.node.webform.user.drafts\";i:2;s:36:\"entity.node.webform.user.submissions\";}}s:25:\"default_results_customize\";b:0;s:35:\"default_previous_submission_message\";s:87:\"You have already submitted this webform. <a href=\"#\">View your previous submission</a>.\";s:36:\"default_previous_submissions_message\";s:88:\"You have already submitted this webform. <a href=\"#\">View your previous submissions</a>.\";s:24:\"default_autofill_message\";s:66:\"This submission has been autofilled with your previous submission.\";s:15:\"preview_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:20:\"confirmation_classes\";s:78:\"messages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:25:\"confirmation_back_classes\";s:7:\"button\n\";s:27:\"default_limit_total_message\";s:34:\"No more submissions are permitted.\";s:26:\"default_limit_user_message\";s:34:\"No more submissions are permitted.\";s:13:\"default_share\";b:0;s:18:\"default_share_node\";b:0;s:24:\"default_share_theme_name\";s:0:\"\";s:6:\"dialog\";b:0;s:14:\"dialog_options\";a:3:{s:6:\"narrow\";a:2:{s:5:\"title\";s:6:\"Narrow\";s:5:\"width\";i:600;}s:6:\"normal\";a:2:{s:5:\"title\";s:6:\"Normal\";s:5:\"width\";i:800;}s:4:\"wide\";a:2:{s:5:\"title\";s:4:\"Wide\";s:5:\"width\";i:1000;}}s:17:\"webform_bulk_form\";b:1;s:25:\"webform_bulk_form_actions\";a:5:{i:0;s:19:\"webform_open_action\";i:1;s:20:\"webform_close_action\";i:2;s:22:\"webform_archive_action\";i:3;s:24:\"webform_unarchive_action\";i:4;s:21:\"webform_delete_action\";}s:28:\"webform_submission_bulk_form\";b:1;s:36:\"webform_submission_bulk_form_actions\";a:5:{i:0;s:37:\"webform_submission_make_sticky_action\";i:1;s:39:\"webform_submission_make_unsticky_action\";i:2;s:35:\"webform_submission_make_lock_action\";i:3;s:37:\"webform_submission_make_unlock_action\";i:4;s:32:\"webform_submission_delete_action\";}}s:6:\"assets\";a:2:{s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";}s:7:\"handler\";a:1:{s:17:\"excluded_handlers\";a:0:{}}s:7:\"variant\";a:1:{s:17:\"excluded_variants\";a:0:{}}s:6:\"export\";a:18:{s:14:\"temp_directory\";s:0:\"\";s:8:\"exporter\";s:9:\"delimited\";s:18:\"multiple_delimiter\";s:1:\";\";s:13:\"header_format\";s:5:\"label\";s:13:\"header_prefix\";b:1;s:29:\"header_prefix_label_delimiter\";s:2:\": \";s:27:\"header_prefix_key_delimiter\";s:2:\"__\";s:29:\"composite_element_item_format\";s:5:\"label\";s:21:\"options_single_format\";s:7:\"compact\";s:23:\"options_multiple_format\";s:7:\"compact\";s:19:\"options_item_format\";s:5:\"label\";s:22:\"entity_reference_items\";a:3:{i:0;s:2:\"id\";i:1;s:5:\"title\";i:2;s:3:\"url\";}s:21:\"likert_answers_format\";s:5:\"label\";s:16:\"signature_format\";s:6:\"status\";s:9:\"delimiter\";s:1:\",\";s:5:\"excel\";b:0;s:12:\"archive_type\";s:3:\"tar\";s:18:\"excluded_exporters\";a:0:{}}s:5:\"batch\";a:5:{s:25:\"default_batch_export_size\";i:500;s:25:\"default_batch_import_size\";i:100;s:25:\"default_batch_update_size\";i:500;s:25:\"default_batch_delete_size\";i:500;s:24:\"default_batch_email_size\";i:500;}s:5:\"purge\";a:1:{s:9:\"cron_size\";i:100;}s:4:\"form\";a:3:{s:5:\"limit\";i:50;s:15:\"filter_category\";s:0:\"\";s:12:\"filter_state\";s:0:\"\";}s:7:\"element\";a:13:{s:20:\"machine_name_pattern\";s:7:\"a-z0-9_\";s:13:\"empty_message\";s:7:\"{Empty}\";s:12:\"allowed_tags\";s:5:\"admin\";s:15:\"wrapper_classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:7:\"classes\";s:126:\"container-inline clearfix\nform--inline clearfix\nmessages messages--error\nmessages messages--warning\nmessages messages--status\n\";s:23:\"horizontal_rule_classes\";s:286:\"webform-horizontal-rule--solid\nwebform-horizontal-rule--dashed\nwebform-horizontal-rule--dotted\nwebform-horizontal-rule--gradient\nwebform-horizontal-rule--thin\nwebform-horizontal-rule--medium\nwebform-horizontal-rule--thick\nwebform-horizontal-rule--flaired\nwebform-horizontal-rule--glyph\n\";s:27:\"default_description_display\";s:0:\"\";s:18:\"default_more_title\";s:4:\"More\";s:25:\"default_section_title_tag\";s:2:\"h2\";s:20:\"default_empty_option\";b:1;s:29:\"default_empty_option_required\";s:0:\"\";s:29:\"default_empty_option_optional\";s:0:\"\";s:17:\"excluded_elements\";a:2:{s:8:\"password\";s:8:\"password\";s:16:\"password_confirm\";s:16:\"password_confirm\";}}s:11:\"html_editor\";a:5:{s:8:\"disabled\";b:0;s:14:\"element_format\";s:15:\"webform_default\";s:11:\"mail_format\";s:15:\"webform_default\";s:4:\"tidy\";b:1;s:35:\"make_unused_managed_files_temporary\";b:1;}s:4:\"file\";a:11:{s:11:\"file_public\";b:0;s:21:\"file_private_redirect\";b:1;s:29:\"file_private_redirect_message\";s:42:\"Please log in to access the uploaded file.\";s:20:\"default_max_filesize\";s:0:\"\";s:31:\"default_managed_file_extensions\";s:148:\"gif jpg jpeg png bmp eps tif pict psd txt rtf html odf pdf doc docx ppt pptx xls xlsx xml avi mov mp3 mp4 ogg wav bz2 dmg gz jar rar sit svg tar zip\";s:29:\"default_audio_file_extensions\";s:11:\"mp3 ogg wav\";s:32:\"default_document_file_extensions\";s:50:\"txt rtf pdf doc docx odt ppt pptx odp xls xlsx ods\";s:29:\"default_image_file_extensions\";s:16:\"gif jpg jpeg png\";s:29:\"default_video_file_extensions\";s:24:\"avi mov mp4 ogg wav webm\";s:35:\"make_unused_managed_files_temporary\";b:1;s:30:\"delete_temporary_managed_files\";b:1;}s:6:\"format\";a:0:{}s:4:\"mail\";a:11:{s:15:\"default_to_mail\";s:11:\"[site:mail]\";s:17:\"default_from_mail\";s:11:\"[site:mail]\";s:17:\"default_from_name\";s:11:\"[site:name]\";s:16:\"default_reply_to\";s:0:\"\";s:19:\"default_return_path\";s:0:\"\";s:19:\"default_sender_mail\";s:0:\"\";s:19:\"default_sender_name\";s:0:\"\";s:15:\"default_subject\";s:58:\"Webform submission from: [webform_submission:source-title]\";s:17:\"default_body_text\";s:133:\"Submitted on [webform_submission:created]\nSubmitted by: [webform_submission:user]\n\nSubmitted values are:\n[webform_submission:values]\n\";s:17:\"default_body_html\";s:153:\"<p>Submitted on [webform_submission:created]</p>\n<p>Submitted by: [webform_submission:user]</p>\n<p>Submitted values are:</p>\n[webform_submission:values]\n\";s:5:\"roles\";a:0:{}}s:4:\"test\";a:2:{s:5:\"types\";s:3347:\"checkbox:\n  - true\ncolor:\n  - \'#ffffcc\'\n  - \'#ffffcc\'\n  - \'#ccffff\'\nemail:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nlanguage_select:\n  - en\nmachine_name:\n  - \'loremipsum\'\n  - \'oratione\'\n  - \'dixisset\'\ntel:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ntextarea:\n  - \'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.\'\n  - \'Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;\'\n  - \'Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.\'\ntext_format:\n  - value: \'<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. Negat esse eam, inquit, propter se expetendam. Primum Theophrasti, Strato, physicum se voluit; Id mihi magnum videtur. Itaque mihi non satis videmini considerare quod iter sit naturae quaeque progressio. Quare hoc videndum est, possitne nobis hoc ratio philosophorum dare. Est enim tanti philosophi tamque nobilis audacter sua decreta defendere.</p>\'\n  - value: \'<p>Huius, Lyco, oratione locuples, rebus ipsis ielunior. Duo Reges: constructio interrete. Sed haec in pueris; Sed utrum hortandus es nobis, Luci, inquit, an etiam tua sponte propensus es? Sapiens autem semper beatus est et est aliquando in dolore; Immo videri fortasse. Paulum, cum regem Persem captum adduceret, eodem flumine invectio? Et ille ridens: Video, inquit, quid agas;</p>\'\n  - value: \'<p>Quae cum dixisset, finem ille. Quamquam non negatis nos intellegere quid sit voluptas, sed quid ille dicat. Progredientibus autem aetatibus sensim tardeve potius quasi nosmet ipsos cognoscimus. Gloriosa ostentatio in constituendo summo bono. Qui-vere falsone, quaerere mittimus-dicitur oculis se privasse; Duarum enim vitarum nobis erunt instituta capienda. Comprehensum, quod cognitum non habet? Qui enim existimabit posse se miserum esse beatus non erit. Causa autem fuit huc veniendi ut quosdam hinc libros promerem. Nunc omni virtuti vitium contrario nomine opponitur.</p>\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\nwebform_email_confirm:\n  - \'example@example.com\'\n  - \'test@test.com\'\n  - \'random@random.com\'\nwebform_email_multiple:\n  - \'example@example.com, test@test.com, random@random.com\'\nwebform_time:\n  - \'09:00\'\n  - \'17:00\'\n\";s:5:\"names\";s:547:\"first_name:\n  - \'John\'\n  - \'Paul\'\n  - \'Ringo\'\n  - \'George\'\nlast_name:\n  - \'Lennon\'\n  - \'McCartney\'\n  - \'Starr\'\n  - \'Harrison\'\naddress:\n  - \'10 Main Street\'\n  - \'11 Brook Alley Road. APT 1\'\nzip:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\npostal_code:\n  - \'11111\'\n  - \'12345\'\n  - \'12345-6789\'\nphone:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\nfax:\n  - \'123-456-7890\'\n  - \'098-765-4321\'\ncity:\n  - \'Springfield\'\n  - \'Pleasantville\'\n  - \'Hill Valley\'\nurl:\n  - \'http://example.com\'\n  - \'http://test.com\'\ndefault:\n  - \'Loremipsum\'\n  - \'Oratione\'\n  - \'Dixisset\'\n\";}s:2:\"ui\";a:9:{s:13:\"video_display\";s:6:\"dialog\";s:12:\"details_save\";b:1;s:13:\"help_disabled\";b:0;s:15:\"dialog_disabled\";b:0;s:18:\"offcanvas_disabled\";b:0;s:19:\"promotions_disabled\";b:0;s:16:\"support_disabled\";b:0;s:16:\"description_help\";b:1;s:12:\"toolbar_item\";b:0;}s:9:\"libraries\";a:1:{s:18:\"excluded_libraries\";a:2:{i:0;s:7:\"choices\";i:1;s:13:\"jquery.chosen\";}}s:12:\"requirements\";a:4:{s:3:\"cdn\";b:1;s:9:\"bootstrap\";b:1;s:21:\"clientside_validation\";b:1;s:4:\"spam\";b:1;}s:8:\"langcode\";s:2:\"en\";s:20:\"third_party_settings\";a:1:{s:7:\"captcha\";a:1:{s:27:\"replace_administration_mode\";b:1;}}}'),
('',	'webform.webform.contact',	'a:22:{s:4:\"uuid\";s:36:\"cff12aaa-4fd4-49c9-bed0-2556200107e6\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";s:4:\"open\";s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"_je-MWeeJB6gfm6iECiqjcyNetfMFbn-YIInYwZ1gIk\";}s:4:\"open\";N;s:5:\"close\";N;s:6:\"weight\";i:0;s:3:\"uid\";N;s:8:\"template\";b:0;s:7:\"archive\";b:0;s:2:\"id\";s:7:\"contact\";s:5:\"title\";s:7:\"Contact\";s:11:\"description\";s:28:\"Basic email contact webform.\";s:10:\"categories\";a:0:{}s:8:\"elements\";s:566:\"name:\n  \'#title\': \'Your Name\'\n  \'#type\': textfield\n  \'#required\': true\n  \'#default_value\': \'[current-user:display-name]\'\nemail:\n  \'#title\': \'Your Email\'\n  \'#type\': email\n  \'#required\': true\n  \'#default_value\': \'[current-user:mail]\'\nsubject:\n  \'#title\': Subject\n  \'#type\': textfield\n  \'#required\': true\n  \'#test\': \'Testing contact webform from [site:name]\'\nmessage:\n  \'#title\': Message\n  \'#type\': textarea\n  \'#required\': true\n  \'#test\': \'Please ignore this email.\'\nactions:\n  \'#type\': webform_actions\n  \'#title\': \'Submit button(s)\'\n  \'#submit__label\': \'Send message\'\n\";s:3:\"css\";s:0:\"\";s:10:\"javascript\";s:0:\"\";s:8:\"settings\";a:133:{s:4:\"ajax\";b:0;s:15:\"ajax_scroll_top\";s:4:\"form\";s:18:\"ajax_progress_type\";s:0:\"\";s:11:\"ajax_effect\";s:0:\"\";s:10:\"ajax_speed\";N;s:4:\"page\";b:1;s:16:\"page_submit_path\";s:0:\"\";s:17:\"page_confirm_path\";s:0:\"\";s:15:\"page_theme_name\";s:0:\"\";s:10:\"form_title\";s:21:\"source_entity_webform\";s:16:\"form_submit_once\";b:0;s:22:\"form_exception_message\";s:0:\"\";s:17:\"form_open_message\";s:0:\"\";s:18:\"form_close_message\";s:0:\"\";s:25:\"form_previous_submissions\";b:1;s:17:\"form_confidential\";b:0;s:25:\"form_confidential_message\";s:0:\"\";s:24:\"form_disable_remote_addr\";b:0;s:22:\"form_convert_anonymous\";b:0;s:16:\"form_prepopulate\";b:0;s:30:\"form_prepopulate_source_entity\";b:0;s:39:\"form_prepopulate_source_entity_required\";b:0;s:35:\"form_prepopulate_source_entity_type\";s:0:\"\";s:10:\"form_reset\";b:0;s:25:\"form_disable_autocomplete\";b:0;s:15:\"form_novalidate\";b:0;s:26:\"form_disable_inline_errors\";b:0;s:13:\"form_required\";b:0;s:12:\"form_unsaved\";b:0;s:17:\"form_disable_back\";b:0;s:16:\"form_submit_back\";b:0;s:14:\"form_autofocus\";b:0;s:19:\"form_details_toggle\";b:0;s:18:\"form_access_denied\";s:7:\"default\";s:24:\"form_access_denied_title\";s:0:\"\";s:26:\"form_access_denied_message\";s:0:\"\";s:29:\"form_access_denied_attributes\";a:0:{}s:15:\"form_file_limit\";s:0:\"\";s:11:\"form_method\";s:0:\"\";s:11:\"form_action\";s:0:\"\";s:15:\"form_attributes\";a:0:{}s:5:\"share\";b:0;s:10:\"share_node\";b:0;s:16:\"share_theme_name\";s:0:\"\";s:11:\"share_title\";b:1;s:26:\"share_page_body_attributes\";a:0:{}s:16:\"submission_label\";s:0:\"\";s:14:\"submission_log\";b:0;s:16:\"submission_views\";a:0:{}s:24:\"submission_views_replace\";a:0:{}s:23:\"submission_user_columns\";a:0:{}s:25:\"submission_user_duplicate\";b:0;s:24:\"submission_access_denied\";s:7:\"default\";s:30:\"submission_access_denied_title\";s:0:\"\";s:32:\"submission_access_denied_message\";s:0:\"\";s:35:\"submission_access_denied_attributes\";a:0:{}s:28:\"submission_exception_message\";s:0:\"\";s:25:\"submission_locked_message\";s:0:\"\";s:28:\"submission_excluded_elements\";a:0:{}s:24:\"submission_exclude_empty\";b:0;s:33:\"submission_exclude_empty_checkbox\";b:0;s:27:\"previous_submission_message\";s:0:\"\";s:28:\"previous_submissions_message\";s:0:\"\";s:8:\"autofill\";b:0;s:16:\"autofill_message\";s:0:\"\";s:26:\"autofill_excluded_elements\";a:0:{}s:19:\"wizard_progress_bar\";b:1;s:21:\"wizard_progress_pages\";b:0;s:26:\"wizard_progress_percentage\";b:0;s:20:\"wizard_progress_link\";b:0;s:22:\"wizard_progress_states\";b:0;s:19:\"wizard_auto_forward\";b:1;s:36:\"wizard_auto_forward_hide_next_button\";b:0;s:15:\"wizard_keyboard\";b:1;s:18:\"wizard_start_label\";s:0:\"\";s:19:\"wizard_preview_link\";b:0;s:19:\"wizard_confirmation\";b:1;s:25:\"wizard_confirmation_label\";s:0:\"\";s:12:\"wizard_track\";s:0:\"\";s:24:\"wizard_prev_button_label\";s:0:\"\";s:24:\"wizard_next_button_label\";s:0:\"\";s:13:\"wizard_toggle\";b:0;s:24:\"wizard_toggle_show_label\";s:0:\"\";s:24:\"wizard_toggle_hide_label\";s:0:\"\";s:16:\"wizard_page_type\";s:9:\"container\";s:21:\"wizard_page_title_tag\";s:2:\"h2\";s:7:\"preview\";i:0;s:13:\"preview_label\";s:0:\"\";s:13:\"preview_title\";s:0:\"\";s:15:\"preview_message\";s:0:\"\";s:18:\"preview_attributes\";a:0:{}s:25:\"preview_excluded_elements\";a:0:{}s:21:\"preview_exclude_empty\";b:1;s:30:\"preview_exclude_empty_checkbox\";b:0;s:5:\"draft\";s:4:\"none\";s:14:\"draft_multiple\";b:0;s:15:\"draft_auto_save\";b:0;s:19:\"draft_saved_message\";s:0:\"\";s:20:\"draft_loaded_message\";s:0:\"\";s:28:\"draft_pending_single_message\";s:0:\"\";s:30:\"draft_pending_multiple_message\";s:0:\"\";s:17:\"confirmation_type\";s:11:\"url_message\";s:18:\"confirmation_title\";s:0:\"\";s:20:\"confirmation_message\";s:27:\"Your message has been sent.\";s:16:\"confirmation_url\";s:7:\"<front>\";s:23:\"confirmation_attributes\";a:0:{}s:17:\"confirmation_back\";b:1;s:23:\"confirmation_back_label\";s:0:\"\";s:28:\"confirmation_back_attributes\";a:0:{}s:26:\"confirmation_exclude_query\";b:0;s:26:\"confirmation_exclude_token\";b:0;s:19:\"confirmation_update\";b:0;s:11:\"limit_total\";N;s:20:\"limit_total_interval\";N;s:19:\"limit_total_message\";s:0:\"\";s:18:\"limit_total_unique\";b:0;s:10:\"limit_user\";N;s:19:\"limit_user_interval\";N;s:18:\"limit_user_message\";s:0:\"\";s:17:\"limit_user_unique\";b:0;s:18:\"entity_limit_total\";N;s:27:\"entity_limit_total_interval\";N;s:17:\"entity_limit_user\";N;s:26:\"entity_limit_user_interval\";N;s:5:\"purge\";s:4:\"none\";s:10:\"purge_days\";N;s:16:\"results_disabled\";b:0;s:23:\"results_disabled_ignore\";b:0;s:17:\"results_customize\";b:0;s:10:\"token_view\";b:0;s:12:\"token_update\";b:0;s:12:\"token_delete\";b:0;s:15:\"serial_disabled\";b:0;}s:6:\"access\";a:11:{s:6:\"create\";a:3:{s:5:\"roles\";a:2:{i:0;s:9:\"anonymous\";i:1;s:13:\"authenticated\";}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:9:\"purge_any\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:8:\"view_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"update_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"delete_own\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:10:\"administer\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:4:\"test\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}s:13:\"configuration\";a:3:{s:5:\"roles\";a:0:{}s:5:\"users\";a:0:{}s:11:\"permissions\";a:0:{}}}s:8:\"handlers\";a:2:{s:18:\"email_confirmation\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email confirmation\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_confirmation\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:1;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:19:\"[current-user:mail]\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:8:\"_default\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:8:\"_default\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}s:18:\"email_notification\";a:8:{s:2:\"id\";s:5:\"email\";s:5:\"label\";s:18:\"Email notification\";s:5:\"notes\";s:0:\"\";s:10:\"handler_id\";s:18:\"email_notification\";s:6:\"status\";b:1;s:10:\"conditions\";a:0:{}s:6:\"weight\";i:2;s:8:\"settings\";a:27:{s:6:\"states\";a:1:{i:0;s:9:\"completed\";}s:7:\"to_mail\";s:8:\"_default\";s:10:\"to_options\";a:0:{}s:7:\"cc_mail\";s:0:\"\";s:10:\"cc_options\";a:0:{}s:8:\"bcc_mail\";s:0:\"\";s:11:\"bcc_options\";a:0:{}s:9:\"from_mail\";s:37:\"[webform_submission:values:email:raw]\";s:12:\"from_options\";a:0:{}s:9:\"from_name\";s:36:\"[webform_submission:values:name:raw]\";s:7:\"subject\";s:39:\"[webform_submission:values:subject:raw]\";s:4:\"body\";s:41:\"[webform_submission:values:message:value]\";s:17:\"excluded_elements\";a:0:{}s:13:\"ignore_access\";b:0;s:13:\"exclude_empty\";b:1;s:22:\"exclude_empty_checkbox\";b:0;s:19:\"exclude_attachments\";b:0;s:4:\"html\";b:1;s:11:\"attachments\";b:0;s:4:\"twig\";b:0;s:10:\"theme_name\";s:0:\"\";s:10:\"parameters\";a:0:{}s:5:\"debug\";b:0;s:8:\"reply_to\";s:0:\"\";s:11:\"return_path\";s:0:\"\";s:11:\"sender_mail\";s:0:\"\";s:11:\"sender_name\";s:0:\"\";}}}s:8:\"variants\";a:0:{}}'),
('',	'webform.webform_options.country_codes',	'a:10:{s:4:\"uuid\";s:36:\"ff13f706-a0ad-416d-9f29-9d2d43722997\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"adQ16YGDPk7QfUKrfrC35o2sKdHEozdNtdpiH7CftQQ\";}s:2:\"id\";s:13:\"country_codes\";s:5:\"label\";s:13:\"Country codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.country_names',	'a:10:{s:4:\"uuid\";s:36:\"e8e266de-5ba1-42b8-aab4-68928e91aea7\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zsfFP124dAM-sJkuEfnwaA7DN6o3-IsaXLgdNmObbYg\";}s:2:\"id\";s:13:\"country_names\";s:5:\"label\";s:13:\"Country names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.days',	'a:10:{s:4:\"uuid\";s:36:\"e1a9a156-02bc-4ffe-b6cb-55c0d4da6931\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YNrKbYrWWjeubUUM8AsQ19KnX7cU1elACR14CZJHmdg\";}s:2:\"id\";s:4:\"days\";s:5:\"label\";s:4:\"Days\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:121:\"Sunday: Sunday\nMonday: Monday\nTuesday: Tuesday\nWednesday: Wednesday\nThursday: Thursday\nFriday: Friday\nSaturday: Saturday\n\";}'),
('',	'webform.webform_options.education',	'a:10:{s:4:\"uuid\";s:36:\"f59dde6d-88c7-46f8-9148-aa56a18a13ba\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mII4acOv33s-j8PINywrCag4OITbeJGxdPO373dnHHw\";}s:2:\"id\";s:9:\"education\";s:5:\"label\";s:9:\"Education\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:152:\"High School: High School\nAssociate Degree: Associate Degree\nGraduate or Professional Degree: Graduate or Professional Degree\nSome College: Some College\n\";}'),
('',	'webform.webform_options.employment_status',	'a:10:{s:4:\"uuid\";s:36:\"369dc8ce-cc18-40ec-b90a-91c195e015af\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8MCmsz_csdJkVItxI8g_s4zp2PM285YqCy_gWTzOLPw\";}s:2:\"id\";s:17:\"employment_status\";s:5:\"label\";s:17:\"Employment status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:113:\"\'Full Time\': \'Full Time\'\n\'Part Time\': \'Part Time\'\n\'Military\': \'Military\'\nUnemployed: Unemployed\nRetired: Retired\n\";}'),
('',	'webform.webform_options.ethnicity',	'a:10:{s:4:\"uuid\";s:36:\"d8eb5c8c-04ba-44b0-83dd-5ab55746daa9\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pIPgrAC82wE2GAk1mOv2UvMYv71YQe4VT8667QIYdvI\";}s:2:\"id\";s:9:\"ethnicity\";s:5:\"label\";s:9:\"Ethnicity\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:200:\"Caucasian: Caucasian\n\'Latino/Hispanic\': \'Latino/Hispanic\'\n\'Middle Eastern\': \'Middle Eastern\'\nAfrican: African\nCaribbean: Caribbean\n\'South Asian\': \'South Asian\'\n\'East Asian\': \'East Asian\'\nMixed: Mixed\n\";}'),
('',	'webform.webform_options.gender',	'a:10:{s:4:\"uuid\";s:36:\"8e01de6b-6df3-4ff4-857e-7f18c86dba94\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yxhG0JmQs2HT-Ro6ZeDQboDc9ZWR4GglflTtyoqxK4A\";}s:2:\"id\";s:6:\"gender\";s:5:\"label\";s:6:\"Gender\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:756:\"Man: Man\nWoman: Woman\nNon-binary: Non-binary\nAgender/Genderless: Agender/Genderless\nAndrogyne/Androgynous: Androgyne/Androgynous\nAporagender: Aporagender\nBigender: Bigender\nDemi-agender: Demi-agender\nDemi-boy: Demi-boy\nDemi-fluid: Demi-fluid\nDemi-girl: Demi-girl\nDemi-gender: Demi-gender\nDemi-non-binary: Demi-non-binary\nGenderqueer: Genderqueer\nGenderflux: Genderflux\nGenderfluid: Genderfluid\nGender-indifferent: Gender-indifferent\nGender-neutral: Gender-neutral\nGraygender: Graygender\nIntergender: Intergender\nMaverique: Maverique\nMaxigender: Maxigender\nMultigender/Polygender: Multigender/Polygender\nNeutrois: Neutrois\nPangender/Omnigender: Pangender/Omnigender\nTrigender: Trigender\nTwo-spirit: Two-spirit\n\'Prefer Not to Answer\': \'Prefer Not to Answer\'\n\";}'),
('',	'webform.webform_options.industry',	'a:10:{s:4:\"uuid\";s:36:\"a1a5d982-5911-4689-8e9d-779071e6f69c\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"s_SXZn2HbRGvTex-TLOCxz2oOnMYqtEZh8HD4_318QI\";}s:2:\"id\";s:8:\"industry\";s:5:\"label\";s:8:\"Industry\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1425:\"Accounting/Finance: Accounting/Finance\nAdvertising/Public Relations: Advertising/Public Relations\nAerospace/Aviation: Aerospace/Aviation\nArts/Entertainment/Publishing: Arts/Entertainment/Publishing\nAutomotive: Automotive\nBanking/Mortgage: Banking/Mortgage\nBusiness Development: Business Development\nBusiness Opportunity: Business Opportunity\nClerical/Administrative: Clerical/Administrative\nConstruction/Facilities: Construction/Facilities\nConsumer Goods: Consumer Goods\nCustomer Service: Customer Service\nEducation/Training: Education/Training\nEnergy/Utilities: Energy/Utilities\nEngineering: Engineering\nGovernment/Military: Government/Military\nHealthcare: Healthcare\nHospitality/Travel: Hospitality/Travel\nHuman Resources: Human Resources\nInstallation/Maintenance: Installation/Maintenance\nInsurance: Insurance\nInternet: Internet\nLaw Enforcement/Security: Law Enforcement/Security\nLegal: Legal\nManagement/Executive: Management/Executive\nManufacturing/Operations: Manufacturing/Operations\nMarketing: Marketing\nNon-Profit/Volunteer: Non-Profit/Volunteer\nPharmaceutical/Biotech: Pharmaceutical/Biotech\nProfessional Services: Professional Services\nReal Estate: Real Estate\nRestaurant/Food Service: Restaurant/Food Service\nRetail: Retail\nSales: Sales\nScience/Research: Science/Research\nSkilled Labor: Skilled Labor\nTechnology: Technology\nTelecommunications: Telecommunications\nTransportation/Logistics: Transportation/Logistics\n\";}'),
('',	'webform.webform_options.languages',	'a:10:{s:4:\"uuid\";s:36:\"da44f184-15d8-46b2-9d27-67fdc87883fa\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mYH14Vi65Ixj10c_GFa7CipxU3D0Bt9wgo8zE8zjOfE\";}s:2:\"id\";s:9:\"languages\";s:5:\"label\";s:9:\"Languages\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.likert_agreement',	'a:10:{s:4:\"uuid\";s:36:\"c1d3035e-7928-41e6-83cb-e5d35f1ddcff\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nPp-CfMKrP0yDMtyO0wQRwawEqaJVAPzQapinXmDgyU\";}s:2:\"id\";s:16:\"likert_agreement\";s:5:\"label\";s:17:\"Likert: Agreement\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:71:\"1: Strongly Disagree\n2: Disagree\n3: Neutral\n4: Agree\n5: Strongly Agree\n\";}'),
('',	'webform.webform_options.likert_comparison',	'a:10:{s:4:\"uuid\";s:36:\"c9690189-5cda-402e-bc23-4fce4d34e427\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"DMG4TKTHEXtHN8ho_sG_GiZHgweZ6nrRm6BAjk0LZ_Y\";}s:2:\"id\";s:17:\"likert_comparison\";s:5:\"label\";s:18:\"Likert: Comparison\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:84:\"1: Much Worse\n2: Somewhat Worse\n3: About the Same\n4: Somewhat Better\n5: Much Better\n\";}'),
('',	'webform.webform_options.likert_importance',	'a:10:{s:4:\"uuid\";s:36:\"120774df-f15f-4a67-b020-8ecedd3cff80\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Hbc8n5HtVZVs5fSBSpSbuY07CVvqkKP76csvRHN9pK8\";}s:2:\"id\";s:17:\"likert_importance\";s:5:\"label\";s:18:\"Likert: Importance\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:88:\"1: Not at all Important\n2: Somewhat Important\n3: Neutral\n4: Important\n5: Very Important\n\";}'),
('',	'webform.webform_options.likert_quality',	'a:10:{s:4:\"uuid\";s:36:\"3f51980b-fdb6-4b07-a304-fb302af23c4d\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"swmYtBVUbwq7aHJWWDN7ODByuvur9vMkexDC9h64NZ8\";}s:2:\"id\";s:14:\"likert_quality\";s:5:\"label\";s:15:\"Likert: Quality\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:50:\"1: Poor\n2: Fair\n3: Good\n4: Very good\n5: Excellent\n\";}'),
('',	'webform.webform_options.likert_satisfaction',	'a:10:{s:4:\"uuid\";s:36:\"3fe1c8dc-5cd9-48b5-a783-23480e3742f3\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AKE2SNwCpl6Mu_cmbq9ZM2_cXxCikCVj1vcPE9oHWTs\";}s:2:\"id\";s:19:\"likert_satisfaction\";s:5:\"label\";s:20:\"Likert: Satisfaction\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:77:\"1: Very Unsatisfied\n2: Unsatisfied\n3: Neutral\n4: Satisfied\n5: Very Satisfied\n\";}'),
('',	'webform.webform_options.likert_ten_scale',	'a:10:{s:4:\"uuid\";s:36:\"3bce0633-cfe2-4f52-8625-00d8c7a98f35\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zEZX8JSVqznnFtqFfpuC593h3t1JDAZhF0Q3pvA229o\";}s:2:\"id\";s:16:\"likert_ten_scale\";s:5:\"label\";s:17:\"Likert: Ten Scale\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:52:\"1: 1\n2: 2\n3: 3\n4: 4\n5: 5\n6: 6\n7: 7\n8: 8\n9: 9\n10: 10\n\";}'),
('',	'webform.webform_options.likert_would_you',	'a:10:{s:4:\"uuid\";s:36:\"ac4202f9-992c-48ac-a36b-aa22452196bb\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qBS2TmfAJB37Qn3TnrNM8x4AWimmDapcizzRllgo0fo\";}s:2:\"id\";s:16:\"likert_would_you\";s:5:\"label\";s:17:\"Likert: Would You\";s:8:\"category\";s:6:\"Likert\";s:6:\"likert\";b:1;s:7:\"options\";s:72:\"1: Definitely Not\n2: Probably Not\n3: Not Sure\n4: Probably\n5: Definitely\n\";}'),
('',	'webform.webform_options.marital_status',	'a:10:{s:4:\"uuid\";s:36:\"197b61b7-7127-4713-9678-b79940b929ea\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cjVDbAE5BlopGrY-tfxsxMoyEibwBBNgdQwDdxOSkow\";}s:2:\"id\";s:14:\"marital_status\";s:5:\"label\";s:14:\"Marital status\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:68:\"Single: Single\nMarried: Married\nDivorced: Divorced\nWidowed: Widowed\n\";}'),
('',	'webform.webform_options.months',	'a:10:{s:4:\"uuid\";s:36:\"281e6e1e-5d64-459a-86ef-5c7109ebb0cf\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pZJnuQkh9afNML5IcMuKTUC__vmHMFn66Qr5IWtedZ4\";}s:2:\"id\";s:6:\"months\";s:5:\"label\";s:6:\"Months\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:184:\"January: January\nFebruary: February\nMarch: March\nApril: April\nMay: May\nJune: June\nJuly: July\nAugust: August\nSeptember: September\nOctober: October\nNovember: November\nDecember: December\n\";}'),
('',	'webform.webform_options.phone_types',	'a:10:{s:4:\"uuid\";s:36:\"13d0d301-6f64-4c63-a190-cfa2990e9a48\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LkO63Zl2cP_l9YdjzWI8dWoD9uD0pytkPiUiUM2bo9A\";}s:2:\"id\";s:11:\"phone_types\";s:5:\"label\";s:10:\"Phone type\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:37:\"Home: Home\nOffice: Office\nCell: Cell\n\";}'),
('',	'webform.webform_options.province_codes',	'a:10:{s:4:\"uuid\";s:36:\"3dd5c388-df64-4a89-9710-1557394c6222\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cR3A6XXinVGC9g5vLS-vVvTC2ppZXRNXLPWA8xBUMew\";}s:2:\"id\";s:14:\"province_codes\";s:5:\"label\";s:14:\"Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:237:\"AB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),
('',	'webform.webform_options.province_names',	'a:10:{s:4:\"uuid\";s:36:\"db9cc306-a4c9-49d1-9f1a-af8959ae1569\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"aaEeYBWoWETLKX2ivmZBpUAd3uPe2iPNydaxBuLPXKc\";}s:2:\"id\";s:14:\"province_names\";s:5:\"label\";s:14:\"Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:379:\"Alberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),
('',	'webform.webform_options.relationship',	'a:10:{s:4:\"uuid\";s:36:\"c451f0ba-7456-4e0e-b2fe-5ebbebf2e2a0\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4J2RPG4JmsD4Fm1NlIQY0JHkrJ08UUl0qTF0_EjUxvw\";}s:2:\"id\";s:12:\"relationship\";s:5:\"label\";s:12:\"Relationship\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:101:\"Parent: Parent\n\'Significant Other\': \'Significant Other\'\nSibling: Sibling\nChild: Child\nFriend: Friend\n\";}'),
('',	'webform.webform_options.sex',	'a:10:{s:4:\"uuid\";s:36:\"e26b351c-bbe3-491b-b4e5-0c8ec30decce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WRpxpwYpfcO_i0so7BV4QXxXlbPiSVppYmAV6DAz4c0\";}s:2:\"id\";s:3:\"sex\";s:5:\"label\";s:3:\"Sex\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:26:\"Male: Male\nFemale: Female\n\";}'),
('',	'webform.webform_options.sex_icao',	'a:10:{s:4:\"uuid\";s:36:\"b54122ee-eb6e-46b5-b89b-a3d6cbff2302\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"9mxo86dMII5OxkHl4mbe2l4AgQloOXuErOte57BU9IY\";}s:2:\"id\";s:8:\"sex_icao\";s:5:\"label\";s:54:\"Sex - International Civil Aviation Organization (ICAO)\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:33:\"M: Male\nF: Female\nX: Unspecified\n\";}'),
('',	'webform.webform_options.size',	'a:10:{s:4:\"uuid\";s:36:\"c06bcacf-40d2-4c65-9f65-f5429245ed23\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"RKkc6tf1VudvYiOtwPCf3Tp_EoA6fov6BFC34D7gMoQ\";}s:2:\"id\";s:4:\"size\";s:5:\"label\";s:4:\"Size\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:91:\"Extra Small: Extra Small\nSmall: Small\nMedium: Medium\nLarge: Large\nExtra Large: Extra Large\n\";}'),
('',	'webform.webform_options.state_codes',	'a:10:{s:4:\"uuid\";s:36:\"86b1fb55-9ca7-480a-a333-ce541cefe1ce\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8mYO8ewsZX3LVfNga69jXa0RNO0LNN8-EGkXLhSAMBU\";}s:2:\"id\";s:11:\"state_codes\";s:5:\"label\";s:11:\"State codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:728:\"AL: Alabama\nAK: Alaska\nAZ: Arizona\nAR: Arkansas\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPA: Pennsylvania\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\n\";}'),
('',	'webform.webform_options.state_names',	'a:10:{s:4:\"uuid\";s:36:\"f50cd86e-1ce6-4e30-a74c-4aa2a46053b8\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KfYqMSrFJ5iGtDzvy_rGUeRUJ4KyM7Xt-tWtYx9WjiM\";}s:2:\"id\";s:11:\"state_names\";s:5:\"label\";s:11:\"State names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1081:\"Alabama: Alabama\nAlaska: Alaska\nArizona: Arizona\nArkansas: Arkansas\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\nFlorida: Florida\nGeorgia: Georgia\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPennsylvania: Pennsylvania\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\n\";}'),
('',	'webform.webform_options.state_province_codes',	'a:10:{s:4:\"uuid\";s:36:\"6c763985-59b0-49e1-a940-e76e2992edca\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ziWv9xVss1UBnP_R38EqduZOprwOAifpxjXhyOPzmys\";}s:2:\"id\";s:20:\"state_province_codes\";s:5:\"label\";s:20:\"State/Province codes\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1241:\"AL: Alabama\nAK: Alaska\nAS: \'American Samoa\'\nAZ: Arizona\nAR: Arkansas\nAE: \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\nAA: \'Armed Forces Americas\'\nAP: \'Armed Forces Pacific\'\nCA: California\nCO: Colorado\nCT: Connecticut\nDE: Delaware\nDC: \'District of Columbia\'\nFM: \'Federated States of Micronesia\'\nFL: Florida\nGA: Georgia\nGU: Guam\nHI: Hawaii\nID: Idaho\nIL: Illinois\nIN: Indiana\nIA: Iowa\nKS: Kansas\nKY: Kentucky\nLA: Louisiana\nME: Maine\nMH: \'Marshall Islands\'\nMD: Maryland\nMA: Massachusetts\nMI: Michigan\nMN: Minnesota\nMS: Mississippi\nMO: Missouri\nMT: Montana\nNE: Nebraska\nNV: Nevada\nNH: \'New Hampshire\'\nNJ: \'New Jersey\'\nNM: \'New Mexico\'\nNY: \'New York\'\nNC: \'North Carolina\'\nND: \'North Dakota\'\nMP: \'Northern Mariana Islands\'\nOH: Ohio\nOK: Oklahoma\nOR: Oregon\nPW: Palau\nPA: Pennsylvania\nPR: \'Puerto Rico\'\nRI: \'Rhode Island\'\nSC: \'South Carolina\'\nSD: \'South Dakota\'\nTN: Tennessee\nTX: Texas\nUT: Utah\nVT: Vermont\nVI: \'Virgin Islands\'\nVA: Virginia\nWA: Washington\nWV: \'West Virginia\'\nWI: Wisconsin\nWY: Wyoming\nAB: Alberta\nBC: \'British Columbia\'\nMB: Manitoba\nNB: \'New Brunswick\'\nNL: \'Newfoundland and Labrador\'\nNS: \'Nova Scotia\'\nNT: \'Northwest Territories\'\nNU: Nunavut\n\'ON\': Ontario\nPE: \'Prince Edward Island\'\nQC: Quebec\nSK: Saskatchewan\nYT: Yukon\n\";}'),
('',	'webform.webform_options.state_province_names',	'a:10:{s:4:\"uuid\";s:36:\"40521304-88f4-47f9-82bb-7eb8bc136320\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"d4mxS_CxdzHZK4WaGQf1H3m-Uubm5HPbu9U4ydzscuo\";}s:2:\"id\";s:20:\"state_province_names\";s:5:\"label\";s:20:\"State/Province names\";s:8:\"category\";s:10:\"Geographic\";s:6:\"likert\";b:0;s:7:\"options\";s:1953:\"Alabama: Alabama\nAlaska: Alaska\n\'American Samoa\': \'American Samoa\'\nArizona: Arizona\nArkansas: Arkansas\n\'Armed Forces (Canada, Europe, Africa, or Middle East)\': \'Armed Forces (Canada, Europe, Africa, or Middle East)\'\n\'Armed Forces Americas\': \'Armed Forces Americas\'\n\'Armed Forces Pacific\': \'Armed Forces Pacific\'\nCalifornia: California\nColorado: Colorado\nConnecticut: Connecticut\nDelaware: Delaware\n\'District of Columbia\': \'District of Columbia\'\n\'Federated States of Micronesia\': \'Federated States of Micronesia\'\nFlorida: Florida\nGeorgia: Georgia\nGuam: Guam\nHawaii: Hawaii\nIdaho: Idaho\nIllinois: Illinois\nIndiana: Indiana\nIowa: Iowa\nKansas: Kansas\nKentucky: Kentucky\nLouisiana: Louisiana\nMaine: Maine\n\'Marshall Islands\': \'Marshall Islands\'\nMaryland: Maryland\nMassachusetts: Massachusetts\nMichigan: Michigan\nMinnesota: Minnesota\nMississippi: Mississippi\nMissouri: Missouri\nMontana: Montana\nNebraska: Nebraska\nNevada: Nevada\n\'New Hampshire\': \'New Hampshire\'\n\'New Jersey\': \'New Jersey\'\n\'New Mexico\': \'New Mexico\'\n\'New York\': \'New York\'\n\'North Carolina\': \'North Carolina\'\n\'North Dakota\': \'North Dakota\'\n\'Northern Mariana Islands\': \'Northern Mariana Islands\'\nOhio: Ohio\nOklahoma: Oklahoma\nOregon: Oregon\nPalau: Palau\nPennsylvania: Pennsylvania\n\'Puerto Rico\': \'Puerto Rico\'\n\'Rhode Island\': \'Rhode Island\'\n\'South Carolina\': \'South Carolina\'\n\'South Dakota\': \'South Dakota\'\nTennessee: Tennessee\nTexas: Texas\nUtah: Utah\nVermont: Vermont\n\'Virgin Islands\': \'Virgin Islands\'\nVirginia: Virginia\nWashington: Washington\n\'West Virginia\': \'West Virginia\'\nWisconsin: Wisconsin\nWyoming: Wyoming\nAlberta: Alberta\n\'British Columbia\': \'British Columbia\'\nManitoba: Manitoba\n\'New Brunswick\': \'New Brunswick\'\n\'Newfoundland and Labrador\': \'Newfoundland and Labrador\'\n\'Nova Scotia\': \'Nova Scotia\'\n\'Northwest Territories\': \'Northwest Territories\'\nNunavut: Nunavut\nOntario: Ontario\n\'Prince Edward Island\': \'Prince Edward Island\'\nQuebec: Quebec\nSaskatchewan: Saskatchewan\nYukon: Yukon\n\";}'),
('',	'webform.webform_options.time_zones',	'a:10:{s:4:\"uuid\";s:36:\"34555c98-49f4-4d02-aca0-fa11a6f7e4b5\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8rVcRXLnTAEoWs7zl8du-7RIUnayqUcGYnvb3JT21-o\";}s:2:\"id\";s:10:\"time_zones\";s:5:\"label\";s:10:\"Time zones\";s:8:\"category\";s:13:\"Date and time\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.titles',	'a:10:{s:4:\"uuid\";s:36:\"1c50e324-cb25-4578-8344-bd2266cbca89\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"PEUoedWrfYEX7oZ8CcOukfBTVxar1cPSROX8534esuU\";}s:2:\"id\";s:6:\"titles\";s:5:\"label\";s:6:\"Titles\";s:8:\"category\";s:11:\"Demographic\";s:6:\"likert\";b:0;s:7:\"options\";s:41:\"Miss: Miss\nMs: Ms\nMr: Mr\nMrs: Mrs\nDr: Dr\n\";}'),
('',	'webform.webform_options.translations',	'a:10:{s:4:\"uuid\";s:36:\"84bf246e-58a4-4bad-ad87-c1ffdd4a4be4\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Mb_L3vE-0IBZH5s2rjpk2LNn0QHClQP9AARQdCmVLt4\";}s:2:\"id\";s:12:\"translations\";s:5:\"label\";s:12:\"Translations\";s:8:\"category\";s:8:\"Language\";s:6:\"likert\";b:0;s:7:\"options\";s:0:\"\";}'),
('',	'webform.webform_options.yes_no',	'a:10:{s:4:\"uuid\";s:36:\"a55ca564-ba76-4d06-b838-79a72132103a\";s:8:\"langcode\";s:2:\"en\";s:6:\"status\";b:1;s:12:\"dependencies\";a:1:{s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:7:\"webform\";}}}s:5:\"_core\";a:1:{s:19:\"default_config_hash\";s:43:\"W88NYg31DbaVNQx1Uir_dwwXHVtF09QOq4VBGsH1Snk\";}s:2:\"id\";s:6:\"yes_no\";s:5:\"label\";s:6:\"Yes/No\";s:8:\"category\";s:7:\"General\";s:6:\"likert\";b:0;s:7:\"options\";s:16:\"Yes: Yes\nNo: No\n\";}');

DROP TABLE IF EXISTS `file_managed`;
CREATE TABLE `file_managed` (
  `fid` int unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `filename` varchar(255) DEFAULT NULL,
  `uri` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
  `filemime` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `filesize` bigint unsigned DEFAULT NULL,
  `status` tinyint NOT NULL,
  `created` int DEFAULT NULL,
  `changed` int NOT NULL,
  PRIMARY KEY (`fid`),
  UNIQUE KEY `file_field__uuid__value` (`uuid`),
  KEY `file_field__uid__target_id` (`uid`),
  KEY `file_field__uri` (`uri`(191)),
  KEY `file_field__status` (`status`),
  KEY `file_field__changed` (`changed`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for file entities.';


DROP TABLE IF EXISTS `file_usage`;
CREATE TABLE `file_usage` (
  `fid` int unsigned NOT NULL COMMENT 'File ID.',
  `module` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the module that is using the file.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the object type in which the file is used.',
  `id` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '0' COMMENT 'The primary key of the object using the file.',
  `count` int unsigned NOT NULL DEFAULT '0' COMMENT 'The number of times this file is used by this object.',
  PRIMARY KEY (`fid`,`type`,`id`,`module`),
  KEY `type_id` (`type`,`id`),
  KEY `fid_count` (`fid`,`count`),
  KEY `fid_module` (`fid`,`module`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Track where a file is used.';


DROP TABLE IF EXISTS `help_search_items`;
CREATE TABLE `help_search_items` (
  `sid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Numeric index of this item in the search index',
  `section_plugin_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The help section the item comes from',
  `permission` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The permission needed to view this item',
  `topic_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The topic ID of the item',
  PRIMARY KEY (`sid`),
  KEY `section_plugin_id` (`section_plugin_id`),
  KEY `topic_id` (`topic_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores information about indexed help search items';

INSERT INTO `help_search_items` (`sid`, `section_plugin_id`, `permission`, `topic_id`) VALUES
(1,	'help_topics',	'',	'config.export_full'),
(2,	'help_topics',	'',	'config.export_single'),
(3,	'help_topics',	'',	'config.import_full'),
(4,	'help_topics',	'',	'config.import_single'),
(5,	'help_topics',	'',	'contact.adding_fields'),
(6,	'help_topics',	'',	'contact.configuring_personal'),
(7,	'help_topics',	'',	'contact.creating'),
(8,	'help_topics',	'',	'contact.overview'),
(9,	'help_topics',	'',	'contact.setting_default'),
(10,	'help_topics',	'',	'core.appearance'),
(11,	'help_topics',	'',	'core.config_overview'),
(12,	'help_topics',	'',	'core.content_structure'),
(13,	'help_topics',	'',	'core.cron'),
(14,	'help_topics',	'',	'core.extending'),
(15,	'help_topics',	'',	'core.maintenance'),
(16,	'help_topics',	'',	'core.media'),
(17,	'help_topics',	'',	'core.menus'),
(18,	'help_topics',	'',	'core.performance'),
(19,	'help_topics',	'',	'core.security'),
(20,	'help_topics',	'',	'core.settings_tray'),
(21,	'help_topics',	'',	'core.tracking_content'),
(22,	'help_topics',	'',	'core.translations'),
(23,	'help_topics',	'',	'core.ui_accessibility'),
(24,	'help_topics',	'',	'core.ui_components'),
(25,	'help_topics',	'',	'core.web_services'),
(26,	'help_topics',	'',	'help.help_topic_search'),
(27,	'help_topics',	'',	'help.overview'),
(28,	'help_topics',	'',	'search.configuring'),
(29,	'help_topics',	'',	'search.index'),
(30,	'help_topics',	'',	'search.overview'),
(31,	'help_topics',	'',	'system.cache'),
(32,	'help_topics',	'',	'system.config_basic'),
(33,	'help_topics',	'',	'system.config_error'),
(34,	'help_topics',	'',	'system.maintenance_mode'),
(35,	'help_topics',	'',	'system.module_install'),
(36,	'help_topics',	'',	'system.module_uninstall'),
(37,	'help_topics',	'',	'system.reports'),
(38,	'help_topics',	'',	'system.theme_install'),
(39,	'help_topics',	'',	'system.theme_uninstall'),
(40,	'help_topics',	'',	'user.create'),
(41,	'help_topics',	'',	'user.new_role'),
(42,	'help_topics',	'',	'user.overview'),
(43,	'help_topics',	'',	'user.permissions'),
(44,	'help_topics',	'',	'user.security_account_settings'),
(45,	'help_topics',	'',	'user.update'),
(46,	'help_topics',	'',	'announcements_feed.overview'),
(47,	'help_topics',	'',	'block.configure'),
(48,	'help_topics',	'',	'block.overview'),
(49,	'help_topics',	'',	'block.place'),
(50,	'help_topics',	'',	'filter.overview'),
(51,	'help_topics',	'',	'block_content.add'),
(52,	'help_topics',	'',	'block_content.type'),
(53,	'help_topics',	'',	'node.creating_content'),
(54,	'help_topics',	'',	'node.creating_type'),
(55,	'help_topics',	'',	'node.editing'),
(56,	'help_topics',	'',	'node.overview'),
(57,	'help_topics',	'',	'breakpoint.overview'),
(58,	'help_topics',	'',	'editor.overview'),
(64,	'help_topics',	'',	'contextual.overview'),
(65,	'help_topics',	'',	'field_ui.add_field'),
(66,	'help_topics',	'',	'field_ui.manage_display'),
(67,	'help_topics',	'',	'field_ui.manage_form'),
(68,	'help_topics',	'',	'field_ui.reference_field'),
(69,	'help_topics',	'',	'history.tracking_user_content'),
(70,	'help_topics',	'',	'taxonomy.configuring'),
(71,	'help_topics',	'',	'taxonomy.overview'),
(72,	'help_topics',	'',	'image.style'),
(73,	'help_topics',	'',	'views.overview'),
(74,	'help_topics',	'',	'menu_ui.content_type_configuration'),
(75,	'help_topics',	'',	'menu_ui.menu_item_add'),
(76,	'help_topics',	'',	'menu_ui.menu_operations'),
(77,	'help_topics',	'',	'menu_ui.overriding'),
(78,	'help_topics',	'',	'path.creating_alias'),
(79,	'help_topics',	'',	'path.editing_alias'),
(80,	'help_topics',	'',	'path.overview'),
(81,	'help_topics',	'',	'shortcut.overview'),
(82,	'help_topics',	'',	'views_ui.add_display'),
(83,	'help_topics',	'',	'views_ui.bulk_operations'),
(84,	'help_topics',	'',	'views_ui.create'),
(85,	'help_topics',	'',	'views_ui.edit'),
(86,	'help_topics',	'',	'layout_builder.overview'),
(87,	'help_topics',	'',	'media.media_type');

DROP TABLE IF EXISTS `history`;
CREATE TABLE `history` (
  `uid` int NOT NULL DEFAULT '0' COMMENT 'The "users".uid that read the "node" nid.',
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid that was read.',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp at which the read occurred.',
  PRIMARY KEY (`uid`,`nid`),
  KEY `nid` (`nid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='A record of which "users" have read which "node"s.';

INSERT INTO `history` (`uid`, `nid`, `timestamp`) VALUES
(1,	1,	1722237482);

DROP TABLE IF EXISTS `inline_block_usage`;
CREATE TABLE `inline_block_usage` (
  `block_content_id` int unsigned NOT NULL COMMENT 'The block_content entity ID.',
  `layout_entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT '' COMMENT 'The entity type of the parent entity.',
  `layout_entity_id` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT '0' COMMENT 'The ID of the parent entity.',
  PRIMARY KEY (`block_content_id`),
  KEY `type_id` (`layout_entity_type`,`layout_entity_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Track where a block_content entity is used.';


DROP TABLE IF EXISTS `key_value`;
CREATE TABLE `key_value` (
  `collection` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A named collection of key and value pairs.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The key of the key-value pair. As KEY is a SQL reserved keyword, name was chosen instead.',
  `value` longblob NOT NULL COMMENT 'The value.',
  PRIMARY KEY (`collection`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Generic key-value storage table. See the state system for…';

INSERT INTO `key_value` (`collection`, `name`, `value`) VALUES
('config.entity.key_store.action',	'uuid:12dedc3c-a189-49b8-bfa3-3925d1475a53',	'a:1:{i:0;s:35:\"system.action.node_unpublish_action\";}'),
('config.entity.key_store.action',	'uuid:15843e3d-3327-4414-a048-e956e137183d',	'a:1:{i:0;s:31:\"system.action.media_save_action\";}'),
('config.entity.key_store.action',	'uuid:1dc10e26-9e52-406f-aa64-78f6f7ff20b9',	'a:1:{i:0;s:35:\"system.action.node_unpromote_action\";}'),
('config.entity.key_store.action',	'uuid:30b42137-73bc-48ad-bd3d-7b1492d2645a',	'a:1:{i:0;s:38:\"system.action.webform_unarchive_action\";}'),
('config.entity.key_store.action',	'uuid:326c9843-f7a5-4f11-a105-e093bfdaae75',	'a:1:{i:0;s:53:\"system.action.webform_submission_make_unsticky_action\";}'),
('config.entity.key_store.action',	'uuid:3a610953-8310-41e6-916e-67a38ded8605',	'a:1:{i:0;s:51:\"system.action.user_remove_role_action.administrator\";}'),
('config.entity.key_store.action',	'uuid:47b35c2c-ef80-4dbb-9bc2-87e5467e802a',	'a:1:{i:0;s:37:\"system.action.user_cancel_user_action\";}'),
('config.entity.key_store.action',	'uuid:49be4fb0-6832-463d-8bbe-69dd46552e18',	'a:1:{i:0;s:40:\"system.action.pathauto_update_alias_node\";}'),
('config.entity.key_store.action',	'uuid:5e4d1084-e98f-408d-9529-89567e88b624',	'a:1:{i:0;s:49:\"system.action.webform_submission_make_lock_action\";}'),
('config.entity.key_store.action',	'uuid:6125548a-6827-4acb-a08b-eda4e1b25de1',	'a:1:{i:0;s:36:\"system.action.webform_archive_action\";}'),
('config.entity.key_store.action',	'uuid:62205804-910a-4719-bbcb-1c8ef9179e61',	'a:1:{i:0;s:33:\"system.action.media_delete_action\";}'),
('config.entity.key_store.action',	'uuid:638ab18d-e126-4bf0-934b-ca0f8e76d21a',	'a:1:{i:0;s:33:\"system.action.node_publish_action\";}'),
('config.entity.key_store.action',	'uuid:71eff68f-3ada-438a-93f8-5554a79cb737',	'a:1:{i:0;s:51:\"system.action.webform_submission_make_sticky_action\";}'),
('config.entity.key_store.action',	'uuid:74ae1caf-547b-4f5b-b2c5-344fbdfc9454',	'a:1:{i:0;s:34:\"system.action.media_publish_action\";}'),
('config.entity.key_store.action',	'uuid:79cd458d-4e0f-42fc-8713-cf8324d4116c',	'a:1:{i:0;s:39:\"system.action.node_make_unsticky_action\";}'),
('config.entity.key_store.action',	'uuid:80e483ef-5cef-449b-b6eb-338611cedfbf',	'a:1:{i:0;s:33:\"system.action.node_promote_action\";}'),
('config.entity.key_store.action',	'uuid:8c900910-1bd8-48a7-abea-4493a2f89f45',	'a:1:{i:0;s:36:\"system.action.redirect_delete_action\";}'),
('config.entity.key_store.action',	'uuid:8ff0ec2c-b155-4314-9b5d-65aef57e6ed9',	'a:1:{i:0;s:32:\"system.action.node_delete_action\";}'),
('config.entity.key_store.action',	'uuid:98441d8b-cb2a-44eb-863f-f500933dc072',	'a:1:{i:0;s:42:\"system.action.taxonomy_term_publish_action\";}'),
('config.entity.key_store.action',	'uuid:9a449986-702c-4f26-a07f-3cbbae693dde',	'a:1:{i:0;s:34:\"system.action.webform_close_action\";}'),
('config.entity.key_store.action',	'uuid:9caf9021-aacc-4038-827b-c7fe7712e0ed',	'a:1:{i:0;s:46:\"system.action.webform_submission_delete_action\";}'),
('config.entity.key_store.action',	'uuid:9d24595c-700e-4798-9d98-3f086528cbd9',	'a:1:{i:0;s:36:\"system.action.media_unpublish_action\";}'),
('config.entity.key_store.action',	'uuid:acf6f444-fa28-4103-ae56-96da6d7abcc5',	'a:1:{i:0;s:40:\"system.action.pathauto_update_alias_user\";}'),
('config.entity.key_store.action',	'uuid:b9252337-7eb0-41ce-b704-8142809ba069',	'a:1:{i:0;s:33:\"system.action.webform_open_action\";}'),
('config.entity.key_store.action',	'uuid:c50e2e3d-3fd4-474f-b4c3-6e9deb3aa4ec',	'a:1:{i:0;s:44:\"system.action.taxonomy_term_unpublish_action\";}'),
('config.entity.key_store.action',	'uuid:d5b780e9-4002-48fb-9961-4890d2e18a4e',	'a:1:{i:0;s:37:\"system.action.node_make_sticky_action\";}'),
('config.entity.key_store.action',	'uuid:d93c6987-507f-40ab-8f7a-1166f768bc12',	'a:1:{i:0;s:35:\"system.action.webform_delete_action\";}'),
('config.entity.key_store.action',	'uuid:e33d4c27-1cb5-4a82-a343-178013992c5b',	'a:1:{i:0;s:36:\"system.action.user_block_user_action\";}'),
('config.entity.key_store.action',	'uuid:e656d6be-7229-49e2-a65a-513fbe566776',	'a:1:{i:0;s:30:\"system.action.node_save_action\";}'),
('config.entity.key_store.action',	'uuid:e9cdc7cd-560d-4c6e-b18d-4086edd12442',	'a:1:{i:0;s:48:\"system.action.user_add_role_action.administrator\";}'),
('config.entity.key_store.action',	'uuid:f372b8db-b95d-43f7-8c2b-b99a92076084',	'a:1:{i:0;s:38:\"system.action.user_unblock_user_action\";}'),
('config.entity.key_store.action',	'uuid:f6b34ab3-4ded-41c8-8a32-ba4e032881fb',	'a:1:{i:0;s:51:\"system.action.webform_submission_make_unlock_action\";}'),
('config.entity.key_store.base_field_override',	'uuid:708a5000-dcce-43d4-8735-a04f3c0ae480',	'a:1:{i:0;s:42:\"core.base_field_override.node.page.promote\";}'),
('config.entity.key_store.block',	'theme:claro',	'a:9:{i:0;s:31:\"block.block.claro_local_actions\";i:1;s:28:\"block.block.claro_page_title\";i:2;s:37:\"block.block.claro_primary_local_tasks\";i:3;s:39:\"block.block.claro_secondary_local_tasks\";i:4;s:22:\"block.block.claro_help\";i:5;s:29:\"block.block.claro_help_search\";i:6;s:29:\"block.block.claro_breadcrumbs\";i:7;s:25:\"block.block.claro_content\";i:8;s:26:\"block.block.claro_messages\";}'),
('config.entity.key_store.block',	'theme:olivero',	'a:15:{i:0;s:24:\"block.block.olivero_help\";i:1;s:30:\"block.block.olivero_page_title\";i:2;s:41:\"block.block.olivero_primary_admin_actions\";i:3;s:39:\"block.block.olivero_primary_local_tasks\";i:4;s:41:\"block.block.olivero_secondary_local_tasks\";i:5;s:29:\"block.block.olivero_syndicate\";i:6;s:38:\"block.block.olivero_search_form_narrow\";i:7;s:36:\"block.block.olivero_search_form_wide\";i:8;s:31:\"block.block.olivero_breadcrumbs\";i:9;s:27:\"block.block.olivero_content\";i:10;s:28:\"block.block.olivero_messages\";i:11;s:27:\"block.block.olivero_powered\";i:12;s:33:\"block.block.olivero_site_branding\";i:13;s:32:\"block.block.olivero_account_menu\";i:14;s:29:\"block.block.olivero_main_menu\";}'),
('config.entity.key_store.block',	'uuid:064ecc20-9718-4137-8404-bb79862b5dbe',	'a:1:{i:0;s:31:\"block.block.olivero_breadcrumbs\";}'),
('config.entity.key_store.block',	'uuid:0cd82e10-9f40-455e-9bc5-67bba0594412',	'a:1:{i:0;s:29:\"block.block.olivero_main_menu\";}'),
('config.entity.key_store.block',	'uuid:10f91465-91e8-4b68-9b23-c26342c32145',	'a:1:{i:0;s:36:\"block.block.olivero_search_form_wide\";}'),
('config.entity.key_store.block',	'uuid:1895f221-afd5-4f39-946d-175efff616ba',	'a:1:{i:0;s:38:\"block.block.olivero_search_form_narrow\";}'),
('config.entity.key_store.block',	'uuid:217ad55d-fd7d-4ae4-8bda-6030889a03b9',	'a:1:{i:0;s:32:\"block.block.olivero_account_menu\";}'),
('config.entity.key_store.block',	'uuid:3aa71fac-64b6-42f2-8b3d-0feb4a6f805e',	'a:1:{i:0;s:27:\"block.block.olivero_powered\";}'),
('config.entity.key_store.block',	'uuid:40baaa9b-4ebb-41cb-a0f8-9438fc1633e2',	'a:1:{i:0;s:25:\"block.block.claro_content\";}'),
('config.entity.key_store.block',	'uuid:53d20db2-085f-49cb-b889-bfcda4fdc4f1',	'a:1:{i:0;s:24:\"block.block.olivero_help\";}'),
('config.entity.key_store.block',	'uuid:58d2b9f3-0bea-4a38-88ec-fdb62db9ccb4',	'a:1:{i:0;s:26:\"block.block.claro_messages\";}'),
('config.entity.key_store.block',	'uuid:592b2a14-a8fb-40ab-af13-fad4757b447c',	'a:1:{i:0;s:30:\"block.block.olivero_page_title\";}'),
('config.entity.key_store.block',	'uuid:642a14ba-b7f3-4788-b6d7-7ec847635558',	'a:1:{i:0;s:29:\"block.block.claro_help_search\";}'),
('config.entity.key_store.block',	'uuid:869275af-a038-43a0-aec0-55d644632865',	'a:1:{i:0;s:39:\"block.block.olivero_primary_local_tasks\";}'),
('config.entity.key_store.block',	'uuid:9826d68e-9bcc-4b43-9656-f3d5f0c60619',	'a:1:{i:0;s:33:\"block.block.olivero_site_branding\";}'),
('config.entity.key_store.block',	'uuid:a425651d-4bbc-4735-b403-60eedd891c6d',	'a:1:{i:0;s:41:\"block.block.olivero_secondary_local_tasks\";}'),
('config.entity.key_store.block',	'uuid:b76437ff-efaf-4c97-84ca-ae001d11fa96',	'a:1:{i:0;s:27:\"block.block.olivero_content\";}'),
('config.entity.key_store.block',	'uuid:b9fe9f3b-f277-4a5a-a681-c952b93cbf81',	'a:1:{i:0;s:31:\"block.block.claro_local_actions\";}'),
('config.entity.key_store.block',	'uuid:d1a331f5-0df6-469b-9594-7d62381385aa',	'a:1:{i:0;s:29:\"block.block.claro_breadcrumbs\";}'),
('config.entity.key_store.block',	'uuid:d47ee844-8c65-44d3-85c0-510835e982ac',	'a:1:{i:0;s:37:\"block.block.claro_primary_local_tasks\";}'),
('config.entity.key_store.block',	'uuid:d4871bcb-88ea-4b21-8c89-7e1c3151ed0b',	'a:1:{i:0;s:29:\"block.block.olivero_syndicate\";}'),
('config.entity.key_store.block',	'uuid:e609269b-1f74-4c6d-8adc-b242386187c9',	'a:1:{i:0;s:22:\"block.block.claro_help\";}'),
('config.entity.key_store.block',	'uuid:ecc6ef43-9d4c-491e-a458-7b4ac180124d',	'a:1:{i:0;s:28:\"block.block.claro_page_title\";}'),
('config.entity.key_store.block',	'uuid:f080d7bf-33c8-49e4-a29b-4f78db0f7c2c',	'a:1:{i:0;s:39:\"block.block.claro_secondary_local_tasks\";}'),
('config.entity.key_store.block',	'uuid:f259c98a-a416-406b-8df1-73b20ade139d',	'a:1:{i:0;s:28:\"block.block.olivero_messages\";}'),
('config.entity.key_store.block',	'uuid:f3ae5ab3-e08f-4d92-8238-c0346ead125d',	'a:1:{i:0;s:41:\"block.block.olivero_primary_admin_actions\";}'),
('config.entity.key_store.block_content_type',	'uuid:17c62d51-6c7f-493f-85b4-fce54035fcf7',	'a:1:{i:0;s:32:\"block_content.type.ebt_countdown\";}'),
('config.entity.key_store.block_content_type',	'uuid:19fbd216-4f28-4209-a30c-bddd372736ae',	'a:1:{i:0;s:27:\"block_content.type.ebt_hero\";}'),
('config.entity.key_store.block_content_type',	'uuid:1a560148-0ddc-4fe6-a137-e201e64082d5',	'a:1:{i:0;s:26:\"block_content.type.ebt_cta\";}'),
('config.entity.key_store.block_content_type',	'uuid:31aff369-3823-4bb0-93db-1bca2acd3aa3',	'a:1:{i:0;s:30:\"block_content.type.ebt_columns\";}'),
('config.entity.key_store.block_content_type',	'uuid:3e06d945-9c14-4d86-add4-87ce46604987',	'a:1:{i:0;s:28:\"block_content.type.ebt_stats\";}'),
('config.entity.key_store.block_content_type',	'uuid:3f1d7aa5-63b0-4cf5-8b1e-c69f240e9a70',	'a:1:{i:0;s:36:\"block_content.type.ebt_webform_popup\";}'),
('config.entity.key_store.block_content_type',	'uuid:49a7d1d2-299c-43f7-8353-442f7c80126a',	'a:1:{i:0;s:33:\"block_content.type.ebt_micromodal\";}'),
('config.entity.key_store.block_content_type',	'uuid:4d70b021-1215-4212-93ff-3a65cfe166f4',	'a:1:{i:0;s:27:\"block_content.type.ebt_text\";}'),
('config.entity.key_store.block_content_type',	'uuid:532936a4-d4ec-4684-97d3-ea06263ffdfe',	'a:1:{i:0;s:32:\"block_content.type.ebt_accordion\";}'),
('config.entity.key_store.block_content_type',	'uuid:5f0bd962-43f3-4e4c-9dad-bd8ad9ad83bc',	'a:1:{i:0;s:35:\"block_content.type.ebt_basic_button\";}'),
('config.entity.key_store.block_content_type',	'uuid:61358808-828f-49a0-a1fc-850ba4856b25',	'a:1:{i:0;s:36:\"block_content.type.ebt_image_gallery\";}'),
('config.entity.key_store.block_content_type',	'uuid:656280fa-6df7-4fb1-97e2-0fba6d8acda7',	'a:1:{i:0;s:30:\"block_content.type.ebt_webform\";}'),
('config.entity.key_store.block_content_type',	'uuid:6c094884-55e1-4ce3-9782-8302e193358e',	'a:1:{i:0;s:28:\"block_content.type.ebt_quote\";}'),
('config.entity.key_store.block_content_type',	'uuid:6eb11d1d-b72a-4d76-a761-9c91bacf5654',	'a:1:{i:0;s:28:\"block_content.type.ebt_views\";}'),
('config.entity.key_store.block_content_type',	'uuid:7d164bb3-5e33-440f-b644-b566e1827e32',	'a:1:{i:0;s:32:\"block_content.type.ebt_slideshow\";}'),
('config.entity.key_store.block_content_type',	'uuid:8299bf83-c3a5-401f-a1b8-bf9bb009af40',	'a:1:{i:0;s:31:\"block_content.type.ebt_timeline\";}'),
('config.entity.key_store.block_content_type',	'uuid:8d0c7ff5-11fa-497e-b1cb-232bad118b10',	'a:1:{i:0;s:24:\"block_content.type.basic\";}'),
('config.entity.key_store.block_content_type',	'uuid:9575961f-7777-487f-988c-3898cad5f5b9',	'a:1:{i:0;s:39:\"block_content.type.ebt_bootstrap_button\";}'),
('config.entity.key_store.block_content_type',	'uuid:9fd85032-8853-4ccb-8f84-451d84cc570c',	'a:1:{i:0;s:28:\"block_content.type.ebt_image\";}'),
('config.entity.key_store.block_content_type',	'uuid:a4695763-bb05-45b7-877a-2988bc9c0c68',	'a:1:{i:0;s:28:\"block_content.type.ebt_tiles\";}'),
('config.entity.key_store.block_content_type',	'uuid:a548c9cd-2123-460d-ac7a-3776cbd6628d',	'a:1:{i:0;s:27:\"block_content.type.ebt_tabs\";}'),
('config.entity.key_store.block_content_type',	'uuid:a5b41dbb-434a-4f8f-aa0f-413c4cc768db',	'a:1:{i:0;s:28:\"block_content.type.ebt_block\";}'),
('config.entity.key_store.block_content_type',	'uuid:a8e8c97d-abf8-4a95-a638-a6a54e403d91',	'a:1:{i:0;s:31:\"block_content.type.ebt_carousel\";}'),
('config.entity.key_store.block_content_type',	'uuid:c8e02878-ad67-4c1d-8022-1bcae43b1e10',	'a:1:{i:0;s:46:\"block_content.type.ebt_video_and_image_gallery\";}'),
('config.entity.key_store.block_content_type',	'uuid:f30a12fb-b405-4036-a46f-fc82d5b577e0',	'a:1:{i:0;s:28:\"block_content.type.ebt_video\";}'),
('config.entity.key_store.block_content_type',	'uuid:f84bf2c7-0d7f-45e5-9e44-618e1cb84f84',	'a:1:{i:0;s:30:\"block_content.type.ebt_counter\";}'),
('config.entity.key_store.block_content_type',	'uuid:fe1604e8-b328-4b89-bd85-fc64bd553f33',	'a:1:{i:0;s:35:\"block_content.type.ebt_slick_slider\";}'),
('config.entity.key_store.contact_form',	'uuid:6c8348fa-3a53-48ce-ac8f-7aa4d1c5c9cd',	'a:1:{i:0;s:21:\"contact.form.personal\";}'),
('config.entity.key_store.contact_form',	'uuid:816a1630-e792-4f5c-a26b-35e17703bb04',	'a:1:{i:0;s:21:\"contact.form.feedback\";}'),
('config.entity.key_store.date_format',	'uuid:1b677438-94c3-4570-af48-166d068688f0',	'a:1:{i:0;s:30:\"core.date_format.html_datetime\";}'),
('config.entity.key_store.date_format',	'uuid:1bea5c34-af20-4053-9459-595e10032d04',	'a:1:{i:0;s:35:\"core.date_format.html_yearless_date\";}'),
('config.entity.key_store.date_format',	'uuid:2ae289c3-6325-45f0-9ec2-99609e297832',	'a:1:{i:0;s:23:\"core.date_format.medium\";}'),
('config.entity.key_store.date_format',	'uuid:3228fcaa-0dfe-4342-b299-d12cfba43674',	'a:1:{i:0;s:21:\"core.date_format.long\";}'),
('config.entity.key_store.date_format',	'uuid:387b27db-0cbb-49c6-bce9-e2ae838a4eb4',	'a:1:{i:0;s:26:\"core.date_format.html_time\";}'),
('config.entity.key_store.date_format',	'uuid:58dd1255-3bf1-465a-af62-74c3770e7861',	'a:1:{i:0;s:26:\"core.date_format.html_year\";}'),
('config.entity.key_store.date_format',	'uuid:7066953f-600d-4fc2-84b8-58826b84da0a',	'a:1:{i:0;s:25:\"core.date_format.fallback\";}'),
('config.entity.key_store.date_format',	'uuid:9f0d1e0f-c3b1-477d-8825-2a12a34e41f7',	'a:1:{i:0;s:31:\"core.date_format.olivero_medium\";}'),
('config.entity.key_store.date_format',	'uuid:aab47b59-a6c1-4205-a1bf-a0a7164b9f8d',	'a:1:{i:0;s:26:\"core.date_format.html_week\";}'),
('config.entity.key_store.date_format',	'uuid:b6631c90-a449-4cb7-93dc-33564909142a',	'a:1:{i:0;s:27:\"core.date_format.html_month\";}'),
('config.entity.key_store.date_format',	'uuid:c8f2ea5d-ee32-44b5-b2a4-73b29881a91d',	'a:1:{i:0;s:26:\"core.date_format.html_date\";}'),
('config.entity.key_store.date_format',	'uuid:ced168ae-c45d-4704-b1d4-c36fb84b47f2',	'a:1:{i:0;s:22:\"core.date_format.short\";}'),
('config.entity.key_store.editor',	'uuid:1926258e-dc0e-4aaa-95d1-5abf3be483cd',	'a:1:{i:0;s:23:\"editor.editor.full_html\";}'),
('config.entity.key_store.editor',	'uuid:4c6d924f-2c8d-4499-9713-799828c76079',	'a:1:{i:0;s:29:\"editor.editor.webform_default\";}'),
('config.entity.key_store.editor',	'uuid:65aded18-2f8d-4ec3-8d69-0a602798f4dd',	'a:1:{i:0;s:24:\"editor.editor.basic_html\";}'),
('config.entity.key_store.entity_form_display',	'uuid:095e0e3b-5060-4869-9c69-f8044cadf927',	'a:1:{i:0;s:42:\"core.entity_form_display.node.page.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:1e354f38-03e4-4eb3-83d9-64e23ea8e653',	'a:1:{i:0;s:60:\"core.entity_form_display.block_content.ebt_slideshow.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:289e89e1-cc7d-4e50-8100-bb16ed9875c1',	'a:1:{i:0;s:58:\"core.entity_form_display.block_content.ebt_counter.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:2d00d268-fcaf-44e1-a5d2-99bf5b954cee',	'a:1:{i:0;s:59:\"core.entity_form_display.block_content.ebt_timeline.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:2e78043c-ec7e-40d3-9893-74a39341e80d',	'a:1:{i:0;s:42:\"core.entity_form_display.user.user.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:2fb7a522-cf93-4f57-be42-0cb4c4d31165',	'a:1:{i:0;s:52:\"core.entity_form_display.block_content.basic.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:37393abe-e80e-4438-a211-2b6937d2a850',	'a:1:{i:0;s:63:\"core.entity_form_display.block_content.ebt_basic_button.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:3ac9c5a0-b4a9-4360-8947-feabad5e7f71',	'a:1:{i:0;s:56:\"core.entity_form_display.block_content.ebt_quote.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:3d16f00d-32eb-4ac9-a711-00689691832b',	'a:1:{i:0;s:50:\"core.entity_form_display.media.image.media_library\";}'),
('config.entity.key_store.entity_form_display',	'uuid:3fd59f0a-2725-4fa8-85fd-69b00e41a16c',	'a:1:{i:0;s:67:\"core.entity_form_display.block_content.ebt_bootstrap_button.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:432d0cdf-b7f6-4927-af19-9a26a2f71c65',	'a:1:{i:0;s:44:\"core.entity_form_display.media.video.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:4579f4f8-31b0-4cd5-b9fe-f87cd45f5fb6',	'a:1:{i:0;s:59:\"core.entity_form_display.paragraph.ebt_counter_item.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:49d083c6-462d-45e8-b2da-c158f1f21e4d',	'a:1:{i:0;s:59:\"core.entity_form_display.paragraph.ebt_slick_slider.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:4d6b8979-02dc-432e-a1ee-1e39bf6d0736',	'a:1:{i:0;s:56:\"core.entity_form_display.paragraph.ebt_slideshow.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:4de506fd-736b-43b4-b4e9-87a88229b117',	'a:1:{i:0;s:74:\"core.entity_form_display.block_content.ebt_video_and_image_gallery.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:50e0e4ff-bae9-4a5d-a915-ec8cdc49ff77',	'a:1:{i:0;s:61:\"core.entity_form_display.block_content.ebt_micromodal.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:52b22b0d-85e9-4340-9aa7-8f4febf9050e',	'a:1:{i:0;s:56:\"core.entity_form_display.block_content.ebt_stats.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:70924fc9-698f-43ce-8125-c9f66ca37236',	'a:1:{i:0;s:50:\"core.entity_form_display.media.audio.media_library\";}'),
('config.entity.key_store.entity_form_display',	'uuid:76422ca6-6b1c-4ebd-b6e5-d362e8bc423d',	'a:1:{i:0;s:64:\"core.entity_form_display.block_content.ebt_webform_popup.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:7b876128-538a-4826-a5a4-52747a729203',	'a:1:{i:0;s:44:\"core.entity_form_display.media.image.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:7f7f76e5-ece6-4e93-9154-f7a914b883b8',	'a:1:{i:0;s:60:\"core.entity_form_display.block_content.ebt_accordion.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:8876d1b6-9d39-4029-abb6-793bf6be88df',	'a:1:{i:0;s:56:\"core.entity_form_display.block_content.ebt_tiles.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:8a7d1838-30dd-4dc0-a2ae-b9e053ede2c9',	'a:1:{i:0;s:54:\"core.entity_form_display.block_content.ebt_cta.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:8df854a8-6d93-49a7-803e-4334857e73fc',	'a:1:{i:0;s:53:\"core.entity_form_display.media.document.media_library\";}'),
('config.entity.key_store.entity_form_display',	'uuid:90302297-9a10-4688-91b6-c1672cf0a17e',	'a:1:{i:0;s:64:\"core.entity_form_display.block_content.ebt_image_gallery.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:913c0375-72d6-4813-b10b-3696ff0b8a73',	'a:1:{i:0;s:58:\"core.entity_form_display.block_content.ebt_columns.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:9166e36b-940f-481e-9cf3-5aacb1ef1208',	'a:1:{i:0;s:56:\"core.entity_form_display.block_content.ebt_views.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:92792509-019c-4727-be95-79a35850d3e8',	'a:1:{i:0;s:63:\"core.entity_form_display.block_content.ebt_slick_slider.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:99244a65-d42c-43a2-baae-958073fef48f',	'a:1:{i:0;s:50:\"core.entity_form_display.paragraph.ebt_tab.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:996b87ca-42a9-4803-afcc-24ebfbdf7849',	'a:1:{i:0;s:57:\"core.entity_form_display.media.remote_video.media_library\";}'),
('config.entity.key_store.entity_form_display',	'uuid:9ade0a26-a08a-49b3-8f21-5cc52e0a9d4a',	'a:1:{i:0;s:55:\"core.entity_form_display.paragraph.ebt_timeline.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:9efccee6-8cc4-4ff4-92bb-0553278490ef',	'a:1:{i:0;s:44:\"core.entity_form_display.media.audio.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:a186725f-445b-4043-83f2-c3bc2d5b1b87',	'a:1:{i:0;s:55:\"core.entity_form_display.block_content.ebt_text.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:a7152796-e586-430a-a770-6b093d09cb7c',	'a:1:{i:0;s:57:\"core.entity_form_display.paragraph.ebt_stats_item.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:a7d39dc1-5b23-4427-87b3-0bbc28e7b99b',	'a:1:{i:0;s:55:\"core.entity_form_display.block_content.ebt_tabs.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:adebe1bd-2c8a-4e24-8830-be649450bd8e',	'a:1:{i:0;s:56:\"core.entity_form_display.block_content.ebt_video.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:af68c1f1-a952-4c8a-ad1c-06f3eaa33777',	'a:1:{i:0;s:75:\"core.entity_form_display.paragraph.ebt_video_and_image_gallery_item.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:b9105cc0-df88-453b-a92d-90b5e523a386',	'a:1:{i:0;s:60:\"core.entity_form_display.block_content.ebt_countdown.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:c224932f-6de0-4883-88df-0c2ae5186624',	'a:1:{i:0;s:45:\"core.entity_form_display.node.article.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:c99f3040-4f5d-4326-9040-193db1713a88',	'a:1:{i:0;s:47:\"core.entity_form_display.media.document.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:d00c707c-3248-4967-a6d8-4410bbfeb58f',	'a:1:{i:0;s:56:\"core.entity_form_display.block_content.ebt_image.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:d145d9a4-1eb4-4ece-a5e9-4e77dd7a4b2a',	'a:1:{i:0;s:51:\"core.entity_form_display.media.remote_video.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:d1b4eb72-c64f-476b-bb62-88226cb19793',	'a:1:{i:0;s:55:\"core.entity_form_display.paragraph.ebt_carousel.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:d6f88c18-d8de-40c5-9c43-c1c4d94583bd',	'a:1:{i:0;s:55:\"core.entity_form_display.block_content.ebt_hero.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:d9501a4e-79d4-4429-a572-1bc3f75caa0e',	'a:1:{i:0;s:59:\"core.entity_form_display.block_content.ebt_carousel.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:db7027b5-0083-4c23-932e-b8140582e848',	'a:1:{i:0;s:56:\"core.entity_form_display.block_content.ebt_block.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:e6638a9a-dd30-4dab-b46a-9c913eb531bb',	'a:1:{i:0;s:58:\"core.entity_form_display.block_content.ebt_webform.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:ee2f8f98-b9f7-4254-9737-68dc2197b2fd',	'a:1:{i:0;s:56:\"core.entity_form_display.paragraph.ebt_accordion.default\";}'),
('config.entity.key_store.entity_form_display',	'uuid:eed6f1c2-957f-4ca5-9d11-57d9fb6c9564',	'a:1:{i:0;s:50:\"core.entity_form_display.media.video.media_library\";}'),
('config.entity.key_store.entity_form_display',	'uuid:fbaff897-1222-45d2-bdee-f1c92ecc517d',	'a:1:{i:0;s:57:\"core.entity_form_display.paragraph.ebt_tiles_item.default\";}'),
('config.entity.key_store.entity_form_mode',	'uuid:2a875655-65fd-42f4-bd80-8b41714fa393',	'a:1:{i:0;s:35:\"core.entity_form_mode.user.register\";}'),
('config.entity.key_store.entity_form_mode',	'uuid:4f486238-f30d-4022-ac1d-42675ab0f17a',	'a:1:{i:0;s:41:\"core.entity_form_mode.media.media_library\";}'),
('config.entity.key_store.entity_view_display',	'uuid:08318816-b086-4cdd-b48c-c020f5a6f328',	'a:1:{i:0;s:44:\"core.entity_view_display.node.article.teaser\";}'),
('config.entity.key_store.entity_view_display',	'uuid:0a70dbed-c211-4ec2-a7e5-7d9b701046db',	'a:1:{i:0;s:75:\"core.entity_view_display.paragraph.ebt_video_and_image_gallery_item.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:0ad5cd1c-3a95-492c-a42a-3a33aad2fc81',	'a:1:{i:0;s:54:\"core.entity_view_display.block_content.ebt_cta.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:0cdde055-9011-4c16-b82c-494a58ce39ed',	'a:1:{i:0;s:41:\"core.entity_view_display.node.page.teaser\";}'),
('config.entity.key_store.entity_view_display',	'uuid:1395e5da-67f6-420f-a32d-094a7d218bd0',	'a:1:{i:0;s:59:\"core.entity_view_display.block_content.ebt_timeline.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:152c6a3e-8703-40b0-ad21-283b4ae6cc5b',	'a:1:{i:0;s:59:\"core.entity_view_display.paragraph.ebt_slick_slider.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:1c220693-f471-4184-9453-cd90fc0030d2',	'a:1:{i:0;s:42:\"core.entity_view_display.user.user.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:1e1b792b-f71b-470f-9810-bc2e2d11f17f',	'a:1:{i:0;s:53:\"core.entity_view_display.media.remote_video.ebt_video\";}'),
('config.entity.key_store.entity_view_display',	'uuid:2b267e2d-1fdb-48ce-9cb4-9e8ab433ed76',	'a:1:{i:0;s:56:\"core.entity_view_display.block_content.ebt_image.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:2e2b2311-9c14-4e94-aecd-97a3f060f45a',	'a:1:{i:0;s:55:\"core.entity_view_display.paragraph.ebt_carousel.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:2e2f92c3-c50a-4139-9c95-4e46ce1f757d',	'a:1:{i:0;s:41:\"core.entity_view_display.node.article.rss\";}'),
('config.entity.key_store.entity_view_display',	'uuid:38a6ca87-814c-4d4a-b346-9326e4c72021',	'a:1:{i:0;s:44:\"core.entity_view_display.media.audio.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:4043bfd5-1d8c-40be-b5b7-7566608c0a10',	'a:1:{i:0;s:60:\"core.entity_view_display.block_content.ebt_accordion.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:4117f5ae-b100-40a0-82be-376d1b9cdd5c',	'a:1:{i:0;s:58:\"core.entity_view_display.block_content.ebt_counter.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:4b41c82a-77c1-47f0-a052-9b87649b8136',	'a:1:{i:0;s:50:\"core.entity_view_display.paragraph.ebt_tab.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:4b5d6bc4-4cc6-4319-a6bf-ffb11737fa1d',	'a:1:{i:0;s:64:\"core.entity_view_display.block_content.ebt_image_gallery.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:4ccbb938-c11d-49a7-ba57-753328efb08b',	'a:1:{i:0;s:57:\"core.entity_view_display.paragraph.ebt_tiles_item.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:5003e24e-550b-4a07-a87f-66e0dbab0e83',	'a:1:{i:0;s:56:\"core.entity_view_display.paragraph.ebt_slideshow.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:513a5e40-b967-4358-8200-0c9cd79302cb',	'a:1:{i:0;s:65:\"core.entity_view_display.media.image.video_and_image_gallery_item\";}'),
('config.entity.key_store.entity_view_display',	'uuid:553c2833-822a-4508-a2f9-99f9ffc89f33',	'a:1:{i:0;s:55:\"core.entity_view_display.paragraph.ebt_timeline.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:5595a634-71e4-4b9c-840c-c1fcb074609f',	'a:1:{i:0;s:59:\"core.entity_view_display.block_content.ebt_carousel.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:5aaa71f3-3511-4b50-8003-331c936478f3',	'a:1:{i:0;s:42:\"core.entity_view_display.node.page.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:62183f0d-0b60-47ba-bb16-40798a4776ef',	'a:1:{i:0;s:55:\"core.entity_view_display.block_content.ebt_tabs.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:65ebcab1-d240-4884-855d-df0c65f731df',	'a:1:{i:0;s:56:\"core.entity_view_display.block_content.ebt_views.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:73223d5a-b425-4fba-9090-7b112d030f92',	'a:1:{i:0;s:42:\"core.entity_view_display.user.user.compact\";}'),
('config.entity.key_store.entity_view_display',	'uuid:7606605a-9eff-4f52-aff9-3a7d785bb2a3',	'a:1:{i:0;s:56:\"core.entity_view_display.block_content.ebt_quote.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:764e5ba9-f7cd-4885-88bb-ab706b279f69',	'a:1:{i:0;s:60:\"core.entity_view_display.block_content.ebt_slideshow.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:77949beb-f2e0-46a7-bbe3-3ede2ef7f061',	'a:1:{i:0;s:57:\"core.entity_view_display.paragraph.ebt_stats_item.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:7b9a2dff-1714-4265-92f5-b08cb9237f6b',	'a:1:{i:0;s:51:\"core.entity_view_display.media.remote_video.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:7bab1942-d337-4497-a621-f6cc29536967',	'a:1:{i:0;s:46:\"core.entity_view_display.media.video.ebt_video\";}'),
('config.entity.key_store.entity_view_display',	'uuid:7dac4777-4a33-402e-a4fb-d2ec54e7bdbf',	'a:1:{i:0;s:56:\"core.entity_view_display.block_content.ebt_block.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:814b296d-272d-49bd-b543-8a896015c80d',	'a:1:{i:0;s:60:\"core.entity_view_display.block_content.ebt_countdown.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:863188fb-17da-49e4-8e79-ddeb23903eef',	'a:1:{i:0;s:44:\"core.entity_view_display.media.video.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:86bcc126-14bc-40cd-a04a-95794d3f1e10',	'a:1:{i:0;s:58:\"core.entity_view_display.block_content.ebt_columns.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:8a03d29e-a687-49e7-9a56-0dfe88836e7a',	'a:1:{i:0;s:67:\"core.entity_view_display.block_content.ebt_bootstrap_button.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:8c54cc11-1b16-48f3-a610-44727c203a3d',	'a:1:{i:0;s:56:\"core.entity_view_display.block_content.ebt_stats.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:8d599765-5bbf-4aff-b2cb-bd108e6c5046',	'a:1:{i:0;s:64:\"core.entity_view_display.block_content.ebt_webform_popup.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:8feddd3f-45a8-46bf-a16f-2be6634a45ea',	'a:1:{i:0;s:63:\"core.entity_view_display.block_content.ebt_slick_slider.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:9672ae47-7a64-49d5-904a-cba847d9377d',	'a:1:{i:0;s:72:\"core.entity_view_display.media.remote_video.video_and_image_gallery_item\";}'),
('config.entity.key_store.entity_view_display',	'uuid:96a65454-d2c6-4d47-8247-42a53fffe403',	'a:1:{i:0;s:56:\"core.entity_view_display.block_content.ebt_video.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:97d9050c-f2b4-4b7e-9f3f-10de564e06a0',	'a:1:{i:0;s:45:\"core.entity_view_display.node.article.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:9cd9785e-414b-4ccf-a6f4-9b5039218fd0',	'a:1:{i:0;s:59:\"core.entity_view_display.paragraph.ebt_counter_item.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:a35ebe6b-2715-41f7-a570-96ae3af68c78',	'a:1:{i:0;s:54:\"core.entity_view_display.media.image.ebt_image_gallery\";}'),
('config.entity.key_store.entity_view_display',	'uuid:b0e61493-d3f5-4a7d-8ead-492300acdf21',	'a:1:{i:0;s:53:\"core.entity_view_display.media.document.media_library\";}'),
('config.entity.key_store.entity_view_display',	'uuid:b33df2ac-91d5-4257-bfa4-bb4911c6a960',	'a:1:{i:0;s:55:\"core.entity_view_display.block_content.ebt_text.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:b7590d64-18fe-489a-8317-2999e71355e3',	'a:1:{i:0;s:74:\"core.entity_view_display.block_content.ebt_video_and_image_gallery.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:beb45182-e505-48ae-a153-5d34274d8013',	'a:1:{i:0;s:47:\"core.entity_view_display.media.document.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:c80bfe30-db84-4270-a319-1c27729f2edf',	'a:1:{i:0;s:44:\"core.entity_view_display.media.image.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:d00b3c78-35a0-460e-a063-a98a387591cc',	'a:1:{i:0;s:50:\"core.entity_view_display.media.video.media_library\";}'),
('config.entity.key_store.entity_view_display',	'uuid:d5902a81-52d9-49dd-b8db-4665dbc4368c',	'a:1:{i:0;s:52:\"core.entity_view_display.block_content.basic.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:d7bca4fc-d99f-4966-929d-15f5247c8564',	'a:1:{i:0;s:56:\"core.entity_view_display.paragraph.ebt_accordion.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:dc06c30d-3cfa-4f39-809f-8390cd056466',	'a:1:{i:0;s:58:\"core.entity_view_display.block_content.ebt_webform.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:e002007d-e402-414c-a43e-0e11a4ff059c',	'a:1:{i:0;s:63:\"core.entity_view_display.block_content.ebt_basic_button.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:e91b1f8e-5ba5-485e-9c6e-04afe2948e85',	'a:1:{i:0;s:57:\"core.entity_view_display.media.remote_video.media_library\";}'),
('config.entity.key_store.entity_view_display',	'uuid:ede5e29a-aefb-40b5-9859-1ac8ed22e499',	'a:1:{i:0;s:50:\"core.entity_view_display.media.audio.media_library\";}'),
('config.entity.key_store.entity_view_display',	'uuid:ef3f9c37-ba74-4569-9402-eb895497b1ee',	'a:1:{i:0;s:55:\"core.entity_view_display.block_content.ebt_hero.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:f5514d94-f0a7-4adb-af94-b565702bcb87',	'a:1:{i:0;s:61:\"core.entity_view_display.block_content.ebt_micromodal.default\";}'),
('config.entity.key_store.entity_view_display',	'uuid:f69a9286-8f3b-42cf-a15a-5f569ca96e99',	'a:1:{i:0;s:50:\"core.entity_view_display.media.image.media_library\";}'),
('config.entity.key_store.entity_view_display',	'uuid:fb6bfaa3-7636-41c1-a411-dff1def2fef0',	'a:1:{i:0;s:56:\"core.entity_view_display.block_content.ebt_tiles.default\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:004ad1d4-03ad-4317-af82-4bb9f039c686',	'a:1:{i:0;s:41:\"core.entity_view_mode.block_content.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:06ded9f9-3e1a-44f0-a5e0-224efcca6431',	'a:1:{i:0;s:34:\"core.entity_view_mode.user.compact\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:1a098749-bd7d-429f-9d91-d4e7913c8c3c',	'a:1:{i:0;s:41:\"core.entity_view_mode.media.media_library\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:33a56e28-1d42-4a4f-b42a-88eb552104a7',	'a:1:{i:0;s:45:\"core.entity_view_mode.menu_link_content.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:3ec23f24-50ef-434e-a7b6-3d8cb9a2a4f4',	'a:1:{i:0;s:32:\"core.entity_view_mode.node.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:416e3f7c-ab1b-4bb4-b428-aabf9906eecf',	'a:1:{i:0;s:39:\"core.entity_view_mode.node.search_index\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:550ba8ad-246f-433e-8c0d-f2c76255df0e',	'a:1:{i:0;s:36:\"core.entity_view_mode.shortcut.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:5aefb664-7e3c-4ebe-86a2-07194cada9f4',	'a:1:{i:0;s:31:\"core.entity_view_mode.node.full\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:5f8faafa-6ec3-4704-a06c-08d5391b12d7',	'a:1:{i:0;s:35:\"core.entity_view_mode.webform.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:676a8206-d9d0-4094-bf54-66a60c6bad53',	'a:1:{i:0;s:32:\"core.entity_view_mode.user.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:6b3209c3-0ae1-46f6-8e2c-44d4391f2434',	'a:1:{i:0;s:30:\"core.entity_view_mode.node.rss\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:6f5a787d-85f5-4bea-aab2-4094c6f7772f',	'a:1:{i:0;s:56:\"core.entity_view_mode.media.video_and_image_gallery_item\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:9268fa23-36f9-4a94-a9ef-799f2d1c5eb5',	'a:1:{i:0;s:40:\"core.entity_view_mode.block_content.full\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:92d0137a-b4c4-4c19-b07b-84c8b8844019',	'a:1:{i:0;s:46:\"core.entity_view_mode.webform_submission.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:99749d8d-98ee-49e8-b272-054f53d7c97f',	'a:1:{i:0;s:32:\"core.entity_view_mode.file.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:9ff59caf-8ee9-4fca-bffa-89132c94c813',	'a:1:{i:0;s:37:\"core.entity_view_mode.media.ebt_video\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:aa6556df-5384-471d-96b4-a6d264801693',	'a:1:{i:0;s:33:\"core.entity_view_mode.media.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:aa910ffb-3a87-4512-af06-273b721bc12f',	'a:1:{i:0;s:33:\"core.entity_view_mode.node.teaser\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:ad69e028-e0a2-4eab-9d8b-d18e904da6bf',	'a:1:{i:0;s:31:\"core.entity_view_mode.user.full\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:b47111c9-dcb8-4762-af5c-3f7acca095d2',	'a:1:{i:0;s:38:\"core.entity_view_mode.path_alias.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:b51e5b3c-1a2e-49cf-acff-bfc2dea5ad40',	'a:1:{i:0;s:43:\"core.entity_view_mode.contact_message.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:c196759a-15b6-47d3-b672-f853645cc638',	'a:1:{i:0;s:40:\"core.entity_view_mode.node.search_result\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:c298243a-fc61-46e8-8878-5de88a9bcb0b',	'a:1:{i:0;s:33:\"core.entity_view_mode.block.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:d8772b40-e75a-46fe-a0eb-48e3c2f13441',	'a:1:{i:0;s:45:\"core.entity_view_mode.media.ebt_image_gallery\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:e72ba8d8-dba4-4920-91d6-5e916b81a6fc',	'a:1:{i:0;s:40:\"core.entity_view_mode.taxonomy_term.full\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:ea887f34-9e29-4000-aef4-21112004577d',	'a:1:{i:0;s:41:\"core.entity_view_mode.taxonomy_term.token\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:f30f214f-6163-41a8-a996-f703e5fd92cb',	'a:1:{i:0;s:39:\"core.entity_view_mode.paragraph.preview\";}'),
('config.entity.key_store.entity_view_mode',	'uuid:fb758fd6-28cd-4155-8eda-49912e1da3f8',	'a:1:{i:0;s:32:\"core.entity_view_mode.media.full\";}'),
('config.entity.key_store.field_config',	'uuid:02b3090f-c1e2-41ef-961f-8f9dbe3677b7',	'a:1:{i:0;s:57:\"field.field.block_content.ebt_block.field_ebt_block_block\";}'),
('config.entity.key_store.field_config',	'uuid:04371c34-46be-4086-ae87-cc361d2d3ced',	'a:1:{i:0;s:61:\"field.field.block_content.ebt_hero.field_ebt_hero_second_link\";}'),
('config.entity.key_store.field_config',	'uuid:06f91975-9ecb-430d-b7f8-3de8ae8601c8',	'a:1:{i:0;s:39:\"field.field.node.article.field_metatags\";}'),
('config.entity.key_store.field_config',	'uuid:0776e496-c917-49a5-a502-a77f73b79b69',	'a:1:{i:0;s:61:\"field.field.block_content.ebt_counter.field_ebt_counter_items\";}'),
('config.entity.key_store.field_config',	'uuid:082df8d4-f424-4ec5-9be7-fa79dca0bc70',	'a:1:{i:0;s:58:\"field.field.block_content.ebt_accordion.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:087b3c83-4e91-4f68-b458-96330c343db8',	'a:1:{i:0;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_text\";}'),
('config.entity.key_store.field_config',	'uuid:0cb50bf8-21aa-4ea6-a7d0-90d454555f86',	'a:1:{i:0;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_text\";}'),
('config.entity.key_store.field_config',	'uuid:0ed191f1-4795-4501-9075-ad48a0ed7ef5',	'a:1:{i:0;s:67:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_image\";}'),
('config.entity.key_store.field_config',	'uuid:11b83dfa-e605-4b74-8cab-d665ab3d12a3',	'a:1:{i:0;s:55:\"field.field.block_content.ebt_hero.field_ebt_hero_title\";}'),
('config.entity.key_store.field_config',	'uuid:1396353c-ec74-4693-9d16-7ffb5a6090cc',	'a:1:{i:0;s:53:\"field.field.block_content.ebt_tabs.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:13cbf6a5-260c-40e0-b225-a8dd66d72da5',	'a:1:{i:0;s:60:\"field.field.block_content.ebt_cta.field_ebt_cta_column_image\";}'),
('config.entity.key_store.field_config',	'uuid:157b9dd5-a769-42f1-9986-195e571255c4',	'a:1:{i:0;s:59:\"field.field.block_content.ebt_micromodal.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:161669c7-6a7e-4616-86d5-a2e3de9c8fe5',	'a:1:{i:0;s:58:\"field.field.block_content.ebt_video_and_image_gallery.body\";}'),
('config.entity.key_store.field_config',	'uuid:1dd47019-ce01-47d2-8520-e5625b17bd32',	'a:1:{i:0;s:45:\"field.field.block_content.ebt_micromodal.body\";}'),
('config.entity.key_store.field_config',	'uuid:1df891a3-3bde-4def-8c4e-79dd5182017a',	'a:1:{i:0;s:56:\"field.field.block_content.ebt_counter.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:1e3aa7ba-222f-4f33-8628-7c5bf22f00fe',	'a:1:{i:0;s:54:\"field.field.block_content.ebt_stats.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:1e88de7b-7c46-4562-a223-9ccf83779820',	'a:1:{i:0;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_title\";}'),
('config.entity.key_store.field_config',	'uuid:1ebfa792-cf03-471d-9e5c-2dccd1fedd38',	'a:1:{i:0;s:47:\"field.field.media.document.field_media_document\";}'),
('config.entity.key_store.field_config',	'uuid:20361483-5f67-45d3-a3cb-a44f2e7bbae3',	'a:1:{i:0;s:48:\"field.field.block_content.ebt_image_gallery.body\";}'),
('config.entity.key_store.field_config',	'uuid:217d9d46-984c-450c-b218-1d58121ced68',	'a:1:{i:0;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_title\";}'),
('config.entity.key_store.field_config',	'uuid:21e7fce1-906b-4e52-94b2-deaee971de2d',	'a:1:{i:0;s:59:\"field.field.block_content.ebt_cta.field_ebt_cta_second_link\";}'),
('config.entity.key_store.field_config',	'uuid:22004f3b-acef-4ec7-a26a-84514e3b0755',	'a:1:{i:0;s:36:\"field.field.block_content.basic.body\";}'),
('config.entity.key_store.field_config',	'uuid:22d74b30-be52-4cee-91ea-a0aa04de5dff',	'a:1:{i:0;s:61:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_icon\";}'),
('config.entity.key_store.field_config',	'uuid:237e10e6-95ca-4f5e-9d1b-2f1d8f7eef67',	'a:1:{i:0;s:65:\"field.field.block_content.ebt_slick_slider.field_ebt_slick_slider\";}'),
('config.entity.key_store.field_config',	'uuid:24fd2c38-f992-42ae-89ce-590dd574cb31',	'a:1:{i:0;s:61:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_current\";}'),
('config.entity.key_store.field_config',	'uuid:265711bf-cab4-450f-83c7-f401aa255ff1',	'a:1:{i:0;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_text\";}'),
('config.entity.key_store.field_config',	'uuid:278f7615-4ab0-4e87-963f-33f2ae8f78ed',	'a:1:{i:0;s:72:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:280d2344-5e0c-42f5-bd77-7b358f9b2c08',	'a:1:{i:0;s:51:\"field.field.block_content.ebt_stats.field_ebt_stats\";}'),
('config.entity.key_store.field_config',	'uuid:28cf0280-0877-4dba-9961-a719b378e9f3',	'a:1:{i:0;s:44:\"field.field.block_content.ebt_accordion.body\";}'),
('config.entity.key_store.field_config',	'uuid:28dce901-3d51-4486-b431-ddbf214523f7',	'a:1:{i:0;s:61:\"field.field.block_content.ebt_basic_button.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:2907b7cd-48be-4276-8c1a-ad20ca437cd4',	'a:1:{i:0;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_text\";}'),
('config.entity.key_store.field_config',	'uuid:2a94aaad-3c54-4074-9d7a-fc204b0cc509',	'a:1:{i:0;s:53:\"field.field.block_content.ebt_text.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:2bc22340-9888-4636-9768-5a9bc9ffd66c',	'a:1:{i:0;s:57:\"field.field.block_content.ebt_carousel.field_ebt_carousel\";}'),
('config.entity.key_store.field_config',	'uuid:2c335583-7279-4b40-95b9-09d17b06fc4a',	'a:1:{i:0;s:85:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_gallery_item_description\";}'),
('config.entity.key_store.field_config',	'uuid:2d4456ac-0c7c-4f72-8624-a25a5d933b9b',	'a:1:{i:0;s:79:\"field.field.paragraph.ebt_video_and_image_gallery_item.field_video_gallery_item\";}'),
('config.entity.key_store.field_config',	'uuid:2e2ec692-0d82-4b56-9cfc-4e871f3a1882',	'a:1:{i:0;s:51:\"field.field.block_content.ebt_tiles.field_ebt_tiles\";}'),
('config.entity.key_store.field_config',	'uuid:2e653244-7a00-41c7-a943-06eade5f15ef',	'a:1:{i:0;s:51:\"field.field.block_content.ebt_video.field_ebt_video\";}'),
('config.entity.key_store.field_config',	'uuid:308dba68-d030-422d-b8e9-72568d1fd20a',	'a:1:{i:0;s:78:\"field.field.block_content.ebt_bootstrap_button.field_ebt_bootstrap_button_link\";}'),
('config.entity.key_store.field_config',	'uuid:33c69170-b2b4-49a9-9557-a9542eb08865',	'a:1:{i:0;s:40:\"field.field.block_content.ebt_stats.body\";}'),
('config.entity.key_store.field_config',	'uuid:34788ebc-a5ee-43a6-be6c-58bf07f8a47a',	'a:1:{i:0;s:54:\"field.field.block_content.ebt_tiles.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:35e70eb2-5981-4ca9-9540-a6263e5f01ee',	'a:1:{i:0;s:61:\"field.field.block_content.ebt_slick_slider.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:3a0e2513-d1ec-4966-9162-427a855b0977',	'a:1:{i:0;s:54:\"field.field.block_content.ebt_views.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:3c7cd9d7-a4c3-49a9-9bbc-1ced5ab70209',	'a:1:{i:0;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_link\";}'),
('config.entity.key_store.field_config',	'uuid:47eab2ed-be4c-44cf-8125-61c4726d2170',	'a:1:{i:0;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_column_image\";}'),
('config.entity.key_store.field_config',	'uuid:4ae0f11b-4c4f-43c8-a58e-9413b992ad4d',	'a:1:{i:0;s:60:\"field.field.paragraph.ebt_stats_item.field_stats_item_number\";}'),
('config.entity.key_store.field_config',	'uuid:4c8c9d22-d8fd-4927-b62c-41815a17d1c4',	'a:1:{i:0;s:62:\"field.field.block_content.ebt_image_gallery.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:4cf8e43c-52cf-40e7-8fab-03ba24e5671d',	'a:1:{i:0;s:54:\"field.field.block_content.ebt_block.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:4f2baecc-10aa-4164-b62a-d414a7a219b8',	'a:1:{i:0;s:54:\"field.field.block_content.ebt_image.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:4fa57014-dbe5-4dc4-b5c9-e6cb3404ad5c',	'a:1:{i:0;s:46:\"field.field.media.audio.field_media_audio_file\";}'),
('config.entity.key_store.field_config',	'uuid:5201e488-c9af-4ec2-867e-3b3dbe8c8b16',	'a:1:{i:0;s:57:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_text\";}'),
('config.entity.key_store.field_config',	'uuid:55445905-ca67-4040-b176-00e1fc2ebb3e',	'a:1:{i:0;s:54:\"field.field.block_content.ebt_video.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:55f4a1e8-6366-4c0b-aba3-0f05bdc8dccc',	'a:1:{i:0;s:38:\"field.field.block_content.ebt_cta.body\";}'),
('config.entity.key_store.field_config',	'uuid:56e05cdb-f253-4954-9c39-5253face9482',	'a:1:{i:0;s:58:\"field.field.block_content.ebt_countdown.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:59e52aef-8c74-4576-ae43-df723099b73d',	'a:1:{i:0;s:67:\"field.field.block_content.ebt_micromodal.field_ebt_micromodal_title\";}'),
('config.entity.key_store.field_config',	'uuid:5c306dcf-d85c-424e-b5d0-a819386f6ecc',	'a:1:{i:0;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_views\";}'),
('config.entity.key_store.field_config',	'uuid:5c41064f-97a8-4a0e-aea7-eab453f27eb0',	'a:1:{i:0;s:58:\"field.field.block_content.ebt_quote.field_ebt_quote_author\";}'),
('config.entity.key_store.field_config',	'uuid:5f1f69e3-3f90-4442-95f1-5c1579c679ab',	'a:1:{i:0;s:57:\"field.field.block_content.ebt_views.field_ebt_views_views\";}'),
('config.entity.key_store.field_config',	'uuid:61a810a4-e29c-4fbf-b132-9fe51b115626',	'a:1:{i:0;s:35:\"field.field.node.article.field_tags\";}'),
('config.entity.key_store.field_config',	'uuid:62ea8aa7-eadf-46fe-8360-d5a565d6e339',	'a:1:{i:0;s:62:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_title\";}'),
('config.entity.key_store.field_config',	'uuid:67606c2f-9b8c-41b7-80d6-aa24493fa0d3',	'a:1:{i:0;s:53:\"field.field.block_content.ebt_cta.field_ebt_cta_title\";}'),
('config.entity.key_store.field_config',	'uuid:67b6c95b-30fa-471d-a031-e84ec26a1a54',	'a:1:{i:0;s:58:\"field.field.paragraph.ebt_stats_item.field_stats_item_link\";}'),
('config.entity.key_store.field_config',	'uuid:6821e0ef-8080-428a-ac78-f51249bb5e2d',	'a:1:{i:0;s:49:\"field.field.paragraph.ebt_tab.field_ebt_tab_block\";}'),
('config.entity.key_store.field_config',	'uuid:6b77acaf-9fab-4d2e-9843-cfe8180ce9fe',	'a:1:{i:0;s:48:\"field.field.paragraph.ebt_tab.field_ebt_tab_page\";}'),
('config.entity.key_store.field_config',	'uuid:7266abd1-c799-4ff0-96ef-b464471e6583',	'a:1:{i:0;s:44:\"field.field.block_content.ebt_countdown.body\";}'),
('config.entity.key_store.field_config',	'uuid:72a4ef65-870a-4488-8009-80269e968b1b',	'a:1:{i:0;s:57:\"field.field.block_content.ebt_timeline.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:79c176b7-33a8-419d-b175-1853525a7e50',	'a:1:{i:0;s:44:\"field.field.node.page.layout_builder__layout\";}'),
('config.entity.key_store.field_config',	'uuid:7bd9f73f-8c64-46d8-9848-e86bcb5b491e',	'a:1:{i:0;s:62:\"field.field.block_content.ebt_webform_popup.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:7f75b85e-a8a9-4e63-8ba8-42cd18f1d713',	'a:1:{i:0;s:29:\"field.field.node.article.body\";}'),
('config.entity.key_store.field_config',	'uuid:82540ccc-a725-412b-b6ba-bc89d09e03fb',	'a:1:{i:0;s:57:\"field.field.block_content.ebt_carousel.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:8733818b-9c02-4e2c-91a6-045583f1e01d',	'a:1:{i:0;s:42:\"field.field.block_content.ebt_webform.body\";}'),
('config.entity.key_store.field_config',	'uuid:87a15adf-8be6-4080-925b-ebc76f101b32',	'a:1:{i:0;s:57:\"field.field.block_content.ebt_timeline.field_ebt_timeline\";}'),
('config.entity.key_store.field_config',	'uuid:89d82ff4-da95-426e-b0c1-c9f18b4c7e6a',	'a:1:{i:0;s:68:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_description\";}'),
('config.entity.key_store.field_config',	'uuid:8c50936f-d412-4429-a9af-fe0720478b0f',	'a:1:{i:0;s:54:\"field.field.block_content.ebt_hero.field_ebt_hero_link\";}'),
('config.entity.key_store.field_config',	'uuid:9093a2e3-eafc-42f9-9d74-0c76cf2fa7e6',	'a:1:{i:0;s:51:\"field.field.paragraph.ebt_tab.field_ebt_tab_content\";}'),
('config.entity.key_store.field_config',	'uuid:96b9388f-0779-4e2b-8429-6932b1a68ead',	'a:1:{i:0;s:55:\"field.field.media.remote_video.field_media_oembed_video\";}'),
('config.entity.key_store.field_config',	'uuid:97640446-27d5-4146-8b2a-a776d7a62ec7',	'a:1:{i:0;s:47:\"field.field.node.article.layout_builder__layout\";}'),
('config.entity.key_store.field_config',	'uuid:9ab7be9d-f391-4845-abb9-9620046d2cea',	'a:1:{i:0;s:53:\"field.field.block_content.ebt_hero.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:9b4acfb1-3d8e-4e3d-8901-6120a3b342b2',	'a:1:{i:0;s:40:\"field.field.block_content.ebt_video.body\";}'),
('config.entity.key_store.field_config',	'uuid:9ba660a3-d550-47fe-aaa5-4325e7ffe30d',	'a:1:{i:0;s:60:\"field.field.block_content.ebt_counter.field_ebt_counter_icon\";}'),
('config.entity.key_store.field_config',	'uuid:9c984eac-a275-47d3-a7ac-029f8216fcb8',	'a:1:{i:0;s:60:\"field.field.block_content.ebt_webform.field_ebt_webform_form\";}'),
('config.entity.key_store.field_config',	'uuid:9cc6560f-9a4a-4969-9e4b-0d667ef4817c',	'a:1:{i:0;s:56:\"field.field.block_content.ebt_columns.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:9d903341-553f-4311-8a83-c48130d410e0',	'a:1:{i:0;s:58:\"field.field.paragraph.ebt_tiles_item.field_ebt_tiles_image\";}'),
('config.entity.key_store.field_config',	'uuid:a0651ff8-3cb5-478f-acbe-120dd869e921',	'a:1:{i:0;s:65:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_media_image\";}'),
('config.entity.key_store.field_config',	'uuid:a50fcf2c-9887-448e-a18c-78ac4e87b38c',	'a:1:{i:0;s:56:\"field.field.block_content.ebt_webform.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:a99bd180-01c5-4300-997c-47456c8ba004',	'a:1:{i:0;s:34:\"field.field.user.user.user_picture\";}'),
('config.entity.key_store.field_config',	'uuid:aa44dee9-e2fb-4a02-8f85-0ed2534a54e9',	'a:1:{i:0;s:57:\"field.field.block_content.ebt_quote.field_ebt_quote_image\";}'),
('config.entity.key_store.field_config',	'uuid:ac203ba4-4731-48c0-a489-49772d98bbcc',	'a:1:{i:0;s:47:\"field.field.block_content.ebt_slick_slider.body\";}'),
('config.entity.key_store.field_config',	'uuid:ae101647-2196-429e-ba3e-cbb55e4e92f3',	'a:1:{i:0;s:59:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_title\";}'),
('config.entity.key_store.field_config',	'uuid:ae270a12-20ca-4ebe-a2f1-69ea8b4fe6e9',	'a:1:{i:0;s:66:\"field.field.paragraph.ebt_slick_slider.field_ebt_slick_slider_link\";}'),
('config.entity.key_store.field_config',	'uuid:af846c60-eb6c-4029-84b4-aa0ccf412591',	'a:1:{i:0;s:46:\"field.field.media.video.field_media_video_file\";}'),
('config.entity.key_store.field_config',	'uuid:b13d5126-3f86-4bb5-8cdc-a9b72478ab6b',	'a:1:{i:0;s:40:\"field.field.block_content.ebt_tiles.body\";}'),
('config.entity.key_store.field_config',	'uuid:b2ba6467-2022-4aa3-9527-2821ef8b3866',	'a:1:{i:0;s:52:\"field.field.block_content.ebt_cta.field_ebt_cta_link\";}'),
('config.entity.key_store.field_config',	'uuid:b3a9c8ab-38aa-42a9-9c7a-8d9b4c4e0192',	'a:1:{i:0;s:52:\"field.field.block_content.ebt_cta.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:b4ecb5ee-b852-4360-ab89-92327a624bdf',	'a:1:{i:0;s:62:\"field.field.block_content.ebt_counter.field_ebt_counter_number\";}'),
('config.entity.key_store.field_config',	'uuid:b6bcf941-67b4-43b7-9747-c95baf1b7bc4',	'a:1:{i:0;s:61:\"field.field.paragraph.ebt_tiles_item.field_ebt_clickable_tile\";}'),
('config.entity.key_store.field_config',	'uuid:b6c8e80f-807f-4acf-b36e-55ea98dc4fb3',	'a:1:{i:0;s:42:\"field.field.block_content.ebt_columns.body\";}'),
('config.entity.key_store.field_config',	'uuid:b6ea63fb-dfef-42aa-bda8-892c68583ffc',	'a:1:{i:0;s:65:\"field.field.block_content.ebt_bootstrap_button.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:b89072e5-91ec-40a1-aa9c-2a20808308cb',	'a:1:{i:0;s:49:\"field.field.block_content.ebt_tabs.field_ebt_tabs\";}'),
('config.entity.key_store.field_config',	'uuid:b8c36a1d-4e00-47c8-8d3b-5f5c824c1c41',	'a:1:{i:0;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_slide\";}'),
('config.entity.key_store.field_config',	'uuid:b99d81f7-46a3-4dd4-8588-c20bf7f86b06',	'a:1:{i:0;s:39:\"field.field.block_content.ebt_hero.body\";}'),
('config.entity.key_store.field_config',	'uuid:ba97827c-59cc-4fb5-be06-7c44f9e98113',	'a:1:{i:0;s:36:\"field.field.node.article.field_image\";}'),
('config.entity.key_store.field_config',	'uuid:bcd054c1-c1e6-47a1-9c84-af43855b0dc7',	'a:1:{i:0;s:40:\"field.field.block_content.ebt_quote.body\";}'),
('config.entity.key_store.field_config',	'uuid:c0f9b024-755c-40ce-9a70-2d7135b9b02d',	'a:1:{i:0;s:70:\"field.field.block_content.ebt_basic_button.field_ebt_basic_button_link\";}'),
('config.entity.key_store.field_config',	'uuid:c23a3476-69db-400e-a938-54992d1cfa18',	'a:1:{i:0;s:42:\"field.field.block_content.ebt_counter.body\";}'),
('config.entity.key_store.field_config',	'uuid:c5fb6c52-df83-49a6-982d-13cd459b5086',	'a:1:{i:0;s:54:\"field.field.block_content.ebt_quote.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:c72f430e-7366-4a91-bce3-aa5dc0cf8726',	'a:1:{i:0;s:39:\"field.field.block_content.ebt_text.body\";}'),
('config.entity.key_store.field_config',	'uuid:c7bb20d0-7c3a-4e1d-80bd-fc8145337db5',	'a:1:{i:0;s:61:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_title\";}'),
('config.entity.key_store.field_config',	'uuid:c82da539-0efe-4f63-b7ed-cfb0c65f3022',	'a:1:{i:0;s:40:\"field.field.block_content.ebt_block.body\";}'),
('config.entity.key_store.field_config',	'uuid:cc62f49e-1354-4058-a151-c4c1e7e5994a',	'a:1:{i:0;s:61:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_title\";}'),
('config.entity.key_store.field_config',	'uuid:cdf69cb6-7607-44f2-8e15-66eff3ea978e',	'a:1:{i:0;s:61:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_caption\";}'),
('config.entity.key_store.field_config',	'uuid:cf3345b8-8872-40ef-818f-2e94b33e8961',	'a:1:{i:0;s:59:\"field.field.paragraph.ebt_carousel.field_ebt_carousel_image\";}'),
('config.entity.key_store.field_config',	'uuid:d1569baf-9302-4e38-9ed4-987caeafa2e4',	'a:1:{i:0;s:58:\"field.field.paragraph.ebt_timeline.field_ebt_timeline_date\";}'),
('config.entity.key_store.field_config',	'uuid:d64d6cf7-d342-4551-933f-875ccf757101',	'a:1:{i:0;s:56:\"field.field.block_content.ebt_image.field_ebt_image_link\";}'),
('config.entity.key_store.field_config',	'uuid:d7eb3cf3-fabf-4526-9e59-2559843a4b10',	'a:1:{i:0;s:59:\"field.field.block_content.ebt_image.field_ebt_image_caption\";}'),
('config.entity.key_store.field_config',	'uuid:da20cc91-36e0-4116-8c1e-1b5e33ccbd6e',	'a:1:{i:0;s:59:\"field.field.block_content.ebt_accordion.field_ebt_accordion\";}'),
('config.entity.key_store.field_config',	'uuid:daee2d15-8abc-4764-8789-2fcf13604386',	'a:1:{i:0;s:64:\"field.field.block_content.ebt_countdown.field_ebt_countdown_date\";}'),
('config.entity.key_store.field_config',	'uuid:db307a56-3f8e-4027-b5d1-28fe5edaa11e',	'a:1:{i:0;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_text\";}'),
('config.entity.key_store.field_config',	'uuid:dfe1a625-168b-485c-9c9e-2e8296f0dec8',	'a:1:{i:0;s:59:\"field.field.block_content.ebt_slideshow.field_ebt_slideshow\";}'),
('config.entity.key_store.field_config',	'uuid:e2b79a9d-deda-4076-bcbe-2c9ae00b616e',	'a:1:{i:0;s:41:\"field.field.media.image.field_media_image\";}'),
('config.entity.key_store.field_config',	'uuid:e3b02b26-e9be-46ee-be2a-9c0cdb537a47',	'a:1:{i:0;s:63:\"field.field.paragraph.ebt_counter_item.field_ebt_counter_number\";}'),
('config.entity.key_store.field_config',	'uuid:e785ab1b-0edf-46aa-bbaf-56e645079434',	'a:1:{i:0;s:36:\"field.field.node.page.field_metatags\";}'),
('config.entity.key_store.field_config',	'uuid:e7dc4733-12c7-4748-975b-b7d57accd4ee',	'a:1:{i:0;s:59:\"field.field.paragraph.ebt_stats_item.field_stats_item_image\";}'),
('config.entity.key_store.field_config',	'uuid:ebbc4709-9eb2-4a48-bc09-0d83eaad805d',	'a:1:{i:0;s:72:\"field.field.block_content.ebt_webform_popup.field_ebt_webform_popup_form\";}'),
('config.entity.key_store.field_config',	'uuid:eca7b2b8-8806-49f1-ae15-756018a6c67f',	'a:1:{i:0;s:62:\"field.field.block_content.ebt_columns.field_ebt_columns_blocks\";}'),
('config.entity.key_store.field_config',	'uuid:efc991a5-26b8-4df3-977e-953a90c2f86c',	'a:1:{i:0;s:81:\"field.field.block_content.ebt_video_and_image_gallery.field_ebt_videos_and_images\";}'),
('config.entity.key_store.field_config',	'uuid:f07c72d3-6387-4d4d-a4eb-5a81420e247b',	'a:1:{i:0;s:51:\"field.field.block_content.ebt_image.field_ebt_image\";}'),
('config.entity.key_store.field_config',	'uuid:f0b63cf1-7f17-4dea-a7e0-b54d5d7d823f',	'a:1:{i:0;s:60:\"field.field.paragraph.ebt_accordion.field_ebt_accordion_text\";}'),
('config.entity.key_store.field_config',	'uuid:f115e5b7-c8ee-4130-9311-4bc5ac45d6d1',	'a:1:{i:0;s:62:\"field.field.block_content.ebt_hero.field_ebt_hero_title_prefix\";}'),
('config.entity.key_store.field_config',	'uuid:f2e704ba-2d4f-4bf0-976b-19d893472d4f',	'a:1:{i:0;s:26:\"field.field.node.page.body\";}'),
('config.entity.key_store.field_config',	'uuid:f3fdd942-959d-4943-993f-2d7c52030728',	'a:1:{i:0;s:60:\"field.field.paragraph.ebt_slideshow.field_ebt_slideshow_link\";}'),
('config.entity.key_store.field_config',	'uuid:f6196b18-31e7-4003-842a-206131de10c0',	'a:1:{i:0;s:58:\"field.field.block_content.ebt_slideshow.field_ebt_settings\";}'),
('config.entity.key_store.field_config',	'uuid:f746c64f-5c49-4079-bb53-0a1a1dd1a7c4',	'a:1:{i:0;s:40:\"field.field.block_content.ebt_views.body\";}'),
('config.entity.key_store.field_config',	'uuid:f76e7399-746c-4735-a354-63cad22949ff',	'a:1:{i:0;s:67:\"field.field.block_content.ebt_image_gallery.field_ebt_image_gallery\";}'),
('config.entity.key_store.field_storage_config',	'uuid:007c60bc-7d54-4666-8065-f77200cca762',	'a:1:{i:0;s:52:\"field.storage.block_content.field_ebt_columns_blocks\";}'),
('config.entity.key_store.field_storage_config',	'uuid:01dcf303-887c-48ba-8de3-a183f2dc164d',	'a:1:{i:0;s:41:\"field.storage.node.layout_builder__layout\";}'),
('config.entity.key_store.field_storage_config',	'uuid:069a665c-1062-4320-b384-be548389f826',	'a:1:{i:0;s:46:\"field.storage.block_content.field_ebt_cta_link\";}'),
('config.entity.key_store.field_storage_config',	'uuid:08365941-eddc-446f-8fc9-72a7728df65c',	'a:1:{i:0;s:50:\"field.storage.block_content.field_ebt_webform_form\";}'),
('config.entity.key_store.field_storage_config',	'uuid:0ab015a1-cb97-4ec7-ad66-d236d2472cee',	'a:1:{i:0;s:51:\"field.storage.block_content.field_ebt_image_gallery\";}'),
('config.entity.key_store.field_storage_config',	'uuid:0c03a11f-8242-48d7-ae98-2da2e80f3f2e',	'a:1:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_title\";}'),
('config.entity.key_store.field_storage_config',	'uuid:0ce9563d-0108-4dd8-9768-e3f3f692efb8',	'a:1:{i:0;s:30:\"field.storage.node.field_image\";}'),
('config.entity.key_store.field_storage_config',	'uuid:0d6fd00f-5382-443f-ae8a-996e1552af22',	'a:1:{i:0;s:45:\"field.storage.paragraph.field_stats_item_text\";}'),
('config.entity.key_store.field_storage_config',	'uuid:0fc30373-baea-48fd-8769-4b6c582ae3d8',	'a:1:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_block\";}'),
('config.entity.key_store.field_storage_config',	'uuid:1043de86-9fe2-4436-8425-6f47521f1f00',	'a:1:{i:0;s:50:\"field.storage.paragraph.field_ebt_timeline_current\";}'),
('config.entity.key_store.field_storage_config',	'uuid:11256bc1-c4ef-404b-ae80-826c196dfc3c',	'a:1:{i:0;s:29:\"field.storage.node.field_tags\";}'),
('config.entity.key_store.field_storage_config',	'uuid:13a3c6c5-6417-4477-8a58-0b066b2141c3',	'a:1:{i:0;s:31:\"field.storage.user.user_picture\";}'),
('config.entity.key_store.field_storage_config',	'uuid:17ec174c-0286-4b9d-8d57-f5618c7d73b5',	'a:1:{i:0;s:46:\"field.storage.paragraph.field_ebt_counter_icon\";}'),
('config.entity.key_store.field_storage_config',	'uuid:18c467c8-f5f7-4380-a5b7-5d8dd1bd6891',	'a:1:{i:0;s:52:\"field.storage.block_content.field_ebt_countdown_date\";}'),
('config.entity.key_store.field_storage_config',	'uuid:1e11b0a4-9fbb-4f77-a027-2abe7c00a623',	'a:1:{i:0;s:54:\"field.storage.block_content.field_ebt_cta_column_image\";}'),
('config.entity.key_store.field_storage_config',	'uuid:20a2702c-d0d9-491e-bc0d-48bd8f4e5479',	'a:1:{i:0;s:49:\"field.storage.paragraph.field_ebt_slideshow_slide\";}'),
('config.entity.key_store.field_storage_config',	'uuid:227cb366-5e8c-44f6-bcc0-a4197c0060f2',	'a:1:{i:0;s:55:\"field.storage.block_content.field_ebt_basic_button_link\";}'),
('config.entity.key_store.field_storage_config',	'uuid:233843a3-22c1-4376-a920-f894f695b87c',	'a:1:{i:0;s:46:\"field.storage.paragraph.field_stats_item_image\";}'),
('config.entity.key_store.field_storage_config',	'uuid:27029cab-99df-44cd-891e-de41f3558b7c',	'a:1:{i:0;s:47:\"field.storage.block_content.field_ebt_hero_link\";}'),
('config.entity.key_store.field_storage_config',	'uuid:27acecd6-ddfe-41ab-ad13-d09a77410226',	'a:1:{i:0;s:23:\"field.storage.node.body\";}'),
('config.entity.key_store.field_storage_config',	'uuid:2807bb2f-4aff-460c-9cf6-46dd6ddcf653',	'a:1:{i:0;s:48:\"field.storage.block_content.field_ebt_hero_title\";}'),
('config.entity.key_store.field_storage_config',	'uuid:28d853cc-13c3-4be6-9b85-37001544855b',	'a:1:{i:0;s:47:\"field.storage.block_content.field_ebt_cta_title\";}'),
('config.entity.key_store.field_storage_config',	'uuid:2c293a08-a63a-47a3-8b49-8e7650f47903',	'a:1:{i:0;s:40:\"field.storage.media.field_media_document\";}'),
('config.entity.key_store.field_storage_config',	'uuid:2fa60bf2-361b-4902-b836-53c11ea98d00',	'a:1:{i:0;s:43:\"field.storage.block_content.field_ebt_tiles\";}'),
('config.entity.key_store.field_storage_config',	'uuid:31c1cb14-3677-44d6-951e-3560a93c8f65',	'a:1:{i:0;s:54:\"field.storage.paragraph.field_gallery_item_description\";}'),
('config.entity.key_store.field_storage_config',	'uuid:34f357a7-4ec0-459d-9349-7c3b933ed9ca',	'a:1:{i:0;s:46:\"field.storage.block_content.field_ebt_timeline\";}'),
('config.entity.key_store.field_storage_config',	'uuid:379994ed-ae76-4656-ab52-4f8661d6efc4',	'a:1:{i:0;s:37:\"field.storage.media.field_media_image\";}'),
('config.entity.key_store.field_storage_config',	'uuid:37d2f916-06b4-418e-91ad-84a23f9fe7aa',	'a:1:{i:0;s:46:\"field.storage.block_content.field_ebt_settings\";}'),
('config.entity.key_store.field_storage_config',	'uuid:3988ff22-66ff-4325-be58-387a6451784f',	'a:1:{i:0;s:45:\"field.storage.paragraph.field_ebt_tiles_image\";}'),
('config.entity.key_store.field_storage_config',	'uuid:3a56d56d-4fea-4e6d-abfd-6e9fd5799d1f',	'a:1:{i:0;s:33:\"field.storage.node.field_metatags\";}'),
('config.entity.key_store.field_storage_config',	'uuid:3db51960-3062-400f-b922-f0a7373dacb5',	'a:1:{i:0;s:32:\"field.storage.block_content.body\";}'),
('config.entity.key_store.field_storage_config',	'uuid:3dc81a0a-ea91-4e72-af8b-18c1abffc08d',	'a:1:{i:0;s:43:\"field.storage.paragraph.field_ebt_tab_views\";}'),
('config.entity.key_store.field_storage_config',	'uuid:474cb9c9-f18d-40c9-8bdc-2b263c5bf1bb',	'a:1:{i:0;s:53:\"field.storage.paragraph.field_ebt_counter_description\";}'),
('config.entity.key_store.field_storage_config',	'uuid:4a6ac85b-3418-4331-8d82-82c365e01b2a',	'a:1:{i:0;s:48:\"field.storage.paragraph.field_ebt_clickable_tile\";}'),
('config.entity.key_store.field_storage_config',	'uuid:4f31d892-e4c2-45d6-a14e-723ccc4c06f0',	'a:1:{i:0;s:50:\"field.storage.block_content.field_ebt_slick_slider\";}'),
('config.entity.key_store.field_storage_config',	'uuid:4f8a6296-0295-4cc5-8e6a-c61c708a78ba',	'a:1:{i:0;s:42:\"field.storage.media.field_media_video_file\";}'),
('config.entity.key_store.field_storage_config',	'uuid:510be1fe-456a-4a0f-8638-40b7764bd46a',	'a:1:{i:0;s:47:\"field.storage.block_content.field_ebt_accordion\";}'),
('config.entity.key_store.field_storage_config',	'uuid:51b55e7c-d254-49db-b70a-396cd9835bd2',	'a:1:{i:0;s:55:\"field.storage.block_content.field_ebt_videos_and_images\";}'),
('config.entity.key_store.field_storage_config',	'uuid:527f69af-c7cb-450d-a95f-a0199f66a3fc',	'a:1:{i:0;s:42:\"field.storage.paragraph.field_ebt_tab_page\";}'),
('config.entity.key_store.field_storage_config',	'uuid:535ff977-be0f-4fa5-8d38-7803ae8b9094',	'a:1:{i:0;s:54:\"field.storage.block_content.field_ebt_hero_second_link\";}'),
('config.entity.key_store.field_storage_config',	'uuid:5476f31f-53b6-41ea-919f-8ea57cf902fc',	'a:1:{i:0;s:48:\"field.storage.paragraph.field_ebt_slideshow_text\";}'),
('config.entity.key_store.field_storage_config',	'uuid:5c6f70cc-17fc-4f18-bcfb-4c0d8a66500e',	'a:1:{i:0;s:48:\"field.storage.paragraph.field_video_gallery_item\";}'),
('config.entity.key_store.field_storage_config',	'uuid:62a1a67b-d505-4c27-8636-6a9c35a21cf3',	'a:1:{i:0;s:52:\"field.storage.block_content.field_ebt_counter_number\";}'),
('config.entity.key_store.field_storage_config',	'uuid:646af88e-2cb1-4e61-9b5a-1720fbe00d94',	'a:1:{i:0;s:47:\"field.storage.paragraph.field_ebt_counter_title\";}'),
('config.entity.key_store.field_storage_config',	'uuid:65f88f19-ba20-4a37-8258-22b4bbd0bed3',	'a:1:{i:0;s:43:\"field.storage.block_content.field_ebt_stats\";}'),
('config.entity.key_store.field_storage_config',	'uuid:66105a0b-52fa-455d-9673-6bab401dd3d9',	'a:1:{i:0;s:50:\"field.storage.block_content.field_ebt_quote_author\";}'),
('config.entity.key_store.field_storage_config',	'uuid:6848e7e6-6bb4-4d7b-bfe3-64cb965c8d83',	'a:1:{i:0;s:59:\"field.storage.block_content.field_ebt_bootstrap_button_link\";}'),
('config.entity.key_store.field_storage_config',	'uuid:6e677df8-5ee4-417d-be3a-d5036e605903',	'a:1:{i:0;s:44:\"field.storage.paragraph.field_ebt_tiles_text\";}'),
('config.entity.key_store.field_storage_config',	'uuid:7003f50c-c76e-4efe-bfcc-67453daeb93c',	'a:1:{i:0;s:45:\"field.storage.paragraph.field_stats_item_link\";}'),
('config.entity.key_store.field_storage_config',	'uuid:7089f45d-1e3c-4225-bba6-736084040e5b',	'a:1:{i:0;s:54:\"field.storage.paragraph.field_ebt_timeline_media_image\";}'),
('config.entity.key_store.field_storage_config',	'uuid:7205b1e6-f387-4cb5-80f3-ea6e935096ea',	'a:1:{i:0;s:49:\"field.storage.paragraph.field_ebt_accordion_title\";}'),
('config.entity.key_store.field_storage_config',	'uuid:7492acc6-65ae-4f1f-b3c7-3e41a385e8cb',	'a:1:{i:0;s:42:\"field.storage.paragraph.field_ebt_tab_text\";}'),
('config.entity.key_store.field_storage_config',	'uuid:75a1e1d5-184d-4541-96b7-8957dddb2453',	'a:1:{i:0;s:42:\"field.storage.media.field_media_audio_file\";}'),
('config.entity.key_store.field_storage_config',	'uuid:7b0677d8-0312-4994-b0a6-cd1c0852a050',	'a:1:{i:0;s:48:\"field.storage.paragraph.field_ebt_timeline_title\";}'),
('config.entity.key_store.field_storage_config',	'uuid:7b1e8d87-89a6-4d9c-b0ae-16292b52f88b',	'a:1:{i:0;s:52:\"field.storage.paragraph.field_ebt_slick_slider_image\";}'),
('config.entity.key_store.field_storage_config',	'uuid:80c677f9-529e-499e-959c-dc9187ab7a49',	'a:1:{i:0;s:47:\"field.storage.paragraph.field_ebt_timeline_date\";}'),
('config.entity.key_store.field_storage_config',	'uuid:8889dde4-ff00-4644-8af5-1d22a85992bc',	'a:1:{i:0;s:54:\"field.storage.block_content.field_ebt_micromodal_title\";}'),
('config.entity.key_store.field_storage_config',	'uuid:8b001212-3460-4d07-af2d-efb8bed64599',	'a:1:{i:0;s:42:\"field.storage.block_content.field_ebt_tabs\";}'),
('config.entity.key_store.field_storage_config',	'uuid:90e79693-e9f5-46f1-bb04-df225231b9a7',	'a:1:{i:0;s:43:\"field.storage.block_content.field_ebt_image\";}'),
('config.entity.key_store.field_storage_config',	'uuid:90f3734d-9d21-4723-8027-039393a502ef',	'a:1:{i:0;s:50:\"field.storage.block_content.field_ebt_counter_icon\";}'),
('config.entity.key_store.field_storage_config',	'uuid:93988320-9748-44ab-ac19-9ac1a6feaa9d',	'a:1:{i:0;s:49:\"field.storage.block_content.field_ebt_block_block\";}'),
('config.entity.key_store.field_storage_config',	'uuid:95a9a9f7-3de1-4e44-8f20-3d0f2dfe6baa',	'a:1:{i:0;s:53:\"field.storage.block_content.field_ebt_cta_second_link\";}'),
('config.entity.key_store.field_storage_config',	'uuid:99143ce8-61ee-4652-a122-2b74cf0353a8',	'a:1:{i:0;s:48:\"field.storage.paragraph.field_ebt_slideshow_link\";}'),
('config.entity.key_store.field_storage_config',	'uuid:9950466c-7cf2-451c-a90c-6d94bc4223d2',	'a:1:{i:0;s:50:\"field.storage.paragraph.field_ebt_carousel_caption\";}'),
('config.entity.key_store.field_storage_config',	'uuid:adfc8f4b-838d-40b5-956a-1f813f9dc592',	'a:1:{i:0;s:45:\"field.storage.paragraph.field_ebt_tiles_title\";}'),
('config.entity.key_store.field_storage_config',	'uuid:aec7f7b6-b7a3-414f-8026-620c99e80fee',	'a:1:{i:0;s:47:\"field.storage.block_content.field_ebt_slideshow\";}'),
('config.entity.key_store.field_storage_config',	'uuid:b514672e-03d7-4efa-81b8-0f04c6b94cd1',	'a:1:{i:0;s:49:\"field.storage.paragraph.field_ebt_slideshow_title\";}'),
('config.entity.key_store.field_storage_config',	'uuid:c31eee89-5d35-4da4-a2f9-daca2ffd26b7',	'a:1:{i:0;s:46:\"field.storage.block_content.field_ebt_carousel\";}'),
('config.entity.key_store.field_storage_config',	'uuid:c53a9a24-143b-4766-a552-e983659465b5',	'a:1:{i:0;s:49:\"field.storage.block_content.field_ebt_quote_image\";}'),
('config.entity.key_store.field_storage_config',	'uuid:c88354ca-8244-4d5a-8c63-2709d938c811',	'a:1:{i:0;s:48:\"field.storage.paragraph.field_ebt_accordion_text\";}'),
('config.entity.key_store.field_storage_config',	'uuid:c9955fe0-9e81-4347-b5c8-b3a2813ea422',	'a:1:{i:0;s:48:\"field.storage.paragraph.field_ebt_carousel_image\";}'),
('config.entity.key_store.field_storage_config',	'uuid:cd7bca62-bdaa-494e-8d09-d0af7c881721',	'a:1:{i:0;s:43:\"field.storage.block_content.field_ebt_video\";}'),
('config.entity.key_store.field_storage_config',	'uuid:ce8c8911-2694-45d2-b941-6c8f08c9a8fd',	'a:1:{i:0;s:51:\"field.storage.paragraph.field_ebt_slick_slider_link\";}'),
('config.entity.key_store.field_storage_config',	'uuid:d00f9fc0-b613-4eed-90b2-740af89205eb',	'a:1:{i:0;s:45:\"field.storage.paragraph.field_ebt_tab_content\";}'),
('config.entity.key_store.field_storage_config',	'uuid:d53112b6-fda3-4a60-9140-a4f4d8c03704',	'a:1:{i:0;s:48:\"field.storage.block_content.field_ebt_image_link\";}'),
('config.entity.key_store.field_storage_config',	'uuid:d972b731-9ab7-4ca0-8ee1-32320e00018b',	'a:1:{i:0;s:55:\"field.storage.block_content.field_ebt_hero_title_prefix\";}'),
('config.entity.key_store.field_storage_config',	'uuid:d9f39667-4231-4f25-b5b5-7d6a627c0143',	'a:1:{i:0;s:51:\"field.storage.block_content.field_ebt_image_caption\";}'),
('config.entity.key_store.field_storage_config',	'uuid:eca9af3a-0023-4307-a38b-526dac079818',	'a:1:{i:0;s:44:\"field.storage.media.field_media_oembed_video\";}'),
('config.entity.key_store.field_storage_config',	'uuid:ef778f49-5062-47e4-bca2-1b340272972f',	'a:1:{i:0;s:55:\"field.storage.block_content.field_ebt_hero_column_image\";}'),
('config.entity.key_store.field_storage_config',	'uuid:f11fd5af-293c-41e7-91eb-52f5c2b14f5a',	'a:1:{i:0;s:49:\"field.storage.block_content.field_ebt_views_views\";}'),
('config.entity.key_store.field_storage_config',	'uuid:f1992284-2903-4d4f-b4c2-4336abc56b45',	'a:1:{i:0;s:44:\"field.storage.paragraph.field_ebt_tiles_link\";}'),
('config.entity.key_store.field_storage_config',	'uuid:f6763f4c-c4a6-4d80-ab1d-f0e2aca44f60',	'a:1:{i:0;s:47:\"field.storage.paragraph.field_stats_item_number\";}'),
('config.entity.key_store.field_storage_config',	'uuid:fb27b8eb-ae9d-44ec-8d20-6aa1287b8b5f',	'a:1:{i:0;s:56:\"field.storage.block_content.field_ebt_webform_popup_form\";}'),
('config.entity.key_store.field_storage_config',	'uuid:fcff8171-e2db-44a5-9585-8b9fb7992b79',	'a:1:{i:0;s:51:\"field.storage.block_content.field_ebt_counter_items\";}'),
('config.entity.key_store.field_storage_config',	'uuid:fd3e2c50-dcff-4f84-bd3f-a28c9352ea81',	'a:1:{i:0;s:51:\"field.storage.paragraph.field_ebt_slick_slider_text\";}'),
('config.entity.key_store.field_storage_config',	'uuid:fe035edd-b535-4ceb-bd54-a3c604fbae92',	'a:1:{i:0;s:47:\"field.storage.paragraph.field_ebt_timeline_text\";}'),
('config.entity.key_store.field_storage_config',	'uuid:fe9a8722-bb07-4268-815a-a4b9b20eb504',	'a:1:{i:0;s:48:\"field.storage.paragraph.field_ebt_counter_number\";}'),
('config.entity.key_store.filter_format',	'uuid:5d0c18fb-1e15-4eac-9e4b-1484b52ff943',	'a:1:{i:0;s:24:\"filter.format.basic_html\";}'),
('config.entity.key_store.filter_format',	'uuid:8ca43f73-d620-4c03-bbd7-8221d546124f',	'a:1:{i:0;s:29:\"filter.format.restricted_html\";}'),
('config.entity.key_store.filter_format',	'uuid:98975409-6030-4f9b-8f64-18610166736a',	'a:1:{i:0;s:24:\"filter.format.plain_text\";}'),
('config.entity.key_store.filter_format',	'uuid:cf32d962-2f58-41c9-989d-a8f82367e8e1',	'a:1:{i:0;s:29:\"filter.format.webform_default\";}'),
('config.entity.key_store.filter_format',	'uuid:e00030fb-b30d-42df-a35b-b9dca992742e',	'a:1:{i:0;s:23:\"filter.format.full_html\";}'),
('config.entity.key_store.image_style',	'uuid:3387ae71-e231-4ddd-9e5f-664ca37b095b',	'a:1:{i:0;s:29:\"image.style.ebt_gallery_image\";}'),
('config.entity.key_store.image_style',	'uuid:527e81f9-fafb-4f3e-aad6-f169b5885095',	'a:1:{i:0;s:17:\"image.style.large\";}'),
('config.entity.key_store.image_style',	'uuid:60fb949e-3206-43f8-8a85-d75fa8ec9bf5',	'a:1:{i:0;s:23:\"image.style.quote_image\";}'),
('config.entity.key_store.image_style',	'uuid:7751cf12-1253-4c81-bcd8-bc001066b67b',	'a:1:{i:0;s:35:\"image.style.linkit_result_thumbnail\";}'),
('config.entity.key_store.image_style',	'uuid:7e8ff02c-5435-43f6-8dc3-916788ea8d9f',	'a:1:{i:0;s:21:\"image.style.thumbnail\";}'),
('config.entity.key_store.image_style',	'uuid:9fcd2b87-5cd2-4214-90f8-d2a1c4229d26',	'a:1:{i:0;s:25:\"image.style.media_library\";}'),
('config.entity.key_store.image_style',	'uuid:a7519911-04cf-4e32-8dd4-55d8d342ddfc',	'a:1:{i:0;s:29:\"image.style.slick_slider_card\";}'),
('config.entity.key_store.image_style',	'uuid:c4e70146-66c8-4f81-9049-d4e41b4c5305',	'a:1:{i:0;s:39:\"image.style.ebt_video_and_image_gallery\";}'),
('config.entity.key_store.image_style',	'uuid:c8b8fa24-4235-4e63-abae-72f30beb637e',	'a:1:{i:0;s:18:\"image.style.medium\";}'),
('config.entity.key_store.image_style',	'uuid:cf4a237b-4886-4db6-90a2-e2f1348070b5',	'a:1:{i:0;s:16:\"image.style.wide\";}'),
('config.entity.key_store.linkit_profile',	'uuid:655a70f6-77d9-4568-ad74-866e455f296a',	'a:1:{i:0;s:29:\"linkit.linkit_profile.default\";}'),
('config.entity.key_store.media_type',	'uuid:474a8161-6e84-4c54-8d09-7cd6cf51ca6f',	'a:1:{i:0;s:19:\"media.type.document\";}'),
('config.entity.key_store.media_type',	'uuid:47a446d2-2250-4e11-98eb-8a4c51117635',	'a:1:{i:0;s:16:\"media.type.video\";}'),
('config.entity.key_store.media_type',	'uuid:59bb7b69-536f-47d7-b202-4c65a9b02036',	'a:1:{i:0;s:23:\"media.type.remote_video\";}'),
('config.entity.key_store.media_type',	'uuid:5b9f8640-5def-4f1f-8cbb-9a34ee0d322b',	'a:1:{i:0;s:16:\"media.type.audio\";}'),
('config.entity.key_store.media_type',	'uuid:d02792ed-7ab7-466f-94e2-1bc1eb7fc178',	'a:1:{i:0;s:16:\"media.type.image\";}'),
('config.entity.key_store.menu',	'uuid:7f6e64bf-0677-4eaf-82ae-a29df89f11b9',	'a:1:{i:0;s:16:\"system.menu.main\";}'),
('config.entity.key_store.menu',	'uuid:90616064-32be-41e1-baa8-be78784e75f1',	'a:1:{i:0;s:17:\"system.menu.admin\";}'),
('config.entity.key_store.menu',	'uuid:a2a145f9-0c16-431e-975e-9af61b72ef36',	'a:1:{i:0;s:17:\"system.menu.tools\";}'),
('config.entity.key_store.menu',	'uuid:ba5622c9-4800-414f-8f65-c096cf34841d',	'a:1:{i:0;s:18:\"system.menu.footer\";}'),
('config.entity.key_store.menu',	'uuid:c0346b12-c5cd-40d6-886c-cf0888f426ac',	'a:1:{i:0;s:19:\"system.menu.account\";}'),
('config.entity.key_store.metatag_defaults',	'uuid:1131c9da-259d-4688-af2b-8cd70c4d304f',	'a:1:{i:0;s:28:\"metatag.metatag_defaults.404\";}'),
('config.entity.key_store.metatag_defaults',	'uuid:14e6bd6a-5fd4-4abb-b304-231e944ee914',	'a:1:{i:0;s:30:\"metatag.metatag_defaults.front\";}'),
('config.entity.key_store.metatag_defaults',	'uuid:2ce7b5a6-e273-4808-988d-bd51796041d7',	'a:1:{i:0;s:29:\"metatag.metatag_defaults.user\";}'),
('config.entity.key_store.metatag_defaults',	'uuid:32de19c3-215d-4985-a7d7-d588a90d7f0d',	'a:1:{i:0;s:28:\"metatag.metatag_defaults.403\";}'),
('config.entity.key_store.metatag_defaults',	'uuid:3950fa9e-d155-4064-8913-f7928e563aa1',	'a:1:{i:0;s:29:\"metatag.metatag_defaults.node\";}'),
('config.entity.key_store.metatag_defaults',	'uuid:7175fa40-e959-4cb9-a9af-08b0acf53b23',	'a:1:{i:0;s:38:\"metatag.metatag_defaults.taxonomy_term\";}'),
('config.entity.key_store.metatag_defaults',	'uuid:c377ec68-aa9d-4ed0-8e17-b44da3051c14',	'a:1:{i:0;s:31:\"metatag.metatag_defaults.global\";}'),
('config.entity.key_store.node_type',	'uuid:1edca201-7650-4af0-af2a-47c5a971bfde',	'a:1:{i:0;s:14:\"node.type.page\";}'),
('config.entity.key_store.node_type',	'uuid:23740c9e-4bc8-422a-a456-7efd997502e9',	'a:1:{i:0;s:17:\"node.type.article\";}'),
('config.entity.key_store.paragraphs_type',	'uuid:0700c7f4-0990-4033-a96a-7eac220fe625',	'a:1:{i:0;s:39:\"paragraphs.paragraphs_type.ebt_timeline\";}'),
('config.entity.key_store.paragraphs_type',	'uuid:210023af-0ce2-4183-bbba-6adbe094a405',	'a:1:{i:0;s:41:\"paragraphs.paragraphs_type.ebt_stats_item\";}'),
('config.entity.key_store.paragraphs_type',	'uuid:332e9a66-40d4-4d0f-a252-bacb76456f61',	'a:1:{i:0;s:41:\"paragraphs.paragraphs_type.ebt_tiles_item\";}'),
('config.entity.key_store.paragraphs_type',	'uuid:5071ad52-b6e8-4a13-88ad-a0e644e823f9',	'a:1:{i:0;s:40:\"paragraphs.paragraphs_type.ebt_accordion\";}'),
('config.entity.key_store.paragraphs_type',	'uuid:68f7444a-b28e-4ac9-abc5-57a62d63fe7f',	'a:1:{i:0;s:40:\"paragraphs.paragraphs_type.ebt_slideshow\";}'),
('config.entity.key_store.paragraphs_type',	'uuid:69becd39-ca29-4229-a5e0-b50dda5e664e',	'a:1:{i:0;s:59:\"paragraphs.paragraphs_type.ebt_video_and_image_gallery_item\";}'),
('config.entity.key_store.paragraphs_type',	'uuid:70607742-51bf-4b77-8d46-c07397b718e6',	'a:1:{i:0;s:43:\"paragraphs.paragraphs_type.ebt_slick_slider\";}'),
('config.entity.key_store.paragraphs_type',	'uuid:8a0e0b99-a544-4c46-8cb3-534e418ac0e9',	'a:1:{i:0;s:43:\"paragraphs.paragraphs_type.ebt_counter_item\";}'),
('config.entity.key_store.paragraphs_type',	'uuid:d24c7342-50a5-4bba-a2ca-23838ec42c25',	'a:1:{i:0;s:34:\"paragraphs.paragraphs_type.ebt_tab\";}'),
('config.entity.key_store.paragraphs_type',	'uuid:eae57e5f-f332-4203-be4f-1ead1a6c1ebf',	'a:1:{i:0;s:39:\"paragraphs.paragraphs_type.ebt_carousel\";}'),
('config.entity.key_store.search_page',	'uuid:294f8603-9cb9-4c47-91cb-def8653638f4',	'a:1:{i:0;s:23:\"search.page.user_search\";}'),
('config.entity.key_store.search_page',	'uuid:72642a28-df7e-4618-aa8c-3f52bf7d9f97',	'a:1:{i:0;s:23:\"search.page.node_search\";}'),
('config.entity.key_store.search_page',	'uuid:fec10881-499f-4858-a42b-9b60cee45abe',	'a:1:{i:0;s:23:\"search.page.help_search\";}'),
('config.entity.key_store.shortcut_set',	'uuid:bc9830ea-c02f-4ef4-a17e-f3539c02304b',	'a:1:{i:0;s:20:\"shortcut.set.default\";}'),
('config.entity.key_store.taxonomy_vocabulary',	'uuid:bae62ed0-d39a-4ca0-a737-86bf6ae374a6',	'a:1:{i:0;s:24:\"taxonomy.vocabulary.tags\";}'),
('config.entity.key_store.user_role',	'uuid:55c650b9-b5a7-4ff4-bc0f-f89243b36175',	'a:1:{i:0;s:23:\"user.role.administrator\";}'),
('config.entity.key_store.user_role',	'uuid:8ae6303e-51a9-461e-9cd1-3548f02fd2f7',	'a:1:{i:0;s:19:\"user.role.anonymous\";}'),
('config.entity.key_store.user_role',	'uuid:a817234d-3eaa-4c9f-a2ec-0f6cada70063',	'a:1:{i:0;s:23:\"user.role.authenticated\";}'),
('config.entity.key_store.user_role',	'uuid:d6e980dc-d5d4-42cf-8308-888d9c255fa0',	'a:1:{i:0;s:24:\"user.role.content_editor\";}'),
('config.entity.key_store.view',	'uuid:0aadfe89-23e4-4ec3-a50a-3c76c79be76a',	'a:1:{i:0;s:25:\"views.view.content_recent\";}'),
('config.entity.key_store.view',	'uuid:1d71a232-99d5-4253-868e-76836877a513',	'a:1:{i:0;s:19:\"views.view.watchdog\";}'),
('config.entity.key_store.view',	'uuid:2b2425c7-ad13-4164-afc2-8d66592f2a30',	'a:1:{i:0;s:24:\"views.view.block_content\";}'),
('config.entity.key_store.view',	'uuid:36a349da-87e8-43e4-89c5-350096634510',	'a:1:{i:0;s:16:\"views.view.media\";}'),
('config.entity.key_store.view',	'uuid:4b34ee05-e652-40b7-8ec4-c522b22c6013',	'a:1:{i:0;s:19:\"views.view.glossary\";}'),
('config.entity.key_store.view',	'uuid:534a8e69-2ee4-4c66-98d4-040cedf2dcd1',	'a:1:{i:0;s:16:\"views.view.files\";}'),
('config.entity.key_store.view',	'uuid:53b483f4-38d1-4359-99b2-b24e9f23a505',	'a:1:{i:0;s:18:\"views.view.content\";}'),
('config.entity.key_store.view',	'uuid:5c298710-8d19-4662-a5cc-dcd249b03b1d',	'a:1:{i:0;s:30:\"views.view.webform_submissions\";}'),
('config.entity.key_store.view',	'uuid:697fbe61-72f2-4f36-9ef0-93f40a5476d1',	'a:1:{i:0;s:20:\"views.view.frontpage\";}'),
('config.entity.key_store.view',	'uuid:869573d7-3210-47a6-a85b-2b4f70595558',	'a:1:{i:0;s:18:\"views.view.archive\";}'),
('config.entity.key_store.view',	'uuid:a7f5e956-bb75-4caf-908d-26f2bf0d1ceb',	'a:1:{i:0;s:20:\"views.view.who_s_new\";}'),
('config.entity.key_store.view',	'uuid:bc9a8070-9681-4b94-8d52-549af33d0dbe',	'a:1:{i:0;s:24:\"views.view.media_library\";}'),
('config.entity.key_store.view',	'uuid:c473d286-cede-440e-97e5-6d2909d58b05',	'a:1:{i:0;s:23:\"views.view.who_s_online\";}'),
('config.entity.key_store.view',	'uuid:cb66f7a4-4661-4051-8a2d-40c096d4f55d',	'a:1:{i:0;s:19:\"views.view.redirect\";}'),
('config.entity.key_store.view',	'uuid:d74333b1-feb4-4d77-9bb9-7230d2bc1f92',	'a:1:{i:0;s:24:\"views.view.taxonomy_term\";}'),
('config.entity.key_store.view',	'uuid:dd75f214-13a9-43b5-af70-9953d491803c',	'a:1:{i:0;s:28:\"views.view.user_admin_people\";}'),
('config.entity.key_store.webform',	'status:open',	'a:1:{i:0;s:23:\"webform.webform.contact\";}'),
('config.entity.key_store.webform',	'template:',	'a:1:{i:0;s:23:\"webform.webform.contact\";}'),
('config.entity.key_store.webform',	'uuid:cff12aaa-4fd4-49c9-bed0-2556200107e6',	'a:1:{i:0;s:23:\"webform.webform.contact\";}'),
('config.entity.key_store.webform_options',	'uuid:120774df-f15f-4a67-b020-8ecedd3cff80',	'a:1:{i:0;s:41:\"webform.webform_options.likert_importance\";}'),
('config.entity.key_store.webform_options',	'uuid:13d0d301-6f64-4c63-a190-cfa2990e9a48',	'a:1:{i:0;s:35:\"webform.webform_options.phone_types\";}'),
('config.entity.key_store.webform_options',	'uuid:197b61b7-7127-4713-9678-b79940b929ea',	'a:1:{i:0;s:38:\"webform.webform_options.marital_status\";}'),
('config.entity.key_store.webform_options',	'uuid:1c50e324-cb25-4578-8344-bd2266cbca89',	'a:1:{i:0;s:30:\"webform.webform_options.titles\";}'),
('config.entity.key_store.webform_options',	'uuid:281e6e1e-5d64-459a-86ef-5c7109ebb0cf',	'a:1:{i:0;s:30:\"webform.webform_options.months\";}'),
('config.entity.key_store.webform_options',	'uuid:34555c98-49f4-4d02-aca0-fa11a6f7e4b5',	'a:1:{i:0;s:34:\"webform.webform_options.time_zones\";}'),
('config.entity.key_store.webform_options',	'uuid:369dc8ce-cc18-40ec-b90a-91c195e015af',	'a:1:{i:0;s:41:\"webform.webform_options.employment_status\";}'),
('config.entity.key_store.webform_options',	'uuid:3bce0633-cfe2-4f52-8625-00d8c7a98f35',	'a:1:{i:0;s:40:\"webform.webform_options.likert_ten_scale\";}'),
('config.entity.key_store.webform_options',	'uuid:3dd5c388-df64-4a89-9710-1557394c6222',	'a:1:{i:0;s:38:\"webform.webform_options.province_codes\";}'),
('config.entity.key_store.webform_options',	'uuid:3f51980b-fdb6-4b07-a304-fb302af23c4d',	'a:1:{i:0;s:38:\"webform.webform_options.likert_quality\";}'),
('config.entity.key_store.webform_options',	'uuid:3fe1c8dc-5cd9-48b5-a783-23480e3742f3',	'a:1:{i:0;s:43:\"webform.webform_options.likert_satisfaction\";}'),
('config.entity.key_store.webform_options',	'uuid:40521304-88f4-47f9-82bb-7eb8bc136320',	'a:1:{i:0;s:44:\"webform.webform_options.state_province_names\";}'),
('config.entity.key_store.webform_options',	'uuid:6c763985-59b0-49e1-a940-e76e2992edca',	'a:1:{i:0;s:44:\"webform.webform_options.state_province_codes\";}'),
('config.entity.key_store.webform_options',	'uuid:84bf246e-58a4-4bad-ad87-c1ffdd4a4be4',	'a:1:{i:0;s:36:\"webform.webform_options.translations\";}'),
('config.entity.key_store.webform_options',	'uuid:86b1fb55-9ca7-480a-a333-ce541cefe1ce',	'a:1:{i:0;s:35:\"webform.webform_options.state_codes\";}'),
('config.entity.key_store.webform_options',	'uuid:8e01de6b-6df3-4ff4-857e-7f18c86dba94',	'a:1:{i:0;s:30:\"webform.webform_options.gender\";}'),
('config.entity.key_store.webform_options',	'uuid:a1a5d982-5911-4689-8e9d-779071e6f69c',	'a:1:{i:0;s:32:\"webform.webform_options.industry\";}'),
('config.entity.key_store.webform_options',	'uuid:a55ca564-ba76-4d06-b838-79a72132103a',	'a:1:{i:0;s:30:\"webform.webform_options.yes_no\";}'),
('config.entity.key_store.webform_options',	'uuid:ac4202f9-992c-48ac-a36b-aa22452196bb',	'a:1:{i:0;s:40:\"webform.webform_options.likert_would_you\";}'),
('config.entity.key_store.webform_options',	'uuid:b54122ee-eb6e-46b5-b89b-a3d6cbff2302',	'a:1:{i:0;s:32:\"webform.webform_options.sex_icao\";}'),
('config.entity.key_store.webform_options',	'uuid:c06bcacf-40d2-4c65-9f65-f5429245ed23',	'a:1:{i:0;s:28:\"webform.webform_options.size\";}'),
('config.entity.key_store.webform_options',	'uuid:c1d3035e-7928-41e6-83cb-e5d35f1ddcff',	'a:1:{i:0;s:40:\"webform.webform_options.likert_agreement\";}'),
('config.entity.key_store.webform_options',	'uuid:c451f0ba-7456-4e0e-b2fe-5ebbebf2e2a0',	'a:1:{i:0;s:36:\"webform.webform_options.relationship\";}'),
('config.entity.key_store.webform_options',	'uuid:c9690189-5cda-402e-bc23-4fce4d34e427',	'a:1:{i:0;s:41:\"webform.webform_options.likert_comparison\";}'),
('config.entity.key_store.webform_options',	'uuid:d8eb5c8c-04ba-44b0-83dd-5ab55746daa9',	'a:1:{i:0;s:33:\"webform.webform_options.ethnicity\";}'),
('config.entity.key_store.webform_options',	'uuid:da44f184-15d8-46b2-9d27-67fdc87883fa',	'a:1:{i:0;s:33:\"webform.webform_options.languages\";}'),
('config.entity.key_store.webform_options',	'uuid:db9cc306-a4c9-49d1-9f1a-af8959ae1569',	'a:1:{i:0;s:38:\"webform.webform_options.province_names\";}'),
('config.entity.key_store.webform_options',	'uuid:e1a9a156-02bc-4ffe-b6cb-55c0d4da6931',	'a:1:{i:0;s:28:\"webform.webform_options.days\";}'),
('config.entity.key_store.webform_options',	'uuid:e26b351c-bbe3-491b-b4e5-0c8ec30decce',	'a:1:{i:0;s:27:\"webform.webform_options.sex\";}'),
('config.entity.key_store.webform_options',	'uuid:e8e266de-5ba1-42b8-aab4-68928e91aea7',	'a:1:{i:0;s:37:\"webform.webform_options.country_names\";}'),
('config.entity.key_store.webform_options',	'uuid:f50cd86e-1ce6-4e30-a74c-4aa2a46053b8',	'a:1:{i:0;s:35:\"webform.webform_options.state_names\";}'),
('config.entity.key_store.webform_options',	'uuid:f59dde6d-88c7-46f8-9148-aa56a18a13ba',	'a:1:{i:0;s:33:\"webform.webform_options.education\";}'),
('config.entity.key_store.webform_options',	'uuid:ff13f706-a0ad-416d-9f29-9d2d43722997',	'a:1:{i:0;s:37:\"webform.webform_options.country_codes\";}'),
('entity.definitions.bundle_field_map',	'block_content',	'a:39:{s:4:\"body\";a:2:{s:4:\"type\";s:17:\"text_with_summary\";s:7:\"bundles\";a:19:{s:5:\"basic\";s:5:\"basic\";s:13:\"ebt_accordion\";s:13:\"ebt_accordion\";s:9:\"ebt_block\";s:9:\"ebt_block\";s:11:\"ebt_columns\";s:11:\"ebt_columns\";s:13:\"ebt_countdown\";s:13:\"ebt_countdown\";s:11:\"ebt_counter\";s:11:\"ebt_counter\";s:7:\"ebt_cta\";s:7:\"ebt_cta\";s:8:\"ebt_hero\";s:8:\"ebt_hero\";s:17:\"ebt_image_gallery\";s:17:\"ebt_image_gallery\";s:14:\"ebt_micromodal\";s:14:\"ebt_micromodal\";s:9:\"ebt_quote\";s:9:\"ebt_quote\";s:16:\"ebt_slick_slider\";s:16:\"ebt_slick_slider\";s:9:\"ebt_stats\";s:9:\"ebt_stats\";s:8:\"ebt_text\";s:8:\"ebt_text\";s:9:\"ebt_tiles\";s:9:\"ebt_tiles\";s:9:\"ebt_video\";s:9:\"ebt_video\";s:27:\"ebt_video_and_image_gallery\";s:27:\"ebt_video_and_image_gallery\";s:9:\"ebt_views\";s:9:\"ebt_views\";s:11:\"ebt_webform\";s:11:\"ebt_webform\";}}s:18:\"field_ebt_settings\";a:2:{s:4:\"type\";s:12:\"ebt_settings\";s:7:\"bundles\";a:26:{s:13:\"ebt_accordion\";s:13:\"ebt_accordion\";s:16:\"ebt_basic_button\";s:16:\"ebt_basic_button\";s:9:\"ebt_block\";s:9:\"ebt_block\";s:20:\"ebt_bootstrap_button\";s:20:\"ebt_bootstrap_button\";s:12:\"ebt_carousel\";s:12:\"ebt_carousel\";s:11:\"ebt_columns\";s:11:\"ebt_columns\";s:13:\"ebt_countdown\";s:13:\"ebt_countdown\";s:11:\"ebt_counter\";s:11:\"ebt_counter\";s:7:\"ebt_cta\";s:7:\"ebt_cta\";s:8:\"ebt_hero\";s:8:\"ebt_hero\";s:9:\"ebt_image\";s:9:\"ebt_image\";s:17:\"ebt_image_gallery\";s:17:\"ebt_image_gallery\";s:14:\"ebt_micromodal\";s:14:\"ebt_micromodal\";s:9:\"ebt_quote\";s:9:\"ebt_quote\";s:16:\"ebt_slick_slider\";s:16:\"ebt_slick_slider\";s:13:\"ebt_slideshow\";s:13:\"ebt_slideshow\";s:9:\"ebt_stats\";s:9:\"ebt_stats\";s:8:\"ebt_tabs\";s:8:\"ebt_tabs\";s:8:\"ebt_text\";s:8:\"ebt_text\";s:9:\"ebt_tiles\";s:9:\"ebt_tiles\";s:12:\"ebt_timeline\";s:12:\"ebt_timeline\";s:9:\"ebt_video\";s:9:\"ebt_video\";s:27:\"ebt_video_and_image_gallery\";s:27:\"ebt_video_and_image_gallery\";s:9:\"ebt_views\";s:9:\"ebt_views\";s:11:\"ebt_webform\";s:11:\"ebt_webform\";s:17:\"ebt_webform_popup\";s:17:\"ebt_webform_popup\";}}s:19:\"field_ebt_accordion\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:13:\"ebt_accordion\";s:13:\"ebt_accordion\";}}s:27:\"field_ebt_basic_button_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:16:\"ebt_basic_button\";s:16:\"ebt_basic_button\";}}s:21:\"field_ebt_block_block\";a:2:{s:4:\"type\";s:11:\"block_field\";s:7:\"bundles\";a:1:{s:9:\"ebt_block\";s:9:\"ebt_block\";}}s:31:\"field_ebt_bootstrap_button_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:20:\"ebt_bootstrap_button\";s:20:\"ebt_bootstrap_button\";}}s:18:\"field_ebt_carousel\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:12:\"ebt_carousel\";s:12:\"ebt_carousel\";}}s:24:\"field_ebt_columns_blocks\";a:2:{s:4:\"type\";s:11:\"block_field\";s:7:\"bundles\";a:1:{s:11:\"ebt_columns\";s:11:\"ebt_columns\";}}s:24:\"field_ebt_countdown_date\";a:2:{s:4:\"type\";s:8:\"datetime\";s:7:\"bundles\";a:1:{s:13:\"ebt_countdown\";s:13:\"ebt_countdown\";}}s:24:\"field_ebt_counter_number\";a:2:{s:4:\"type\";s:7:\"integer\";s:7:\"bundles\";a:1:{s:11:\"ebt_counter\";s:11:\"ebt_counter\";}}s:22:\"field_ebt_counter_icon\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:11:\"ebt_counter\";s:11:\"ebt_counter\";}}s:23:\"field_ebt_counter_items\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:11:\"ebt_counter\";s:11:\"ebt_counter\";}}s:25:\"field_ebt_cta_second_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:7:\"ebt_cta\";s:7:\"ebt_cta\";}}s:18:\"field_ebt_cta_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:7:\"ebt_cta\";s:7:\"ebt_cta\";}}s:26:\"field_ebt_cta_column_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:7:\"ebt_cta\";s:7:\"ebt_cta\";}}s:19:\"field_ebt_cta_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:7:\"ebt_cta\";s:7:\"ebt_cta\";}}s:26:\"field_ebt_hero_second_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:8:\"ebt_hero\";s:8:\"ebt_hero\";}}s:19:\"field_ebt_hero_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:8:\"ebt_hero\";s:8:\"ebt_hero\";}}s:27:\"field_ebt_hero_column_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:8:\"ebt_hero\";s:8:\"ebt_hero\";}}s:27:\"field_ebt_hero_title_prefix\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:8:\"ebt_hero\";s:8:\"ebt_hero\";}}s:20:\"field_ebt_hero_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:8:\"ebt_hero\";s:8:\"ebt_hero\";}}s:20:\"field_ebt_image_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:9:\"ebt_image\";s:9:\"ebt_image\";}}s:15:\"field_ebt_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:9:\"ebt_image\";s:9:\"ebt_image\";}}s:23:\"field_ebt_image_caption\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:9:\"ebt_image\";s:9:\"ebt_image\";}}s:23:\"field_ebt_image_gallery\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:17:\"ebt_image_gallery\";s:17:\"ebt_image_gallery\";}}s:26:\"field_ebt_micromodal_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ebt_micromodal\";s:14:\"ebt_micromodal\";}}s:21:\"field_ebt_quote_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:9:\"ebt_quote\";s:9:\"ebt_quote\";}}s:22:\"field_ebt_quote_author\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:9:\"ebt_quote\";s:9:\"ebt_quote\";}}s:22:\"field_ebt_slick_slider\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:16:\"ebt_slick_slider\";s:16:\"ebt_slick_slider\";}}s:19:\"field_ebt_slideshow\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:13:\"ebt_slideshow\";s:13:\"ebt_slideshow\";}}s:15:\"field_ebt_stats\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:9:\"ebt_stats\";s:9:\"ebt_stats\";}}s:14:\"field_ebt_tabs\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:8:\"ebt_tabs\";s:8:\"ebt_tabs\";}}s:15:\"field_ebt_tiles\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:9:\"ebt_tiles\";s:9:\"ebt_tiles\";}}s:18:\"field_ebt_timeline\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:12:\"ebt_timeline\";s:12:\"ebt_timeline\";}}s:15:\"field_ebt_video\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:9:\"ebt_video\";s:9:\"ebt_video\";}}s:27:\"field_ebt_videos_and_images\";a:2:{s:4:\"type\";s:26:\"entity_reference_revisions\";s:7:\"bundles\";a:1:{s:27:\"ebt_video_and_image_gallery\";s:27:\"ebt_video_and_image_gallery\";}}s:21:\"field_ebt_views_views\";a:2:{s:4:\"type\";s:14:\"viewsreference\";s:7:\"bundles\";a:1:{s:9:\"ebt_views\";s:9:\"ebt_views\";}}s:22:\"field_ebt_webform_form\";a:2:{s:4:\"type\";s:7:\"webform\";s:7:\"bundles\";a:1:{s:11:\"ebt_webform\";s:11:\"ebt_webform\";}}s:28:\"field_ebt_webform_popup_form\";a:2:{s:4:\"type\";s:7:\"webform\";s:7:\"bundles\";a:1:{s:17:\"ebt_webform_popup\";s:17:\"ebt_webform_popup\";}}}'),
('entity.definitions.bundle_field_map',	'comment',	'a:0:{}'),
('entity.definitions.bundle_field_map',	'media',	'a:5:{s:22:\"field_media_audio_file\";a:2:{s:4:\"type\";s:4:\"file\";s:7:\"bundles\";a:1:{s:5:\"audio\";s:5:\"audio\";}}s:20:\"field_media_document\";a:2:{s:4:\"type\";s:4:\"file\";s:7:\"bundles\";a:1:{s:8:\"document\";s:8:\"document\";}}s:17:\"field_media_image\";a:2:{s:4:\"type\";s:5:\"image\";s:7:\"bundles\";a:1:{s:5:\"image\";s:5:\"image\";}}s:24:\"field_media_oembed_video\";a:2:{s:4:\"type\";s:6:\"string\";s:7:\"bundles\";a:1:{s:12:\"remote_video\";s:12:\"remote_video\";}}s:22:\"field_media_video_file\";a:2:{s:4:\"type\";s:4:\"file\";s:7:\"bundles\";a:1:{s:5:\"video\";s:5:\"video\";}}}'),
('entity.definitions.bundle_field_map',	'node',	'a:5:{s:11:\"field_image\";a:2:{s:4:\"type\";s:5:\"image\";s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}s:10:\"field_tags\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:7:\"article\";s:7:\"article\";}}s:4:\"body\";a:2:{s:4:\"type\";s:17:\"text_with_summary\";s:7:\"bundles\";a:2:{s:4:\"page\";s:4:\"page\";s:7:\"article\";s:7:\"article\";}}s:14:\"field_metatags\";a:2:{s:4:\"type\";s:7:\"metatag\";s:7:\"bundles\";a:2:{s:7:\"article\";s:7:\"article\";s:4:\"page\";s:4:\"page\";}}s:22:\"layout_builder__layout\";a:2:{s:4:\"type\";s:14:\"layout_section\";s:7:\"bundles\";a:2:{s:7:\"article\";s:7:\"article\";s:4:\"page\";s:4:\"page\";}}}'),
('entity.definitions.bundle_field_map',	'paragraph',	'a:37:{s:25:\"field_ebt_accordion_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:13:\"ebt_accordion\";s:13:\"ebt_accordion\";}}s:24:\"field_ebt_accordion_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:13:\"ebt_accordion\";s:13:\"ebt_accordion\";}}s:24:\"field_ebt_carousel_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:12:\"ebt_carousel\";s:12:\"ebt_carousel\";}}s:26:\"field_ebt_carousel_caption\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:12:\"ebt_carousel\";s:12:\"ebt_carousel\";}}s:24:\"field_ebt_counter_number\";a:2:{s:4:\"type\";s:7:\"integer\";s:7:\"bundles\";a:1:{s:16:\"ebt_counter_item\";s:16:\"ebt_counter_item\";}}s:22:\"field_ebt_counter_icon\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:16:\"ebt_counter_item\";s:16:\"ebt_counter_item\";}}s:23:\"field_ebt_counter_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:16:\"ebt_counter_item\";s:16:\"ebt_counter_item\";}}s:29:\"field_ebt_counter_description\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:16:\"ebt_counter_item\";s:16:\"ebt_counter_item\";}}s:27:\"field_ebt_slick_slider_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:16:\"ebt_slick_slider\";s:16:\"ebt_slick_slider\";}}s:28:\"field_ebt_slick_slider_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:16:\"ebt_slick_slider\";s:16:\"ebt_slick_slider\";}}s:27:\"field_ebt_slick_slider_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:16:\"ebt_slick_slider\";s:16:\"ebt_slick_slider\";}}s:25:\"field_ebt_slideshow_slide\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:13:\"ebt_slideshow\";s:13:\"ebt_slideshow\";}}s:24:\"field_ebt_slideshow_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:13:\"ebt_slideshow\";s:13:\"ebt_slideshow\";}}s:25:\"field_ebt_slideshow_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:13:\"ebt_slideshow\";s:13:\"ebt_slideshow\";}}s:24:\"field_ebt_slideshow_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:13:\"ebt_slideshow\";s:13:\"ebt_slideshow\";}}s:21:\"field_stats_item_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:14:\"ebt_stats_item\";s:14:\"ebt_stats_item\";}}s:22:\"field_stats_item_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:14:\"ebt_stats_item\";s:14:\"ebt_stats_item\";}}s:21:\"field_stats_item_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ebt_stats_item\";s:14:\"ebt_stats_item\";}}s:23:\"field_stats_item_number\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ebt_stats_item\";s:14:\"ebt_stats_item\";}}s:18:\"field_ebt_tab_page\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:7:\"ebt_tab\";s:7:\"ebt_tab\";}}s:21:\"field_ebt_tab_content\";a:2:{s:4:\"type\";s:11:\"list_string\";s:7:\"bundles\";a:1:{s:7:\"ebt_tab\";s:7:\"ebt_tab\";}}s:19:\"field_ebt_tab_block\";a:2:{s:4:\"type\";s:11:\"block_field\";s:7:\"bundles\";a:1:{s:7:\"ebt_tab\";s:7:\"ebt_tab\";}}s:19:\"field_ebt_tab_title\";a:2:{s:4:\"type\";s:4:\"text\";s:7:\"bundles\";a:1:{s:7:\"ebt_tab\";s:7:\"ebt_tab\";}}s:18:\"field_ebt_tab_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:7:\"ebt_tab\";s:7:\"ebt_tab\";}}s:19:\"field_ebt_tab_views\";a:2:{s:4:\"type\";s:14:\"viewsreference\";s:7:\"bundles\";a:1:{s:7:\"ebt_tab\";s:7:\"ebt_tab\";}}s:20:\"field_ebt_tiles_link\";a:2:{s:4:\"type\";s:4:\"link\";s:7:\"bundles\";a:1:{s:14:\"ebt_tiles_item\";s:14:\"ebt_tiles_item\";}}s:21:\"field_ebt_tiles_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:14:\"ebt_tiles_item\";s:14:\"ebt_tiles_item\";}}s:24:\"field_ebt_clickable_tile\";a:2:{s:4:\"type\";s:7:\"boolean\";s:7:\"bundles\";a:1:{s:14:\"ebt_tiles_item\";s:14:\"ebt_tiles_item\";}}s:21:\"field_ebt_tiles_title\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ebt_tiles_item\";s:14:\"ebt_tiles_item\";}}s:20:\"field_ebt_tiles_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:14:\"ebt_tiles_item\";s:14:\"ebt_tiles_item\";}}s:24:\"field_ebt_timeline_title\";a:2:{s:4:\"type\";s:6:\"string\";s:7:\"bundles\";a:1:{s:12:\"ebt_timeline\";s:12:\"ebt_timeline\";}}s:30:\"field_ebt_timeline_media_image\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:12:\"ebt_timeline\";s:12:\"ebt_timeline\";}}s:23:\"field_ebt_timeline_date\";a:2:{s:4:\"type\";s:6:\"string\";s:7:\"bundles\";a:1:{s:12:\"ebt_timeline\";s:12:\"ebt_timeline\";}}s:26:\"field_ebt_timeline_current\";a:2:{s:4:\"type\";s:7:\"boolean\";s:7:\"bundles\";a:1:{s:12:\"ebt_timeline\";s:12:\"ebt_timeline\";}}s:23:\"field_ebt_timeline_text\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:12:\"ebt_timeline\";s:12:\"ebt_timeline\";}}s:24:\"field_video_gallery_item\";a:2:{s:4:\"type\";s:16:\"entity_reference\";s:7:\"bundles\";a:1:{s:32:\"ebt_video_and_image_gallery_item\";s:32:\"ebt_video_and_image_gallery_item\";}}s:30:\"field_gallery_item_description\";a:2:{s:4:\"type\";s:9:\"text_long\";s:7:\"bundles\";a:1:{s:32:\"ebt_video_and_image_gallery_item\";s:32:\"ebt_video_and_image_gallery_item\";}}}'),
('entity.definitions.bundle_field_map',	'user',	'a:1:{s:12:\"user_picture\";a:2:{s:4:\"type\";s:5:\"image\";s:7:\"bundles\";a:1:{s:4:\"user\";s:4:\"user\";}}}'),
('entity.definitions.installed',	'action.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:6:\"action\";s:8:\"\0*\0class\";s:27:\"Drupal\\system\\Entity\\Action\";s:11:\"\0*\0provider\";s:6:\"system\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\system\\Entity\\Action\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:18:\"administer actions\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Actions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"action\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"actions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:13:\"@count action\";s:6:\"plural\";s:14:\"@count actions\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"config:action_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:4:\"type\";i:3;s:6:\"plugin\";i:4;s:13:\"configuration\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'base_field_override.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"base_field_override\";s:8:\"\0*\0class\";s:42:\"Drupal\\Core\\Field\\Entity\\BaseFieldOverride\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:42:\"Drupal\\Core\\Field\\Entity\\BaseFieldOverride\";s:11:\"\0*\0handlers\";a:2:{s:7:\"storage\";s:42:\"Drupal\\Core\\Field\\BaseFieldOverrideStorage\";s:6:\"access\";s:55:\"Drupal\\Core\\Field\\BaseFieldOverrideAccessControlHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Base field override\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:base_field_override_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:5:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:6:\"bundle\";i:3;s:10:\"field_name\";i:4;s:10:\"field_type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:19:\"base_field_override\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:6:\"bundle\";i:4;s:5:\"label\";i:5;s:11:\"description\";i:6;s:8:\"required\";i:7;s:12:\"translatable\";i:8;s:13:\"default_value\";i:9;s:22:\"default_value_callback\";i:10;s:8:\"settings\";i:11;s:10:\"field_type\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'block.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:5:\"block\";s:8:\"\0*\0class\";s:25:\"Drupal\\block\\Entity\\Block\";s:11:\"\0*\0provider\";s:5:\"block\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:25:\"Drupal\\block\\Entity\\Block\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:38:\"Drupal\\block\\BlockAccessControlHandler\";s:12:\"view_builder\";s:29:\"Drupal\\block\\BlockViewBuilder\";s:12:\"list_builder\";s:29:\"Drupal\\block\\BlockListBuilder\";s:4:\"form\";a:2:{s:7:\"default\";s:22:\"Drupal\\block\\BlockForm\";s:6:\"delete\";s:33:\"Drupal\\block\\Form\\BlockDeleteForm\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:17:\"administer blocks\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:44:\"/admin/structure/block/manage/{block}/delete\";s:9:\"edit-form\";s:37:\"/admin/structure/block/manage/{block}\";s:6:\"enable\";s:44:\"/admin/structure/block/manage/{block}/enable\";s:7:\"disable\";s:45:\"/admin/structure/block/manage/{block}/disable\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:12:\"@count block\";s:6:\"plural\";s:13:\"@count blocks\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:17:\"config:block_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:2:{i:0;s:5:\"theme\";i:1;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"theme\";i:2;s:6:\"region\";i:3;s:6:\"weight\";i:4;s:8:\"provider\";i:5;s:6:\"plugin\";i:6;s:8:\"settings\";i:7;s:10:\"visibility\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'block_content.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:13:\"block_content\";s:8:\"\0*\0class\";s:40:\"Drupal\\block_content\\Entity\\BlockContent\";s:11:\"\0*\0provider\";s:13:\"block_content\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:0;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:6:\"bundle\";s:4:\"type\";s:5:\"label\";s:4:\"info\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\block_content\\Entity\\BlockContent\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:14:\"storage_schema\";s:46:\"Drupal\\block_content\\BlockContentStorageSchema\";s:6:\"access\";s:53:\"Drupal\\block_content\\BlockContentAccessControlHandler\";s:12:\"list_builder\";s:44:\"Drupal\\block_content\\BlockContentListBuilder\";s:12:\"view_builder\";s:44:\"Drupal\\block_content\\BlockContentViewBuilder\";s:10:\"views_data\";s:42:\"Drupal\\block_content\\BlockContentViewsData\";s:4:\"form\";a:6:{s:3:\"add\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:4:\"edit\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:6:\"delete\";s:48:\"Drupal\\block_content\\Form\\BlockContentDeleteForm\";s:7:\"default\";s:37:\"Drupal\\block_content\\BlockContentForm\";s:15:\"revision-delete\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm\";s:15:\"revision-revert\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionRevertForm\";}s:14:\"route_provider\";a:1:{s:8:\"revision\";s:52:\"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider\";}s:11:\"translation\";s:51:\"Drupal\\block_content\\BlockContentTranslationHandler\";}s:19:\"\0*\0admin_permission\";s:24:\"administer block content\";s:24:\"\0*\0collection_permission\";s:20:\"access block library\";s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:8:{s:9:\"canonical\";s:36:\"/admin/content/block/{block_content}\";s:11:\"delete-form\";s:43:\"/admin/content/block/{block_content}/delete\";s:9:\"edit-form\";s:36:\"/admin/content/block/{block_content}\";s:10:\"collection\";s:20:\"/admin/content/block\";s:6:\"create\";s:6:\"/block\";s:20:\"revision-delete-form\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/delete\";s:20:\"revision-revert-form\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/revert\";s:15:\"version-history\";s:46:\"/admin/content/block/{block_content}/revisions\";}s:21:\"\0*\0bundle_entity_type\";s:18:\"block_content_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:13:\"block_content\";s:22:\"\0*\0revision_data_table\";s:28:\"block_content_field_revision\";s:17:\"\0*\0revision_table\";s:22:\"block_content_revision\";s:13:\"\0*\0data_table\";s:24:\"block_content_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Content blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"content blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count content block\";s:6:\"plural\";s:21:\"@count content blocks\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:35:\"entity.block_content_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"block_content_list\";}s:14:\"\0*\0constraints\";a:2:{s:26:\"EntityUntranslatableFields\";N;s:25:\"BlockContentEntityChanged\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:12:\"revision_log\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'block_content.field_storage_definitions',	'a:54:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Content block ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"The content block ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The content block UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"The revision ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"The content block language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"The block type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:18:\"block_content_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:155;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:193;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:223;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_log\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The log entry explaining the changes in this revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:12:\"revision_log\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:260;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:302;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"info\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Block description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"A brief description of your block.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:4:\"info\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:341;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"The time that the content block was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:384;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"reusable\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Reusable\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"A boolean indicating whether this block is reusable.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:0;s:12:\"revisionable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:8:\"reusable\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:415;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:458;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:501;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:13:\"block_content\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:13:\"block_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:543;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"body\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:18:\"block_content.body\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"3db51960-3062-400f-b922-f0a7373dacb5\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eS0snV_L3dx9shtWRTzm5eblwOJ7qKWC9IE-4GMTDFc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:18:\"block_content.body\";s:13:\"\0*\0field_name\";s:4:\"body\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:17:\"text_with_summary\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ebt_settings\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"block_content.field_ebt_settings\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"37d2f916-06b4-418e-91ad-84a23f9fe7aa\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ifyYbCOsv_c2p19zBnvPk39PxYWsMjVLhswFVxeoMEk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:8:\"ebt_core\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"block_content.field_ebt_settings\";s:13:\"\0*\0field_name\";s:18:\"field_ebt_settings\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:12:\"ebt_settings\";s:9:\"\0*\0module\";s:8:\"ebt_core\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ebt_accordion\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"block_content.field_ebt_accordion\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"510be1fe-456a-4a0f-8638-40b7764bd46a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-9lmszSGOf8FvJqERXt4Y75SqfNFnjrUmffe3mvm63E\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"block_content.field_ebt_accordion\";s:13:\"\0*\0field_name\";s:19:\"field_ebt_accordion\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ebt_basic_button_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:41:\"block_content.field_ebt_basic_button_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"227cb366-5e8c-44f6-bcc0-a4197c0060f2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BzBSGwNX6bKi7xiNAKiETrdJPbGYMNk27dC6VzdE2Z4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:41:\"block_content.field_ebt_basic_button_link\";s:13:\"\0*\0field_name\";s:27:\"field_ebt_basic_button_link\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ebt_block_block\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"block_content.field_ebt_block_block\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"93988320-9748-44ab-ac19-9ac1a6feaa9d\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qUmxIKbmrhd1TnlvNUsQ24_IqgsilgfToL8gamHgjPk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:11:\"block_field\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"block_content.field_ebt_block_block\";s:13:\"\0*\0field_name\";s:21:\"field_ebt_block_block\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:11:\"block_field\";s:9:\"\0*\0module\";s:11:\"block_field\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:31:\"field_ebt_bootstrap_button_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:45:\"block_content.field_ebt_bootstrap_button_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"6848e7e6-6bb4-4d7b-bfe3-64cb965c8d83\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"4Mn_2tFUWa7Mu6w06yP9iFQ7KLLKr83YOpxoaTd3IDo\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:45:\"block_content.field_ebt_bootstrap_button_link\";s:13:\"\0*\0field_name\";s:31:\"field_ebt_bootstrap_button_link\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ebt_carousel\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"block_content.field_ebt_carousel\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"c31eee89-5d35-4da4-a2f9-daca2ffd26b7\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"5RyRgQO2iOVZE4gIaH8pGJ4s3UZCNOm5nqfkFXWwVvE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"block_content.field_ebt_carousel\";s:13:\"\0*\0field_name\";s:18:\"field_ebt_carousel\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ebt_columns_blocks\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:38:\"block_content.field_ebt_columns_blocks\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"007c60bc-7d54-4666-8065-f77200cca762\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8ubMRbdfnR4zPhu3EFrCWZOc2hr9_Dum6gPo01gA7OE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:11:\"block_field\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:38:\"block_content.field_ebt_columns_blocks\";s:13:\"\0*\0field_name\";s:24:\"field_ebt_columns_blocks\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:11:\"block_field\";s:9:\"\0*\0module\";s:11:\"block_field\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ebt_countdown_date\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:38:\"block_content.field_ebt_countdown_date\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"18c467c8-f5f7-4380-a5b7-5d8dd1bd6891\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tfVOPr7E66mYxIOwRxWNsSw4nFQnztb5FQbxuKg7_Dg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:8:\"datetime\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:38:\"block_content.field_ebt_countdown_date\";s:13:\"\0*\0field_name\";s:24:\"field_ebt_countdown_date\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:8:\"datetime\";s:9:\"\0*\0module\";s:8:\"datetime\";s:11:\"\0*\0settings\";a:1:{s:13:\"datetime_type\";s:8:\"datetime\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ebt_counter_number\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:38:\"block_content.field_ebt_counter_number\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"62a1a67b-d505-4c27-8636-6a9c35a21cf3\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"fzJ_kU3wKSQOA7gdcWs4erHYixRul2pFzixpKaUIEcs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:13:\"block_content\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:38:\"block_content.field_ebt_counter_number\";s:13:\"\0*\0field_name\";s:24:\"field_ebt_counter_number\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ebt_counter_icon\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"block_content.field_ebt_counter_icon\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"90f3734d-9d21-4723-8027-039393a502ef\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2bYFfyXow5e24VR-vUVn5lG3PHuSyRBkkEZ_qOShiuk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"block_content.field_ebt_counter_icon\";s:13:\"\0*\0field_name\";s:22:\"field_ebt_counter_icon\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ebt_counter_items\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"block_content.field_ebt_counter_items\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"fcff8171-e2db-44a5-9585-8b9fb7992b79\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"n1DI17J39aMu-YkFmfdRmeqTQflyy2-_xOR8jw99LkE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"block_content.field_ebt_counter_items\";s:13:\"\0*\0field_name\";s:23:\"field_ebt_counter_items\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ebt_cta_second_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:39:\"block_content.field_ebt_cta_second_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"95a9a9f7-3de1-4e44-8f20-3d0f2dfe6baa\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nldTu1l1Acs-EQQUI6pM7wxOCM_8L8QdevFiQDrvqdk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:39:\"block_content.field_ebt_cta_second_link\";s:13:\"\0*\0field_name\";s:25:\"field_ebt_cta_second_link\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ebt_cta_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"block_content.field_ebt_cta_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"069a665c-1062-4320-b384-be548389f826\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"rx7cMICk6v3oU3DQBozX_KkK6bXWe9gJNBM2H0aC6n4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"block_content.field_ebt_cta_link\";s:13:\"\0*\0field_name\";s:18:\"field_ebt_cta_link\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ebt_cta_column_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:40:\"block_content.field_ebt_cta_column_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"1e11b0a4-9fbb-4f77-a027-2abe7c00a623\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cWseV862aJoW9_oVsbhZOp1F-1WgQGPaPWt4miaSdoM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:40:\"block_content.field_ebt_cta_column_image\";s:13:\"\0*\0field_name\";s:26:\"field_ebt_cta_column_image\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ebt_cta_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"block_content.field_ebt_cta_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"28d853cc-13c3-4be6-9b85-37001544855b\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QzI1KYIZiUFHadsdJPmZk_6XW4wCrROvPpgDNWpBa8M\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"block_content.field_ebt_cta_title\";s:13:\"\0*\0field_name\";s:19:\"field_ebt_cta_title\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ebt_hero_second_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:40:\"block_content.field_ebt_hero_second_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"535ff977-be0f-4fa5-8d38-7803ae8b9094\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"zmAY3AWa6AyFxiDtFl2a9fy666r6LZkvLTF540UTBdE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:40:\"block_content.field_ebt_hero_second_link\";s:13:\"\0*\0field_name\";s:26:\"field_ebt_hero_second_link\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ebt_hero_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"block_content.field_ebt_hero_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"27029cab-99df-44cd-891e-de41f3558b7c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"u6S6Tua-DwnyB3sGdBXHub-aGYa1PeUoR9SfeJOlpYE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"block_content.field_ebt_hero_link\";s:13:\"\0*\0field_name\";s:19:\"field_ebt_hero_link\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ebt_hero_column_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:41:\"block_content.field_ebt_hero_column_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ef778f49-5062-47e4-bca2-1b340272972f\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qRkbr3wurZNCdoGUXFQbfo3Q8o-iJ-GBBGGEAY2iPYg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:41:\"block_content.field_ebt_hero_column_image\";s:13:\"\0*\0field_name\";s:27:\"field_ebt_hero_column_image\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ebt_hero_title_prefix\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:41:\"block_content.field_ebt_hero_title_prefix\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d972b731-9ab7-4ca0-8ee1-32320e00018b\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yPT-fy4fwafnNJhdyQ0u1kFfPiRvtGiJ8-5FOUcKyaw\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:41:\"block_content.field_ebt_hero_title_prefix\";s:13:\"\0*\0field_name\";s:27:\"field_ebt_hero_title_prefix\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ebt_hero_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"block_content.field_ebt_hero_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"2807bb2f-4aff-460c-9cf6-46dd6ddcf653\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"tz0LPZeke3wFWFFnRzkakjNgB9UGwLj1eCtzzQv6XSA\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"block_content.field_ebt_hero_title\";s:13:\"\0*\0field_name\";s:20:\"field_ebt_hero_title\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ebt_image_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"block_content.field_ebt_image_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d53112b6-fda3-4a60-9140-a4f4d8c03704\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"wLzveDC1XvIz7oYfIvN4OjokbzzjPzDc9Ik730ZY254\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"link\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"block_content.field_ebt_image_link\";s:13:\"\0*\0field_name\";s:20:\"field_ebt_image_link\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ebt_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"block_content.field_ebt_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"90e79693-e9f5-46f1-bb04-df225231b9a7\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"glPjB_880Y127LFOondnNWS1FPhcaT_fJa11BR0P5BA\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"block_content.field_ebt_image\";s:13:\"\0*\0field_name\";s:15:\"field_ebt_image\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ebt_image_caption\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"block_content.field_ebt_image_caption\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d9f39667-4231-4f25-b5b5-7d6a627c0143\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"LJgW5JIAhD9XCJuoflFRdy-F8SWYW2Cix0FvZz4SYiY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"block_content.field_ebt_image_caption\";s:13:\"\0*\0field_name\";s:23:\"field_ebt_image_caption\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ebt_image_gallery\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"block_content.field_ebt_image_gallery\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"0ab015a1-cb97-4ec7-ad66-d236d2472cee\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"VTE6qLfHmQDITpk4f42HVWATR8Wgh7o2ygcj4yx3iNQ\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"block_content.field_ebt_image_gallery\";s:13:\"\0*\0field_name\";s:23:\"field_ebt_image_gallery\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ebt_micromodal_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:40:\"block_content.field_ebt_micromodal_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"8889dde4-ff00-4644-8af5-1d22a85992bc\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"KxeGHZZZNOmgTH3mTuMpwjJqQoqqDIsVOiT05vaOjSQ\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:40:\"block_content.field_ebt_micromodal_title\";s:13:\"\0*\0field_name\";s:26:\"field_ebt_micromodal_title\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ebt_quote_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"block_content.field_ebt_quote_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"c53a9a24-143b-4766-a552-e983659465b5\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"usPfnGqFjnh9WSQ4-5tqsU1G2FvbPHpJMyt4Omq2btU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"block_content.field_ebt_quote_image\";s:13:\"\0*\0field_name\";s:21:\"field_ebt_quote_image\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ebt_quote_author\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"block_content.field_ebt_quote_author\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"66105a0b-52fa-455d-9673-6bab401dd3d9\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"un8UvEIKf-pPNdISDAwHz8cnHArBXUbFHb8rYis_-KU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"block_content.field_ebt_quote_author\";s:13:\"\0*\0field_name\";s:22:\"field_ebt_quote_author\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ebt_slick_slider\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"block_content.field_ebt_slick_slider\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"4f31d892-e4c2-45d6-a14e-723ccc4c06f0\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvQGqiPKTXqRaJpknm7I-jiTH0_2U95OADILQZQt5zA\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"block_content.field_ebt_slick_slider\";s:13:\"\0*\0field_name\";s:22:\"field_ebt_slick_slider\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ebt_slideshow\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"block_content.field_ebt_slideshow\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"aec7f7b6-b7a3-414f-8026-620c99e80fee\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"pGo99IMeEAHZnIdMVP18pkNzYTjRT7opYqgiP2t4CzI\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"block_content.field_ebt_slideshow\";s:13:\"\0*\0field_name\";s:19:\"field_ebt_slideshow\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ebt_stats\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"block_content.field_ebt_stats\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"65f88f19-ba20-4a37-8258-22b4bbd0bed3\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"TCxq8NOVtHeT-j0H_fF1rrmP8AxlDhBMsOm8KSQlkrs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"block_content.field_ebt_stats\";s:13:\"\0*\0field_name\";s:15:\"field_ebt_stats\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"field_ebt_tabs\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"block_content.field_ebt_tabs\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"8b001212-3460-4d07-af2d-efb8bed64599\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"-l2aVtFab9PohqPfDUp_RU4Ji6kBJLDWSfB6L_rUZmo\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"block_content.field_ebt_tabs\";s:13:\"\0*\0field_name\";s:14:\"field_ebt_tabs\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ebt_tiles\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"block_content.field_ebt_tiles\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"2fa60bf2-361b-4902-b836-53c11ea98d00\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xpk_uqKrbVXj3nCNx7pki4z-Cql8XOb4a0GLo-PxaDE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"block_content.field_ebt_tiles\";s:13:\"\0*\0field_name\";s:15:\"field_ebt_tiles\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ebt_timeline\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"block_content.field_ebt_timeline\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"34f357a7-4ec0-459d-9349-7c3b933ed9ca\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"w5cvHJQa6dOxx4ke6vQ8dBNORP8_2BYC8XoDyNSh_ag\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"block_content.field_ebt_timeline\";s:13:\"\0*\0field_name\";s:18:\"field_ebt_timeline\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:15:\"field_ebt_video\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"block_content.field_ebt_video\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"cd7bca62-bdaa-494e-8d09-d0af7c881721\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yqpxggVM9qa9BsCQ0dK4C8x0wU_GrVyhYXeHKQe-IMI\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"block_content.field_ebt_video\";s:13:\"\0*\0field_name\";s:15:\"field_ebt_video\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ebt_videos_and_images\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:41:\"block_content.field_ebt_videos_and_images\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"51b55e7c-d254-49db-b70a-396cd9835bd2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"gzA7OAqszgyne63vWHEzNQQzhp58wo4JD5jrt82tjk8\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:26:\"entity_reference_revisions\";i:2;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:41:\"block_content.field_ebt_videos_and_images\";s:13:\"\0*\0field_name\";s:27:\"field_ebt_videos_and_images\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:26:\"entity_reference_revisions\";s:9:\"\0*\0module\";s:26:\"entity_reference_revisions\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ebt_views_views\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"block_content.field_ebt_views_views\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"f11fd5af-293c-41e7-91eb-52f5c2b14f5a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"crklekBdziPXiKGCBhoUfqwhWUXAuyDEQHEw0J7NdQI\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:13:\"block_content\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"block_content.field_ebt_views_views\";s:13:\"\0*\0field_name\";s:21:\"field_ebt_views_views\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:14:\"viewsreference\";s:9:\"\0*\0module\";s:14:\"viewsreference\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ebt_webform_form\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"block_content.field_ebt_webform_form\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"08365941-eddc-446f-8fc9-72a7728df65c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"K4nKI1yvxZ4s40vKrpuBiz09L15lK0ygK9etUTwYVRw\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:7:\"webform\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"block_content.field_ebt_webform_form\";s:13:\"\0*\0field_name\";s:22:\"field_ebt_webform_form\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:7:\"webform\";s:9:\"\0*\0module\";s:7:\"webform\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:28:\"field_ebt_webform_popup_form\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:42:\"block_content.field_ebt_webform_popup_form\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"fb27b8eb-ae9d-44ec-8d20-6aa1287b8b5f\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"GlZwbpK_4w1bHHs_IAnr12BJmD-fvq2QCviVBXnfiRA\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:13:\"block_content\";i:1;s:7:\"webform\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:42:\"block_content.field_ebt_webform_popup_form\";s:13:\"\0*\0field_name\";s:28:\"field_ebt_webform_popup_form\";s:14:\"\0*\0entity_type\";s:13:\"block_content\";s:7:\"\0*\0type\";s:7:\"webform\";s:9:\"\0*\0module\";s:7:\"webform\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:7:\"webform\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),
('entity.definitions.installed',	'block_content_type.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:18:\"block_content_type\";s:8:\"\0*\0class\";s:44:\"Drupal\\block_content\\Entity\\BlockContentType\";s:11:\"\0*\0provider\";s:13:\"block_content\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:44:\"Drupal\\block_content\\Entity\\BlockContentType\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:50:\"Drupal\\block_content\\BlockTypeAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:3:\"add\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:4:\"edit\";s:41:\"Drupal\\block_content\\BlockContentTypeForm\";s:6:\"delete\";s:52:\"Drupal\\block_content\\Form\\BlockContentTypeDeleteForm\";}s:14:\"route_provider\";a:2:{s:4:\"html\";s:49:\"Drupal\\Core\\Entity\\Routing\\AdminHtmlRouteProvider\";s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:12:\"list_builder\";s:48:\"Drupal\\block_content\\BlockContentTypeListBuilder\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:22:\"administer block types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/delete\";s:9:\"edit-form\";s:58:\"/admin/structure/block-content/manage/{block_content_type}\";s:23:\"entity-permissions-form\";s:70:\"/admin/structure/block-content/manage/{block_content_type}/permissions\";s:10:\"collection\";s:30:\"/admin/structure/block-content\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:13:\"block_content\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"block type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count block type\";s:6:\"plural\";s:18:\"@count block types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:30:\"config:block_content_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:8:\"revision\";i:3;s:11:\"description\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'ckeditor5_template.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:18:\"ckeditor5_template\";s:8:\"\0*\0class\";s:63:\"Drupal\\ckeditor5_plugin_pack_templates\\Entity\\CKEditor5Template\";s:11:\"\0*\0provider\";s:31:\"ckeditor5_plugin_pack_templates\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"weight\";s:6:\"weight\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:63:\"Drupal\\ckeditor5_plugin_pack_templates\\Entity\\CKEditor5Template\";s:11:\"\0*\0handlers\";a:4:{s:12:\"list_builder\";s:67:\"Drupal\\ckeditor5_plugin_pack_templates\\CKEditor5TemplateListBuilder\";s:4:\"form\";a:4:{s:7:\"default\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:3:\"add\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:4:\"edit\";s:88:\"Drupal\\ckeditor5_plugin_pack_templates\\Form\\ContentTemplates\\CKEditor5TemplateEntityForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:30:\"administer ckeditor5 templates\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:10:\"collection\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:8:\"add-form\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:9:\"edit-form\";s:72:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}\";s:11:\"delete-form\";s:61:\"/admin/config/ckeditor5-templates/{ckeditor5_template}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"CKEditor5 Template\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"CKEditor5 Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"CKEditor5 Template\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"CKEditor5 Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:25:\"@count ckeditor5 template\";s:6:\"plural\";s:26:\"@count ckeditor5 templates\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:30:\"config:ckeditor5_template_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:18:\"ckeditor5_template\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"status\";i:4;s:4:\"data\";i:5;s:4:\"icon\";i:6;s:11:\"textFormats\";i:7;s:6:\"weight\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'contact_form.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"contact_form\";s:8:\"\0*\0class\";s:33:\"Drupal\\contact\\Entity\\ContactForm\";s:11:\"\0*\0provider\";s:7:\"contact\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\contact\\Entity\\ContactForm\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:46:\"Drupal\\contact\\ContactFormAccessControlHandler\";s:12:\"list_builder\";s:37:\"Drupal\\contact\\ContactFormListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:34:\"Drupal\\contact\\ContactFormEditForm\";s:4:\"edit\";s:34:\"Drupal\\contact\\ContactFormEditForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:14:\"route_provider\";a:1:{s:11:\"permissions\";s:58:\"Drupal\\user\\Entity\\EntityPermissionsRouteProviderWithCheck\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:24:\"administer contact forms\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:11:\"delete-form\";s:53:\"/admin/structure/contact/manage/{contact_form}/delete\";s:9:\"edit-form\";s:46:\"/admin/structure/contact/manage/{contact_form}\";s:23:\"entity-permissions-form\";s:58:\"/admin/structure/contact/manage/{contact_form}/permissions\";s:10:\"collection\";s:24:\"/admin/structure/contact\";s:9:\"canonical\";s:23:\"/contact/{contact_form}\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:15:\"contact_message\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count contact form\";s:6:\"plural\";s:20:\"@count contact forms\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:contact_form_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"form\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:7:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:10:\"recipients\";i:3;s:5:\"reply\";i:4;s:6:\"weight\";i:5;s:7:\"message\";i:6;s:8:\"redirect\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'contact_message.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:15:\"contact_message\";s:8:\"\0*\0class\";s:29:\"Drupal\\contact\\Entity\\Message\";s:11:\"\0*\0provider\";s:7:\"contact\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:6:{s:6:\"bundle\";s:12:\"contact_form\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\contact\\Entity\\Message\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:49:\"Drupal\\contact\\ContactMessageAccessControlHandler\";s:7:\"storage\";s:43:\"Drupal\\Core\\Entity\\ContentEntityNullStorage\";s:12:\"view_builder\";s:33:\"Drupal\\contact\\MessageViewBuilder\";s:4:\"form\";a:1:{s:7:\"default\";s:26:\"Drupal\\contact\\MessageForm\";}}s:19:\"\0*\0admin_permission\";s:24:\"administer contact forms\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";s:12:\"contact_form\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Contact message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Contact messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"contact message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"contact messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:22:\"@count contact message\";s:6:\"plural\";s:23:\"@count contact messages\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:29:\"entity.contact_form.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:20:\"contact_message_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'contact_message.field_storage_definitions',	'a:9:{s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The message UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The message language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:28;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:12:\"contact_form\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Form ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The ID of the associated form.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:12:\"contact_form\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:12:\"contact_form\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:58;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"The sender\'s name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"The name of the person that is sending the contact message.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:85;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"mail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"The sender\'s email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"The email of the person that is sending the contact message.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"mail\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:110;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:7:\"subject\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Subject\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-10;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:7:\"subject\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:100;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:132;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:7:\"message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:0;s:8:\"settings\";a:1:{s:4:\"rows\";i:12;}}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:0;s:5:\"label\";s:5:\"above\";}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:7:\"message\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:160;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:4:\"copy\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Copy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"Whether to send a copy of the message to the sender.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:4:\"copy\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:194;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}s:9:\"recipient\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:6:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Recipient ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"The ID of the recipient user for personal contact messages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"contact\";s:10:\"field_name\";s:9:\"recipient\";s:11:\"entity_type\";s:15:\"contact_message\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:224;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";N;s:10:\"\0*\0indexes\";a:0:{}}}'),
('entity.definitions.installed',	'date_format.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"date_format\";s:8:\"\0*\0class\";s:38:\"Drupal\\Core\\Datetime\\Entity\\DateFormat\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:38:\"Drupal\\Core\\Datetime\\Entity\\DateFormat\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:44:\"Drupal\\system\\DateFormatAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";s:4:\"form\";a:3:{s:3:\"add\";s:36:\"Drupal\\system\\Form\\DateFormatAddForm\";s:4:\"edit\";s:37:\"Drupal\\system\\Form\\DateFormatEditForm\";s:6:\"delete\";s:39:\"Drupal\\system\\Form\\DateFormatDeleteForm\";}s:12:\"list_builder\";s:35:\"Drupal\\system\\DateFormatListBuilder\";}s:19:\"\0*\0admin_permission\";s:29:\"administer site configuration\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"edit-form\";s:61:\"/admin/config/regional/date-time/formats/manage/{date_format}\";s:11:\"delete-form\";s:68:\"/admin/config/regional/date-time/formats/manage/{date_format}/delete\";s:10:\"collection\";s:40:\"/admin/config/regional/date-time/formats\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Date format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:8:\"rendered\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"locked\";i:3;s:7:\"pattern\";}s:21:\"\0*\0mergedConfigExport\";a:10:{s:4:\"uuid\";s:4:\"uuid\";s:8:\"langcode\";s:8:\"langcode\";s:6:\"status\";s:6:\"status\";s:12:\"dependencies\";s:12:\"dependencies\";s:20:\"third_party_settings\";s:20:\"third_party_settings\";s:5:\"_core\";s:5:\"_core\";s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"locked\";s:6:\"locked\";s:7:\"pattern\";s:7:\"pattern\";}}'),
('entity.definitions.installed',	'editor.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:6:\"editor\";s:8:\"\0*\0class\";s:27:\"Drupal\\editor\\Entity\\Editor\";s:11:\"\0*\0provider\";s:6:\"editor\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:6:\"format\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\editor\\Entity\\Editor\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:40:\"Drupal\\editor\\EditorAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Text editor\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Text editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"text editor\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"text editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count text editor\";s:6:\"plural\";s:19:\"@count text editors\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"config:editor_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"RequiredConfigDependencies\";a:1:{i:0;s:13:\"filter_format\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:6:\"format\";i:1;s:6:\"editor\";i:2;s:8:\"settings\";i:3;s:12:\"image_upload\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'entity_form_display.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"entity_form_display\";s:8:\"\0*\0class\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityFormDisplay\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:71:\"\\Drupal\\Core\\Entity\\Entity\\Access\\EntityFormDisplayAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Entity form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:entity_form_display_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";i:4;s:7:\"content\";i:5;s:6:\"hidden\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'entity_form_mode.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"entity_form_mode\";s:8:\"\0*\0class\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityFormMode\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:11:\"description\";s:11:\"description\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityFormMode\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Form mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:entity_form_mode_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:2:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:16:\"targetEntityType\";i:4;s:5:\"cache\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'entity_view_display.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"entity_view_display\";s:8:\"\0*\0class\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityViewDisplay\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:43:\"Drupal\\Core\\Entity\\Entity\\EntityViewDisplay\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:71:\"\\Drupal\\Core\\Entity\\Entity\\Access\\EntityViewDisplayAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Entity view display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:entity_view_display_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";i:2;s:6:\"bundle\";i:3;s:4:\"mode\";i:4;s:7:\"content\";i:5;s:6:\"hidden\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'entity_view_mode.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"entity_view_mode\";s:8:\"\0*\0class\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityViewMode\";s:11:\"\0*\0provider\";s:4:\"core\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:11:\"description\";s:11:\"description\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:40:\"Drupal\\Core\\Entity\\Entity\\EntityViewMode\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"View mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:entity_view_mode_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:2:{i:0;s:2:\"id\";i:1;s:16:\"targetEntityType\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:16:\"targetEntityType\";i:4;s:5:\"cache\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'field_config.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"field_config\";s:8:\"\0*\0class\";s:31:\"Drupal\\field\\Entity\\FieldConfig\";s:11:\"\0*\0provider\";s:5:\"field\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\field\\Entity\\FieldConfig\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:44:\"Drupal\\field\\FieldConfigAccessControlHandler\";s:7:\"storage\";s:31:\"Drupal\\field\\FieldConfigStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"field\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:12:\"@count field\";s:6:\"plural\";s:13:\"@count fields\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:field_config_list\";}s:14:\"\0*\0constraints\";a:2:{s:26:\"RequiredConfigDependencies\";a:1:{i:0;s:20:\"field_storage_config\";}s:19:\"ImmutableProperties\";a:5:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";i:3;s:6:\"bundle\";i:4;s:10:\"field_type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:5:\"field\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:6:\"bundle\";i:4;s:5:\"label\";i:5;s:11:\"description\";i:6;s:8:\"required\";i:7;s:12:\"translatable\";i:8;s:13:\"default_value\";i:9;s:22:\"default_value_callback\";i:10;s:8:\"settings\";i:11;s:10:\"field_type\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'field_storage_config.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:20:\"field_storage_config\";s:8:\"\0*\0class\";s:38:\"Drupal\\field\\Entity\\FieldStorageConfig\";s:11:\"\0*\0provider\";s:5:\"field\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:2:\"id\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:38:\"Drupal\\field\\Entity\\FieldStorageConfig\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:51:\"Drupal\\field\\FieldStorageConfigAccessControlHandler\";s:7:\"storage\";s:38:\"Drupal\\field\\FieldStorageConfigStorage\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Field storage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Field storages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"field storage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"field storages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count field storage\";s:6:\"plural\";s:21:\"@count field storages\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:32:\"config:field_storage_config_list\";}s:14:\"\0*\0constraints\";a:1:{s:19:\"ImmutableProperties\";a:4:{i:0;s:2:\"id\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";i:3;s:4:\"type\";}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:7:\"storage\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:12:{i:0;s:2:\"id\";i:1;s:10:\"field_name\";i:2;s:11:\"entity_type\";i:3;s:4:\"type\";i:4;s:8:\"settings\";i:5;s:6:\"module\";i:6;s:6:\"locked\";i:7;s:11:\"cardinality\";i:8;s:12:\"translatable\";i:9;s:7:\"indexes\";i:10;s:22:\"persist_with_no_fields\";i:11;s:14:\"custom_storage\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'file.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"file\";s:8:\"\0*\0class\";s:23:\"Drupal\\file\\Entity\\File\";s:11:\"\0*\0provider\";s:4:\"file\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"fid\";s:5:\"label\";s:8:\"filename\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:5:\"owner\";s:3:\"uid\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\file\\Entity\\File\";s:11:\"\0*\0handlers\";a:8:{s:7:\"storage\";s:23:\"Drupal\\file\\FileStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\file\\FileStorageSchema\";s:6:\"access\";s:36:\"Drupal\\file\\FileAccessControlHandler\";s:10:\"views_data\";s:25:\"Drupal\\file\\FileViewsData\";s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:4:\"form\";a:1:{s:6:\"delete\";s:42:\"Drupal\\Core\\Entity\\ContentEntityDeleteForm\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\file\\Entity\\FileRouteProvider\";}s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:1:{s:11:\"delete-form\";s:19:\"/file/{file}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:12:\"file_managed\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"File\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"file\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count file\";s:6:\"plural\";s:12:\"@count files\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"file_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'file.field_storage_definitions',	'a:11:{s:3:\"fid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"File ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The file ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"fid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The file UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The file language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:0;s:22:\"default_value_callback\";s:46:\"Drupal\\file\\Entity\\File::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"The user ID of the file.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filename\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Filename\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"Name of the file with no path components.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filename\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:153;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uri\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"URI\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The URI to access the file (either local or remote).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:1:{s:13:\"FileUriUnique\";N;}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:3:\"uri\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:file_uri\";s:8:\"settings\";a:2:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:1;}}s:18:\"\0*\0fieldDefinition\";r:187;}s:7:\"\0*\0type\";s:8:\"file_uri\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:1;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filemime\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"File MIME type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"The file\'s MIME type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filemime\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:222;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"filesize\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"File size\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"The size of the file in bytes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:8:\"filesize\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:256;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Status\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:63:\"The status of the file, temporary (FALSE) and permanent (TRUE).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:293;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The timestamp that the file was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:334;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"The timestamp that the file was last changed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"file\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"file\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:363;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),
('entity.definitions.installed',	'filter_format.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:13:\"filter_format\";s:8:\"\0*\0class\";s:33:\"Drupal\\filter\\Entity\\FilterFormat\";s:11:\"\0*\0provider\";s:6:\"filter\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:6:\"format\";s:5:\"label\";s:4:\"name\";s:6:\"weight\";s:6:\"weight\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\filter\\Entity\\FilterFormat\";s:11:\"\0*\0handlers\";a:4:{s:4:\"form\";a:3:{s:3:\"add\";s:33:\"Drupal\\filter\\FilterFormatAddForm\";s:4:\"edit\";s:34:\"Drupal\\filter\\FilterFormatEditForm\";s:7:\"disable\";s:36:\"Drupal\\filter\\Form\\FilterDisableForm\";}s:12:\"list_builder\";s:37:\"Drupal\\filter\\FilterFormatListBuilder\";s:6:\"access\";s:46:\"Drupal\\filter\\FilterFormatAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:18:\"administer filters\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:2:{s:9:\"edit-form\";s:52:\"/admin/config/content/formats/manage/{filter_format}\";s:7:\"disable\";s:60:\"/admin/config/content/formats/manage/{filter_format}/disable\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Text format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Text formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"text format\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"text formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count text format\";s:6:\"plural\";s:19:\"@count text formats\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:25:\"config:filter_format_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:6:\"format\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:4:\"name\";i:1;s:6:\"format\";i:2;s:6:\"weight\";i:3;s:5:\"roles\";i:4;s:7:\"filters\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'image_style.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"image_style\";s:8:\"\0*\0class\";s:30:\"Drupal\\image\\Entity\\ImageStyle\";s:11:\"\0*\0provider\";s:5:\"image\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:4:\"name\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:30:\"Drupal\\image\\Entity\\ImageStyle\";s:11:\"\0*\0handlers\";a:4:{s:4:\"form\";a:4:{s:3:\"add\";s:35:\"Drupal\\image\\Form\\ImageStyleAddForm\";s:4:\"edit\";s:36:\"Drupal\\image\\Form\\ImageStyleEditForm\";s:6:\"delete\";s:38:\"Drupal\\image\\Form\\ImageStyleDeleteForm\";s:5:\"flush\";s:37:\"Drupal\\image\\Form\\ImageStyleFlushForm\";}s:12:\"list_builder\";s:34:\"Drupal\\image\\ImageStyleListBuilder\";s:7:\"storage\";s:30:\"Drupal\\image\\ImageStyleStorage\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";}s:19:\"\0*\0admin_permission\";s:23:\"administer image styles\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:10:\"flush-form\";s:59:\"/admin/config/media/image-styles/manage/{image_style}/flush\";s:9:\"edit-form\";s:53:\"/admin/config/media/image-styles/manage/{image_style}\";s:11:\"delete-form\";s:60:\"/admin/config/media/image-styles/manage/{image_style}/delete\";s:10:\"collection\";s:32:\"/admin/config/media/image-styles\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Image style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"image style\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count image style\";s:6:\"plural\";s:19:\"@count image styles\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:23:\"config:image_style_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:5:\"style\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:3:{i:0;s:4:\"name\";i:1;s:5:\"label\";i:2;s:7:\"effects\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'linkit_profile.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:14:\"linkit_profile\";s:8:\"\0*\0class\";s:28:\"Drupal\\linkit\\Entity\\Profile\";s:11:\"\0*\0provider\";s:6:\"linkit\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:28:\"Drupal\\linkit\\Entity\\Profile\";s:11:\"\0*\0handlers\";a:4:{s:12:\"list_builder\";s:32:\"Drupal\\linkit\\ProfileListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:34:\"Drupal\\linkit\\Form\\Profile\\AddForm\";s:4:\"edit\";s:35:\"Drupal\\linkit\\Form\\Profile\\EditForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:26:\"administer linkit profiles\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:10:\"collection\";s:28:\"/admin/config/content/linkit\";s:9:\"edit-form\";s:52:\"/admin/config/content/linkit/manage/{linkit_profile}\";s:11:\"delete-form\";s:59:\"/admin/config/content/linkit/manage/{linkit_profile}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Linkit profile\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:26:\"config:linkit_profile_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:14:\"linkit_profile\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:5:\"label\";i:1;s:2:\"id\";i:2;s:11:\"description\";i:3;s:8:\"matchers\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'media.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:5:\"media\";s:8:\"\0*\0class\";s:25:\"Drupal\\media\\Entity\\Media\";s:11:\"\0*\0provider\";s:5:\"media\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:3:\"mid\";s:8:\"revision\";s:3:\"vid\";s:6:\"bundle\";s:6:\"bundle\";s:5:\"label\";s:4:\"name\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:5:\"owner\";s:3:\"uid\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:25:\"Drupal\\media\\Entity\\Media\";s:11:\"\0*\0handlers\";a:7:{s:7:\"storage\";s:25:\"Drupal\\media\\MediaStorage\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";s:12:\"list_builder\";s:29:\"Drupal\\media\\MediaListBuilder\";s:6:\"access\";s:38:\"Drupal\\media\\MediaAccessControlHandler\";s:4:\"form\";a:8:{s:7:\"default\";s:22:\"Drupal\\media\\MediaForm\";s:3:\"add\";s:22:\"Drupal\\media\\MediaForm\";s:4:\"edit\";s:22:\"Drupal\\media\\MediaForm\";s:6:\"delete\";s:42:\"Drupal\\Core\\Entity\\ContentEntityDeleteForm\";s:23:\"delete-multiple-confirm\";s:42:\"Drupal\\Core\\Entity\\Form\\DeleteMultipleForm\";s:15:\"revision-delete\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm\";s:15:\"revision-revert\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionRevertForm\";s:14:\"layout_builder\";s:46:\"Drupal\\layout_builder\\Form\\OverridesEntityForm\";}s:10:\"views_data\";s:27:\"Drupal\\media\\MediaViewsData\";s:14:\"route_provider\";a:2:{s:4:\"html\";s:39:\"Drupal\\media\\Routing\\MediaRouteProvider\";s:8:\"revision\";s:52:\"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider\";}}s:19:\"\0*\0admin_permission\";s:16:\"administer media\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:11:{s:8:\"add-page\";s:10:\"/media/add\";s:8:\"add-form\";s:23:\"/media/add/{media_type}\";s:9:\"canonical\";s:19:\"/media/{media}/edit\";s:10:\"collection\";s:20:\"/admin/content/media\";s:11:\"delete-form\";s:21:\"/media/{media}/delete\";s:20:\"delete-multiple-form\";s:13:\"/media/delete\";s:9:\"edit-form\";s:19:\"/media/{media}/edit\";s:8:\"revision\";s:46:\"/media/{media}/revisions/{media_revision}/view\";s:20:\"revision-delete-form\";s:47:\"/media/{media}/revision/{media_revision}/delete\";s:20:\"revision-revert-form\";s:47:\"/media/{media}/revision/{media_revision}/revert\";s:15:\"version-history\";s:24:\"/media/{media}/revisions\";}s:21:\"\0*\0bundle_entity_type\";s:10:\"media_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:5:\"media\";s:22:\"\0*\0revision_data_table\";s:20:\"media_field_revision\";s:17:\"\0*\0revision_table\";s:14:\"media_revision\";s:13:\"\0*\0data_table\";s:16:\"media_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"media item\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"media items\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count media item\";s:6:\"plural\";s:18:\"@count media items\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:27:\"entity.media_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:10:\"media_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:20:\"revision_log_message\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'media.field_storage_definitions',	'a:22:{s:3:\"mid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:3:\"mid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"vid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:3:\"vid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"bundle\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";s:10:\"Media type\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:6:\"bundle\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:10:\"media_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:139;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:170;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:200;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"revision_log_message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:20:\"revision_log_message\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:237;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:100;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:279;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored by\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:48:\"Drupal\\media\\Entity\\Media::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The user ID of the author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:8:\"settings\";a:4:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:4:\"size\";s:2:\"60\";s:17:\"autocomplete_type\";s:4:\"tags\";s:11:\"placeholder\";s:0:\"\";}}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"author\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:326;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:382;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"thumbnail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Thumbnail\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"The thumbnail of the media item.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"view\";a:2:{s:7:\"options\";a:4:{s:4:\"type\";s:5:\"image\";s:6:\"weight\";i:5;s:5:\"label\";s:6:\"hidden\";s:8:\"settings\";a:1:{s:11:\"image_style\";s:9:\"thumbnail\";}}s:12:\"configurable\";b:1;}}s:9:\"read-only\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:9:\"thumbnail\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:image\";s:8:\"settings\";a:16:{s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:15:\"file_extensions\";s:21:\"png gif jpg jpeg webp\";s:9:\"alt_field\";i:1;s:18:\"alt_field_required\";i:1;s:11:\"title_field\";i:0;s:20:\"title_field_required\";i:0;s:14:\"max_resolution\";s:0:\"\";s:14:\"min_resolution\";s:0:\"\";s:14:\"file_directory\";s:31:\"[date:custom:Y]-[date:custom:m]\";s:12:\"max_filesize\";s:0:\"\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:428;}s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:5:{s:9:\"target_id\";a:3:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}s:3:\"alt\";a:3:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;}s:5:\"title\";a:3:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;}s:5:\"width\";a:3:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}s:6:\"height\";a:3:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:12:\"foreign keys\";a:1:{s:9:\"target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:9:\"target_id\";s:3:\"fid\";}}}s:11:\"unique keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored on\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"The time the media item was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:22:\"default_value_callback\";s:41:\"Drupal\\media\\Entity\\Media::getRequestTime\";s:7:\"display\";a:2:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;}s:12:\"configurable\";b:1;}s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:9:\"timestamp\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:514;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The time the media item was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:558;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:589;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:632;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:5:\"media\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:5:\"media\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:674;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:22:\"field_media_audio_file\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"media.field_media_audio_file\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"75a1e1d5-184d-4541-96b7-8957dddb2453\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"JCHoh95CpUeBx9ch24Tmi6ru0nwmNz8xWVH4Qs7RnTg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"media.field_media_audio_file\";s:13:\"\0*\0field_name\";s:22:\"field_media_audio_file\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:4:\"file\";s:9:\"\0*\0module\";s:4:\"file\";s:11:\"\0*\0settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_media_document\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:26:\"media.field_media_document\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"2c293a08-a63a-47a3-8b49-8e7650f47903\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"BdkTx7IL59MCw5a_fOZprPTOGM_wcjz-Fm8g7HV3vFk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:2:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:26:\"media.field_media_document\";s:13:\"\0*\0field_name\";s:20:\"field_media_document\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:4:\"file\";s:9:\"\0*\0module\";s:4:\"file\";s:11:\"\0*\0settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:17:\"field_media_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":32:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:23:\"media.field_media_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"379994ed-ae76-4656-ab52-4f8661d6efc4\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0N0KSFk57p6qsq3qM4lYVGSuROvzXK-tSsdwByqUh3g\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:2:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:5:\"media\";}s:8:\"enforced\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:23:\"media.field_media_image\";s:13:\"\0*\0field_name\";s:17:\"field_media_image\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0module\";s:5:\"image\";s:11:\"\0*\0settings\";a:5:{s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;s:20:\"field_storage_submit\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Update settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:18:\"cardinality_number\";s:1:\"1\";}s:24:\"field_media_oembed_video\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"media.field_media_oembed_video\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"eca9af3a-0023-4307-a38b-526dac079818\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cNf_852Dq-fNnSaMI4LxL-J6N7bLkHuDbD9EUqOn4_U\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"media.field_media_oembed_video\";s:13:\"\0*\0field_name\";s:24:\"field_media_oembed_video\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:3:{s:10:\"max_length\";i:255;s:14:\"case_sensitive\";b:0;s:8:\"is_ascii\";b:0;}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_media_video_file\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"media.field_media_video_file\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"4f8a6296-0295-4cc5-8e6a-c61c708a78ba\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"z5mgbn1PIVZ5TNMByBmivqo_u3Rdk58UIzpyN4ypTeM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"file\";i:1;s:5:\"media\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"media.field_media_video_file\";s:13:\"\0*\0field_name\";s:22:\"field_media_video_file\";s:14:\"\0*\0entity_type\";s:5:\"media\";s:7:\"\0*\0type\";s:4:\"file\";s:9:\"\0*\0module\";s:4:\"file\";s:11:\"\0*\0settings\";a:4:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),
('entity.definitions.installed',	'media_type.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:10:\"media_type\";s:8:\"\0*\0class\";s:29:\"Drupal\\media\\Entity\\MediaType\";s:11:\"\0*\0provider\";s:5:\"media\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\media\\Entity\\MediaType\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:42:\"Drupal\\media\\MediaTypeAccessControlHandler\";s:4:\"form\";a:3:{s:3:\"add\";s:26:\"Drupal\\media\\MediaTypeForm\";s:4:\"edit\";s:26:\"Drupal\\media\\MediaTypeForm\";s:6:\"delete\";s:44:\"Drupal\\media\\Form\\MediaTypeDeleteConfirmForm\";}s:12:\"list_builder\";s:33:\"Drupal\\media\\MediaTypeListBuilder\";s:14:\"route_provider\";a:2:{s:4:\"html\";s:51:\"Drupal\\Core\\Entity\\Routing\\DefaultHtmlRouteProvider\";s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:22:\"administer media types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:8:\"add-form\";s:26:\"/admin/structure/media/add\";s:9:\"edit-form\";s:42:\"/admin/structure/media/manage/{media_type}\";s:11:\"delete-form\";s:49:\"/admin/structure/media/manage/{media_type}/delete\";s:23:\"entity-permissions-form\";s:54:\"/admin/structure/media/manage/{media_type}/permissions\";s:10:\"collection\";s:22:\"/admin/structure/media\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:5:\"media\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Media types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"media types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count media type\";s:6:\"plural\";s:18:\"@count media types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:22:\"config:media_type_list\";}s:14:\"\0*\0constraints\";a:2:{s:19:\"ImmutableProperties\";a:2:{i:0;s:2:\"id\";i:1;s:6:\"source\";}s:23:\"MediaMappingsConstraint\";a:0:{}}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:9:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"source\";i:4;s:25:\"queue_thumbnail_downloads\";i:5;s:12:\"new_revision\";i:6;s:20:\"source_configuration\";i:7;s:9:\"field_map\";i:8;s:6:\"status\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'menu.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:4:\"menu\";s:8:\"\0*\0class\";s:25:\"Drupal\\system\\Entity\\Menu\";s:11:\"\0*\0provider\";s:6:\"system\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:25:\"Drupal\\system\\Entity\\Menu\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:38:\"Drupal\\system\\MenuAccessControlHandler\";s:7:\"storage\";s:25:\"Drupal\\system\\MenuStorage\";}s:19:\"\0*\0admin_permission\";s:15:\"administer menu\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count menu\";s:6:\"plural\";s:12:\"@count menus\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:16:\"config:menu_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:4:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:11:\"description\";i:3;s:6:\"locked\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'menu_link_content.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":40:{s:5:\"\0*\0id\";s:17:\"menu_link_content\";s:8:\"\0*\0class\";s:47:\"Drupal\\menu_link_content\\Entity\\MenuLinkContent\";s:11:\"\0*\0provider\";s:17:\"menu_link_content\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:6:\"bundle\";s:9:\"published\";s:7:\"enabled\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:47:\"Drupal\\menu_link_content\\Entity\\MenuLinkContent\";s:11:\"\0*\0handlers\";a:7:{s:7:\"storage\";s:48:\"\\Drupal\\menu_link_content\\MenuLinkContentStorage\";s:14:\"storage_schema\";s:53:\"Drupal\\menu_link_content\\MenuLinkContentStorageSchema\";s:6:\"access\";s:60:\"Drupal\\menu_link_content\\MenuLinkContentAccessControlHandler\";s:4:\"form\";a:2:{s:7:\"default\";s:49:\"Drupal\\menu_link_content\\Form\\MenuLinkContentForm\";s:6:\"delete\";s:55:\"Drupal\\menu_link_content\\Form\\MenuLinkContentDeleteForm\";}s:12:\"list_builder\";s:44:\"Drupal\\menu_link_content\\MenuLinkListBuilder\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";s:10:\"moderation\";s:0:\"\";}s:19:\"\0*\0admin_permission\";s:15:\"administer menu\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"canonical\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:9:\"edit-form\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:11:\"delete-form\";s:53:\"/admin/structure/menu/item/{menu_link_content}/delete\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:17:\"menu_link_content\";s:22:\"\0*\0revision_data_table\";s:32:\"menu_link_content_field_revision\";s:17:\"\0*\0revision_table\";s:26:\"menu_link_content_revision\";s:13:\"\0*\0data_table\";s:22:\"menu_link_content_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Custom menu link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Custom menu links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"custom menu link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"custom menu links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:23:\"@count custom menu link\";s:6:\"plural\";s:24:\"@count custom menu links\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:22:\"menu_link_content_list\";}s:14:\"\0*\0constraints\";a:3:{s:17:\"MenuTreeHierarchy\";a:0:{}s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:1:{s:17:\"stringTranslation\";s:18:\"string_translation\";}s:18:\"\0*\0_entityStorages\";a:0:{}s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:20:\"revision_log_message\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'menu_link_content.field_storage_definitions',	'a:22:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Entity ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"The entity ID for this menu link content entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"The content menu link UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"The menu link language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:111;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"bundle\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";s:23:\"Custom menu link bundle\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"The content menu link bundle.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"bundle\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:151;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:184;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:214;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"revision_log_message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:20:\"revision_log_message\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:251;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"enabled\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Enabled\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"A flag for whether the link should be enabled in menus or hidden.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:7:\"boolean\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:-1;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:7:\"enabled\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:290;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Menu link title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:46:\"The text to be used for this link in the menu.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:344;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"description\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Shown when hovering over the menu link.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:0;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:11:\"description\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:392;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"menu_name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Menu name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:93:\"The menu name. All links with the same menu name (such as \"tools\") are part of the same menu.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:5:\"tools\";}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:9:\"menu_name\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:438;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"link\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"The location this menu link points to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:-2;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:4:\"link\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:link\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}}s:18:\"\0*\0fieldDefinition\";r:475;}s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:3:{s:3:\"uri\";a:3:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"title\";a:3:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;}s:7:\"options\";a:4:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:3:\"uri\";a:1:{i:0;a:2:{i:0;s:3:\"uri\";i:1;i:30;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"external\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"External\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:120:\"A flag to indicate if the link points to a full URL starting with a protocol, like http:// (1 = external, 0 = internal).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"external\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:528;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:10:\"rediscover\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"Indicates whether the menu link should be rediscovered\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:10:\"rediscover\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:570;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:172:\"Link weight among links in the same menu at the same depth. In the menu, the links with high weight will sink and links with a low weight will be positioned nearer the top.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:14:\"number_integer\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:6:\"number\";s:6:\"weight\";i:20;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:607;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"expanded\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Show as expanded\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:164:\"If selected and this menu link has children, the menu will always appear expanded. This option may be overridden for the entire menu tree when placing a menu block.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:7:\"boolean\";s:6:\"weight\";i:0;}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:0;}}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:8:\"expanded\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:657;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"parent\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Parent plugin ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:94:\"The ID of the parent menu link plugin, or empty string when at the top level of the hierarchy.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:6:\"parent\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:709;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"The time that the menu link was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:743;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:774;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:817;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:17:\"menu_link_content\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:17:\"menu_link_content\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:859;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),
('entity.definitions.installed',	'metatag_defaults.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"metatag_defaults\";s:8:\"\0*\0class\";s:37:\"Drupal\\metatag\\Entity\\MetatagDefaults\";s:11:\"\0*\0provider\";s:7:\"metatag\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:37:\"Drupal\\metatag\\Entity\\MetatagDefaults\";s:11:\"\0*\0handlers\";a:4:{s:12:\"list_builder\";s:41:\"Drupal\\metatag\\MetatagDefaultsListBuilder\";s:4:\"form\";a:4:{s:3:\"add\";s:39:\"Drupal\\metatag\\Form\\MetatagDefaultsForm\";s:4:\"edit\";s:39:\"Drupal\\metatag\\Form\\MetatagDefaultsForm\";s:6:\"delete\";s:45:\"Drupal\\metatag\\Form\\MetatagDefaultsDeleteForm\";s:6:\"revert\";s:45:\"Drupal\\metatag\\Form\\MetatagDefaultsRevertForm\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:20:\"administer meta tags\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:9:\"edit-form\";s:52:\"/admin/config/search/metatag/{metatag_defaults}/edit\";s:11:\"delete-form\";s:54:\"/admin/config/search/metatag/{metatag_defaults}/delete\";s:11:\"revert-form\";s:54:\"/admin/config/search/metatag/{metatag_defaults}/revert\";s:10:\"collection\";s:28:\"/admin/config/search/metatag\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Metatag defaults\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:metatag_defaults_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:16:\"metatag_defaults\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:16:\"metatag_defaults\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:3:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:4:\"tags\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'node.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"node\";s:8:\"\0*\0class\";s:23:\"Drupal\\node\\Entity\\Node\";s:11:\"\0*\0provider\";s:4:\"node\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:12:{s:2:\"id\";s:3:\"nid\";s:8:\"revision\";s:3:\"vid\";s:6:\"bundle\";s:4:\"type\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"status\";s:6:\"status\";s:9:\"published\";s:6:\"status\";s:3:\"uid\";s:3:\"uid\";s:5:\"owner\";s:3:\"uid\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\node\\Entity\\Node\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:23:\"Drupal\\node\\NodeStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\node\\NodeStorageSchema\";s:12:\"view_builder\";s:27:\"Drupal\\node\\NodeViewBuilder\";s:6:\"access\";s:36:\"Drupal\\node\\NodeAccessControlHandler\";s:10:\"views_data\";s:25:\"Drupal\\node\\NodeViewsData\";s:4:\"form\";a:4:{s:7:\"default\";s:20:\"Drupal\\node\\NodeForm\";s:6:\"delete\";s:31:\"Drupal\\node\\Form\\NodeDeleteForm\";s:4:\"edit\";s:20:\"Drupal\\node\\NodeForm\";s:23:\"delete-multiple-confirm\";s:31:\"Drupal\\node\\Form\\DeleteMultiple\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\node\\Entity\\NodeRouteProvider\";}s:12:\"list_builder\";s:27:\"Drupal\\node\\NodeListBuilder\";s:11:\"translation\";s:34:\"Drupal\\node\\NodeTranslationHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";s:23:\"access content overview\";s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:7:{s:9:\"canonical\";s:12:\"/node/{node}\";s:11:\"delete-form\";s:19:\"/node/{node}/delete\";s:20:\"delete-multiple-form\";s:26:\"/admin/content/node/delete\";s:9:\"edit-form\";s:17:\"/node/{node}/edit\";s:15:\"version-history\";s:22:\"/node/{node}/revisions\";s:8:\"revision\";s:43:\"/node/{node}/revisions/{node_revision}/view\";s:6:\"create\";s:5:\"/node\";}s:21:\"\0*\0bundle_entity_type\";s:9:\"node_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:4:\"node\";s:22:\"\0*\0revision_data_table\";s:19:\"node_field_revision\";s:17:\"\0*\0revision_table\";s:13:\"node_revision\";s:13:\"\0*\0data_table\";s:15:\"node_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"content item\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content items\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count content item\";s:6:\"plural\";s:20:\"@count content items\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:26:\"entity.node_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:1:{i:0;s:21:\"user.node_grants:view\";}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"node_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:12:\"revision_uid\";s:16:\"revision_created\";s:18:\"revision_timestamp\";s:20:\"revision_log_message\";s:12:\"revision_log\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'node.field_storage_definitions',	'a:23:{s:3:\"nid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"nid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"vid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"vid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";s:12:\"Content type\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:9:\"node_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:139;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:18:\"revision_timestamp\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:18:\"revision_timestamp\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:170;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:12:\"revision_uid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:200;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"revision_log\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:12:\"revision_log\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:237;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:120;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:279;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored by\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:22:\"default_value_callback\";s:46:\"Drupal\\node\\Entity\\Node::getDefaultEntityOwner\";s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The username of the content author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"author\";s:6:\"weight\";i:0;}}s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:29:\"entity_reference_autocomplete\";s:6:\"weight\";i:5;s:8:\"settings\";a:3:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:4:\"size\";s:2:\"60\";s:11:\"placeholder\";s:0:\"\";}}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:326;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Title\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:380;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored on\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The date and time that the content was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:9:\"timestamp\";s:6:\"weight\";i:0;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:18:\"datetime_timestamp\";s:6:\"weight\";i:10;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:424;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the node was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:466;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"promote\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Promoted to front page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:15;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:7:\"promote\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:497;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"sticky\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Sticky at top of lists\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:16;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:6:\"sticky\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:544;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:591;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:634;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"node\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:4:\"node\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:676;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"body\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:9:\"node.body\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"27acecd6-ddfe-41ab-ad13-d09a77410226\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EBUo7qOWqaiZaQ_RC9sLY5IoDKphS34v77VIHSACmVY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:9:\"node.body\";s:13:\"\0*\0field_name\";s:4:\"body\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:17:\"text_with_summary\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:1;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:11:\"field_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":32:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:16:\"node.field_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"0ce9563d-0108-4dd8-9768-e3f3f692efb8\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"EymokncRIZ7SgQT2IdOQhQJicX4nNc0K89ik-LxmOHE\";}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"node\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:16:\"node.field_image\";s:13:\"\0*\0field_name\";s:11:\"field_image\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0module\";s:5:\"image\";s:11:\"\0*\0settings\";a:5:{s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";s:0:\"\";s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:10:\"\0*\0deleted\";b:0;s:20:\"field_storage_submit\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Update settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:18:\"cardinality_number\";s:1:\"1\";}s:10:\"field_tags\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:15:\"node.field_tags\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"11256bc1-c4ef-404b-ae80-826c196dfc3c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"WpOE_bs8Bs_HY2ns7n2r__de-xno0-Bxkqep5-MsHAs\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:8:\"taxonomy\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:15:\"node.field_tags\";s:13:\"\0*\0field_name\";s:10:\"field_tags\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:13:\"taxonomy_term\";}s:14:\"\0*\0cardinality\";i:-1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:14:\"field_metatags\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":32:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";N;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:19:\"node.field_metatags\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"3a56d56d-4fea-4e6d-abfd-6e9fd5799d1f\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"metatag\";i:1;s:4:\"node\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:19:\"node.field_metatags\";s:13:\"\0*\0field_name\";s:14:\"field_metatags\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:7:\"metatag\";s:9:\"\0*\0module\";s:7:\"metatag\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;s:20:\"field_storage_submit\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Update settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:18:\"cardinality_number\";i:1;}s:22:\"layout_builder__layout\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:27:\"node.layout_builder__layout\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"01dcf303-887c-48ba-8de3-a183f2dc164d\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:0:{}s:14:\"\0*\0trustedData\";b:0;s:15:\"\0*\0dependencies\";a:0:{}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:27:\"node.layout_builder__layout\";s:13:\"\0*\0field_name\";s:22:\"layout_builder__layout\";s:14:\"\0*\0entity_type\";s:4:\"node\";s:7:\"\0*\0type\";s:14:\"layout_section\";s:9:\"\0*\0module\";s:14:\"layout_builder\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:0;s:9:\"\0*\0locked\";b:1;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),
('entity.definitions.installed',	'node_type.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:9:\"node_type\";s:8:\"\0*\0class\";s:27:\"Drupal\\node\\Entity\\NodeType\";s:11:\"\0*\0provider\";s:4:\"node\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:4:\"type\";s:5:\"label\";s:4:\"name\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\node\\Entity\\NodeType\";s:11:\"\0*\0handlers\";a:5:{s:6:\"access\";s:40:\"Drupal\\node\\NodeTypeAccessControlHandler\";s:4:\"form\";a:3:{s:3:\"add\";s:24:\"Drupal\\node\\NodeTypeForm\";s:4:\"edit\";s:24:\"Drupal\\node\\NodeTypeForm\";s:6:\"delete\";s:38:\"Drupal\\node\\Form\\NodeTypeDeleteConfirm\";}s:14:\"route_provider\";a:1:{s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}s:12:\"list_builder\";s:31:\"Drupal\\node\\NodeTypeListBuilder\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:24:\"administer content types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:9:\"edit-form\";s:41:\"/admin/structure/types/manage/{node_type}\";s:11:\"delete-form\";s:48:\"/admin/structure/types/manage/{node_type}/delete\";s:23:\"entity-permissions-form\";s:53:\"/admin/structure/types/manage/{node_type}/permissions\";s:10:\"collection\";s:22:\"/admin/structure/types\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:4:\"node\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count content type\";s:6:\"plural\";s:20:\"@count content types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:21:\"config:node_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:7:{i:0;s:4:\"name\";i:1;s:4:\"type\";i:2;s:11:\"description\";i:3;s:4:\"help\";i:4;s:12:\"new_revision\";i:5;s:12:\"preview_mode\";i:6;s:17:\"display_submitted\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'paragraph.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:9:\"paragraph\";s:8:\"\0*\0class\";s:34:\"Drupal\\paragraphs\\Entity\\Paragraph\";s:11:\"\0*\0provider\";s:10:\"paragraphs\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:0;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:4:\"type\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:11:\"revision_id\";s:9:\"published\";s:6:\"status\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:34:\"Drupal\\paragraphs\\Entity\\Paragraph\";s:11:\"\0*\0handlers\";a:7:{s:12:\"view_builder\";s:38:\"Drupal\\paragraphs\\ParagraphViewBuilder\";s:6:\"access\";s:47:\"Drupal\\paragraphs\\ParagraphAccessControlHandler\";s:14:\"storage_schema\";s:40:\"Drupal\\paragraphs\\ParagraphStorageSchema\";s:4:\"form\";a:4:{s:7:\"default\";s:36:\"Drupal\\Core\\Entity\\ContentEntityForm\";s:6:\"delete\";s:42:\"Drupal\\Core\\Entity\\ContentEntityDeleteForm\";s:4:\"edit\";s:36:\"Drupal\\Core\\Entity\\ContentEntityForm\";s:14:\"layout_builder\";s:46:\"Drupal\\layout_builder\\Form\\OverridesEntityForm\";}s:10:\"views_data\";s:28:\"Drupal\\views\\EntityViewsData\";s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:10:\"moderation\";s:0:\"\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";s:15:\"paragraphs_type\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Paragraph type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:15:\"paragraphs_item\";s:22:\"\0*\0revision_data_table\";s:35:\"paragraphs_item_revision_field_data\";s:17:\"\0*\0revision_table\";s:24:\"paragraphs_item_revision\";s:13:\"\0*\0data_table\";s:26:\"paragraphs_item_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Paragraphs\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Paragraph\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Paragraphs\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:16:\"@count Paragraph\";s:6:\"plural\";s:17:\"@count Paragraphs\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:32:\"entity.paragraphs_type.edit_form\";s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:14:\"paragraph_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:8:{s:33:\"entity_revision_parent_type_field\";s:11:\"parent_type\";s:31:\"entity_revision_parent_id_field\";s:9:\"parent_id\";s:39:\"entity_revision_parent_field_name_field\";s:17:\"parent_field_name\";s:33:\"common_reference_revisions_target\";b:1;s:27:\"content_translation_ui_skip\";b:1;s:35:\"default_reference_revision_settings\";a:4:{s:20:\"field_storage_config\";a:2:{s:11:\"cardinality\";i:-1;s:8:\"settings\";a:1:{s:11:\"target_type\";s:9:\"paragraph\";}}s:12:\"field_config\";a:1:{s:8:\"settings\";a:1:{s:7:\"handler\";s:17:\"default:paragraph\";}}s:19:\"entity_form_display\";a:1:{s:4:\"type\";s:10:\"paragraphs\";}s:19:\"entity_view_display\";a:1:{s:4:\"type\";s:38:\"entity_reference_revisions_entity_view\";}}s:31:\"serialized_field_property_names\";a:1:{s:17:\"behavior_settings\";a:1:{i:0;s:5:\"value\";}}s:10:\"token_type\";s:9:\"paragraph\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'paragraph.field_storage_definitions',	'a:51:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"The paragraphs entity language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";s:14:\"Paragraph type\";s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:15:\"paragraphs_type\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:135;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:166;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Authored on\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The time that the Paragraph was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:6:\"region\";s:6:\"hidden\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:210;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"parent_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Parent ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:63:\"The ID of the parent entity of which this entity is referenced.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:9:\"parent_id\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:247;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"parent_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Parent type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"The entity parent type to which this entity is referenced.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:11:\"parent_type\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:282;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:17:\"parent_field_name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Parent field name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:64:\"The entity parent field name to which this entity is referenced.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:17:\"parent_field_name\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:317;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:17:\"behavior_settings\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Behavior settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"The behavior plugin settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:6:\"a:0:{}\";}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:17:\"behavior_settings\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:352;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:387;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:430;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:10:\"paragraphs\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:9:\"paragraph\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:472;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:25:\"field_ebt_accordion_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ebt_accordion_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7205b1e6-f387-4cb5-80f3-ea6e935096ea\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"xtdycMRMTk1-RbuIsXUkC8uoiTiAeIi8PtDCDuev5pM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ebt_accordion_title\";s:13:\"\0*\0field_name\";s:25:\"field_ebt_accordion_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ebt_accordion_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ebt_accordion_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"c88354ca-8244-4d5a-8c63-2709d938c811\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"dl3BMOx4hnrrl4qqLYkCtUssYQ_RkV9iIcbThUL8opE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ebt_accordion_text\";s:13:\"\0*\0field_name\";s:24:\"field_ebt_accordion_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ebt_carousel_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ebt_carousel_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"c9955fe0-9e81-4347-b5c8-b3a2813ea422\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sBBtSihKznwfoZE4RCUfKLyFx5JPJOKThpsezNspQUg\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ebt_carousel_image\";s:13:\"\0*\0field_name\";s:24:\"field_ebt_carousel_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ebt_carousel_caption\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ebt_carousel_caption\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"9950466c-7cf2-451c-a90c-6d94bc4223d2\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"eH045cIw7DgTbyESpPO40c1yE4GkZSKAsRjv6wCv1cc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ebt_carousel_caption\";s:13:\"\0*\0field_name\";s:26:\"field_ebt_carousel_caption\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ebt_counter_number\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ebt_counter_number\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"fe9a8722-bb07-4268-815a-a4b9b20eb504\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"12yti1pJd8_55sJ_ipVJkKkOSBrqJNbIN1ScDohe8Ug\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ebt_counter_number\";s:13:\"\0*\0field_name\";s:24:\"field_ebt_counter_number\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:2:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_ebt_counter_icon\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"paragraph.field_ebt_counter_icon\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"17ec174c-0286-4b9d-8d57-f5618c7d73b5\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"A3xIcHA3Yh7nEExvOCO8fCJ2RKTLwO7PHRzSW91-6ag\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"paragraph.field_ebt_counter_icon\";s:13:\"\0*\0field_name\";s:22:\"field_ebt_counter_icon\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ebt_counter_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_ebt_counter_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"646af88e-2cb1-4e61-9b5a-1720fbe00d94\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"8SSZniajg5zo9MscuowyDAxLHlUJhnpGgVXmpef2Qfc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_ebt_counter_title\";s:13:\"\0*\0field_name\";s:23:\"field_ebt_counter_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:29:\"field_ebt_counter_description\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:39:\"paragraph.field_ebt_counter_description\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"474cb9c9-f18d-40c9-8bdc-2b263c5bf1bb\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"T2aI_SC10fUAVAHAQ6YSjRx-RgZI16Y4DhBlcYV8xTY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:39:\"paragraph.field_ebt_counter_description\";s:13:\"\0*\0field_name\";s:29:\"field_ebt_counter_description\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ebt_slick_slider_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ebt_slick_slider_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"ce8c8911-2694-45d2-b941-6c8f08c9a8fd\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"2sX2ALM8UbHO085MTpnVsKr65w2_hTSuR1OGRh9yhnc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ebt_slick_slider_link\";s:13:\"\0*\0field_name\";s:27:\"field_ebt_slick_slider_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:28:\"field_ebt_slick_slider_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:38:\"paragraph.field_ebt_slick_slider_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7b1e8d87-89a6-4d9c-b0ae-16292b52f88b\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"HwpmmxKvO4846yzGMxYlF27KAqxGN93LugyydI_mAQk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:38:\"paragraph.field_ebt_slick_slider_image\";s:13:\"\0*\0field_name\";s:28:\"field_ebt_slick_slider_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:27:\"field_ebt_slick_slider_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:37:\"paragraph.field_ebt_slick_slider_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"fd3e2c50-dcff-4f84-bd3f-a28c9352ea81\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"bw5ktsaCO3NIoI8s4_-sX-8nheZucWVVtes3gNa3nAM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:37:\"paragraph.field_ebt_slick_slider_text\";s:13:\"\0*\0field_name\";s:27:\"field_ebt_slick_slider_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ebt_slideshow_slide\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ebt_slideshow_slide\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"20a2702c-d0d9-491e-bc0d-48bd8f4e5479\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yvMPSQ3opDpO2Y7W2gLC_lfyYsUerg7quMuaUIXTG6Y\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ebt_slideshow_slide\";s:13:\"\0*\0field_name\";s:25:\"field_ebt_slideshow_slide\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ebt_slideshow_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ebt_slideshow_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"99143ce8-61ee-4652-a122-2b74cf0353a8\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ZYqrMKPAVBTFXGukNiO0LmsHSZLTwSIqlH0B12cWoSc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ebt_slideshow_link\";s:13:\"\0*\0field_name\";s:24:\"field_ebt_slideshow_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:25:\"field_ebt_slideshow_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:35:\"paragraph.field_ebt_slideshow_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"b514672e-03d7-4efa-81b8-0f04c6b94cd1\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"56OfbIVnrkDV6Ei_ldSAYihwJbVyAJds03m4lf7fsqc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:35:\"paragraph.field_ebt_slideshow_title\";s:13:\"\0*\0field_name\";s:25:\"field_ebt_slideshow_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ebt_slideshow_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ebt_slideshow_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"5476f31f-53b6-41ea-919f-8ea57cf902fc\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"l1sRS9qn9Xk0p6T25AqVsGWWAhp74-8ejyMC2cSICnA\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ebt_slideshow_text\";s:13:\"\0*\0field_name\";s:24:\"field_ebt_slideshow_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_stats_item_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_stats_item_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7003f50c-c76e-4efe-bfcc-67453daeb93c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"6Xx4YNeE_zQDdDg8HySkyOGsBrl8RHNnsFsWYoC1GI4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_stats_item_link\";s:13:\"\0*\0field_name\";s:21:\"field_stats_item_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:22:\"field_stats_item_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:32:\"paragraph.field_stats_item_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"233843a3-22c1-4376-a920-f894f695b87c\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"ml8f47_-t_lza9fvHT7YnpccMFPtmO5CC_TKle1QMr8\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:32:\"paragraph.field_stats_item_image\";s:13:\"\0*\0field_name\";s:22:\"field_stats_item_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_stats_item_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_stats_item_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"0d6fd00f-5382-443f-ae8a-996e1552af22\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7R83PXXuAu39Em7tMg3vXyaerbWjilK3AuSi3IXVRYc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_stats_item_text\";s:13:\"\0*\0field_name\";s:21:\"field_stats_item_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_stats_item_number\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_stats_item_number\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"f6763f4c-c4a6-4d80-ab1d-f0e2aca44f60\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"YWL60ZrNzy_L7BYYe7ipJCC3__awGcG9ewUwecK82J4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_stats_item_number\";s:13:\"\0*\0field_name\";s:23:\"field_stats_item_number\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ebt_tab_page\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ebt_tab_page\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"527f69af-c7cb-450d-a95f-a0199f66a3fc\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"Lx2SQWOPiXsxTotbjz7VPPAu-QERRb10_IFn-ApZRDo\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"node\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ebt_tab_page\";s:13:\"\0*\0field_name\";s:18:\"field_ebt_tab_page\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:4:\"node\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ebt_tab_content\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ebt_tab_content\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"d00f9fc0-b613-4eed-90b2-740af89205eb\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"7FvDDnDFUS9rxHT4MbM9RwHPArBckbhp09KzHNMtD10\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:7:\"options\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ebt_tab_content\";s:13:\"\0*\0field_name\";s:21:\"field_ebt_tab_content\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:11:\"list_string\";s:9:\"\0*\0module\";s:7:\"options\";s:11:\"\0*\0settings\";a:2:{s:14:\"allowed_values\";a:4:{s:4:\"text\";s:4:\"Text\";s:4:\"page\";s:4:\"Page\";s:5:\"block\";s:5:\"Block\";s:5:\"views\";s:5:\"Views\";}s:23:\"allowed_values_function\";s:0:\"\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ebt_tab_block\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ebt_tab_block\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"0fc30373-baea-48fd-8769-4b6c582ae3d8\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"AwzF4qJWahe58UULrqET0cwFen2kxLMygeAFj96-4Kk\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:11:\"block_field\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ebt_tab_block\";s:13:\"\0*\0field_name\";s:19:\"field_ebt_tab_block\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:11:\"block_field\";s:9:\"\0*\0module\";s:11:\"block_field\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ebt_tab_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ebt_tab_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"0c03a11f-8242-48d7-ae98-2da2e80f3f2e\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"chlF7z3GEcHoQnXo-49bdW3H_FSDPxAqWy0miEMc3AM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ebt_tab_title\";s:13:\"\0*\0field_name\";s:19:\"field_ebt_tab_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"text\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:1:{s:10:\"max_length\";i:1023;}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:18:\"field_ebt_tab_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:28:\"paragraph.field_ebt_tab_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7492acc6-65ae-4f1f-b3c7-3e41a385e8cb\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jvq8PSEOBXAVYlGbuM_TA0t_zulyHA_Bkjc6MrrkLWY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:28:\"paragraph.field_ebt_tab_text\";s:13:\"\0*\0field_name\";s:18:\"field_ebt_tab_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:19:\"field_ebt_tab_views\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:29:\"paragraph.field_ebt_tab_views\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"3dc81a0a-ea91-4e72-af8b-18c1abffc08d\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"QmZGd58IuoXxDcUvh8hfNHnRLR71GZA3qzfZpuVSjH4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:10:\"paragraphs\";i:1;s:5:\"views\";i:2;s:14:\"viewsreference\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:29:\"paragraph.field_ebt_tab_views\";s:13:\"\0*\0field_name\";s:19:\"field_ebt_tab_views\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:14:\"viewsreference\";s:9:\"\0*\0module\";s:14:\"viewsreference\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:4:\"view\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ebt_tiles_link\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"paragraph.field_ebt_tiles_link\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"f1992284-2903-4d4f-b4c2-4336abc56b45\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"mUN0Fv2hYJXOjWBr3fDMeZnblvk6m_qvnRncjAS5Jz0\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:4:\"link\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"paragraph.field_ebt_tiles_link\";s:13:\"\0*\0field_name\";s:20:\"field_ebt_tiles_link\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0module\";s:4:\"link\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ebt_tiles_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ebt_tiles_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"3988ff22-66ff-4325-be58-387a6451784f\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"3aeaxW3pHrK5yFagP66-FT7HXAGYacr2YhOcg-h70n0\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ebt_tiles_image\";s:13:\"\0*\0field_name\";s:21:\"field_ebt_tiles_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ebt_clickable_tile\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ebt_clickable_tile\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"4a6ac85b-3418-4331-8d82-82c365e01b2a\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"sqyvMHG_MfFRoRtp9QsU69-Hqibbf7-n0L6nXXuy-RY\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ebt_clickable_tile\";s:13:\"\0*\0field_name\";s:24:\"field_ebt_clickable_tile\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:21:\"field_ebt_tiles_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:31:\"paragraph.field_ebt_tiles_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"adfc8f4b-838d-40b5-956a-1f813f9dc592\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"__j2dIJmEb5SExuxv7f5bTbyHtFYlG0BqQD9owZgiFA\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:31:\"paragraph.field_ebt_tiles_title\";s:13:\"\0*\0field_name\";s:21:\"field_ebt_tiles_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:20:\"field_ebt_tiles_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:30:\"paragraph.field_ebt_tiles_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"6e677df8-5ee4-417d-be3a-d5036e605903\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"SYBCp04_zUg3tqwrydEEBCSg6JWf7CR4f2Jym-jtu7Y\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:30:\"paragraph.field_ebt_tiles_text\";s:13:\"\0*\0field_name\";s:20:\"field_ebt_tiles_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_ebt_timeline_title\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_ebt_timeline_title\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7b0677d8-0312-4994-b0a6-cd1c0852a050\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"cM8ncQUeGNJamKPS5THMY_gIhCe_qsCwn4s-_6YPaq4\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_ebt_timeline_title\";s:13:\"\0*\0field_name\";s:24:\"field_ebt_timeline_title\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:3:{s:10:\"max_length\";i:512;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:30:\"field_ebt_timeline_media_image\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:40:\"paragraph.field_ebt_timeline_media_image\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"7089f45d-1e3c-4225-bba6-736084040e5b\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"yB2KT5oQDNzQfggkUQGHhoqlikRSVCE8a5MSV_5NvEo\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:40:\"paragraph.field_ebt_timeline_media_image\";s:13:\"\0*\0field_name\";s:30:\"field_ebt_timeline_media_image\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ebt_timeline_date\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_ebt_timeline_date\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"80c677f9-529e-499e-959c-dc9187ab7a49\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"nmy2TG7m2qANlPD4kTWJk7016mawyxdzgYZ3omLSCVc\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_ebt_timeline_date\";s:13:\"\0*\0field_name\";s:23:\"field_ebt_timeline_date\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:26:\"field_ebt_timeline_current\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:36:\"paragraph.field_ebt_timeline_current\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"1043de86-9fe2-4436-8425-6f47521f1f00\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"io0Gxmv8qUwbnmMiTtgXlnMKWybAbO4f6d7W3yHn9vE\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:1:{i:0;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:36:\"paragraph.field_ebt_timeline_current\";s:13:\"\0*\0field_name\";s:26:\"field_ebt_timeline_current\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:23:\"field_ebt_timeline_text\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:33:\"paragraph.field_ebt_timeline_text\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"fe035edd-b535-4ceb-bd54-a3c604fbae92\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"CFCHP9vAPguIB2d677v2iLm245zKg4MRxpfICMcUHo8\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:33:\"paragraph.field_ebt_timeline_text\";s:13:\"\0*\0field_name\";s:23:\"field_ebt_timeline_text\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:24:\"field_video_gallery_item\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:34:\"paragraph.field_video_gallery_item\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"5c6f70cc-17fc-4f18-bcfb-4c0d8a66500e\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"qNGEoWbTX-CnhncjUmfOTlH2eL2GnzBZckwY_yzsHfM\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:5:\"media\";i:1;s:10:\"paragraphs\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:34:\"paragraph.field_video_gallery_item\";s:13:\"\0*\0field_name\";s:24:\"field_video_gallery_item\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0module\";s:4:\"core\";s:11:\"\0*\0settings\";a:1:{s:11:\"target_type\";s:5:\"media\";}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}s:30:\"field_gallery_item_description\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:40:\"paragraph.field_gallery_item_description\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"31c1cb14-3677-44d6-951e-3560a93c8f65\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"jf90xTmsti89Pjc4bIjB0aBV5QshhjB0mhGkqONmGjU\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:2:{i:0;s:10:\"paragraphs\";i:1;s:4:\"text\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:40:\"paragraph.field_gallery_item_description\";s:13:\"\0*\0field_name\";s:30:\"field_gallery_item_description\";s:14:\"\0*\0entity_type\";s:9:\"paragraph\";s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0module\";s:4:\"text\";s:11:\"\0*\0settings\";a:0:{}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:0:{}s:10:\"\0*\0deleted\";b:0;}}'),
('entity.definitions.installed',	'paragraphs_type.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:15:\"paragraphs_type\";s:8:\"\0*\0class\";s:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\";s:11:\"\0*\0provider\";s:10:\"paragraphs\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:39:\"Drupal\\paragraphs\\Entity\\ParagraphsType\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:52:\"Drupal\\paragraphs\\ParagraphsTypeAccessControlHandler\";s:12:\"list_builder\";s:54:\"Drupal\\paragraphs\\Controller\\ParagraphsTypeListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:41:\"Drupal\\paragraphs\\Form\\ParagraphsTypeForm\";s:4:\"edit\";s:41:\"Drupal\\paragraphs\\Form\\ParagraphsTypeForm\";s:6:\"delete\";s:50:\"Drupal\\paragraphs\\Form\\ParagraphsTypeDeleteConfirm\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:27:\"administer paragraphs types\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"edit-form\";s:50:\"/admin/structure/paragraphs_type/{paragraphs_type}\";s:11:\"delete-form\";s:57:\"/admin/structure/paragraphs_type/{paragraphs_type}/delete\";s:10:\"collection\";s:32:\"/admin/structure/paragraphs_type\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:9:\"paragraph\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Paragraphs type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Paragraphs types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Paragraphs type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Paragraphs types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:22:\"@count Paragraphs type\";s:6:\"plural\";s:23:\"@count Paragraphs types\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:27:\"config:paragraphs_type_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:15:\"paragraphs_type\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:15:\"paragraphs_type\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:9:\"icon_uuid\";i:3;s:12:\"icon_default\";i:4;s:11:\"description\";i:5;s:16:\"behavior_plugins\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'pathauto_pattern.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:16:\"pathauto_pattern\";s:8:\"\0*\0class\";s:38:\"Drupal\\pathauto\\Entity\\PathautoPattern\";s:11:\"\0*\0provider\";s:8:\"pathauto\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"weight\";s:6:\"weight\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:38:\"Drupal\\pathauto\\Entity\\PathautoPattern\";s:11:\"\0*\0handlers\";a:5:{s:12:\"list_builder\";s:42:\"Drupal\\pathauto\\PathautoPatternListBuilder\";s:4:\"form\";a:5:{s:7:\"default\";s:36:\"Drupal\\pathauto\\Form\\PatternEditForm\";s:9:\"duplicate\";s:41:\"Drupal\\pathauto\\Form\\PatternDuplicateForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";s:6:\"enable\";s:38:\"Drupal\\pathauto\\Form\\PatternEnableForm\";s:7:\"disable\";s:39:\"Drupal\\pathauto\\Form\\PatternDisableForm\";}s:14:\"route_provider\";a:1:{s:4:\"html\";s:51:\"Drupal\\Core\\Entity\\Routing\\DefaultHtmlRouteProvider\";}s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:19:\"administer pathauto\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:6:{s:10:\"collection\";s:34:\"/admin/config/search/path/patterns\";s:9:\"edit-form\";s:53:\"/admin/config/search/path/patterns/{pathauto_pattern}\";s:11:\"delete-form\";s:60:\"/admin/config/search/path/patterns/{pathauto_pattern}/delete\";s:6:\"enable\";s:60:\"/admin/config/search/path/patterns/{pathauto_pattern}/enable\";s:7:\"disable\";s:61:\"/admin/config/search/path/patterns/{pathauto_pattern}/disable\";s:14:\"duplicate-form\";s:63:\"/admin/config/search/path/patterns/{pathauto_pattern}/duplicate\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Pathauto pattern\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:28:\"config:pathauto_pattern_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:16:\"pathauto_pattern\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:7:\"pattern\";s:14:\"\0*\0lookup_keys\";a:3:{i:0;s:4:\"type\";i:1;s:6:\"status\";i:2;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:4:\"type\";i:3;s:7:\"pattern\";i:4;s:18:\"selection_criteria\";i:5;s:15:\"selection_logic\";i:6;s:6:\"weight\";i:7;s:13:\"relationships\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'path_alias.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:10:\"path_alias\";s:8:\"\0*\0class\";s:34:\"Drupal\\path_alias\\Entity\\PathAlias\";s:11:\"\0*\0provider\";s:10:\"path_alias\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:8:\"revision\";s:11:\"revision_id\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:34:\"Drupal\\path_alias\\Entity\\PathAlias\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:34:\"Drupal\\path_alias\\PathAliasStorage\";s:14:\"storage_schema\";s:40:\"Drupal\\path_alias\\PathAliasStorageSchema\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";s:22:\"administer url aliases\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:10:\"path_alias\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";s:19:\"path_alias_revision\";s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:16:\"@count URL alias\";s:6:\"plural\";s:18:\"@count URL aliases\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:11:\"route_match\";}s:14:\"\0*\0constraints\";a:2:{s:15:\"UniquePathAlias\";a:0:{}s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'path_alias.field_storage_definitions',	'a:8:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:36;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:69;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:3:\"und\";}}s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:103;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"path\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"System path\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"The path that this alias belongs to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:4:\"path\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:9:\"ValidPath\";a:0:{}s:5:\"Regex\";a:2:{s:7:\"pattern\";s:6:\"/^\\//i\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"The source path has to start with a slash.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}}s:18:\"\0*\0fieldDefinition\";r:141;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"alias\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"URL alias\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"An alias used with this path.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:5:\"alias\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:5:\"Regex\";a:2:{s:7:\"pattern\";s:6:\"/^\\//i\";s:7:\"message\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"The alias path has to start with a slash.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}}}}s:18:\"\0*\0fieldDefinition\";r:187;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:0;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:232;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:10:\"path_alias\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:10:\"path_alias\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:271;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),
('entity.definitions.installed',	'redirect.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:8:\"redirect\";s:8:\"\0*\0class\";s:31:\"Drupal\\redirect\\Entity\\Redirect\";s:11:\"\0*\0provider\";s:8:\"redirect\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:3:\"rid\";s:5:\"label\";s:15:\"redirect_source\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:4:\"type\";s:8:\"langcode\";s:8:\"language\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\redirect\\Entity\\Redirect\";s:11:\"\0*\0handlers\";a:7:{s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:4:\"form\";a:4:{s:7:\"default\";s:33:\"Drupal\\redirect\\Form\\RedirectForm\";s:6:\"delete\";s:39:\"Drupal\\redirect\\Form\\RedirectDeleteForm\";s:4:\"edit\";s:33:\"Drupal\\redirect\\Form\\RedirectForm\";s:14:\"layout_builder\";s:46:\"Drupal\\layout_builder\\Form\\OverridesEntityForm\";}s:10:\"views_data\";s:33:\"Drupal\\redirect\\RedirectViewsData\";s:14:\"storage_schema\";s:38:\"\\Drupal\\redirect\\RedirectStorageSchema\";s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";s:20:\"administer redirects\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"canonical\";s:45:\"/admin/config/search/redirect/edit/{redirect}\";s:11:\"delete-form\";s:47:\"/admin/config/search/redirect/delete/{redirect}\";s:9:\"edit-form\";s:45:\"/admin/config/search/redirect/edit/{redirect}\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Redirect type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:8:\"redirect\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Redirect\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";s:0:\"\";s:17:\"\0*\0label_singular\";s:0:\"\";s:15:\"\0*\0label_plural\";s:0:\"\";s:14:\"\0*\0label_count\";a:0:{}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:13:\"redirect_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:1:{s:10:\"token_type\";s:8:\"redirect\";}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'redirect.field_storage_definitions',	'a:10:{s:3:\"rid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Redirect ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"The redirect ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:3:\"rid\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"The record UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"hash\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Hash\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"The redirect hash.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:4:\"hash\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:64;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:64;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"The redirect type.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:4:\"type\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:111;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:31:\"The user ID of the node author.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:22:\"default_value_callback\";s:50:\"\\Drupal\\redirect\\Entity\\Redirect::getCurrentUserId\";s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:145;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:15:\"redirect_source\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"From\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:152:\"Enter an internal Drupal path or path alias to redirect (e.g. %example1 or %example2). Fragment anchors (e.g. %anchor) are <strong>not</strong> allowed.\";s:12:\"\0*\0arguments\";a:3:{s:9:\"%example1\";s:8:\"node/123\";s:9:\"%example2\";s:17:\"taxonomy/term/123\";s:7:\"%anchor\";s:7:\"#anchor\";}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:13:\"redirect_link\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:15:\"redirect_source\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:26:\"field_item:redirect_source\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:182;}s:7:\"\0*\0type\";s:15:\"redirect_source\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:2:{s:4:\"path\";a:3:{s:11:\"description\";s:15:\"The source path\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"query\";a:4:{s:11:\"description\";s:32:\"Serialized array of path queries\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:4:\"path\";a:1:{i:0;a:2:{i:0;s:4:\"path\";i:1;i:50;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:17:\"redirect_redirect\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"To\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:0;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:4:\"link\";s:6:\"weight\";i:-4;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:17:\"redirect_redirect\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:link\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:17;}}s:18:\"\0*\0fieldDefinition\";r:233;}s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:3:{s:3:\"uri\";a:3:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"title\";a:3:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;}s:7:\"options\";a:4:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:3:\"uri\";a:1:{i:0;a:2:{i:0;s:3:\"uri\";i:1;i:30;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"language\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"The redirect language.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:8:\"language\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:283;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"status_code\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Status code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The redirect status code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:11:\"status_code\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:318;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The date when the redirect was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"redirect\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:8:\"redirect\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:358;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),
('entity.definitions.installed',	'search_page.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:11:\"search_page\";s:8:\"\0*\0class\";s:31:\"Drupal\\search\\Entity\\SearchPage\";s:11:\"\0*\0provider\";s:6:\"search\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:10:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"weight\";s:6:\"weight\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\search\\Entity\\SearchPage\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:44:\"Drupal\\search\\SearchPageAccessControlHandler\";s:12:\"list_builder\";s:35:\"Drupal\\search\\SearchPageListBuilder\";s:4:\"form\";a:3:{s:3:\"add\";s:36:\"Drupal\\search\\Form\\SearchPageAddForm\";s:4:\"edit\";s:37:\"Drupal\\search\\Form\\SearchPageEditForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:17:\"administer search\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:6:{s:9:\"edit-form\";s:47:\"/admin/config/search/pages/manage/{search_page}\";s:11:\"delete-form\";s:54:\"/admin/config/search/pages/manage/{search_page}/delete\";s:6:\"enable\";s:54:\"/admin/config/search/pages/manage/{search_page}/enable\";s:7:\"disable\";s:55:\"/admin/config/search/pages/manage/{search_page}/disable\";s:11:\"set-default\";s:59:\"/admin/config/search/pages/manage/{search_page}/set-default\";s:10:\"collection\";s:26:\"/admin/config/search/pages\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Search page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Search pages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"search page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"search pages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:18:\"@count search page\";s:6:\"plural\";s:19:\"@count search pages\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:23:\"config:search_page_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"page\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:4:\"path\";i:3;s:6:\"weight\";i:4;s:6:\"plugin\";i:5;s:13:\"configuration\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'shortcut.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:8:\"shortcut\";s:8:\"\0*\0class\";s:31:\"Drupal\\shortcut\\Entity\\Shortcut\";s:11:\"\0*\0provider\";s:8:\"shortcut\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:4:\"uuid\";s:4:\"uuid\";s:6:\"bundle\";s:12:\"shortcut_set\";s:5:\"label\";s:5:\"title\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:31:\"Drupal\\shortcut\\Entity\\Shortcut\";s:11:\"\0*\0handlers\";a:4:{s:6:\"access\";s:44:\"Drupal\\shortcut\\ShortcutAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:3:\"add\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:4:\"edit\";s:28:\"Drupal\\shortcut\\ShortcutForm\";s:6:\"delete\";s:39:\"Drupal\\shortcut\\Form\\ShortcutDeleteForm\";}s:7:\"storage\";s:46:\"Drupal\\Core\\Entity\\Sql\\SqlContentEntityStorage\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:3:{s:9:\"canonical\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:11:\"delete-form\";s:60:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete\";s:9:\"edit-form\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";}s:21:\"\0*\0bundle_entity_type\";s:12:\"shortcut_set\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:8:\"shortcut\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";s:19:\"shortcut_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Shortcut link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Shortcut links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"shortcut link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"shortcut links\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count shortcut link\";s:6:\"plural\";s:21:\"@count shortcut links\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:shortcut_set_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'shortcut.field_storage_definitions',	'a:8:{s:2:\"id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The ID of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:2:\"id\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The UUID of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"The language code of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"shortcut_set\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"The bundle of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:12:\"shortcut_set\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:12:\"shortcut_set\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:116;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"title\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The name of the shortcut.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:12:\"translatable\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-10;s:8:\"settings\";a:1:{s:4:\"size\";i:40;}}}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:5:\"title\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:154;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Weight among shortcuts in the same shortcut set.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:197;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"link\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Path\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"The location this shortcut points to.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:12:\"link_default\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:4:\"link\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:link\";s:8:\"settings\";a:2:{s:5:\"title\";i:0;s:9:\"link_type\";i:1;}}s:18:\"\0*\0fieldDefinition\";r:234;}s:7:\"\0*\0type\";s:4:\"link\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:3:{s:3:\"uri\";a:3:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;}s:5:\"title\";a:3:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;}s:7:\"options\";a:4:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;}}s:7:\"indexes\";a:1:{s:3:\"uri\";a:1:{i:0;a:2:{i:0;s:3:\"uri\";i:1;i:30;}}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:8:\"shortcut\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:8:\"shortcut\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:287;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),
('entity.definitions.installed',	'shortcut_set.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:12:\"shortcut_set\";s:8:\"\0*\0class\";s:34:\"Drupal\\shortcut\\Entity\\ShortcutSet\";s:11:\"\0*\0provider\";s:8:\"shortcut\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:34:\"Drupal\\shortcut\\Entity\\ShortcutSet\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:34:\"Drupal\\shortcut\\ShortcutSetStorage\";s:6:\"access\";s:47:\"Drupal\\shortcut\\ShortcutSetAccessControlHandler\";s:12:\"list_builder\";s:38:\"Drupal\\shortcut\\ShortcutSetListBuilder\";s:4:\"form\";a:5:{s:7:\"default\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:3:\"add\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:4:\"edit\";s:31:\"Drupal\\shortcut\\ShortcutSetForm\";s:9:\"customize\";s:33:\"Drupal\\shortcut\\Form\\SetCustomize\";s:6:\"delete\";s:42:\"Drupal\\shortcut\\Form\\ShortcutSetDeleteForm\";}}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:14:\"customize-form\";s:69:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize\";s:11:\"delete-form\";s:66:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete\";s:9:\"edit-form\";s:59:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}\";s:10:\"collection\";s:37:\"/admin/config/user-interface/shortcut\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:8:\"shortcut\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Shortcut sets\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"shortcut set\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"shortcut sets\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:19:\"@count shortcut set\";s:6:\"plural\";s:20:\"@count shortcut sets\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:24:\"config:shortcut_set_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:3:\"set\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:2:{i:0;s:2:\"id\";i:1;s:5:\"label\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'taxonomy_term.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:13:\"taxonomy_term\";s:8:\"\0*\0class\";s:27:\"Drupal\\taxonomy\\Entity\\Term\";s:11:\"\0*\0provider\";s:8:\"taxonomy\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"tid\";s:8:\"revision\";s:11:\"revision_id\";s:6:\"bundle\";s:3:\"vid\";s:5:\"label\";s:4:\"name\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:9:\"published\";s:6:\"status\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:27:\"Drupal\\taxonomy\\Entity\\Term\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:27:\"Drupal\\taxonomy\\TermStorage\";s:14:\"storage_schema\";s:33:\"Drupal\\taxonomy\\TermStorageSchema\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";s:12:\"list_builder\";s:36:\"Drupal\\Core\\Entity\\EntityListBuilder\";s:6:\"access\";s:40:\"Drupal\\taxonomy\\TermAccessControlHandler\";s:10:\"views_data\";s:29:\"Drupal\\taxonomy\\TermViewsData\";s:4:\"form\";a:4:{s:7:\"default\";s:24:\"Drupal\\taxonomy\\TermForm\";s:6:\"delete\";s:35:\"Drupal\\taxonomy\\Form\\TermDeleteForm\";s:15:\"revision-delete\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionDeleteForm\";s:15:\"revision-revert\";s:42:\"Drupal\\Core\\Entity\\Form\\RevisionRevertForm\";}s:14:\"route_provider\";a:1:{s:8:\"revision\";s:52:\"Drupal\\Core\\Entity\\Routing\\RevisionHtmlRouteProvider\";}s:11:\"translation\";s:38:\"Drupal\\taxonomy\\TermTranslationHandler\";}s:19:\"\0*\0admin_permission\";N;s:24:\"\0*\0collection_permission\";s:24:\"access taxonomy overview\";s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:8:{s:9:\"canonical\";s:30:\"/taxonomy/term/{taxonomy_term}\";s:11:\"delete-form\";s:37:\"/taxonomy/term/{taxonomy_term}/delete\";s:9:\"edit-form\";s:35:\"/taxonomy/term/{taxonomy_term}/edit\";s:6:\"create\";s:14:\"/taxonomy/term\";s:8:\"revision\";s:69:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view\";s:20:\"revision-delete-form\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete\";s:20:\"revision-revert-form\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert\";s:15:\"version-history\";s:40:\"/taxonomy/term/{taxonomy_term}/revisions\";}s:21:\"\0*\0bundle_entity_type\";s:19:\"taxonomy_vocabulary\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:18:\"taxonomy_term_data\";s:22:\"\0*\0revision_data_table\";s:28:\"taxonomy_term_field_revision\";s:17:\"\0*\0revision_table\";s:22:\"taxonomy_term_revision\";s:13:\"\0*\0data_table\";s:24:\"taxonomy_term_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:1;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Taxonomy term\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Taxonomy terms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"taxonomy term\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"taxonomy terms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:20:\"@count taxonomy term\";s:6:\"plural\";s:21:\"@count taxonomy terms\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:40:\"entity.taxonomy_vocabulary.overview_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:18:\"taxonomy_term_list\";}s:14:\"\0*\0constraints\";a:3:{s:17:\"TaxonomyHierarchy\";a:0:{}s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:4:{s:13:\"revision_user\";s:13:\"revision_user\";s:16:\"revision_created\";s:16:\"revision_created\";s:20:\"revision_log_message\";s:20:\"revision_log_message\";s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'taxonomy_term.field_storage_definitions',	'a:17:{s:3:\"tid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Term ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The term ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:3:\"tid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The term UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"revision_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Revision ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:11:\"revision_id\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:2:{s:4:\"type\";s:15:\"language_select\";s:6:\"weight\";i:2;}}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The term language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:111;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"vid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"The vocabulary to which the term is assigned.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:3:\"vid\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:19:\"taxonomy_vocabulary\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:151;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision create time\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"The time that the current revision was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"revision_created\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:189;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:13:\"revision_user\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Revision user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"The user ID of the author of the current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:13:\"revision_user\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:219;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:20:\"revision_log_message\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Revision log message\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Briefly describe the changes you have made.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:7:\"display\";a:1:{s:4:\"form\";a:1:{s:7:\"options\";a:3:{s:4:\"type\";s:15:\"string_textarea\";s:6:\"weight\";i:25;s:8:\"settings\";a:1:{s:4:\"rows\";i:4;}}}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:20:\"revision_log_message\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:256;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Published\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:7:\"display\";a:1:{s:4:\"form\";a:2:{s:7:\"options\";a:3:{s:4:\"type\";s:16:\"boolean_checkbox\";s:8:\"settings\";a:1:{s:13:\"display_label\";b:1;}s:6:\"weight\";i:100;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:5:\"class\";s:22:\"Drupal\\user\\StatusItem\";}s:18:\"\0*\0fieldDefinition\";r:298;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"required\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:6:\"string\";s:6:\"weight\";i:-5;}}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:16:\"string_textfield\";s:6:\"weight\";i:-5;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:346;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"description\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Description\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:7:\"display\";a:2:{s:4:\"view\";a:2:{s:7:\"options\";a:3:{s:5:\"label\";s:6:\"hidden\";s:4:\"type\";s:12:\"text_default\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}s:4:\"form\";a:2:{s:7:\"options\";a:2:{s:4:\"type\";s:14:\"text_textfield\";s:6:\"weight\";i:0;}s:12:\"configurable\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:11:\"description\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:text_long\";s:8:\"settings\";a:1:{s:15:\"allowed_formats\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:390;}s:7:\"\0*\0type\";s:9:\"text_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:2:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}s:6:\"format\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;}}s:7:\"indexes\";a:1:{s:6:\"format\";a:1:{i:0;s:6:\"format\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"weight\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Weight\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"The weight of this term in relation to other terms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"weight\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:436;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"parent\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Term Parents\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"The parents of this term.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"cardinality\";i:-1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:6:\"parent\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:13:\"taxonomy_term\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:476;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the term was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:512;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:543;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"revision_default\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:11:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Default revision\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"A flag indicating whether this was a default revision when it was saved.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:16:\"storage_required\";b:1;s:8:\"internal\";b:1;s:12:\"translatable\";b:0;s:12:\"revisionable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:16:\"revision_default\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:586;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:29:\"revision_translation_affected\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Revision translation affected\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"Indicates if the last edit of a translation belongs to current revision.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:12:\"revisionable\";b:1;s:12:\"translatable\";b:1;s:8:\"provider\";s:8:\"taxonomy\";s:10:\"field_name\";s:29:\"revision_translation_affected\";s:11:\"entity_type\";s:13:\"taxonomy_term\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:628;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),
('entity.definitions.installed',	'taxonomy_vocabulary.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:19:\"taxonomy_vocabulary\";s:8:\"\0*\0class\";s:33:\"Drupal\\taxonomy\\Entity\\Vocabulary\";s:11:\"\0*\0provider\";s:8:\"taxonomy\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:3:\"vid\";s:5:\"label\";s:4:\"name\";s:6:\"weight\";s:6:\"weight\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:33:\"Drupal\\taxonomy\\Entity\\Vocabulary\";s:11:\"\0*\0handlers\";a:5:{s:7:\"storage\";s:33:\"Drupal\\taxonomy\\VocabularyStorage\";s:12:\"list_builder\";s:37:\"Drupal\\taxonomy\\VocabularyListBuilder\";s:6:\"access\";s:46:\"Drupal\\taxonomy\\VocabularyAccessControlHandler\";s:4:\"form\";a:4:{s:7:\"default\";s:30:\"Drupal\\taxonomy\\VocabularyForm\";s:5:\"reset\";s:40:\"Drupal\\taxonomy\\Form\\VocabularyResetForm\";s:6:\"delete\";s:41:\"Drupal\\taxonomy\\Form\\VocabularyDeleteForm\";s:8:\"overview\";s:34:\"Drupal\\taxonomy\\Form\\OverviewTerms\";}s:14:\"route_provider\";a:2:{s:4:\"html\";s:54:\"Drupal\\taxonomy\\Entity\\Routing\\VocabularyRouteProvider\";s:11:\"permissions\";s:49:\"Drupal\\user\\Entity\\EntityPermissionsRouteProvider\";}}s:19:\"\0*\0admin_permission\";s:19:\"administer taxonomy\";s:24:\"\0*\0collection_permission\";s:24:\"access taxonomy overview\";s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:7:{s:8:\"add-form\";s:29:\"/admin/structure/taxonomy/add\";s:11:\"delete-form\";s:61:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete\";s:10:\"reset-form\";s:60:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset\";s:13:\"overview-form\";s:63:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview\";s:9:\"edit-form\";s:54:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}\";s:23:\"entity-permissions-form\";s:75:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions\";s:10:\"collection\";s:25:\"/admin/structure/taxonomy\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:13:\"taxonomy_term\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Taxonomy vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Taxonomy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"vocabularies\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count vocabulary\";s:6:\"plural\";s:19:\"@count vocabularies\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:31:\"config:taxonomy_vocabulary_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:10:\"vocabulary\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:4:\"name\";i:1;s:3:\"vid\";i:2;s:11:\"description\";i:3;s:6:\"weight\";i:4;s:12:\"new_revision\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'user.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:4:\"user\";s:8:\"\0*\0class\";s:23:\"Drupal\\user\\Entity\\User\";s:11:\"\0*\0provider\";s:4:\"user\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:3:\"uid\";s:8:\"langcode\";s:8:\"langcode\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\user\\Entity\\User\";s:11:\"\0*\0handlers\";a:9:{s:7:\"storage\";s:23:\"Drupal\\user\\UserStorage\";s:14:\"storage_schema\";s:29:\"Drupal\\user\\UserStorageSchema\";s:6:\"access\";s:36:\"Drupal\\user\\UserAccessControlHandler\";s:12:\"list_builder\";s:27:\"Drupal\\user\\UserListBuilder\";s:10:\"views_data\";s:25:\"Drupal\\user\\UserViewsData\";s:14:\"route_provider\";a:1:{s:4:\"html\";s:36:\"Drupal\\user\\Entity\\UserRouteProvider\";}s:4:\"form\";a:3:{s:7:\"default\";s:23:\"Drupal\\user\\ProfileForm\";s:6:\"cancel\";s:31:\"Drupal\\user\\Form\\UserCancelForm\";s:8:\"register\";s:24:\"Drupal\\user\\RegisterForm\";}s:11:\"translation\";s:37:\"Drupal\\user\\ProfileTranslationHandler\";s:12:\"view_builder\";s:36:\"Drupal\\Core\\Entity\\EntityViewBuilder\";}s:19:\"\0*\0admin_permission\";s:16:\"administer users\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:9:\"canonical\";s:12:\"/user/{user}\";s:9:\"edit-form\";s:17:\"/user/{user}/edit\";s:11:\"cancel-form\";s:19:\"/user/{user}/cancel\";s:10:\"collection\";s:13:\"/admin/people\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";s:5:\"users\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";s:16:\"users_field_data\";s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:1;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"User\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Users\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"users\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count user\";s:6:\"plural\";s:12:\"@count users\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";s:22:\"entity.user.admin_form\";s:26:\"\0*\0common_reference_target\";b:1;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:9:\"user_list\";}s:14:\"\0*\0constraints\";a:2:{s:13:\"EntityChanged\";N;s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'user.field_storage_definitions',	'a:18:{s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"User ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"The user ID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"The user UUID.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:7:\"display\";a:2:{s:4:\"view\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}s:4:\"form\";a:1:{s:7:\"options\";a:1:{s:6:\"region\";s:6:\"hidden\";}}}s:12:\"translatable\";b:1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The user language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:77;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:18:\"preferred_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Preferred language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"The user\'s preferred language code for receiving emails and viewing the site.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:18:\"preferred_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:60:\"Drupal\\user\\Entity\\User::getAllowedConfigurableLanguageCodes\";}s:6:\"Length\";a:1:{s:3:\"max\";i:12;}}}}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:24:\"preferred_admin_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Preferred admin language code\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:68:\"The user\'s preferred language code for viewing administration pages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";N;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:24:\"preferred_admin_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:2:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:60:\"Drupal\\user\\Entity\\User::getAllowedConfigurableLanguageCodes\";}s:6:\"Length\";a:1:{s:3:\"max\";i:12;}}}}}s:18:\"\0*\0fieldDefinition\";r:152;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"name\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Name\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"The name of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"required\";b:1;s:11:\"constraints\";a:2:{s:8:\"UserName\";a:0:{}s:14:\"UserNameUnique\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"name\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:5:\"class\";s:25:\"\\Drupal\\user\\UserNameItem\";}s:18:\"\0*\0fieldDefinition\";r:192;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"pass\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Password\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The password of this user (hashed).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"constraints\";a:1:{s:18:\"ProtectedUserField\";N;}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"pass\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:password\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:231;}s:7:\"\0*\0type\";s:8:\"password\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"mail\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:9:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The email of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:11:\"constraints\";a:3:{s:14:\"UserMailUnique\";N;s:16:\"UserMailRequired\";N;s:18:\"ProtectedUserField\";N;}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"mail\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:267;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"timezone\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Timezone\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"The timezone of this user.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:8:\"timezone\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:4:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}s:11:\"constraints\";a:1:{s:11:\"ComplexData\";a:1:{s:5:\"value\";a:1:{s:13:\"AllowedValues\";a:1:{s:8:\"callback\";s:44:\"Drupal\\user\\Entity\\User::getAllowedTimezones\";}}}}s:5:\"class\";s:24:\"Drupal\\user\\TimeZoneItem\";}s:18:\"\0*\0fieldDefinition\";r:304;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"status\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"User status\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"Whether the user is active or blocked.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:6:\"status\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:3:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}s:5:\"class\";s:22:\"Drupal\\user\\StatusItem\";}s:18:\"\0*\0fieldDefinition\";r:344;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"The time that the user was created.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:386;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The time that the user was last edited.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:415;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"access\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Last access\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:46:\"The time that the user last accessed the site.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:6:\"access\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:timestamp\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:445;}s:7:\"\0*\0type\";s:9:\"timestamp\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"login\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Last login\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"The time that the user last logged in.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";i:0;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:5:\"login\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:timestamp\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:477;}s:7:\"\0*\0type\";s:9:\"timestamp\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"init\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Initial email\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The email address used for initial account creation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:4:\"init\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:16:\"field_item:email\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:509;}s:7:\"\0*\0type\";s:5:\"email\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"roles\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"cardinality\";i:-1;s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The roles the user has.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:5:\"roles\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:9:\"user_role\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:542;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:16:\"default_langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:10:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Default translation\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag indicating whether this is the default translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:12:\"translatable\";b:1;s:12:\"revisionable\";b:1;s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:1;}}s:8:\"provider\";s:4:\"user\";s:10:\"field_name\";s:16:\"default_langcode\";s:11:\"entity_type\";s:4:\"user\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:578;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"user_picture\";O:38:\"Drupal\\field\\Entity\\FieldStorageConfig\":30:{s:15:\"\0*\0entityTypeId\";s:20:\"field_storage_config\";s:15:\"\0*\0enforceIsNew\";b:1;s:12:\"\0*\0typedData\";N;s:16:\"\0*\0cacheContexts\";a:0:{}s:12:\"\0*\0cacheTags\";a:0:{}s:14:\"\0*\0cacheMaxAge\";i:-1;s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:13:\"\0*\0originalId\";s:17:\"user.user_picture\";s:9:\"\0*\0status\";b:1;s:7:\"\0*\0uuid\";s:36:\"13a3c6c5-6417-4477-8a58-0b066b2141c3\";s:11:\"\0*\0langcode\";s:2:\"en\";s:23:\"\0*\0third_party_settings\";a:0:{}s:8:\"\0*\0_core\";a:1:{s:19:\"default_config_hash\";s:43:\"0q8-mw8y-Ls5I578sIPQFLp4ljpH7WvVYpzY-I9O-8E\";}s:14:\"\0*\0trustedData\";b:1;s:15:\"\0*\0dependencies\";a:1:{s:6:\"module\";a:3:{i:0;s:4:\"file\";i:1;s:5:\"image\";i:2;s:4:\"user\";}}s:12:\"\0*\0isSyncing\";b:0;s:5:\"\0*\0id\";s:17:\"user.user_picture\";s:13:\"\0*\0field_name\";s:12:\"user_picture\";s:14:\"\0*\0entity_type\";s:4:\"user\";s:7:\"\0*\0type\";s:5:\"image\";s:9:\"\0*\0module\";s:5:\"image\";s:11:\"\0*\0settings\";a:5:{s:11:\"target_type\";s:4:\"file\";s:13:\"display_field\";b:0;s:15:\"display_default\";b:0;s:10:\"uri_scheme\";s:6:\"public\";s:13:\"default_image\";a:5:{s:4:\"uuid\";N;s:3:\"alt\";s:0:\"\";s:5:\"title\";s:0:\"\";s:5:\"width\";N;s:6:\"height\";N;}}s:14:\"\0*\0cardinality\";i:1;s:15:\"\0*\0translatable\";b:1;s:9:\"\0*\0locked\";b:0;s:25:\"\0*\0persist_with_no_fields\";b:0;s:14:\"custom_storage\";b:0;s:10:\"\0*\0indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:10:\"\0*\0deleted\";b:0;}}'),
('entity.definitions.installed',	'user_role.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:9:\"user_role\";s:8:\"\0*\0class\";s:23:\"Drupal\\user\\Entity\\Role\";s:11:\"\0*\0provider\";s:4:\"user\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:6:\"weight\";s:6:\"weight\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:23:\"Drupal\\user\\Entity\\Role\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:23:\"Drupal\\user\\RoleStorage\";s:6:\"access\";s:36:\"Drupal\\user\\RoleAccessControlHandler\";s:12:\"list_builder\";s:27:\"Drupal\\user\\RoleListBuilder\";s:4:\"form\";a:2:{s:7:\"default\";s:20:\"Drupal\\user\\RoleForm\";s:6:\"delete\";s:35:\"Drupal\\Core\\Entity\\EntityDeleteForm\";}}s:19:\"\0*\0admin_permission\";s:22:\"administer permissions\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:4:{s:11:\"delete-form\";s:45:\"/admin/people/roles/manage/{user_role}/delete\";s:9:\"edit-form\";s:38:\"/admin/people/roles/manage/{user_role}\";s:21:\"edit-permissions-form\";s:37:\"/admin/people/permissions/{user_role}\";s:10:\"collection\";s:19:\"/admin/people/roles\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Role\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"role\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count role\";s:6:\"plural\";s:12:\"@count roles\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:21:\"config:user_role_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";s:4:\"role\";s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:5:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"weight\";i:3;s:8:\"is_admin\";i:4;s:11:\"permissions\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'view.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:4:\"view\";s:8:\"\0*\0class\";s:24:\"Drupal\\views\\Entity\\View\";s:11:\"\0*\0provider\";s:5:\"views\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:9:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:6:\"status\";s:6:\"status\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:24:\"Drupal\\views\\Entity\\View\";s:11:\"\0*\0handlers\";a:2:{s:6:\"access\";s:45:\"Drupal\\Core\\Entity\\EntityAccessControlHandler\";s:7:\"storage\";s:45:\"Drupal\\Core\\Config\\Entity\\ConfigEntityStorage\";}s:19:\"\0*\0admin_permission\";s:16:\"administer views\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:0:{}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"View\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"view\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:16:\"View entity type\";}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:11:\"@count view\";s:6:\"plural\";s:12:\"@count views\";s:7:\"context\";s:16:\"View entity type\";}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:16:\"config:view_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:8:{i:0;s:2:\"id\";i:1;s:5:\"label\";i:2;s:6:\"module\";i:3;s:11:\"description\";i:4;s:3:\"tag\";i:5;s:10:\"base_table\";i:6;s:10:\"base_field\";i:7;s:7:\"display\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'webform.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:7:\"webform\";s:8:\"\0*\0class\";s:29:\"Drupal\\webform\\Entity\\Webform\";s:11:\"\0*\0provider\";s:7:\"webform\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"title\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:29:\"Drupal\\webform\\Entity\\Webform\";s:11:\"\0*\0handlers\";a:5:{s:7:\"storage\";s:36:\"\\Drupal\\webform\\WebformEntityStorage\";s:12:\"view_builder\";s:39:\"Drupal\\webform\\WebformEntityViewBuilder\";s:12:\"list_builder\";s:39:\"Drupal\\webform\\WebformEntityListBuilder\";s:6:\"access\";s:48:\"Drupal\\webform\\WebformEntityAccessControlHandler\";s:4:\"form\";a:14:{s:3:\"add\";s:35:\"Drupal\\webform\\WebformEntityAddForm\";s:9:\"duplicate\";s:35:\"Drupal\\webform\\WebformEntityAddForm\";s:6:\"delete\";s:38:\"Drupal\\webform\\WebformEntityDeleteForm\";s:23:\"delete-multiple-confirm\";s:51:\"Drupal\\webform\\Form\\WebformEntityDeleteMultipleForm\";s:4:\"edit\";s:40:\"Drupal\\webform\\WebformEntityElementsForm\";s:6:\"export\";s:38:\"Drupal\\webform\\WebformEntityExportForm\";s:8:\"settings\";s:62:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsGeneralForm\";s:13:\"settings_form\";s:59:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsFormForm\";s:20:\"settings_submissions\";s:66:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsSubmissionsForm\";s:21:\"settings_confirmation\";s:67:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsConfirmationForm\";s:15:\"settings_assets\";s:61:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsAssetsForm\";s:15:\"settings_access\";s:61:\"Drupal\\webform\\EntitySettings\\WebformEntitySettingsAccessForm\";s:8:\"handlers\";s:40:\"Drupal\\webform\\WebformEntityHandlersForm\";s:8:\"variants\";s:40:\"Drupal\\webform\\WebformEntityVariantsForm\";}}s:19:\"\0*\0admin_permission\";s:18:\"administer webform\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:23:{s:9:\"canonical\";s:18:\"/webform/{webform}\";s:13:\"access-denied\";s:32:\"/webform/{webform}/access-denied\";s:11:\"submissions\";s:30:\"/webform/{webform}/submissions\";s:8:\"add-form\";s:18:\"/webform/{webform}\";s:9:\"edit-form\";s:50:\"/admin/structure/webform/manage/{webform}/elements\";s:9:\"test-form\";s:23:\"/webform/{webform}/test\";s:14:\"duplicate-form\";s:51:\"/admin/structure/webform/manage/{webform}/duplicate\";s:11:\"delete-form\";s:48:\"/admin/structure/webform/manage/{webform}/delete\";s:20:\"delete-multiple-form\";s:31:\"/admin/structure/webform/delete\";s:11:\"export-form\";s:48:\"/admin/structure/webform/manage/{webform}/export\";s:8:\"settings\";s:50:\"/admin/structure/webform/manage/{webform}/settings\";s:13:\"settings-form\";s:55:\"/admin/structure/webform/manage/{webform}/settings/form\";s:20:\"settings-submissions\";s:62:\"/admin/structure/webform/manage/{webform}/settings/submissions\";s:21:\"settings-confirmation\";s:63:\"/admin/structure/webform/manage/{webform}/settings/confirmation\";s:15:\"settings-assets\";s:57:\"/admin/structure/webform/manage/{webform}/settings/assets\";s:15:\"settings-access\";s:57:\"/admin/structure/webform/manage/{webform}/settings/access\";s:8:\"handlers\";s:50:\"/admin/structure/webform/manage/{webform}/handlers\";s:8:\"variants\";s:50:\"/admin/structure/webform/manage/{webform}/variants\";s:19:\"results-submissions\";s:61:\"/admin/structure/webform/manage/{webform}/results/submissions\";s:14:\"results-export\";s:58:\"/admin/structure/webform/manage/{webform}/results/download\";s:11:\"results-log\";s:53:\"/admin/structure/webform/manage/{webform}/results/log\";s:13:\"results-clear\";s:55:\"/admin/structure/webform/manage/{webform}/results/clear\";s:10:\"collection\";s:24:\"/admin/structure/webform\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";s:18:\"webform_submission\";s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Webforms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"webforms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:14:\"@count webform\";s:6:\"plural\";s:15:\"@count webforms\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:19:\"config:webform_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:3:{i:0;s:6:\"status\";i:1;s:8:\"template\";i:2;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:20:{i:0;s:6:\"status\";i:1;s:4:\"open\";i:2;s:5:\"close\";i:3;s:6:\"weight\";i:4;s:3:\"uid\";i:5;s:8:\"template\";i:6;s:7:\"archive\";i:7;s:2:\"id\";i:8;s:4:\"uuid\";i:9;s:5:\"title\";i:10;s:11:\"description\";i:11;s:10:\"categories\";i:12;s:8:\"elements\";i:13;s:3:\"css\";i:14;s:10:\"javascript\";i:15;s:8:\"settings\";i:16;s:6:\"access\";i:17;s:8:\"handlers\";i:18;s:8:\"variants\";i:19;s:20:\"third_party_settings\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'webform_options.entity_type',	'O:42:\"Drupal\\Core\\Config\\Entity\\ConfigEntityType\":44:{s:5:\"\0*\0id\";s:15:\"webform_options\";s:8:\"\0*\0class\";s:36:\"Drupal\\webform\\Entity\\WebformOptions\";s:11:\"\0*\0provider\";s:7:\"webform\";s:15:\"\0*\0static_cache\";b:0;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:8:{s:2:\"id\";s:2:\"id\";s:5:\"label\";s:5:\"label\";s:8:\"revision\";s:0:\"\";s:6:\"bundle\";s:0:\"\";s:8:\"langcode\";s:8:\"langcode\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";s:4:\"uuid\";s:4:\"uuid\";}s:16:\"\0*\0originalClass\";s:36:\"Drupal\\webform\\Entity\\WebformOptions\";s:11:\"\0*\0handlers\";a:4:{s:7:\"storage\";s:37:\"\\Drupal\\webform\\WebformOptionsStorage\";s:6:\"access\";s:49:\"Drupal\\webform\\WebformOptionsAccessControlHandler\";s:12:\"list_builder\";s:40:\"Drupal\\webform\\WebformOptionsListBuilder\";s:4:\"form\";a:4:{s:3:\"add\";s:33:\"Drupal\\webform\\WebformOptionsForm\";s:4:\"edit\";s:33:\"Drupal\\webform\\WebformOptionsForm\";s:9:\"duplicate\";s:33:\"Drupal\\webform\\WebformOptionsForm\";s:6:\"delete\";s:39:\"Drupal\\webform\\WebformOptionsDeleteForm\";}}s:19:\"\0*\0admin_permission\";s:18:\"administer webform\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:11:\"entity_type\";s:8:\"\0*\0links\";a:5:{s:8:\"add-form\";s:43:\"/admin/structure/webform/options/manage/add\";s:9:\"edit-form\";s:62:\"/admin/structure/webform/options/manage/{webform_options}/edit\";s:14:\"duplicate-form\";s:67:\"/admin/structure/webform/options/manage/{webform_options}/duplicate\";s:11:\"delete-form\";s:64:\"/admin/structure/webform/options/manage/{webform_options}/delete\";s:10:\"collection\";s:39:\"/admin/structure/webform/options/manage\";}s:21:\"\0*\0bundle_entity_type\";N;s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";N;s:13:\"\0*\0base_table\";N;s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"webform options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:22:\"@count webform options\";s:6:\"plural\";s:22:\"@count webform options\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:13:\"configuration\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:0:{}s:18:\"\0*\0list_cache_tags\";a:1:{i:0;s:27:\"config:webform_options_list\";}s:14:\"\0*\0constraints\";a:0:{}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:16:\"\0*\0config_prefix\";N;s:14:\"\0*\0lookup_keys\";a:1:{i:0;s:4:\"uuid\";}s:16:\"\0*\0config_export\";a:6:{i:0;s:2:\"id\";i:1;s:4:\"uuid\";i:2;s:5:\"label\";i:3;s:8:\"category\";i:4;s:6:\"likert\";i:5;s:7:\"options\";}s:21:\"\0*\0mergedConfigExport\";a:0:{}}'),
('entity.definitions.installed',	'webform_submission.entity_type',	'O:36:\"Drupal\\Core\\Entity\\ContentEntityType\":41:{s:5:\"\0*\0id\";s:18:\"webform_submission\";s:8:\"\0*\0class\";s:39:\"Drupal\\webform\\Entity\\WebformSubmission\";s:11:\"\0*\0provider\";s:7:\"webform\";s:15:\"\0*\0static_cache\";b:1;s:15:\"\0*\0render_cache\";b:1;s:19:\"\0*\0persistent_cache\";b:1;s:14:\"\0*\0entity_keys\";a:7:{s:2:\"id\";s:3:\"sid\";s:6:\"bundle\";s:10:\"webform_id\";s:4:\"uuid\";s:4:\"uuid\";s:8:\"langcode\";s:8:\"langcode\";s:8:\"revision\";s:0:\"\";s:16:\"default_langcode\";s:16:\"default_langcode\";s:29:\"revision_translation_affected\";s:29:\"revision_translation_affected\";}s:16:\"\0*\0originalClass\";s:39:\"Drupal\\webform\\Entity\\WebformSubmission\";s:11:\"\0*\0handlers\";a:7:{s:7:\"storage\";s:39:\"Drupal\\webform\\WebformSubmissionStorage\";s:14:\"storage_schema\";s:45:\"Drupal\\webform\\WebformSubmissionStorageSchema\";s:10:\"views_data\";s:41:\"Drupal\\webform\\WebformSubmissionViewsData\";s:12:\"view_builder\";s:43:\"Drupal\\webform\\WebformSubmissionViewBuilder\";s:12:\"list_builder\";s:43:\"Drupal\\webform\\WebformSubmissionListBuilder\";s:6:\"access\";s:52:\"Drupal\\webform\\WebformSubmissionAccessControlHandler\";s:4:\"form\";a:9:{s:3:\"add\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:4:\"edit\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:8:\"edit_all\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:3:\"api\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:4:\"test\";s:36:\"Drupal\\webform\\WebformSubmissionForm\";s:5:\"notes\";s:41:\"Drupal\\webform\\WebformSubmissionNotesForm\";s:9:\"duplicate\";s:45:\"Drupal\\webform\\WebformSubmissionDuplicateForm\";s:6:\"delete\";s:47:\"Drupal\\webform\\Form\\WebformSubmissionDeleteForm\";s:14:\"layout_builder\";s:46:\"Drupal\\layout_builder\\Form\\OverridesEntityForm\";}}s:19:\"\0*\0admin_permission\";s:18:\"administer webform\";s:24:\"\0*\0collection_permission\";N;s:25:\"\0*\0permission_granularity\";s:6:\"bundle\";s:8:\"\0*\0links\";a:11:{s:9:\"canonical\";s:73:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}\";s:13:\"access-denied\";s:87:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/access-denied\";s:5:\"table\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/table\";s:4:\"text\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/text\";s:4:\"yaml\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/yaml\";s:9:\"edit-form\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit\";s:10:\"notes-form\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/notes\";s:11:\"resend-form\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/resend\";s:14:\"duplicate-form\";s:83:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/duplicate\";s:11:\"delete-form\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/delete\";s:10:\"collection\";s:48:\"/admin/structure/webform/submissions/manage/list\";}s:21:\"\0*\0bundle_entity_type\";s:7:\"webform\";s:12:\"\0*\0bundle_of\";N;s:15:\"\0*\0bundle_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"\0*\0base_table\";s:18:\"webform_submission\";s:22:\"\0*\0revision_data_table\";N;s:17:\"\0*\0revision_table\";N;s:13:\"\0*\0data_table\";N;s:11:\"\0*\0internal\";b:0;s:15:\"\0*\0translatable\";b:0;s:19:\"\0*\0show_revision_ui\";b:0;s:8:\"\0*\0label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Webform submission\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:19:\"\0*\0label_collection\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Submissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:17:\"\0*\0label_singular\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"submission\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:15:\"\0*\0label_plural\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"submissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:14:\"\0*\0label_count\";a:3:{s:8:\"singular\";s:17:\"@count submission\";s:6:\"plural\";s:18:\"@count submissions\";s:7:\"context\";N;}s:15:\"\0*\0uri_callback\";N;s:8:\"\0*\0group\";s:7:\"content\";s:14:\"\0*\0group_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:1:{s:7:\"context\";s:17:\"Entity type group\";}}s:22:\"\0*\0field_ui_base_route\";N;s:26:\"\0*\0common_reference_target\";b:0;s:22:\"\0*\0list_cache_contexts\";a:1:{i:0;s:4:\"user\";}s:18:\"\0*\0list_cache_tags\";a:2:{i:0;s:19:\"config:webform_list\";i:1;s:23:\"webform_submission_list\";}s:14:\"\0*\0constraints\";a:1:{s:26:\"EntityUntranslatableFields\";N;}s:13:\"\0*\0additional\";a:0:{}s:14:\"\0*\0_serviceIds\";a:0:{}s:18:\"\0*\0_entityStorages\";a:0:{}s:20:\"\0*\0stringTranslation\";N;s:25:\"\0*\0revision_metadata_keys\";a:1:{s:16:\"revision_default\";s:16:\"revision_default\";}}'),
('entity.definitions.installed',	'webform_submission.field_storage_definitions',	'a:19:{s:6:\"serial\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Serial number\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"The serial number of the webform submission entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:6:\"serial\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:2;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"sid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Submission ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"The ID of the webform submission entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:3:\"sid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:integer\";s:8:\"settings\";a:6:{s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:3:\"min\";s:0:\"\";s:3:\"max\";s:0:\"\";s:6:\"prefix\";s:0:\"\";s:6:\"suffix\";s:0:\"\";}}s:18:\"\0*\0fieldDefinition\";r:40;}s:7:\"\0*\0type\";s:7:\"integer\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:4:\"uuid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Submission UUID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:42:\"The UUID of the webform submission entity.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:4:\"uuid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:15:\"field_item:uuid\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:78;}s:7:\"\0*\0type\";s:4:\"uuid\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:1:{s:5:\"value\";a:1:{i:0;s:5:\"value\";}}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"token\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Token\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"A secure token used to look up a submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:5:\"token\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:115;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uri\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Submission URI\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"The URI the user submitted the webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"read-only\";b:1;s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:3:\"uri\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:2000;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:150;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2000;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"created\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Created\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:75:\"The time that the webform submission was first saved as draft or submitted.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:7:\"created\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:created\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:185;}s:7:\"\0*\0type\";s:7:\"created\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"completed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Completed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:75:\"The time that the webform submission was submitted as complete (not draft).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:9:\"completed\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:20:\"field_item:timestamp\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:214;}s:7:\"\0*\0type\";s:9:\"timestamp\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:7:\"changed\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Changed\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:72:\"The time that the webform submission was last saved (complete or draft).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:7:\"changed\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:changed\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:243;}s:7:\"\0*\0type\";s:7:\"changed\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:1:{s:4:\"type\";s:3:\"int\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"in_draft\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Is draft\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Is this a draft of the submission?\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:8:\"in_draft\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:272;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:12:\"current_page\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Current page\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"The current wizard page.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:12:\"current_page\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:313;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"remote_addr\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Remote IP address\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:54:\"The IP address of the user that submitted the webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:11:\"remote_addr\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:128;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:347;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:3:\"uid\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Submitted by\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:52:\"The username of the user that submitted the webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:22:\"default_value_callback\";s:57:\"Drupal\\webform\\Entity\\WebformSubmission::getCurrentUserId\";s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:3:\"uid\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:4:\"user\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:381;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:8:\"langcode\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"The submission language code.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:8:\"langcode\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:19:\"field_item:language\";s:8:\"settings\";a:0:{}}s:18:\"\0*\0fieldDefinition\";r:418;}s:7:\"\0*\0type\";s:8:\"language\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:10:\"webform_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Webform\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"The associated webform.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:10:\"webform_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:27:\"field_item:entity_reference\";s:8:\"settings\";a:3:{s:11:\"target_type\";s:7:\"webform\";s:7:\"handler\";s:7:\"default\";s:16:\"handler_settings\";a:0:{}}}s:18:\"\0*\0fieldDefinition\";r:448;}s:7:\"\0*\0type\";s:16:\"entity_reference\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:9:\"target_id\";a:3:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;}}s:7:\"indexes\";a:1:{s:9:\"target_id\";a:1:{i:0;s:9:\"target_id\";}}s:11:\"unique keys\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:11:\"entity_type\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Submitted to: Entity type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:60:\"The entity type to which this submission was submitted from.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:11:\"entity_type\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:32;s:8:\"is_ascii\";b:1;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:484;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:9:\"entity_id\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:7:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Submitted to: Entity ID\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:73:\"The ID of the entity of which this webform submission was submitted from.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:9:\"entity_id\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:17:\"field_item:string\";s:8:\"settings\";a:3:{s:10:\"max_length\";i:255;s:8:\"is_ascii\";b:0;s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:518;}s:7:\"\0*\0type\";s:6:\"string\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"locked\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Locked\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"A flag that indicates a locked webform submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:6:\"locked\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:552;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:6:\"sticky\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Sticky\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:58:\"A flag that indicate the status of the webform submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";b:0;}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:6:\"sticky\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:18:\"field_item:boolean\";s:8:\"settings\";a:2:{s:8:\"on_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:2:\"On\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:9:\"off_label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:3:\"Off\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}}}s:18:\"\0*\0fieldDefinition\";r:593;}s:7:\"\0*\0type\";s:7:\"boolean\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}s:5:\"notes\";O:37:\"Drupal\\Core\\Field\\BaseFieldDefinition\":5:{s:13:\"\0*\0definition\";a:8:{s:5:\"label\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Notes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:11:\"description\";O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:50:\"Administrative notes about the webform submission.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}s:13:\"default_value\";a:1:{i:0;a:1:{s:5:\"value\";s:0:\"\";}}s:8:\"provider\";s:7:\"webform\";s:10:\"field_name\";s:5:\"notes\";s:11:\"entity_type\";s:18:\"webform_submission\";s:6:\"bundle\";N;s:13:\"initial_value\";N;}s:17:\"\0*\0itemDefinition\";O:51:\"Drupal\\Core\\Field\\TypedData\\FieldItemDataDefinition\":2:{s:13:\"\0*\0definition\";a:2:{s:4:\"type\";s:22:\"field_item:string_long\";s:8:\"settings\";a:1:{s:14:\"case_sensitive\";b:0;}}s:18:\"\0*\0fieldDefinition\";r:634;}s:7:\"\0*\0type\";s:11:\"string_long\";s:9:\"\0*\0schema\";a:4:{s:7:\"columns\";a:1:{s:5:\"value\";a:2:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";}}s:11:\"unique keys\";a:0:{}s:7:\"indexes\";a:0:{}s:12:\"foreign keys\";a:0:{}}s:10:\"\0*\0indexes\";a:0:{}}}'),
('entity.storage_schema.sql',	'block_content.entity_schema_data',	'a:4:{s:13:\"block_content\";a:2:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:11:\"unique keys\";a:1:{s:26:\"block_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:22:\"block_content_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:17:\"block_content__id\";a:1:{i:0;s:2:\"id\";}}}s:24:\"block_content_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:45:\"block_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:26:\"block_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"block_content__status_type\";a:3:{i:0;s:6:\"status\";i:1;s:4:\"type\";i:2;s:2:\"id\";}}}s:28:\"block_content_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:45:\"block_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.body',	'a:2:{s:19:\"block_content__body\";a:4:{s:11:\"description\";s:42:\"Data storage for block_content field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}s:28:\"block_content_revision__body\";a:4:{s:11:\"description\";s:54:\"Revision archive storage for block_content field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.changed',	'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.default_langcode',	'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_accordion',	'a:2:{s:34:\"block_content__field_ebt_accordion\";a:4:{s:11:\"description\";s:57:\"Data storage for block_content field field_ebt_accordion.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_accordion_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ebt_accordion_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_accordion_target_id\";a:1:{i:0;s:29:\"field_ebt_accordion_target_id\";}s:38:\"field_ebt_accordion_target_revision_id\";a:1:{i:0;s:38:\"field_ebt_accordion_target_revision_id\";}}}s:43:\"block_content_revision__field_ebt_accordion\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for block_content field field_ebt_accordion.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_accordion_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ebt_accordion_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_accordion_target_id\";a:1:{i:0;s:29:\"field_ebt_accordion_target_id\";}s:38:\"field_ebt_accordion_target_revision_id\";a:1:{i:0;s:38:\"field_ebt_accordion_target_revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_basic_button_link',	'a:2:{s:42:\"block_content__field_ebt_basic_button_link\";a:4:{s:11:\"description\";s:65:\"Data storage for block_content field field_ebt_basic_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_basic_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ebt_basic_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ebt_basic_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_basic_button_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ebt_basic_button_link_uri\";i:1;i:30;}}}}s:27:\"block_content_r__6145a3a301\";a:4:{s:11:\"description\";s:77:\"Revision archive storage for block_content field field_ebt_basic_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_basic_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ebt_basic_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ebt_basic_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_basic_button_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ebt_basic_button_link_uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_block_block',	'a:2:{s:36:\"block_content__field_ebt_block_block\";a:4:{s:11:\"description\";s:59:\"Data storage for block_content field field_ebt_block_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_block_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ebt_block_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_block_block_plugin_id\";a:1:{i:0;s:31:\"field_ebt_block_block_plugin_id\";}}}s:45:\"block_content_revision__field_ebt_block_block\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for block_content field field_ebt_block_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_block_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ebt_block_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_block_block_plugin_id\";a:1:{i:0;s:31:\"field_ebt_block_block_plugin_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_bootstrap_button_link',	'a:2:{s:46:\"block_content__field_ebt_bootstrap_button_link\";a:4:{s:11:\"description\";s:69:\"Data storage for block_content field field_ebt_bootstrap_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ebt_bootstrap_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:37:\"field_ebt_bootstrap_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:39:\"field_ebt_bootstrap_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ebt_bootstrap_button_link_uri\";a:1:{i:0;a:2:{i:0;s:35:\"field_ebt_bootstrap_button_link_uri\";i:1;i:30;}}}}s:27:\"block_content_r__2d12375ee7\";a:4:{s:11:\"description\";s:81:\"Revision archive storage for block_content field field_ebt_bootstrap_button_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ebt_bootstrap_button_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:37:\"field_ebt_bootstrap_button_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:39:\"field_ebt_bootstrap_button_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ebt_bootstrap_button_link_uri\";a:1:{i:0;a:2:{i:0;s:35:\"field_ebt_bootstrap_button_link_uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_carousel',	'a:2:{s:33:\"block_content__field_ebt_carousel\";a:4:{s:11:\"description\";s:56:\"Data storage for block_content field field_ebt_carousel.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ebt_carousel_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:37:\"field_ebt_carousel_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ebt_carousel_target_id\";a:1:{i:0;s:28:\"field_ebt_carousel_target_id\";}s:37:\"field_ebt_carousel_target_revision_id\";a:1:{i:0;s:37:\"field_ebt_carousel_target_revision_id\";}}}s:42:\"block_content_revision__field_ebt_carousel\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for block_content field field_ebt_carousel.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ebt_carousel_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:37:\"field_ebt_carousel_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ebt_carousel_target_id\";a:1:{i:0;s:28:\"field_ebt_carousel_target_id\";}s:37:\"field_ebt_carousel_target_revision_id\";a:1:{i:0;s:37:\"field_ebt_carousel_target_revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_columns_blocks',	'a:2:{s:39:\"block_content__field_ebt_columns_blocks\";a:4:{s:11:\"description\";s:62:\"Data storage for block_content field field_ebt_columns_blocks.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:34:\"field_ebt_columns_blocks_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:33:\"field_ebt_columns_blocks_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ebt_columns_blocks_plugin_id\";a:1:{i:0;s:34:\"field_ebt_columns_blocks_plugin_id\";}}}s:48:\"block_content_revision__field_ebt_columns_blocks\";a:4:{s:11:\"description\";s:74:\"Revision archive storage for block_content field field_ebt_columns_blocks.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:34:\"field_ebt_columns_blocks_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:33:\"field_ebt_columns_blocks_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ebt_columns_blocks_plugin_id\";a:1:{i:0;s:34:\"field_ebt_columns_blocks_plugin_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_countdown_date',	'a:2:{s:39:\"block_content__field_ebt_countdown_date\";a:4:{s:11:\"description\";s:62:\"Data storage for block_content field field_ebt_countdown_date.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_countdown_date_value\";a:4:{s:11:\"description\";s:15:\"The date value.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ebt_countdown_date_value\";a:1:{i:0;s:30:\"field_ebt_countdown_date_value\";}}}s:48:\"block_content_revision__field_ebt_countdown_date\";a:4:{s:11:\"description\";s:74:\"Revision archive storage for block_content field field_ebt_countdown_date.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_countdown_date_value\";a:4:{s:11:\"description\";s:15:\"The date value.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ebt_countdown_date_value\";a:1:{i:0;s:30:\"field_ebt_countdown_date_value\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_counter_icon',	'a:2:{s:37:\"block_content__field_ebt_counter_icon\";a:4:{s:11:\"description\";s:60:\"Data storage for block_content field field_ebt_counter_icon.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_counter_icon_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_counter_icon_target_id\";a:1:{i:0;s:32:\"field_ebt_counter_icon_target_id\";}}}s:46:\"block_content_revision__field_ebt_counter_icon\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for block_content field field_ebt_counter_icon.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_counter_icon_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_counter_icon_target_id\";a:1:{i:0;s:32:\"field_ebt_counter_icon_target_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_counter_items',	'a:2:{s:38:\"block_content__field_ebt_counter_items\";a:4:{s:11:\"description\";s:61:\"Data storage for block_content field field_ebt_counter_items.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ebt_counter_items_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:42:\"field_ebt_counter_items_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ebt_counter_items_target_id\";a:1:{i:0;s:33:\"field_ebt_counter_items_target_id\";}s:42:\"field_ebt_counter_items_target_revision_id\";a:1:{i:0;s:42:\"field_ebt_counter_items_target_revision_id\";}}}s:47:\"block_content_revision__field_ebt_counter_items\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for block_content field field_ebt_counter_items.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ebt_counter_items_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:42:\"field_ebt_counter_items_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ebt_counter_items_target_id\";a:1:{i:0;s:33:\"field_ebt_counter_items_target_id\";}s:42:\"field_ebt_counter_items_target_revision_id\";a:1:{i:0;s:42:\"field_ebt_counter_items_target_revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_counter_number',	'a:2:{s:39:\"block_content__field_ebt_counter_number\";a:4:{s:11:\"description\";s:62:\"Data storage for block_content field field_ebt_counter_number.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_counter_number_value\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:48:\"block_content_revision__field_ebt_counter_number\";a:4:{s:11:\"description\";s:74:\"Revision archive storage for block_content field field_ebt_counter_number.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_counter_number_value\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_cta_column_image',	'a:2:{s:41:\"block_content__field_ebt_cta_column_image\";a:4:{s:11:\"description\";s:64:\"Data storage for block_content field field_ebt_cta_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_ebt_cta_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ebt_cta_column_image_target_id\";a:1:{i:0;s:36:\"field_ebt_cta_column_image_target_id\";}}}s:27:\"block_content_r__b5f82fb056\";a:4:{s:11:\"description\";s:76:\"Revision archive storage for block_content field field_ebt_cta_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_ebt_cta_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ebt_cta_column_image_target_id\";a:1:{i:0;s:36:\"field_ebt_cta_column_image_target_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_cta_link',	'a:2:{s:33:\"block_content__field_ebt_cta_link\";a:4:{s:11:\"description\";s:56:\"Data storage for block_content field field_ebt_cta_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:22:\"field_ebt_cta_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:24:\"field_ebt_cta_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:26:\"field_ebt_cta_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"field_ebt_cta_link_uri\";a:1:{i:0;a:2:{i:0;s:22:\"field_ebt_cta_link_uri\";i:1;i:30;}}}}s:42:\"block_content_revision__field_ebt_cta_link\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for block_content field field_ebt_cta_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:22:\"field_ebt_cta_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:24:\"field_ebt_cta_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:26:\"field_ebt_cta_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"field_ebt_cta_link_uri\";a:1:{i:0;a:2:{i:0;s:22:\"field_ebt_cta_link_uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_cta_second_link',	'a:2:{s:40:\"block_content__field_ebt_cta_second_link\";a:4:{s:11:\"description\";s:63:\"Data storage for block_content field field_ebt_cta_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_cta_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:31:\"field_ebt_cta_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:33:\"field_ebt_cta_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_cta_second_link_uri\";a:1:{i:0;a:2:{i:0;s:29:\"field_ebt_cta_second_link_uri\";i:1;i:30;}}}}s:27:\"block_content_r__6a87f4fdb7\";a:4:{s:11:\"description\";s:75:\"Revision archive storage for block_content field field_ebt_cta_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_cta_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:31:\"field_ebt_cta_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:33:\"field_ebt_cta_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_cta_second_link_uri\";a:1:{i:0;a:2:{i:0;s:29:\"field_ebt_cta_second_link_uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_cta_title',	'a:2:{s:34:\"block_content__field_ebt_cta_title\";a:4:{s:11:\"description\";s:57:\"Data storage for block_content field field_ebt_cta_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_cta_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:26:\"field_ebt_cta_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_ebt_cta_title_format\";a:1:{i:0;s:26:\"field_ebt_cta_title_format\";}}}s:43:\"block_content_revision__field_ebt_cta_title\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for block_content field field_ebt_cta_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_cta_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:26:\"field_ebt_cta_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_ebt_cta_title_format\";a:1:{i:0;s:26:\"field_ebt_cta_title_format\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_hero_column_image',	'a:2:{s:42:\"block_content__field_ebt_hero_column_image\";a:4:{s:11:\"description\";s:65:\"Data storage for block_content field field_ebt_hero_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ebt_hero_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ebt_hero_column_image_target_id\";a:1:{i:0;s:37:\"field_ebt_hero_column_image_target_id\";}}}s:27:\"block_content_r__c4c7d0dccb\";a:4:{s:11:\"description\";s:77:\"Revision archive storage for block_content field field_ebt_hero_column_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ebt_hero_column_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ebt_hero_column_image_target_id\";a:1:{i:0;s:37:\"field_ebt_hero_column_image_target_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_hero_link',	'a:2:{s:34:\"block_content__field_ebt_hero_link\";a:4:{s:11:\"description\";s:57:\"Data storage for block_content field field_ebt_hero_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:23:\"field_ebt_hero_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:25:\"field_ebt_hero_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:27:\"field_ebt_hero_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:23:\"field_ebt_hero_link_uri\";a:1:{i:0;a:2:{i:0;s:23:\"field_ebt_hero_link_uri\";i:1;i:30;}}}}s:43:\"block_content_revision__field_ebt_hero_link\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for block_content field field_ebt_hero_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:23:\"field_ebt_hero_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:25:\"field_ebt_hero_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:27:\"field_ebt_hero_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:23:\"field_ebt_hero_link_uri\";a:1:{i:0;a:2:{i:0;s:23:\"field_ebt_hero_link_uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_hero_second_link',	'a:2:{s:41:\"block_content__field_ebt_hero_second_link\";a:4:{s:11:\"description\";s:64:\"Data storage for block_content field field_ebt_hero_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_hero_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:32:\"field_ebt_hero_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:34:\"field_ebt_hero_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ebt_hero_second_link_uri\";a:1:{i:0;a:2:{i:0;s:30:\"field_ebt_hero_second_link_uri\";i:1;i:30;}}}}s:27:\"block_content_r__5ab1225ba6\";a:4:{s:11:\"description\";s:76:\"Revision archive storage for block_content field field_ebt_hero_second_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_hero_second_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:32:\"field_ebt_hero_second_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:34:\"field_ebt_hero_second_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ebt_hero_second_link_uri\";a:1:{i:0;a:2:{i:0;s:30:\"field_ebt_hero_second_link_uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_hero_title',	'a:2:{s:35:\"block_content__field_ebt_hero_title\";a:4:{s:11:\"description\";s:58:\"Data storage for block_content field field_ebt_hero_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_ebt_hero_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:27:\"field_ebt_hero_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ebt_hero_title_format\";a:1:{i:0;s:27:\"field_ebt_hero_title_format\";}}}s:44:\"block_content_revision__field_ebt_hero_title\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for block_content field field_ebt_hero_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_ebt_hero_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:27:\"field_ebt_hero_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ebt_hero_title_format\";a:1:{i:0;s:27:\"field_ebt_hero_title_format\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_hero_title_prefix',	'a:2:{s:42:\"block_content__field_ebt_hero_title_prefix\";a:4:{s:11:\"description\";s:65:\"Data storage for block_content field field_ebt_hero_title_prefix.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ebt_hero_title_prefix_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ebt_hero_title_prefix_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ebt_hero_title_prefix_format\";a:1:{i:0;s:34:\"field_ebt_hero_title_prefix_format\";}}}s:27:\"block_content_r__1d98dd7393\";a:4:{s:11:\"description\";s:77:\"Revision archive storage for block_content field field_ebt_hero_title_prefix.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ebt_hero_title_prefix_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ebt_hero_title_prefix_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ebt_hero_title_prefix_format\";a:1:{i:0;s:34:\"field_ebt_hero_title_prefix_format\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_image',	'a:2:{s:30:\"block_content__field_ebt_image\";a:4:{s:11:\"description\";s:53:\"Data storage for block_content field field_ebt_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ebt_image_target_id\";a:1:{i:0;s:25:\"field_ebt_image_target_id\";}}}s:39:\"block_content_revision__field_ebt_image\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for block_content field field_ebt_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ebt_image_target_id\";a:1:{i:0;s:25:\"field_ebt_image_target_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_image_caption',	'a:2:{s:38:\"block_content__field_ebt_image_caption\";a:4:{s:11:\"description\";s:61:\"Data storage for block_content field field_ebt_image_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_image_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ebt_image_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ebt_image_caption_format\";a:1:{i:0;s:30:\"field_ebt_image_caption_format\";}}}s:47:\"block_content_revision__field_ebt_image_caption\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for block_content field field_ebt_image_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_image_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ebt_image_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ebt_image_caption_format\";a:1:{i:0;s:30:\"field_ebt_image_caption_format\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_image_gallery',	'a:2:{s:38:\"block_content__field_ebt_image_gallery\";a:4:{s:11:\"description\";s:61:\"Data storage for block_content field field_ebt_image_gallery.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ebt_image_gallery_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ebt_image_gallery_target_id\";a:1:{i:0;s:33:\"field_ebt_image_gallery_target_id\";}}}s:47:\"block_content_revision__field_ebt_image_gallery\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for block_content field field_ebt_image_gallery.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ebt_image_gallery_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ebt_image_gallery_target_id\";a:1:{i:0;s:33:\"field_ebt_image_gallery_target_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_image_link',	'a:2:{s:35:\"block_content__field_ebt_image_link\";a:4:{s:11:\"description\";s:58:\"Data storage for block_content field field_ebt_image_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ebt_image_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ebt_image_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ebt_image_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ebt_image_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ebt_image_link_uri\";i:1;i:30;}}}}s:44:\"block_content_revision__field_ebt_image_link\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for block_content field field_ebt_image_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ebt_image_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ebt_image_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ebt_image_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ebt_image_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ebt_image_link_uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_micromodal_title',	'a:2:{s:41:\"block_content__field_ebt_micromodal_title\";a:4:{s:11:\"description\";s:64:\"Data storage for block_content field field_ebt_micromodal_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_micromodal_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ebt_micromodal_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ebt_micromodal_title_format\";a:1:{i:0;s:33:\"field_ebt_micromodal_title_format\";}}}s:27:\"block_content_r__abebd0b113\";a:4:{s:11:\"description\";s:76:\"Revision archive storage for block_content field field_ebt_micromodal_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_micromodal_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ebt_micromodal_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ebt_micromodal_title_format\";a:1:{i:0;s:33:\"field_ebt_micromodal_title_format\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_quote_author',	'a:2:{s:37:\"block_content__field_ebt_quote_author\";a:4:{s:11:\"description\";s:60:\"Data storage for block_content field field_ebt_quote_author.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ebt_quote_author_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:29:\"field_ebt_quote_author_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_quote_author_format\";a:1:{i:0;s:29:\"field_ebt_quote_author_format\";}}}s:46:\"block_content_revision__field_ebt_quote_author\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for block_content field field_ebt_quote_author.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ebt_quote_author_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:29:\"field_ebt_quote_author_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_quote_author_format\";a:1:{i:0;s:29:\"field_ebt_quote_author_format\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_quote_image',	'a:2:{s:36:\"block_content__field_ebt_quote_image\";a:4:{s:11:\"description\";s:59:\"Data storage for block_content field field_ebt_quote_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_quote_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_quote_image_target_id\";a:1:{i:0;s:31:\"field_ebt_quote_image_target_id\";}}}s:45:\"block_content_revision__field_ebt_quote_image\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for block_content field field_ebt_quote_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_quote_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_quote_image_target_id\";a:1:{i:0;s:31:\"field_ebt_quote_image_target_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_settings',	'a:2:{s:33:\"block_content__field_ebt_settings\";a:4:{s:11:\"description\";s:56:\"Data storage for block_content field field_ebt_settings.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_settings_ebt_settings\";a:5:{s:11:\"description\";s:30:\"Serialized block settings data\";s:4:\"type\";s:4:\"blob\";s:9:\"serialize\";b:1;s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:42:\"block_content_revision__field_ebt_settings\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for block_content field field_ebt_settings.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_settings_ebt_settings\";a:5:{s:11:\"description\";s:30:\"Serialized block settings data\";s:4:\"type\";s:4:\"blob\";s:9:\"serialize\";b:1;s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_slick_slider',	'a:2:{s:37:\"block_content__field_ebt_slick_slider\";a:4:{s:11:\"description\";s:60:\"Data storage for block_content field field_ebt_slick_slider.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_slick_slider_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:41:\"field_ebt_slick_slider_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_slick_slider_target_id\";a:1:{i:0;s:32:\"field_ebt_slick_slider_target_id\";}s:41:\"field_ebt_slick_slider_target_revision_id\";a:1:{i:0;s:41:\"field_ebt_slick_slider_target_revision_id\";}}}s:46:\"block_content_revision__field_ebt_slick_slider\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for block_content field field_ebt_slick_slider.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_slick_slider_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:41:\"field_ebt_slick_slider_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_slick_slider_target_id\";a:1:{i:0;s:32:\"field_ebt_slick_slider_target_id\";}s:41:\"field_ebt_slick_slider_target_revision_id\";a:1:{i:0;s:41:\"field_ebt_slick_slider_target_revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_slideshow',	'a:2:{s:34:\"block_content__field_ebt_slideshow\";a:4:{s:11:\"description\";s:57:\"Data storage for block_content field field_ebt_slideshow.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_slideshow_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ebt_slideshow_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_slideshow_target_id\";a:1:{i:0;s:29:\"field_ebt_slideshow_target_id\";}s:38:\"field_ebt_slideshow_target_revision_id\";a:1:{i:0;s:38:\"field_ebt_slideshow_target_revision_id\";}}}s:43:\"block_content_revision__field_ebt_slideshow\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for block_content field field_ebt_slideshow.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_slideshow_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:38:\"field_ebt_slideshow_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_slideshow_target_id\";a:1:{i:0;s:29:\"field_ebt_slideshow_target_id\";}s:38:\"field_ebt_slideshow_target_revision_id\";a:1:{i:0;s:38:\"field_ebt_slideshow_target_revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_stats',	'a:2:{s:30:\"block_content__field_ebt_stats\";a:4:{s:11:\"description\";s:53:\"Data storage for block_content field field_ebt_stats.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_stats_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ebt_stats_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ebt_stats_target_id\";a:1:{i:0;s:25:\"field_ebt_stats_target_id\";}s:34:\"field_ebt_stats_target_revision_id\";a:1:{i:0;s:34:\"field_ebt_stats_target_revision_id\";}}}s:39:\"block_content_revision__field_ebt_stats\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for block_content field field_ebt_stats.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_stats_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ebt_stats_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ebt_stats_target_id\";a:1:{i:0;s:25:\"field_ebt_stats_target_id\";}s:34:\"field_ebt_stats_target_revision_id\";a:1:{i:0;s:34:\"field_ebt_stats_target_revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_tabs',	'a:2:{s:29:\"block_content__field_ebt_tabs\";a:4:{s:11:\"description\";s:52:\"Data storage for block_content field field_ebt_tabs.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ebt_tabs_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:33:\"field_ebt_tabs_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ebt_tabs_target_id\";a:1:{i:0;s:24:\"field_ebt_tabs_target_id\";}s:33:\"field_ebt_tabs_target_revision_id\";a:1:{i:0;s:33:\"field_ebt_tabs_target_revision_id\";}}}s:38:\"block_content_revision__field_ebt_tabs\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for block_content field field_ebt_tabs.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ebt_tabs_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:33:\"field_ebt_tabs_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ebt_tabs_target_id\";a:1:{i:0;s:24:\"field_ebt_tabs_target_id\";}s:33:\"field_ebt_tabs_target_revision_id\";a:1:{i:0;s:33:\"field_ebt_tabs_target_revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_tiles',	'a:2:{s:30:\"block_content__field_ebt_tiles\";a:4:{s:11:\"description\";s:53:\"Data storage for block_content field field_ebt_tiles.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_tiles_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ebt_tiles_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ebt_tiles_target_id\";a:1:{i:0;s:25:\"field_ebt_tiles_target_id\";}s:34:\"field_ebt_tiles_target_revision_id\";a:1:{i:0;s:34:\"field_ebt_tiles_target_revision_id\";}}}s:39:\"block_content_revision__field_ebt_tiles\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for block_content field field_ebt_tiles.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_tiles_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:34:\"field_ebt_tiles_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ebt_tiles_target_id\";a:1:{i:0;s:25:\"field_ebt_tiles_target_id\";}s:34:\"field_ebt_tiles_target_revision_id\";a:1:{i:0;s:34:\"field_ebt_tiles_target_revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_timeline',	'a:2:{s:33:\"block_content__field_ebt_timeline\";a:4:{s:11:\"description\";s:56:\"Data storage for block_content field field_ebt_timeline.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ebt_timeline_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:37:\"field_ebt_timeline_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ebt_timeline_target_id\";a:1:{i:0;s:28:\"field_ebt_timeline_target_id\";}s:37:\"field_ebt_timeline_target_revision_id\";a:1:{i:0;s:37:\"field_ebt_timeline_target_revision_id\";}}}s:42:\"block_content_revision__field_ebt_timeline\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for block_content field field_ebt_timeline.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ebt_timeline_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:37:\"field_ebt_timeline_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ebt_timeline_target_id\";a:1:{i:0;s:28:\"field_ebt_timeline_target_id\";}s:37:\"field_ebt_timeline_target_revision_id\";a:1:{i:0;s:37:\"field_ebt_timeline_target_revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_video',	'a:2:{s:30:\"block_content__field_ebt_video\";a:4:{s:11:\"description\";s:53:\"Data storage for block_content field field_ebt_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_video_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ebt_video_target_id\";a:1:{i:0;s:25:\"field_ebt_video_target_id\";}}}s:39:\"block_content_revision__field_ebt_video\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for block_content field field_ebt_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_video_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ebt_video_target_id\";a:1:{i:0;s:25:\"field_ebt_video_target_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_videos_and_images',	'a:2:{s:42:\"block_content__field_ebt_videos_and_images\";a:4:{s:11:\"description\";s:65:\"Data storage for block_content field field_ebt_videos_and_images.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ebt_videos_and_images_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:46:\"field_ebt_videos_and_images_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ebt_videos_and_images_target_id\";a:1:{i:0;s:37:\"field_ebt_videos_and_images_target_id\";}s:46:\"field_ebt_videos_and_images_target_revision_id\";a:1:{i:0;s:46:\"field_ebt_videos_and_images_target_revision_id\";}}}s:27:\"block_content_r__340d64eab4\";a:4:{s:11:\"description\";s:77:\"Revision archive storage for block_content field field_ebt_videos_and_images.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:37:\"field_ebt_videos_and_images_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:46:\"field_ebt_videos_and_images_target_revision_id\";a:4:{s:11:\"description\";s:37:\"The revision ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_ebt_videos_and_images_target_id\";a:1:{i:0;s:37:\"field_ebt_videos_and_images_target_id\";}s:46:\"field_ebt_videos_and_images_target_revision_id\";a:1:{i:0;s:46:\"field_ebt_videos_and_images_target_revision_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_views_views',	'a:2:{s:36:\"block_content__field_ebt_views_views\";a:4:{s:11:\"description\";s:59:\"Data storage for block_content field field_ebt_views_views.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_views_views_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:32:\"field_ebt_views_views_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:26:\"field_ebt_views_views_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_views_views_target_id\";a:1:{i:0;s:31:\"field_ebt_views_views_target_id\";}s:32:\"field_ebt_views_views_display_id\";a:1:{i:0;s:32:\"field_ebt_views_views_display_id\";}}}s:45:\"block_content_revision__field_ebt_views_views\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for block_content field field_ebt_views_views.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_views_views_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:32:\"field_ebt_views_views_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:26:\"field_ebt_views_views_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_views_views_target_id\";a:1:{i:0;s:31:\"field_ebt_views_views_target_id\";}s:32:\"field_ebt_views_views_display_id\";a:1:{i:0;s:32:\"field_ebt_views_views_display_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_webform_form',	'a:2:{s:37:\"block_content__field_ebt_webform_form\";a:4:{s:11:\"description\";s:60:\"Data storage for block_content field field_ebt_webform_form.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_webform_form_target_id\";a:4:{s:11:\"description\";s:29:\"The ID of the webform entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}s:35:\"field_ebt_webform_form_default_data\";a:3:{s:11:\"description\";s:24:\"Default submission data.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}s:29:\"field_ebt_webform_form_status\";a:4:{s:11:\"description\";s:94:\"Flag to control whether this webform should be open, closed, or scheduled for new submissions.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:27:\"field_ebt_webform_form_open\";a:4:{s:11:\"description\";s:19:\"The open date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:28:\"field_ebt_webform_form_close\";a:4:{s:11:\"description\";s:20:\"The close date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_webform_form_target_id\";a:1:{i:0;s:32:\"field_ebt_webform_form_target_id\";}}}s:46:\"block_content_revision__field_ebt_webform_form\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for block_content field field_ebt_webform_form.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_webform_form_target_id\";a:4:{s:11:\"description\";s:29:\"The ID of the webform entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}s:35:\"field_ebt_webform_form_default_data\";a:3:{s:11:\"description\";s:24:\"Default submission data.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}s:29:\"field_ebt_webform_form_status\";a:4:{s:11:\"description\";s:94:\"Flag to control whether this webform should be open, closed, or scheduled for new submissions.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:27:\"field_ebt_webform_form_open\";a:4:{s:11:\"description\";s:19:\"The open date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:28:\"field_ebt_webform_form_close\";a:4:{s:11:\"description\";s:20:\"The close date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_webform_form_target_id\";a:1:{i:0;s:32:\"field_ebt_webform_form_target_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.field_ebt_webform_popup_form',	'a:2:{s:43:\"block_content__field_ebt_webform_popup_form\";a:4:{s:11:\"description\";s:66:\"Data storage for block_content field field_ebt_webform_popup_form.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:38:\"field_ebt_webform_popup_form_target_id\";a:4:{s:11:\"description\";s:29:\"The ID of the webform entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}s:41:\"field_ebt_webform_popup_form_default_data\";a:3:{s:11:\"description\";s:24:\"Default submission data.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}s:35:\"field_ebt_webform_popup_form_status\";a:4:{s:11:\"description\";s:94:\"Flag to control whether this webform should be open, closed, or scheduled for new submissions.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:33:\"field_ebt_webform_popup_form_open\";a:4:{s:11:\"description\";s:19:\"The open date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:34:\"field_ebt_webform_popup_form_close\";a:4:{s:11:\"description\";s:20:\"The close date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:38:\"field_ebt_webform_popup_form_target_id\";a:1:{i:0;s:38:\"field_ebt_webform_popup_form_target_id\";}}}s:27:\"block_content_r__b1f6f83596\";a:4:{s:11:\"description\";s:78:\"Revision archive storage for block_content field field_ebt_webform_popup_form.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:38:\"field_ebt_webform_popup_form_target_id\";a:4:{s:11:\"description\";s:29:\"The ID of the webform entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}s:41:\"field_ebt_webform_popup_form_default_data\";a:3:{s:11:\"description\";s:24:\"Default submission data.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}s:35:\"field_ebt_webform_popup_form_status\";a:4:{s:11:\"description\";s:94:\"Flag to control whether this webform should be open, closed, or scheduled for new submissions.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:33:\"field_ebt_webform_popup_form_open\";a:4:{s:11:\"description\";s:19:\"The open date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}s:34:\"field_ebt_webform_popup_form_close\";a:4:{s:11:\"description\";s:20:\"The close date/time.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:20;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:38:\"field_ebt_webform_popup_form_target_id\";a:1:{i:0;s:38:\"field_ebt_webform_popup_form_target_id\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.id',	'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.info',	'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"info\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"info\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.langcode',	'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.reusable',	'a:1:{s:24:\"block_content_field_data\";a:2:{s:6:\"fields\";a:1:{s:8:\"reusable\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:29:\"block_content_field__reusable\";a:1:{i:0;s:8:\"reusable\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.revision_created',	'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.revision_default',	'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.revision_id',	'a:4:{s:13:\"block_content\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.revision_log',	'a:1:{s:22:\"block_content_revision\";a:1:{s:6:\"fields\";a:1:{s:12:\"revision_log\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.revision_translation_affected',	'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.revision_user',	'a:1:{s:22:\"block_content_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:45:\"block_content_field__revision_user__target_id\";a:1:{i:0;s:13:\"revision_user\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.status',	'a:2:{s:24:\"block_content_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"block_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.type',	'a:2:{s:13:\"block_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:36:\"block_content_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}s:24:\"block_content_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:36:\"block_content_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}}'),
('entity.storage_schema.sql',	'block_content.field_schema_data.uuid',	'a:1:{s:13:\"block_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:32:\"block_content_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'file.entity_schema_data',	'a:1:{s:12:\"file_managed\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"fid\";}}}'),
('entity.storage_schema.sql',	'file.field_schema_data.changed',	'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"file_field__changed\";a:1:{i:0;s:7:\"changed\";}}}}'),
('entity.storage_schema.sql',	'file.field_schema_data.created',	'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'file.field_schema_data.fid',	'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:3:\"fid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'file.field_schema_data.filemime',	'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filemime\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'file.field_schema_data.filename',	'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filename\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'file.field_schema_data.filesize',	'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"filesize\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'file.field_schema_data.langcode',	'a:1:{s:12:\"file_managed\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'file.field_schema_data.status',	'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:18:\"file_field__status\";a:1:{i:0;s:6:\"status\";}}}}'),
('entity.storage_schema.sql',	'file.field_schema_data.uid',	'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:26:\"file_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),
('entity.storage_schema.sql',	'file.field_schema_data.uri',	'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:3:\"uri\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:15:\"file_field__uri\";a:1:{i:0;s:3:\"uri\";}}}}'),
('entity.storage_schema.sql',	'file.field_schema_data.uuid',	'a:1:{s:12:\"file_managed\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"file_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'media.entity_schema_data',	'a:4:{s:5:\"media\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"mid\";}s:11:\"unique keys\";a:1:{s:10:\"media__vid\";a:1:{i:0;s:3:\"vid\";}}}s:14:\"media_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"vid\";}s:7:\"indexes\";a:1:{s:10:\"media__mid\";a:1:{i:0;s:3:\"mid\";}}}s:16:\"media_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"mid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:37:\"media__id__default_langcode__langcode\";a:3:{i:0;s:3:\"mid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:10:\"media__vid\";a:1:{i:0;s:3:\"vid\";}s:20:\"media__status_bundle\";a:3:{i:0;s:6:\"status\";i:1;s:6:\"bundle\";i:2;s:3:\"mid\";}}}s:20:\"media_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"vid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:37:\"media__id__default_langcode__langcode\";a:3:{i:0;s:3:\"mid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.bundle',	'a:2:{s:5:\"media\";a:2:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:30:\"media_field__bundle__target_id\";a:1:{i:0;s:6:\"bundle\";}}}s:16:\"media_field_data\";a:2:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:30:\"media_field__bundle__target_id\";a:1:{i:0;s:6:\"bundle\";}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.changed',	'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.created',	'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.default_langcode',	'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.field_media_audio_file',	'a:2:{s:29:\"media__field_media_audio_file\";a:5:{s:11:\"description\";s:52:\"Data storage for media field field_media_audio_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_audio_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_audio_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_audio_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_audio_file_target_id\";a:1:{i:0;s:32:\"field_media_audio_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_audio_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_audio_file_target_id\";s:3:\"fid\";}}}}s:38:\"media_revision__field_media_audio_file\";a:5:{s:11:\"description\";s:64:\"Revision archive storage for media field field_media_audio_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_audio_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_audio_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_audio_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_audio_file_target_id\";a:1:{i:0;s:32:\"field_media_audio_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_audio_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_audio_file_target_id\";s:3:\"fid\";}}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.field_media_document',	'a:2:{s:27:\"media__field_media_document\";a:5:{s:11:\"description\";s:50:\"Data storage for media field field_media_document.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_document_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:28:\"field_media_document_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:32:\"field_media_document_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_media_document_target_id\";a:1:{i:0;s:30:\"field_media_document_target_id\";}}s:12:\"foreign keys\";a:1:{s:30:\"field_media_document_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:30:\"field_media_document_target_id\";s:3:\"fid\";}}}}s:36:\"media_revision__field_media_document\";a:5:{s:11:\"description\";s:62:\"Revision archive storage for media field field_media_document.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_document_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:28:\"field_media_document_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:32:\"field_media_document_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_media_document_target_id\";a:1:{i:0;s:30:\"field_media_document_target_id\";}}s:12:\"foreign keys\";a:1:{s:30:\"field_media_document_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:30:\"field_media_document_target_id\";s:3:\"fid\";}}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.field_media_image',	'a:2:{s:24:\"media__field_media_image\";a:5:{s:11:\"description\";s:47:\"Data storage for media field field_media_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_media_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:21:\"field_media_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:23:\"field_media_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:23:\"field_media_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:24:\"field_media_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_media_image_target_id\";a:1:{i:0;s:27:\"field_media_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:27:\"field_media_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:27:\"field_media_image_target_id\";s:3:\"fid\";}}}}s:33:\"media_revision__field_media_image\";a:5:{s:11:\"description\";s:59:\"Revision archive storage for media field field_media_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_media_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:21:\"field_media_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:23:\"field_media_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:23:\"field_media_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:24:\"field_media_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_media_image_target_id\";a:1:{i:0;s:27:\"field_media_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:27:\"field_media_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:27:\"field_media_image_target_id\";s:3:\"fid\";}}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.field_media_oembed_video',	'a:2:{s:31:\"media__field_media_oembed_video\";a:4:{s:11:\"description\";s:54:\"Data storage for media field field_media_oembed_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_oembed_video_value\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:40:\"media_revision__field_media_oembed_video\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for media field field_media_oembed_video.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_media_oembed_video_value\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.field_media_video_file',	'a:2:{s:29:\"media__field_media_video_file\";a:5:{s:11:\"description\";s:52:\"Data storage for media field field_media_video_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_video_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_video_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_video_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_video_file_target_id\";a:1:{i:0;s:32:\"field_media_video_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_video_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_video_file_target_id\";s:3:\"fid\";}}}}s:38:\"media_revision__field_media_video_file\";a:5:{s:11:\"description\";s:64:\"Revision archive storage for media field field_media_video_file.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_media_video_file_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:30:\"field_media_video_file_display\";a:6:{s:11:\"description\";s:75:\"Flag to control whether this file should be displayed when viewing content.\";s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"unsigned\";b:1;s:7:\"default\";i:1;s:8:\"not null\";b:0;}s:34:\"field_media_video_file_description\";a:3:{s:11:\"description\";s:26:\"A description of the file.\";s:4:\"type\";s:4:\"text\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_media_video_file_target_id\";a:1:{i:0;s:32:\"field_media_video_file_target_id\";}}s:12:\"foreign keys\";a:1:{s:32:\"field_media_video_file_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:32:\"field_media_video_file_target_id\";s:3:\"fid\";}}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.langcode',	'a:4:{s:5:\"media\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.mid',	'a:4:{s:5:\"media\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"mid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.name',	'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.revision_created',	'a:1:{s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.revision_default',	'a:1:{s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.revision_log_message',	'a:1:{s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:20:\"revision_log_message\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.revision_translation_affected',	'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.revision_user',	'a:1:{s:14:\"media_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:37:\"media_field__revision_user__target_id\";a:1:{i:0;s:13:\"revision_user\";}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.status',	'a:2:{s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.thumbnail',	'a:2:{s:16:\"media_field_data\";a:3:{s:6:\"fields\";a:5:{s:20:\"thumbnail__target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:14:\"thumbnail__alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:16:\"thumbnail__title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:16:\"thumbnail__width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:17:\"thumbnail__height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:1:{i:0;s:20:\"thumbnail__target_id\";}}s:12:\"foreign keys\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:20:\"thumbnail__target_id\";s:3:\"fid\";}}}}s:20:\"media_field_revision\";a:3:{s:6:\"fields\";a:5:{s:20:\"thumbnail__target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:14:\"thumbnail__alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:16:\"thumbnail__title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:16:\"thumbnail__width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:17:\"thumbnail__height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:1:{i:0;s:20:\"thumbnail__target_id\";}}s:12:\"foreign keys\";a:1:{s:33:\"media_field__thumbnail__target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:20:\"thumbnail__target_id\";s:3:\"fid\";}}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.uid',	'a:2:{s:16:\"media_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"media_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}s:20:\"media_field_revision\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"media_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.uuid',	'a:1:{s:5:\"media\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:24:\"media_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'media.field_schema_data.vid',	'a:4:{s:5:\"media\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:16:\"media_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:14:\"media_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:20:\"media_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.entity_schema_data',	'a:4:{s:17:\"menu_link_content\";a:2:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:11:\"unique keys\";a:1:{s:30:\"menu_link_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:26:\"menu_link_content_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:21:\"menu_link_content__id\";a:1:{i:0;s:2:\"id\";}}}s:22:\"menu_link_content_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:49:\"menu_link_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:30:\"menu_link_content__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"menu_link_content__enabled_bundle\";a:3:{i:0;s:7:\"enabled\";i:1;s:6:\"bundle\";i:2;s:2:\"id\";}}}s:32:\"menu_link_content_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:49:\"menu_link_content__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.bundle',	'a:2:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"bundle\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.changed',	'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.default_langcode',	'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.description',	'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"description\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"description\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.enabled',	'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"enabled\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"enabled\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.expanded',	'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"expanded\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.external',	'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"external\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"external\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.id',	'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.langcode',	'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.link',	'a:2:{s:22:\"menu_link_content_data\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:34:\"menu_link_content_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}s:32:\"menu_link_content_field_revision\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:34:\"menu_link_content_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.menu_name',	'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"menu_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.parent',	'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"parent\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.rediscover',	'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:10:\"rediscover\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.revision_created',	'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.revision_default',	'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.revision_id',	'a:4:{s:17:\"menu_link_content\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.revision_log_message',	'a:1:{s:26:\"menu_link_content_revision\";a:1:{s:6:\"fields\";a:1:{s:20:\"revision_log_message\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.revision_translation_affected',	'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.revision_user',	'a:1:{s:26:\"menu_link_content_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:29:\"menu_link_content__ef029a1897\";a:1:{i:0;s:13:\"revision_user\";}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.title',	'a:2:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:32:\"menu_link_content_field_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.uuid',	'a:1:{s:17:\"menu_link_content\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:36:\"menu_link_content_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'menu_link_content.field_schema_data.weight',	'a:1:{s:22:\"menu_link_content_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'node.entity_schema_data',	'a:4:{s:4:\"node\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"nid\";}s:11:\"unique keys\";a:1:{s:9:\"node__vid\";a:1:{i:0;s:3:\"vid\";}}}s:13:\"node_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"vid\";}s:7:\"indexes\";a:1:{s:9:\"node__nid\";a:1:{i:0;s:3:\"nid\";}}}s:15:\"node_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"nid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:5:{s:36:\"node__id__default_langcode__langcode\";a:3:{i:0;s:3:\"nid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:9:\"node__vid\";a:1:{i:0;s:3:\"vid\";}s:17:\"node__status_type\";a:3:{i:0;s:6:\"status\";i:1;s:4:\"type\";i:2;s:3:\"nid\";}s:15:\"node__frontpage\";a:4:{i:0;s:7:\"promote\";i:1;s:6:\"status\";i:2;s:6:\"sticky\";i:3;s:7:\"created\";}s:16:\"node__title_type\";a:2:{i:0;s:5:\"title\";i:1;a:2:{i:0;s:4:\"type\";i:1;i:4;}}}}s:19:\"node_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"vid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:36:\"node__id__default_langcode__langcode\";a:3:{i:0;s:3:\"nid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.body',	'a:2:{s:10:\"node__body\";a:4:{s:11:\"description\";s:33:\"Data storage for node field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}s:19:\"node_revision__body\";a:4:{s:11:\"description\";s:45:\"Revision archive storage for node field body.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:10:\"body_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:12:\"body_summary\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:11:\"body_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:11:\"body_format\";a:1:{i:0;s:11:\"body_format\";}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.changed',	'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"node_field__changed\";a:1:{i:0;s:7:\"changed\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.created',	'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"node_field__created\";a:1:{i:0;s:7:\"created\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.default_langcode',	'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.field_image',	'a:2:{s:17:\"node__field_image\";a:5:{s:11:\"description\";s:40:\"Data storage for node field field_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:15:\"field_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:17:\"field_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:17:\"field_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:18:\"field_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_image_target_id\";a:1:{i:0;s:21:\"field_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:21:\"field_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:21:\"field_image_target_id\";s:3:\"fid\";}}}}s:26:\"node_revision__field_image\";a:5:{s:11:\"description\";s:52:\"Revision archive storage for node field field_image.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:21:\"field_image_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:15:\"field_image_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:17:\"field_image_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:17:\"field_image_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:18:\"field_image_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:21:\"field_image_target_id\";a:1:{i:0;s:21:\"field_image_target_id\";}}s:12:\"foreign keys\";a:1:{s:21:\"field_image_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:21:\"field_image_target_id\";s:3:\"fid\";}}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.field_metatags',	'a:2:{s:20:\"node__field_metatags\";a:4:{s:11:\"description\";s:43:\"Data storage for node field field_metatags.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_metatags_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:29:\"node_revision__field_metatags\";a:4:{s:11:\"description\";s:55:\"Revision archive storage for node field field_metatags.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_metatags_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.field_tags',	'a:2:{s:16:\"node__field_tags\";a:4:{s:11:\"description\";s:39:\"Data storage for node field field_tags.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_tags_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:20:\"field_tags_target_id\";a:1:{i:0;s:20:\"field_tags_target_id\";}}}s:25:\"node_revision__field_tags\";a:4:{s:11:\"description\";s:51:\"Revision archive storage for node field field_tags.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:20:\"field_tags_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:20:\"field_tags_target_id\";a:1:{i:0;s:20:\"field_tags_target_id\";}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.langcode',	'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:2:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:20:\"node_field__langcode\";a:1:{i:0;s:8:\"langcode\";}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.layout_builder__layout',	'a:2:{s:28:\"node__layout_builder__layout\";a:4:{s:11:\"description\";s:51:\"Data storage for node field layout_builder__layout.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"layout_builder__layout_section\";a:4:{s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:6:\"normal\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:37:\"node_revision__layout_builder__layout\";a:4:{s:11:\"description\";s:63:\"Revision archive storage for node field layout_builder__layout.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"layout_builder__layout_section\";a:4:{s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:6:\"normal\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.nid',	'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"nid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.promote',	'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"promote\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"promote\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.revision_default',	'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.revision_log',	'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:12:\"revision_log\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.revision_timestamp',	'a:1:{s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:18:\"revision_timestamp\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.revision_translation_affected',	'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.revision_uid',	'a:1:{s:13:\"node_revision\";a:3:{s:6:\"fields\";a:1:{s:12:\"revision_uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:35:\"node_field__revision_uid__target_id\";a:1:{i:0;s:12:\"revision_uid\";}}s:12:\"foreign keys\";a:1:{s:24:\"node_field__revision_uid\";a:2:{s:5:\"table\";s:5:\"users\";s:7:\"columns\";a:1:{s:12:\"revision_uid\";s:3:\"uid\";}}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.status',	'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.sticky',	'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"sticky\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"sticky\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.title',	'a:2:{s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.type',	'a:2:{s:4:\"node\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"node_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:27:\"node_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.uid',	'a:2:{s:15:\"node_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:26:\"node_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}s:19:\"node_field_revision\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:26:\"node_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.uuid',	'a:1:{s:4:\"node\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"node_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'node.field_schema_data.vid',	'a:4:{s:4:\"node\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:15:\"node_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:13:\"node_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"node_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'paragraph.entity_schema_data',	'a:4:{s:15:\"paragraphs_item\";a:2:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:11:\"unique keys\";a:1:{s:22:\"paragraph__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:24:\"paragraphs_item_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:13:\"paragraph__id\";a:1:{i:0;s:2:\"id\";}}}s:26:\"paragraphs_item_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:41:\"paragraph__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:22:\"paragraph__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"paragraph__status_type\";a:3:{i:0;s:6:\"status\";i:1;s:4:\"type\";i:2;s:2:\"id\";}s:25:\"paragraphs__parent_fields\";a:3:{i:0;s:11:\"parent_type\";i:1;s:9:\"parent_id\";i:2;s:17:\"parent_field_name\";}}}s:35:\"paragraphs_item_revision_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:41:\"paragraph__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:25:\"paragraphs__parent_fields\";a:3:{i:0;s:11:\"parent_type\";i:1;s:9:\"parent_id\";i:2;s:17:\"parent_field_name\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.behavior_settings',	'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"behavior_settings\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"behavior_settings\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.created',	'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.default_langcode',	'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_accordion_text',	'a:2:{s:35:\"paragraph__field_ebt_accordion_text\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ebt_accordion_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_accordion_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ebt_accordion_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_accordion_text_format\";a:1:{i:0;s:31:\"field_ebt_accordion_text_format\";}}}s:44:\"paragraph_revision__field_ebt_accordion_text\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ebt_accordion_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_accordion_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ebt_accordion_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_accordion_text_format\";a:1:{i:0;s:31:\"field_ebt_accordion_text_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_accordion_title',	'a:2:{s:36:\"paragraph__field_ebt_accordion_title\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ebt_accordion_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_accordion_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ebt_accordion_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_accordion_title_format\";a:1:{i:0;s:32:\"field_ebt_accordion_title_format\";}}}s:45:\"paragraph_revision__field_ebt_accordion_title\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ebt_accordion_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_accordion_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ebt_accordion_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_accordion_title_format\";a:1:{i:0;s:32:\"field_ebt_accordion_title_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_carousel_caption',	'a:2:{s:37:\"paragraph__field_ebt_carousel_caption\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ebt_carousel_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_carousel_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ebt_carousel_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ebt_carousel_caption_format\";a:1:{i:0;s:33:\"field_ebt_carousel_caption_format\";}}}s:46:\"paragraph_revision__field_ebt_carousel_caption\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ebt_carousel_caption.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_carousel_caption_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:33:\"field_ebt_carousel_caption_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:33:\"field_ebt_carousel_caption_format\";a:1:{i:0;s:33:\"field_ebt_carousel_caption_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_carousel_image',	'a:2:{s:35:\"paragraph__field_ebt_carousel_image\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ebt_carousel_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:34:\"field_ebt_carousel_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ebt_carousel_image_target_id\";a:1:{i:0;s:34:\"field_ebt_carousel_image_target_id\";}}}s:44:\"paragraph_revision__field_ebt_carousel_image\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ebt_carousel_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:34:\"field_ebt_carousel_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ebt_carousel_image_target_id\";a:1:{i:0;s:34:\"field_ebt_carousel_image_target_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_clickable_tile',	'a:2:{s:35:\"paragraph__field_ebt_clickable_tile\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ebt_clickable_tile.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_clickable_tile_value\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:44:\"paragraph_revision__field_ebt_clickable_tile\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ebt_clickable_tile.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_clickable_tile_value\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_counter_description',	'a:2:{s:40:\"paragraph__field_ebt_counter_description\";a:4:{s:11:\"description\";s:63:\"Data storage for paragraph field field_ebt_counter_description.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ebt_counter_description_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:36:\"field_ebt_counter_description_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ebt_counter_description_format\";a:1:{i:0;s:36:\"field_ebt_counter_description_format\";}}}s:23:\"paragraph_r__b013e92862\";a:4:{s:11:\"description\";s:75:\"Revision archive storage for paragraph field field_ebt_counter_description.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ebt_counter_description_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:36:\"field_ebt_counter_description_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:36:\"field_ebt_counter_description_format\";a:1:{i:0;s:36:\"field_ebt_counter_description_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_counter_icon',	'a:2:{s:33:\"paragraph__field_ebt_counter_icon\";a:4:{s:11:\"description\";s:56:\"Data storage for paragraph field field_ebt_counter_icon.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_counter_icon_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_counter_icon_target_id\";a:1:{i:0;s:32:\"field_ebt_counter_icon_target_id\";}}}s:42:\"paragraph_revision__field_ebt_counter_icon\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for paragraph field field_ebt_counter_icon.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_counter_icon_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_counter_icon_target_id\";a:1:{i:0;s:32:\"field_ebt_counter_icon_target_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_counter_number',	'a:2:{s:35:\"paragraph__field_ebt_counter_number\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ebt_counter_number.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_counter_number_value\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:44:\"paragraph_revision__field_ebt_counter_number\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ebt_counter_number.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_counter_number_value\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_counter_title',	'a:2:{s:34:\"paragraph__field_ebt_counter_title\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_ebt_counter_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_counter_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ebt_counter_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ebt_counter_title_format\";a:1:{i:0;s:30:\"field_ebt_counter_title_format\";}}}s:43:\"paragraph_revision__field_ebt_counter_title\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_ebt_counter_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_counter_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ebt_counter_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ebt_counter_title_format\";a:1:{i:0;s:30:\"field_ebt_counter_title_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_slick_slider_image',	'a:2:{s:39:\"paragraph__field_ebt_slick_slider_image\";a:4:{s:11:\"description\";s:62:\"Data storage for paragraph field field_ebt_slick_slider_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:38:\"field_ebt_slick_slider_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:38:\"field_ebt_slick_slider_image_target_id\";a:1:{i:0;s:38:\"field_ebt_slick_slider_image_target_id\";}}}s:48:\"paragraph_revision__field_ebt_slick_slider_image\";a:4:{s:11:\"description\";s:74:\"Revision archive storage for paragraph field field_ebt_slick_slider_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:38:\"field_ebt_slick_slider_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:38:\"field_ebt_slick_slider_image_target_id\";a:1:{i:0;s:38:\"field_ebt_slick_slider_image_target_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_slick_slider_link',	'a:2:{s:38:\"paragraph__field_ebt_slick_slider_link\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ebt_slick_slider_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_slick_slider_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ebt_slick_slider_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ebt_slick_slider_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_slick_slider_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ebt_slick_slider_link_uri\";i:1;i:30;}}}}s:47:\"paragraph_revision__field_ebt_slick_slider_link\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ebt_slick_slider_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_slick_slider_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:33:\"field_ebt_slick_slider_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:35:\"field_ebt_slick_slider_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_slick_slider_link_uri\";a:1:{i:0;a:2:{i:0;s:31:\"field_ebt_slick_slider_link_uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_slick_slider_text',	'a:2:{s:38:\"paragraph__field_ebt_slick_slider_text\";a:4:{s:11:\"description\";s:61:\"Data storage for paragraph field field_ebt_slick_slider_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ebt_slick_slider_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ebt_slick_slider_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ebt_slick_slider_text_format\";a:1:{i:0;s:34:\"field_ebt_slick_slider_text_format\";}}}s:47:\"paragraph_revision__field_ebt_slick_slider_text\";a:4:{s:11:\"description\";s:73:\"Revision archive storage for paragraph field field_ebt_slick_slider_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:33:\"field_ebt_slick_slider_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:34:\"field_ebt_slick_slider_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_ebt_slick_slider_text_format\";a:1:{i:0;s:34:\"field_ebt_slick_slider_text_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_slideshow_link',	'a:2:{s:35:\"paragraph__field_ebt_slideshow_link\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ebt_slideshow_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ebt_slideshow_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:30:\"field_ebt_slideshow_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:32:\"field_ebt_slideshow_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ebt_slideshow_link_uri\";a:1:{i:0;a:2:{i:0;s:28:\"field_ebt_slideshow_link_uri\";i:1;i:30;}}}}s:44:\"paragraph_revision__field_ebt_slideshow_link\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ebt_slideshow_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ebt_slideshow_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:30:\"field_ebt_slideshow_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:32:\"field_ebt_slideshow_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ebt_slideshow_link_uri\";a:1:{i:0;a:2:{i:0;s:28:\"field_ebt_slideshow_link_uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_slideshow_slide',	'a:2:{s:36:\"paragraph__field_ebt_slideshow_slide\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ebt_slideshow_slide.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ebt_slideshow_slide_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ebt_slideshow_slide_target_id\";a:1:{i:0;s:35:\"field_ebt_slideshow_slide_target_id\";}}}s:45:\"paragraph_revision__field_ebt_slideshow_slide\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ebt_slideshow_slide.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:35:\"field_ebt_slideshow_slide_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:35:\"field_ebt_slideshow_slide_target_id\";a:1:{i:0;s:35:\"field_ebt_slideshow_slide_target_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_slideshow_text',	'a:2:{s:35:\"paragraph__field_ebt_slideshow_text\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ebt_slideshow_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_slideshow_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ebt_slideshow_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_slideshow_text_format\";a:1:{i:0;s:31:\"field_ebt_slideshow_text_format\";}}}s:44:\"paragraph_revision__field_ebt_slideshow_text\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ebt_slideshow_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_slideshow_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:31:\"field_ebt_slideshow_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_slideshow_text_format\";a:1:{i:0;s:31:\"field_ebt_slideshow_text_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_slideshow_title',	'a:2:{s:36:\"paragraph__field_ebt_slideshow_title\";a:4:{s:11:\"description\";s:59:\"Data storage for paragraph field field_ebt_slideshow_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_slideshow_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ebt_slideshow_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_slideshow_title_format\";a:1:{i:0;s:32:\"field_ebt_slideshow_title_format\";}}}s:45:\"paragraph_revision__field_ebt_slideshow_title\";a:4:{s:11:\"description\";s:71:\"Revision archive storage for paragraph field field_ebt_slideshow_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_slideshow_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:32:\"field_ebt_slideshow_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_ebt_slideshow_title_format\";a:1:{i:0;s:32:\"field_ebt_slideshow_title_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_tab_block',	'a:2:{s:30:\"paragraph__field_ebt_tab_block\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ebt_tab_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_tab_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:28:\"field_ebt_tab_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_tab_block_plugin_id\";a:1:{i:0;s:29:\"field_ebt_tab_block_plugin_id\";}}}s:39:\"paragraph_revision__field_ebt_tab_block\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ebt_tab_block.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_tab_block_plugin_id\";a:4:{s:11:\"description\";s:19:\"The block plugin id\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:28:\"field_ebt_tab_block_settings\";a:5:{s:11:\"description\";s:43:\"Serialized array of settings for the block.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_tab_block_plugin_id\";a:1:{i:0;s:29:\"field_ebt_tab_block_plugin_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_tab_content',	'a:2:{s:32:\"paragraph__field_ebt_tab_content\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ebt_tab_content.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ebt_tab_content_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ebt_tab_content_value\";a:1:{i:0;s:27:\"field_ebt_tab_content_value\";}}}s:41:\"paragraph_revision__field_ebt_tab_content\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ebt_tab_content.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ebt_tab_content_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ebt_tab_content_value\";a:1:{i:0;s:27:\"field_ebt_tab_content_value\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_tab_page',	'a:2:{s:29:\"paragraph__field_ebt_tab_page\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ebt_tab_page.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ebt_tab_page_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ebt_tab_page_target_id\";a:1:{i:0;s:28:\"field_ebt_tab_page_target_id\";}}}s:38:\"paragraph_revision__field_ebt_tab_page\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ebt_tab_page.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:28:\"field_ebt_tab_page_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ebt_tab_page_target_id\";a:1:{i:0;s:28:\"field_ebt_tab_page_target_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_tab_text',	'a:2:{s:29:\"paragraph__field_ebt_tab_text\";a:4:{s:11:\"description\";s:52:\"Data storage for paragraph field field_ebt_tab_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ebt_tab_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:25:\"field_ebt_tab_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ebt_tab_text_format\";a:1:{i:0;s:25:\"field_ebt_tab_text_format\";}}}s:38:\"paragraph_revision__field_ebt_tab_text\";a:4:{s:11:\"description\";s:64:\"Revision archive storage for paragraph field field_ebt_tab_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ebt_tab_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:25:\"field_ebt_tab_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_ebt_tab_text_format\";a:1:{i:0;s:25:\"field_ebt_tab_text_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_tab_title',	'a:2:{s:30:\"paragraph__field_ebt_tab_title\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ebt_tab_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_tab_title_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1023;s:8:\"not null\";b:1;}s:26:\"field_ebt_tab_title_format\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_ebt_tab_title_format\";a:1:{i:0;s:26:\"field_ebt_tab_title_format\";}}}s:39:\"paragraph_revision__field_ebt_tab_title\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ebt_tab_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_ebt_tab_title_value\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1023;s:8:\"not null\";b:1;}s:26:\"field_ebt_tab_title_format\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:26:\"field_ebt_tab_title_format\";a:1:{i:0;s:26:\"field_ebt_tab_title_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_tab_views',	'a:2:{s:30:\"paragraph__field_ebt_tab_views\";a:4:{s:11:\"description\";s:53:\"Data storage for paragraph field field_ebt_tab_views.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_tab_views_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ebt_tab_views_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:24:\"field_ebt_tab_views_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_tab_views_target_id\";a:1:{i:0;s:29:\"field_ebt_tab_views_target_id\";}s:30:\"field_ebt_tab_views_display_id\";a:1:{i:0;s:30:\"field_ebt_tab_views_display_id\";}}}s:39:\"paragraph_revision__field_ebt_tab_views\";a:4:{s:11:\"description\";s:65:\"Revision archive storage for paragraph field field_ebt_tab_views.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_tab_views_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}s:30:\"field_ebt_tab_views_display_id\";a:4:{s:11:\"description\";s:22:\"The ID of the display.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:24:\"field_ebt_tab_views_data\";a:4:{s:11:\"description\";s:16:\"Serialized data.\";s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:4:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:29:\"field_ebt_tab_views_target_id\";a:1:{i:0;s:29:\"field_ebt_tab_views_target_id\";}s:30:\"field_ebt_tab_views_display_id\";a:1:{i:0;s:30:\"field_ebt_tab_views_display_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_tiles_image',	'a:2:{s:32:\"paragraph__field_ebt_tiles_image\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ebt_tiles_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_tiles_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_tiles_image_target_id\";a:1:{i:0;s:31:\"field_ebt_tiles_image_target_id\";}}}s:41:\"paragraph_revision__field_ebt_tiles_image\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ebt_tiles_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:31:\"field_ebt_tiles_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:31:\"field_ebt_tiles_image_target_id\";a:1:{i:0;s:31:\"field_ebt_tiles_image_target_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_tiles_link',	'a:2:{s:31:\"paragraph__field_ebt_tiles_link\";a:4:{s:11:\"description\";s:54:\"Data storage for paragraph field field_ebt_tiles_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ebt_tiles_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ebt_tiles_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ebt_tiles_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ebt_tiles_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ebt_tiles_link_uri\";i:1;i:30;}}}}s:40:\"paragraph_revision__field_ebt_tiles_link\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for paragraph field field_ebt_tiles_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:24:\"field_ebt_tiles_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:26:\"field_ebt_tiles_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:28:\"field_ebt_tiles_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:24:\"field_ebt_tiles_link_uri\";a:1:{i:0;a:2:{i:0;s:24:\"field_ebt_tiles_link_uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_tiles_text',	'a:2:{s:31:\"paragraph__field_ebt_tiles_text\";a:4:{s:11:\"description\";s:54:\"Data storage for paragraph field field_ebt_tiles_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_ebt_tiles_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:27:\"field_ebt_tiles_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ebt_tiles_text_format\";a:1:{i:0;s:27:\"field_ebt_tiles_text_format\";}}}s:40:\"paragraph_revision__field_ebt_tiles_text\";a:4:{s:11:\"description\";s:66:\"Revision archive storage for paragraph field field_ebt_tiles_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:26:\"field_ebt_tiles_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:27:\"field_ebt_tiles_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:27:\"field_ebt_tiles_text_format\";a:1:{i:0;s:27:\"field_ebt_tiles_text_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_tiles_title',	'a:2:{s:32:\"paragraph__field_ebt_tiles_title\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_ebt_tiles_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ebt_tiles_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:28:\"field_ebt_tiles_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ebt_tiles_title_format\";a:1:{i:0;s:28:\"field_ebt_tiles_title_format\";}}}s:41:\"paragraph_revision__field_ebt_tiles_title\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_ebt_tiles_title.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_ebt_tiles_title_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:28:\"field_ebt_tiles_title_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_ebt_tiles_title_format\";a:1:{i:0;s:28:\"field_ebt_tiles_title_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_timeline_current',	'a:2:{s:37:\"paragraph__field_ebt_timeline_current\";a:4:{s:11:\"description\";s:60:\"Data storage for paragraph field field_ebt_timeline_current.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_timeline_current_value\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:46:\"paragraph_revision__field_ebt_timeline_current\";a:4:{s:11:\"description\";s:72:\"Revision archive storage for paragraph field field_ebt_timeline_current.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_ebt_timeline_current_value\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_timeline_date',	'a:2:{s:34:\"paragraph__field_ebt_timeline_date\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_ebt_timeline_date.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_timeline_date_value\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:43:\"paragraph_revision__field_ebt_timeline_date\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_ebt_timeline_date.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_timeline_date_value\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_timeline_media_image',	'a:2:{s:41:\"paragraph__field_ebt_timeline_media_image\";a:4:{s:11:\"description\";s:64:\"Data storage for paragraph field field_ebt_timeline_media_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:40:\"field_ebt_timeline_media_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:40:\"field_ebt_timeline_media_image_target_id\";a:1:{i:0;s:40:\"field_ebt_timeline_media_image_target_id\";}}}s:23:\"paragraph_r__183d076c00\";a:4:{s:11:\"description\";s:76:\"Revision archive storage for paragraph field field_ebt_timeline_media_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:40:\"field_ebt_timeline_media_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:40:\"field_ebt_timeline_media_image_target_id\";a:1:{i:0;s:40:\"field_ebt_timeline_media_image_target_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_timeline_text',	'a:2:{s:34:\"paragraph__field_ebt_timeline_text\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_ebt_timeline_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_timeline_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ebt_timeline_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ebt_timeline_text_format\";a:1:{i:0;s:30:\"field_ebt_timeline_text_format\";}}}s:43:\"paragraph_revision__field_ebt_timeline_text\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_ebt_timeline_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_ebt_timeline_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_ebt_timeline_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_ebt_timeline_text_format\";a:1:{i:0;s:30:\"field_ebt_timeline_text_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_ebt_timeline_title',	'a:2:{s:35:\"paragraph__field_ebt_timeline_title\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_ebt_timeline_title.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_timeline_title_value\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:44:\"paragraph_revision__field_ebt_timeline_title\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_ebt_timeline_title.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:30:\"field_ebt_timeline_title_value\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:2:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_gallery_item_description',	'a:2:{s:41:\"paragraph__field_gallery_item_description\";a:4:{s:11:\"description\";s:64:\"Data storage for paragraph field field_gallery_item_description.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_gallery_item_description_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:37:\"field_gallery_item_description_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_gallery_item_description_format\";a:1:{i:0;s:37:\"field_gallery_item_description_format\";}}}s:23:\"paragraph_r__39b26fa753\";a:4:{s:11:\"description\";s:76:\"Revision archive storage for paragraph field field_gallery_item_description.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:36:\"field_gallery_item_description_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:37:\"field_gallery_item_description_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:37:\"field_gallery_item_description_format\";a:1:{i:0;s:37:\"field_gallery_item_description_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_stats_item_image',	'a:2:{s:33:\"paragraph__field_stats_item_image\";a:4:{s:11:\"description\";s:56:\"Data storage for paragraph field field_stats_item_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_stats_item_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_stats_item_image_target_id\";a:1:{i:0;s:32:\"field_stats_item_image_target_id\";}}}s:42:\"paragraph_revision__field_stats_item_image\";a:4:{s:11:\"description\";s:68:\"Revision archive storage for paragraph field field_stats_item_image.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:32:\"field_stats_item_image_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:32:\"field_stats_item_image_target_id\";a:1:{i:0;s:32:\"field_stats_item_image_target_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_stats_item_link',	'a:2:{s:32:\"paragraph__field_stats_item_link\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_stats_item_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_stats_item_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:27:\"field_stats_item_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:29:\"field_stats_item_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_stats_item_link_uri\";a:1:{i:0;a:2:{i:0;s:25:\"field_stats_item_link_uri\";i:1;i:30;}}}}s:41:\"paragraph_revision__field_stats_item_link\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_stats_item_link.\";s:6:\"fields\";a:9:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:25:\"field_stats_item_link_uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:27:\"field_stats_item_link_title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:29:\"field_stats_item_link_options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"field_stats_item_link_uri\";a:1:{i:0;a:2:{i:0;s:25:\"field_stats_item_link_uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_stats_item_number',	'a:2:{s:34:\"paragraph__field_stats_item_number\";a:4:{s:11:\"description\";s:57:\"Data storage for paragraph field field_stats_item_number.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_stats_item_number_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_stats_item_number_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_stats_item_number_format\";a:1:{i:0;s:30:\"field_stats_item_number_format\";}}}s:43:\"paragraph_revision__field_stats_item_number\";a:4:{s:11:\"description\";s:69:\"Revision archive storage for paragraph field field_stats_item_number.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:29:\"field_stats_item_number_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:30:\"field_stats_item_number_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:30:\"field_stats_item_number_format\";a:1:{i:0;s:30:\"field_stats_item_number_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_stats_item_text',	'a:2:{s:32:\"paragraph__field_stats_item_text\";a:4:{s:11:\"description\";s:55:\"Data storage for paragraph field field_stats_item_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_stats_item_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:28:\"field_stats_item_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_stats_item_text_format\";a:1:{i:0;s:28:\"field_stats_item_text_format\";}}}s:41:\"paragraph_revision__field_stats_item_text\";a:4:{s:11:\"description\";s:67:\"Revision archive storage for paragraph field field_stats_item_text.\";s:6:\"fields\";a:8:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:27:\"field_stats_item_text_value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:1;}s:28:\"field_stats_item_text_format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:28:\"field_stats_item_text_format\";a:1:{i:0;s:28:\"field_stats_item_text_format\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.field_video_gallery_item',	'a:2:{s:35:\"paragraph__field_video_gallery_item\";a:4:{s:11:\"description\";s:58:\"Data storage for paragraph field field_video_gallery_item.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:34:\"field_video_gallery_item_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_video_gallery_item_target_id\";a:1:{i:0;s:34:\"field_video_gallery_item_target_id\";}}}s:44:\"paragraph_revision__field_video_gallery_item\";a:4:{s:11:\"description\";s:70:\"Revision archive storage for paragraph field field_video_gallery_item.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:34:\"field_video_gallery_item_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:34:\"field_video_gallery_item_target_id\";a:1:{i:0;s:34:\"field_video_gallery_item_target_id\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.id',	'a:4:{s:15:\"paragraphs_item\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.langcode',	'a:4:{s:15:\"paragraphs_item\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.parent_field_name',	'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"parent_field_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:17:\"parent_field_name\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.parent_id',	'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"parent_id\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:9:\"parent_id\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.parent_type',	'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"parent_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"parent_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.revision_default',	'a:1:{s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.revision_id',	'a:4:{s:15:\"paragraphs_item\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"paragraphs_item_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.revision_translation_affected',	'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.status',	'a:2:{s:26:\"paragraphs_item_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:35:\"paragraphs_item_revision_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.type',	'a:2:{s:15:\"paragraphs_item\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:32:\"paragraph_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}s:26:\"paragraphs_item_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:32:\"paragraph_field__type__target_id\";a:1:{i:0;s:4:\"type\";}}}}'),
('entity.storage_schema.sql',	'paragraph.field_schema_data.uuid',	'a:1:{s:15:\"paragraphs_item\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:28:\"paragraph_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'path_alias.entity_schema_data',	'a:2:{s:10:\"path_alias\";a:3:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}s:7:\"indexes\";a:2:{s:36:\"path_alias__alias_langcode_id_status\";a:4:{i:0;s:5:\"alias\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}s:35:\"path_alias__path_langcode_id_status\";a:4:{i:0;s:4:\"path\";i:1;s:8:\"langcode\";i:2;s:2:\"id\";i:3;s:6:\"status\";}}s:11:\"unique keys\";a:1:{s:23:\"path_alias__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:19:\"path_alias_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:14:\"path_alias__id\";a:1:{i:0;s:2:\"id\";}}}}'),
('entity.storage_schema.sql',	'path_alias.field_schema_data.alias',	'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:5:\"alias\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:5:\"alias\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'path_alias.field_schema_data.id',	'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'path_alias.field_schema_data.langcode',	'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'path_alias.field_schema_data.path',	'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:4:\"path\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"path\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'path_alias.field_schema_data.revision_default',	'a:1:{s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'path_alias.field_schema_data.revision_id',	'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'path_alias.field_schema_data.status',	'a:2:{s:10:\"path_alias\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:19:\"path_alias_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'path_alias.field_schema_data.uuid',	'a:1:{s:10:\"path_alias\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:29:\"path_alias_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'redirect.entity_schema_data',	'a:1:{s:8:\"redirect\";a:3:{s:11:\"primary key\";a:1:{i:0;s:3:\"rid\";}s:7:\"indexes\";a:1:{s:15:\"source_language\";a:2:{i:0;a:2:{i:0;s:21:\"redirect_source__path\";i:1;i:191;}i:1;s:8:\"language\";}}s:11:\"unique keys\";a:1:{s:4:\"hash\";a:1:{i:0;s:4:\"hash\";}}}}'),
('entity.storage_schema.sql',	'redirect.field_schema_data.created',	'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'redirect.field_schema_data.hash',	'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:4:\"hash\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:64;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}');
INSERT INTO `key_value` (`collection`, `name`, `value`) VALUES
('entity.storage_schema.sql',	'redirect.field_schema_data.language',	'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:8:\"language\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'redirect.field_schema_data.redirect_redirect',	'a:1:{s:8:\"redirect\";a:2:{s:6:\"fields\";a:3:{s:22:\"redirect_redirect__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:24:\"redirect_redirect__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:26:\"redirect_redirect__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:38:\"redirect_field__redirect_redirect__uri\";a:1:{i:0;a:2:{i:0;s:22:\"redirect_redirect__uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'redirect.field_schema_data.redirect_source',	'a:1:{s:8:\"redirect\";a:2:{s:6:\"fields\";a:2:{s:21:\"redirect_source__path\";a:4:{s:11:\"description\";s:15:\"The source path\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:22:\"redirect_source__query\";a:5:{s:11:\"description\";s:32:\"Serialized array of path queries\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:37:\"redirect_field__redirect_source__path\";a:1:{i:0;a:2:{i:0;s:21:\"redirect_source__path\";i:1;i:50;}}}}}'),
('entity.storage_schema.sql',	'redirect.field_schema_data.rid',	'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:3:\"rid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'redirect.field_schema_data.status_code',	'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:11:\"status_code\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'redirect.field_schema_data.type',	'a:1:{s:8:\"redirect\";a:1:{s:6:\"fields\";a:1:{s:4:\"type\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'redirect.field_schema_data.uid',	'a:1:{s:8:\"redirect\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:30:\"redirect_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),
('entity.storage_schema.sql',	'redirect.field_schema_data.uuid',	'a:1:{s:8:\"redirect\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:27:\"redirect_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'shortcut.entity_schema_data',	'a:2:{s:8:\"shortcut\";a:1:{s:11:\"primary key\";a:1:{i:0;s:2:\"id\";}}s:19:\"shortcut_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:2:\"id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:40:\"shortcut__id__default_langcode__langcode\";a:3:{i:0;s:2:\"id\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}}'),
('entity.storage_schema.sql',	'shortcut.field_schema_data.default_langcode',	'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'shortcut.field_schema_data.id',	'a:2:{s:8:\"shortcut\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:2:\"id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'shortcut.field_schema_data.langcode',	'a:2:{s:8:\"shortcut\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'shortcut.field_schema_data.link',	'a:1:{s:19:\"shortcut_field_data\";a:2:{s:6:\"fields\";a:3:{s:9:\"link__uri\";a:4:{s:11:\"description\";s:20:\"The URI of the link.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2048;s:8:\"not null\";b:0;}s:11:\"link__title\";a:4:{s:11:\"description\";s:14:\"The link text.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}s:13:\"link__options\";a:5:{s:11:\"description\";s:41:\"Serialized array of options for the link.\";s:4:\"type\";s:4:\"blob\";s:4:\"size\";s:3:\"big\";s:9:\"serialize\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:25:\"shortcut_field__link__uri\";a:1:{i:0;a:2:{i:0;s:9:\"link__uri\";i:1;i:30;}}}}}'),
('entity.storage_schema.sql',	'shortcut.field_schema_data.shortcut_set',	'a:2:{s:8:\"shortcut\";a:2:{s:6:\"fields\";a:1:{s:12:\"shortcut_set\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:39:\"shortcut_field__shortcut_set__target_id\";a:1:{i:0;s:12:\"shortcut_set\";}}}s:19:\"shortcut_field_data\";a:2:{s:6:\"fields\";a:1:{s:12:\"shortcut_set\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:39:\"shortcut_field__shortcut_set__target_id\";a:1:{i:0;s:12:\"shortcut_set\";}}}}'),
('entity.storage_schema.sql',	'shortcut.field_schema_data.title',	'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"title\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'shortcut.field_schema_data.uuid',	'a:1:{s:8:\"shortcut\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:27:\"shortcut_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'shortcut.field_schema_data.weight',	'a:1:{s:19:\"shortcut_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.entity_schema_data',	'a:5:{s:18:\"taxonomy_term_data\";a:2:{s:11:\"primary key\";a:1:{i:0;s:3:\"tid\";}s:11:\"unique keys\";a:1:{s:26:\"taxonomy_term__revision_id\";a:1:{i:0;s:11:\"revision_id\";}}}s:22:\"taxonomy_term_revision\";a:2:{s:11:\"primary key\";a:1:{i:0;s:11:\"revision_id\";}s:7:\"indexes\";a:1:{s:18:\"taxonomy_term__tid\";a:1:{i:0;s:3:\"tid\";}}}s:24:\"taxonomy_term_field_data\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"tid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:5:{s:45:\"taxonomy_term__id__default_langcode__langcode\";a:3:{i:0;s:3:\"tid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}s:26:\"taxonomy_term__revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:25:\"taxonomy_term__status_vid\";a:3:{i:0;s:6:\"status\";i:1;s:3:\"vid\";i:2;s:3:\"tid\";}s:19:\"taxonomy_term__tree\";a:3:{i:0;s:3:\"vid\";i:1;s:6:\"weight\";i:2;s:4:\"name\";}s:23:\"taxonomy_term__vid_name\";a:2:{i:0;s:3:\"vid\";i:1;s:4:\"name\";}}}s:28:\"taxonomy_term_field_revision\";a:2:{s:11:\"primary key\";a:2:{i:0;s:11:\"revision_id\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:45:\"taxonomy_term__id__default_langcode__langcode\";a:3:{i:0;s:3:\"tid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}}s:14:\"taxonomy_index\";a:2:{s:11:\"primary key\";a:2:{i:0;s:3:\"nid\";i:1;s:3:\"tid\";}s:7:\"indexes\";a:1:{s:9:\"term_node\";a:4:{i:0;s:3:\"tid\";i:1;s:6:\"status\";i:2;s:6:\"sticky\";i:3;s:7:\"created\";}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.changed',	'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.default_langcode',	'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.description',	'a:2:{s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:2:{s:18:\"description__value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:19:\"description__format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:0:{}}s:28:\"taxonomy_term_field_revision\";a:2:{s:6:\"fields\";a:2:{s:18:\"description__value\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}s:19:\"description__format\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:40:\"taxonomy_term_field__description__format\";a:1:{i:0;s:19:\"description__format\";}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.langcode',	'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.name',	'a:2:{s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:25:\"taxonomy_term_field__name\";a:1:{i:0;s:4:\"name\";}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.parent',	'a:2:{s:21:\"taxonomy_term__parent\";a:4:{s:11:\"description\";s:44:\"Data storage for taxonomy_term field parent.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:16:\"parent_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:16:\"parent_target_id\";a:1:{i:0;s:16:\"parent_target_id\";}s:22:\"bundle_delta_target_id\";a:3:{i:0;s:6:\"bundle\";i:1;s:5:\"delta\";i:2;s:16:\"parent_target_id\";}}}s:30:\"taxonomy_term_revision__parent\";a:4:{s:11:\"description\";s:56:\"Revision archive storage for taxonomy_term field parent.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:47:\"The entity revision id this data is attached to\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:16:\"parent_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:5:{i:0;s:9:\"entity_id\";i:1;s:11:\"revision_id\";i:2;s:7:\"deleted\";i:3;s:5:\"delta\";i:4;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:16:\"parent_target_id\";a:1:{i:0;s:16:\"parent_target_id\";}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.revision_created',	'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.revision_default',	'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:16:\"revision_default\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.revision_id',	'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.revision_log_message',	'a:1:{s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:20:\"revision_log_message\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.revision_translation_affected',	'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:29:\"revision_translation_affected\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.revision_user',	'a:1:{s:22:\"taxonomy_term_revision\";a:2:{s:6:\"fields\";a:1:{s:13:\"revision_user\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:45:\"taxonomy_term_field__revision_user__target_id\";a:1:{i:0;s:13:\"revision_user\";}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.status',	'a:2:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.tid',	'a:4:{s:18:\"taxonomy_term_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:22:\"taxonomy_term_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:28:\"taxonomy_term_field_revision\";a:1:{s:6:\"fields\";a:1:{s:3:\"tid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.uuid',	'a:1:{s:18:\"taxonomy_term_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:32:\"taxonomy_term_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.vid',	'a:2:{s:18:\"taxonomy_term_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:35:\"taxonomy_term_field__vid__target_id\";a:1:{i:0;s:3:\"vid\";}}}s:24:\"taxonomy_term_field_data\";a:2:{s:6:\"fields\";a:1:{s:3:\"vid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:0:{}}}'),
('entity.storage_schema.sql',	'taxonomy_term.field_schema_data.weight',	'a:1:{s:24:\"taxonomy_term_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"weight\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'user.entity_schema_data',	'a:2:{s:5:\"users\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"uid\";}}s:16:\"users_field_data\";a:3:{s:11:\"primary key\";a:2:{i:0;s:3:\"uid\";i:1;s:8:\"langcode\";}s:7:\"indexes\";a:1:{s:36:\"user__id__default_langcode__langcode\";a:3:{i:0;s:3:\"uid\";i:1;s:16:\"default_langcode\";i:2;s:8:\"langcode\";}}s:11:\"unique keys\";a:1:{s:10:\"user__name\";a:2:{i:0;s:4:\"name\";i:1;s:8:\"langcode\";}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.access',	'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:6:\"access\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:18:\"user_field__access\";a:1:{i:0;s:6:\"access\";}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.changed',	'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.created',	'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:19:\"user_field__created\";a:1:{i:0;s:7:\"created\";}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.default_langcode',	'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:16:\"default_langcode\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.init',	'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"init\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.langcode',	'a:2:{s:5:\"users\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.login',	'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:5:\"login\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.mail',	'a:1:{s:16:\"users_field_data\";a:2:{s:6:\"fields\";a:1:{s:4:\"mail\";a:3:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:254;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:16:\"user_field__mail\";a:1:{i:0;s:4:\"mail\";}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.name',	'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"name\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:60;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.pass',	'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:4:\"pass\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.preferred_admin_langcode',	'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:24:\"preferred_admin_langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.preferred_langcode',	'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:18:\"preferred_langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.roles',	'a:1:{s:11:\"user__roles\";a:4:{s:11:\"description\";s:34:\"Data storage for user field roles.\";s:6:\"fields\";a:7:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:114:\"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:15:\"roles_target_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:255;s:8:\"not null\";b:1;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:15:\"roles_target_id\";a:1:{i:0;s:15:\"roles_target_id\";}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.status',	'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:6:\"status\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.timezone',	'a:1:{s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:8:\"timezone\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.uid',	'a:2:{s:5:\"users\";a:1:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}s:16:\"users_field_data\";a:1:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.user_picture',	'a:1:{s:18:\"user__user_picture\";a:5:{s:11:\"description\";s:41:\"Data storage for user field user_picture.\";s:6:\"fields\";a:11:{s:6:\"bundle\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:88:\"The field instance bundle to which this row belongs, used when deleting a field instance\";}s:7:\"deleted\";a:5:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:1;s:7:\"default\";i:0;s:11:\"description\";s:60:\"A boolean indicating whether this data item has been deleted\";}s:9:\"entity_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:38:\"The entity id this data is attached to\";}s:11:\"revision_id\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:114:\"The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id\";}s:8:\"langcode\";a:5:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;s:7:\"default\";s:0:\"\";s:11:\"description\";s:37:\"The language code for this data item.\";}s:5:\"delta\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;s:11:\"description\";s:67:\"The sequence number for this data item, used for multi-value fields\";}s:22:\"user_picture_target_id\";a:4:{s:11:\"description\";s:26:\"The ID of the file entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:1;}s:16:\"user_picture_alt\";a:4:{s:11:\"description\";s:56:\"Alternative image text, for the image\'s \'alt\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:512;s:8:\"not null\";b:0;}s:18:\"user_picture_title\";a:4:{s:11:\"description\";s:52:\"Image title text, for the image\'s \'title\' attribute.\";s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:1024;s:8:\"not null\";b:0;}s:18:\"user_picture_width\";a:4:{s:11:\"description\";s:33:\"The width of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}s:19:\"user_picture_height\";a:4:{s:11:\"description\";s:34:\"The height of the image in pixels.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:11:\"primary key\";a:4:{i:0;s:9:\"entity_id\";i:1;s:7:\"deleted\";i:2;s:5:\"delta\";i:3;s:8:\"langcode\";}s:7:\"indexes\";a:3:{s:6:\"bundle\";a:1:{i:0;s:6:\"bundle\";}s:11:\"revision_id\";a:1:{i:0;s:11:\"revision_id\";}s:22:\"user_picture_target_id\";a:1:{i:0;s:22:\"user_picture_target_id\";}}s:12:\"foreign keys\";a:1:{s:22:\"user_picture_target_id\";a:2:{s:5:\"table\";s:12:\"file_managed\";s:7:\"columns\";a:1:{s:22:\"user_picture_target_id\";s:3:\"fid\";}}}}}'),
('entity.storage_schema.sql',	'user.field_schema_data.uuid',	'a:1:{s:5:\"users\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:23:\"user_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'webform_submission.entity_schema_data',	'a:2:{s:18:\"webform_submission\";a:1:{s:11:\"primary key\";a:1:{i:0;s:3:\"sid\";}}s:23:\"webform_submission_data\";a:2:{s:11:\"primary key\";a:4:{i:0;s:3:\"sid\";i:1;s:4:\"name\";i:2;s:8:\"property\";i:3;s:5:\"delta\";}s:7:\"indexes\";a:2:{s:10:\"webform_id\";a:1:{i:0;s:10:\"webform_id\";}s:14:\"sid_webform_id\";a:2:{i:0;s:3:\"sid\";i:1;s:10:\"webform_id\";}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.changed',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:7:\"changed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.completed',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:9:\"completed\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.created',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:7:\"created\";a:2:{s:4:\"type\";s:3:\"int\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.current_page',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:12:\"current_page\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.entity_id',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:9:\"entity_id\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.entity_type',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:11:\"entity_type\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.in_draft',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:8:\"in_draft\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.langcode',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:8:\"langcode\";a:3:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:12;s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.locked',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:6:\"locked\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.notes',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:5:\"notes\";a:3:{s:4:\"type\";s:4:\"text\";s:4:\"size\";s:3:\"big\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.remote_addr',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:11:\"remote_addr\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.serial',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:6:\"serial\";a:4:{s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.sid',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:3:\"sid\";a:4:{s:4:\"type\";s:6:\"serial\";s:8:\"unsigned\";b:0;s:4:\"size\";s:6:\"normal\";s:8:\"not null\";b:1;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.sticky',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:6:\"sticky\";a:3:{s:4:\"type\";s:3:\"int\";s:4:\"size\";s:4:\"tiny\";s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.token',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:5:\"token\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:255;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.uid',	'a:1:{s:18:\"webform_submission\";a:2:{s:6:\"fields\";a:1:{s:3:\"uid\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:3:\"int\";s:8:\"unsigned\";b:1;s:8:\"not null\";b:0;}}s:7:\"indexes\";a:1:{s:40:\"webform_submission_field__uid__target_id\";a:1:{i:0;s:3:\"uid\";}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.uri',	'a:1:{s:18:\"webform_submission\";a:1:{s:6:\"fields\";a:1:{s:3:\"uri\";a:4:{s:4:\"type\";s:7:\"varchar\";s:6:\"length\";i:2000;s:6:\"binary\";b:0;s:8:\"not null\";b:0;}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.uuid',	'a:1:{s:18:\"webform_submission\";a:2:{s:6:\"fields\";a:1:{s:4:\"uuid\";a:4:{s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:128;s:6:\"binary\";b:0;s:8:\"not null\";b:1;}}s:11:\"unique keys\";a:1:{s:37:\"webform_submission_field__uuid__value\";a:1:{i:0;s:4:\"uuid\";}}}}'),
('entity.storage_schema.sql',	'webform_submission.field_schema_data.webform_id',	'a:1:{s:18:\"webform_submission\";a:2:{s:6:\"fields\";a:1:{s:10:\"webform_id\";a:4:{s:11:\"description\";s:28:\"The ID of the target entity.\";s:4:\"type\";s:13:\"varchar_ascii\";s:6:\"length\";i:32;s:8:\"not null\";b:1;}}s:7:\"indexes\";a:1:{s:47:\"webform_submission_field__webform_id__target_id\";a:1:{i:0;s:10:\"webform_id\";}}}}'),
('entity_autocomplete',	'8yzn97uC9KH-TSHD6GZC_uhMG3G29migMmjdSWpN_dw',	'a:5:{s:14:\"target_bundles\";a:1:{s:4:\"tags\";s:4:\"tags\";}s:4:\"sort\";a:1:{s:5:\"field\";s:5:\"_none\";}s:11:\"auto_create\";b:1;s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),
('entity_autocomplete',	'WWJkBRqrwy_M8tCGsTVfMhBwrlzcfFgdSFCGP44G6-s',	'a:2:{s:14:\"match_operator\";s:8:\"CONTAINS\";s:11:\"match_limit\";i:10;}'),
('pathauto_state.node',	'1',	'i:0;'),
('post_update',	'existing_updates',	'a:210:{i:0;s:54:\"system_post_update_add_description_to_entity_form_mode\";i:1;s:54:\"system_post_update_add_description_to_entity_view_mode\";i:2;s:58:\"system_post_update_add_langcode_to_all_translatable_config\";i:3;s:47:\"system_post_update_amend_config_sync_readme_url\";i:4;s:70:\"system_post_update_convert_empty_country_and_timezone_settings_to_null\";i:5;s:48:\"system_post_update_enable_password_compatibility\";i:6;s:35:\"system_post_update_linkset_settings\";i:7;s:44:\"system_post_update_mail_notification_setting\";i:8;s:38:\"system_post_update_mailer_dsn_settings\";i:9;s:49:\"system_post_update_mailer_structured_dsn_settings\";i:10;s:56:\"system_post_update_move_development_settings_to_keyvalue\";i:11;s:39:\"system_post_update_remove_asset_entries\";i:12;s:44:\"system_post_update_remove_asset_query_string\";i:13;s:44:\"system_post_update_set_blank_log_url_to_null\";i:14;s:54:\"system_post_update_set_cron_logging_setting_to_boolean\";i:15;s:38:\"system_post_update_timestamp_formatter\";i:16;s:64:\"system_post_update_recalculate_configuration_entity_dependencies\";i:17;s:48:\"system_post_update_add_region_to_entity_displays\";i:18;s:37:\"system_post_update_hashes_clear_cache\";i:19;s:36:\"system_post_update_timestamp_plugins\";i:20;s:41:\"system_post_update_classy_message_library\";i:21;s:37:\"system_post_update_field_type_plugins\";i:22;s:48:\"system_post_update_field_formatter_entity_schema\";i:23;s:36:\"system_post_update_fix_jquery_extend\";i:24;s:40:\"system_post_update_change_action_plugins\";i:25;s:47:\"system_post_update_change_delete_action_plugins\";i:26;s:41:\"system_post_update_language_item_callback\";i:27;s:31:\"system_post_update_extra_fields\";i:28;s:37:\"system_post_update_states_clear_cache\";i:29;s:64:\"system_post_update_add_expand_all_items_key_in_system_menu_block\";i:30;s:35:\"system_post_update_clear_menu_cache\";i:31;s:46:\"system_post_update_layout_plugin_schema_change\";i:32;s:60:\"system_post_update_entity_reference_autocomplete_match_limit\";i:33;s:44:\"system_post_update_extra_fields_form_display\";i:34;s:39:\"system_post_update_uninstall_simpletest\";i:35;s:52:\"system_post_update_uninstall_entity_reference_module\";i:36;s:54:\"system_post_update_entity_revision_metadata_bc_cleanup\";i:37;s:35:\"system_post_update_uninstall_classy\";i:38;s:35:\"system_post_update_uninstall_stable\";i:39;s:44:\"system_post_update_claro_dropbutton_variants\";i:40;s:37:\"system_post_update_schema_version_int\";i:41;s:38:\"system_post_update_delete_rss_settings\";i:42;s:52:\"system_post_update_remove_key_value_expire_all_index\";i:43;s:44:\"system_post_update_service_advisory_settings\";i:44;s:44:\"system_post_update_delete_authorize_settings\";i:45;s:34:\"system_post_update_sort_all_config\";i:46;s:50:\"system_post_update_enable_provider_database_driver\";i:47;s:33:\"user_post_update_sort_permissions\";i:48;s:39:\"user_post_update_sort_permissions_again\";i:49;s:45:\"user_post_update_enforce_order_of_permissions\";i:50;s:29:\"user_post_update_update_roles\";i:51;s:51:\"path_alias_post_update_drop_path_alias_status_index\";i:52;s:50:\"contact_post_update_set_empty_default_form_to_null\";i:53;s:62:\"contact_post_update_add_message_redirect_field_to_contact_form\";i:54;s:41:\"help_post_update_add_permissions_to_roles\";i:55;s:35:\"help_post_update_help_topics_search\";i:56;s:38:\"help_post_update_help_topics_uninstall\";i:57;s:39:\"big_pipe_post_update_html5_placeholders\";i:58;s:49:\"dblog_post_update_convert_recent_messages_to_view\";i:59;s:29:\"search_post_update_block_page\";i:60;s:55:\"search_post_update_reindex_after_diacritics_rule_change\";i:61;s:54:\"block_post_update_disable_blocks_with_missing_contexts\";i:62;s:40:\"block_post_update_disabled_region_update\";i:63;s:42:\"block_post_update_fix_negate_in_conditions\";i:64;s:45:\"block_post_update_replace_node_type_condition\";i:65;s:46:\"field_post_update_save_custom_storage_property\";i:66;s:50:\"field_post_update_entity_reference_handler_setting\";i:67;s:43:\"field_post_update_email_widget_size_setting\";i:68;s:47:\"field_post_update_remove_handler_submit_setting\";i:69;s:44:\"filter_post_update_consolidate_filter_config\";i:70;s:31:\"filter_post_update_sort_filters\";i:71;s:32:\"text_post_update_allowed_formats\";i:72;s:42:\"text_post_update_add_required_summary_flag\";i:73;s:55:\"text_post_update_add_required_summary_flag_form_display\";i:74;s:55:\"block_content_post_update_block_library_view_permission\";i:75;s:51:\"block_content_post_update_entity_changed_constraint\";i:76;s:51:\"block_content_post_update_move_custom_block_library\";i:77;s:39:\"block_content_post_update_revision_type\";i:78;s:42:\"block_content_post_update_sort_permissions\";i:79;s:51:\"block_content_post_update_add_views_reusable_filter\";i:80;s:59:\"node_post_update_set_node_type_description_and_help_to_null\";i:81;s:46:\"node_post_update_configure_status_field_widget\";i:82;s:41:\"node_post_update_node_revision_views_data\";i:83;s:40:\"node_post_update_glossary_view_published\";i:84;s:45:\"node_post_update_rebuild_node_revision_routes\";i:85;s:50:\"node_post_update_modify_base_field_author_override\";i:86;s:64:\"file_post_update_add_default_filename_sanitization_configuration\";i:87;s:41:\"file_post_update_add_permissions_to_roles\";i:88;s:54:\"file_post_update_add_txt_if_allows_insecure_extensions\";i:89;s:34:\"editor_post_update_image_lazy_load\";i:90;s:49:\"editor_post_update_sanitize_image_upload_settings\";i:91;s:56:\"editor_post_update_clear_cache_for_file_reference_filter\";i:92;s:32:\"ckeditor5_post_update_code_block\";i:93;s:40:\"ckeditor5_post_update_image_toolbar_item\";i:94;s:37:\"ckeditor5_post_update_list_multiblock\";i:95;s:41:\"ckeditor5_post_update_list_start_reversed\";i:96;s:51:\"ckeditor5_post_update_plugins_settings_export_order\";i:97;s:39:\"ckeditor5_post_update_alignment_buttons\";i:98;s:48:\"contextual_post_update_fixed_endpoint_and_markup\";i:99;s:37:\"taxonomy_post_update_set_new_revision\";i:100;s:55:\"taxonomy_post_update_set_vocabulary_description_to_null\";i:101;s:43:\"taxonomy_post_update_clear_views_data_cache\";i:102;s:64:\"taxonomy_post_update_clear_entity_bundle_field_definitions_cache\";i:103;s:63:\"taxonomy_post_update_handle_publishing_status_addition_in_views\";i:104;s:55:\"taxonomy_post_update_remove_hierarchy_from_vocabularies\";i:105;s:52:\"taxonomy_post_update_make_taxonomy_term_revisionable\";i:106;s:50:\"taxonomy_post_update_configure_status_field_widget\";i:107;s:65:\"taxonomy_post_update_clear_views_argument_validator_plugins_cache\";i:108;s:42:\"image_post_update_image_style_dependencies\";i:109;s:50:\"image_post_update_scale_and_crop_effect_add_anchor\";i:110;s:41:\"image_post_update_image_loading_attribute\";i:111;s:36:\"views_post_update_add_missing_labels\";i:112;s:39:\"views_post_update_boolean_custom_titles\";i:113;s:38:\"views_post_update_fix_revision_id_part\";i:114;s:35:\"views_post_update_oembed_eager_load\";i:115;s:31:\"views_post_update_pager_heading\";i:116;s:50:\"views_post_update_remove_default_argument_skip_url\";i:117;s:43:\"views_post_update_remove_skip_cache_setting\";i:118;s:54:\"views_post_update_rendered_entity_field_cache_metadata\";i:119;s:44:\"views_post_update_responsive_image_lazy_load\";i:120;s:46:\"views_post_update_taxonomy_filter_user_context\";i:121;s:37:\"views_post_update_timestamp_formatter\";i:122;s:47:\"views_post_update_views_data_argument_plugin_id\";i:123;s:46:\"views_post_update_update_cacheability_metadata\";i:124;s:46:\"views_post_update_cleanup_duplicate_views_data\";i:125;s:46:\"views_post_update_field_formatter_dependencies\";i:126;s:36:\"views_post_update_taxonomy_index_tid\";i:127;s:41:\"views_post_update_serializer_dependencies\";i:128;s:39:\"views_post_update_boolean_filter_values\";i:129;s:33:\"views_post_update_grouped_filters\";i:130;s:42:\"views_post_update_revision_metadata_fields\";i:131;s:33:\"views_post_update_entity_link_url\";i:132;s:34:\"views_post_update_bulk_field_moved\";i:133;s:41:\"views_post_update_filter_placeholder_text\";i:134;s:47:\"views_post_update_views_data_table_dependencies\";i:135;s:45:\"views_post_update_table_display_cache_max_age\";i:136;s:53:\"views_post_update_exposed_filter_blocks_label_display\";i:137;s:48:\"views_post_update_make_placeholders_translatable\";i:138;s:41:\"views_post_update_limit_operator_defaults\";i:139;s:33:\"views_post_update_remove_core_key\";i:140;s:51:\"views_post_update_field_names_for_multivalue_fields\";i:141;s:52:\"views_post_update_configuration_entity_relationships\";i:142;s:48:\"views_post_update_rename_default_display_setting\";i:143;s:50:\"views_post_update_remove_sorting_global_text_field\";i:144;s:36:\"views_post_update_title_translations\";i:145;s:33:\"views_post_update_sort_identifier\";i:146;s:53:\"views_post_update_provide_revision_table_relationship\";i:147;s:33:\"views_post_update_image_lazy_load\";i:148;s:65:\"menu_link_content_post_update_make_menu_link_content_revisionable\";i:149;s:49:\"path_post_update_create_language_content_settings\";i:150;s:45:\"olivero_post_update_add_olivero_primary_color\";i:151;s:46:\"update_post_update_set_blank_fetch_url_to_null\";i:152;s:73:\"layout_discovery_post_update_recalculate_entity_form_display_dependencies\";i:153;s:73:\"layout_discovery_post_update_recalculate_entity_view_display_dependencies\";i:154;s:65:\"layout_builder_post_update_enable_expose_field_block_feature_flag\";i:155;s:46:\"layout_builder_post_update_timestamp_formatter\";i:156;s:54:\"layout_builder_post_update_rebuild_plugin_dependencies\";i:157;s:43:\"layout_builder_post_update_add_extra_fields\";i:158;s:62:\"layout_builder_post_update_section_storage_context_definitions\";i:159;s:57:\"layout_builder_post_update_overrides_view_mode_annotation\";i:160;s:62:\"layout_builder_post_update_cancel_link_to_discard_changes_form\";i:161;s:54:\"layout_builder_post_update_remove_layout_is_rebuilding\";i:162;s:46:\"layout_builder_post_update_routing_entity_form\";i:163;s:55:\"layout_builder_post_update_discover_blank_layout_plugin\";i:164;s:43:\"layout_builder_post_update_routing_defaults\";i:165;s:56:\"layout_builder_post_update_discover_new_contextual_links\";i:166;s:45:\"layout_builder_post_update_fix_tempstore_keys\";i:167;s:62:\"layout_builder_post_update_section_third_party_settings_schema\";i:168;s:59:\"layout_builder_post_update_layout_builder_dependency_change\";i:169;s:45:\"layout_builder_post_update_update_permissions\";i:170;s:53:\"layout_builder_post_update_make_layout_untranslatable\";i:171;s:58:\"layout_builder_post_update_override_entity_form_controller\";i:172;s:58:\"layout_builder_post_update_section_storage_context_mapping\";i:173;s:51:\"layout_builder_post_update_tempstore_route_enhancer\";i:174;s:42:\"media_post_update_oembed_loading_attribute\";i:175;s:56:\"media_post_update_remove_mappings_targeting_source_field\";i:176;s:49:\"media_post_update_set_blank_iframe_domain_to_null\";i:177;s:34:\"media_post_update_collection_route\";i:178;s:33:\"media_post_update_storage_handler\";i:179;s:39:\"media_post_update_enable_standalone_url\";i:180;s:41:\"media_post_update_add_status_extra_filter\";i:181;s:51:\"media_post_update_modify_base_field_author_override\";i:182;s:39:\"media_library_post_update_display_modes\";i:183;s:39:\"media_library_post_update_table_display\";i:184;s:55:\"media_library_post_update_add_media_library_image_style\";i:185;s:49:\"media_library_post_update_add_status_extra_filter\";i:186;s:50:\"media_library_post_update_add_buttons_to_page_view\";i:187;s:54:\"media_library_post_update_update_8001_checkbox_classes\";i:188;s:70:\"media_library_post_update_default_administrative_list_to_table_display\";i:189;s:46:\"media_library_post_update_add_langcode_filters\";i:190;s:59:\"admin_toolbar_tools_post_update_helper_added_config_factory\";i:191;s:49:\"webform_post_update_authenticated_user_permission\";i:192;s:28:\"webform_post_update_ckeditor\";i:193;s:30:\"webform_post_update_ckeditor01\";i:194;s:45:\"webform_post_update_confirmation_page_noindex\";i:195;s:50:\"webform_post_update_deprecate_jquery_ui_datepicker\";i:196;s:45:\"webform_post_update_deprecate_location_places\";i:197;s:39:\"webform_post_update_multiple_categories\";i:198;s:41:\"metatag_post_update_convert_author_config\";i:199;s:39:\"metatag_post_update_convert_author_data\";i:200;s:53:\"metatag_post_update_convert_mask_icon_to_array_values\";i:201;s:46:\"metatag_post_update_remove_robots_noydir_noodp\";i:202;s:47:\"metatag_post_update_v2_01_change_fields_to_json\";i:203;s:46:\"metatag_post_update_v2_02_remove_entity_values\";i:204;s:46:\"metatag_post_update_v2_03_remove_config_values\";i:205;s:43:\"metatag_post_update_v2_04_uninstall_modules\";i:206;s:46:\"metatag_post_update_v2_05_twitter_type_changes\";i:207;s:28:\"field_group_post_update_0001\";i:208;s:44:\"paragraphs_post_update_rebuild_parent_fields\";i:209;s:51:\"paragraphs_post_update_set_paragraphs_parent_fields\";}'),
('state',	'announcements_feed.last_fetch',	'i:1723018766;'),
('state',	'asset.css_js_query_string',	's:6:\"shvxxk\";'),
('state',	'comment.maintain_entity_statistics',	'b:1;'),
('state',	'help_search_unindexed_count',	's:1:\"0\";'),
('state',	'install_task',	's:4:\"done\";'),
('state',	'install_time',	'i:1722190504;'),
('state',	'node.min_max_update_time',	'a:2:{s:11:\"min_created\";s:10:\"1722237400\";s:11:\"max_created\";s:10:\"1722237400\";}'),
('state',	'router.path_roots',	'a:36:{i:0;s:5:\"admin\";i:1;s:8:\"run-cron\";i:2;s:8:\"big_pipe\";i:3;s:14:\"block-category\";i:4;s:5:\"block\";i:5;s:9:\"ckeditor5\";i:6;s:7:\"contact\";i:7;s:4:\"user\";i:8;s:10:\"contextual\";i:9;s:6:\"editor\";i:10;s:4:\"file\";i:11;s:6:\"filter\";i:12;s:7:\"history\";i:13;s:5:\"sites\";i:14;s:6:\"system\";i:15;s:14:\"layout_builder\";i:16;s:6:\"linkit\";i:17;s:5:\"media\";i:18;s:13:\"media-library\";i:19;s:4:\"node\";i:20;s:6:\"search\";i:21;s:4:\"cron\";i:22;s:12:\"machine_name\";i:23;s:0:\"\";i:24;s:9:\"<current>\";i:25;s:5:\"batch\";i:26;s:10:\"update.php\";i:27;s:29:\"entity_reference_autocomplete\";i:28;s:7:\"session\";i:29;s:8:\"taxonomy\";i:30;s:5:\"token\";i:31;s:7:\"toolbar\";i:32;s:11:\".well-known\";i:33;s:7:\"webform\";i:34;s:7:\"rss.xml\";i:35;s:5:\"views\";}'),
('state',	'routing.menu_masks.router',	'a:64:{i:0;i:1003;i:1;i:987;i:2;i:985;i:3;i:501;i:4;i:500;i:5;i:495;i:6;i:494;i:7;i:493;i:8;i:492;i:9;i:491;i:10;i:489;i:11;i:464;i:12;i:253;i:13;i:252;i:14;i:251;i:15;i:250;i:16;i:249;i:17;i:247;i:18;i:246;i:19;i:245;i:20;i:244;i:21;i:235;i:22;i:233;i:23;i:232;i:24;i:224;i:25;i:126;i:26;i:125;i:27;i:124;i:28;i:123;i:29;i:122;i:30;i:117;i:31;i:116;i:32;i:112;i:33;i:63;i:34;i:62;i:35;i:61;i:36;i:60;i:37;i:59;i:38;i:58;i:39;i:56;i:40;i:53;i:41;i:49;i:42;i:42;i:43;i:31;i:44;i:30;i:45;i:29;i:46;i:28;i:47;i:27;i:48;i:24;i:49;i:23;i:50;i:21;i:51;i:15;i:52;i:14;i:53;i:13;i:54;i:12;i:55;i:11;i:56;i:10;i:57;i:8;i:58;i:7;i:59;i:6;i:60;i:5;i:61;i:3;i:62;i:2;i:63;i:1;}'),
('state',	'routing.non_admin_routes',	'a:144:{i:0;s:22:\"admin_toolbar.run.cron\";i:1;s:13:\"big_pipe.nojs\";i:2;s:27:\"block.category_autocomplete\";i:3;s:22:\"block_content.add_page\";i:4;s:22:\"block_content.add_form\";i:5;s:33:\"entity.block_content.edit_form.bc\";i:6;s:35:\"entity.block_content.delete_form.bc\";i:7;s:31:\"ckeditor5.media_entity_metadata\";i:8;s:17:\"contact.site_page\";i:9;s:29:\"entity.contact_form.canonical\";i:10;s:24:\"entity.user.contact_form\";i:11;s:17:\"contextual.render\";i:12;s:17:\"editor.filter_xss\";i:13;s:19:\"editor.image_dialog\";i:14;s:18:\"editor.link_dialog\";i:15;s:18:\"file.ajax_progress\";i:16;s:15:\"filter.tips_all\";i:17;s:11:\"filter.tips\";i:18;s:26:\"history.get_last_node_view\";i:19;s:17:\"history.read_node\";i:20;s:18:\"image.style_public\";i:21;s:19:\"image.style_private\";i:22;s:29:\"layout_builder.choose_section\";i:23;s:26:\"layout_builder.add_section\";i:24;s:32:\"layout_builder.configure_section\";i:25;s:29:\"layout_builder.remove_section\";i:26;s:27:\"layout_builder.choose_block\";i:27;s:24:\"layout_builder.add_block\";i:28;s:34:\"layout_builder.choose_inline_block\";i:29;s:27:\"layout_builder.update_block\";i:30;s:30:\"layout_builder.move_block_form\";i:31;s:27:\"layout_builder.remove_block\";i:32;s:25:\"layout_builder.move_block\";i:33;s:19:\"linkit.autocomplete\";i:34;s:19:\"media.oembed_iframe\";i:35;s:20:\"media.filter.preview\";i:36;s:16:\"media_library.ui\";i:37;s:13:\"node.add_page\";i:38;s:8:\"node.add\";i:39;s:19:\"entity.node.preview\";i:40;s:27:\"entity.node.version_history\";i:41;s:20:\"entity.node.revision\";i:42;s:28:\"node.revision_revert_confirm\";i:43;s:40:\"node.revision_revert_translation_confirm\";i:44;s:28:\"node.revision_delete_confirm\";i:45;s:11:\"search.view\";i:46;s:23:\"search.view_help_search\";i:47;s:23:\"search.help_help_search\";i:48;s:23:\"search.view_node_search\";i:49;s:23:\"search.help_node_search\";i:50;s:23:\"search.view_user_search\";i:51;s:23:\"search.help_user_search\";i:52;s:19:\"shortcut.set_switch\";i:53;s:16:\"system.css_asset\";i:54;s:15:\"system.js_asset\";i:55;s:10:\"system.401\";i:56;s:10:\"system.403\";i:57;s:10:\"system.404\";i:58;s:10:\"system.4xx\";i:59;s:11:\"system.cron\";i:60;s:33:\"system.machine_name_transliterate\";i:61;s:12:\"system.files\";i:62;s:28:\"system.private_file_download\";i:63;s:16:\"system.temporary\";i:64;s:7:\"<front>\";i:65;s:6:\"<none>\";i:66;s:8:\"<nolink>\";i:67;s:8:\"<button>\";i:68;s:9:\"<current>\";i:69;s:15:\"system.timezone\";i:70;s:22:\"system.batch_page.html\";i:71;s:16:\"system.db_update\";i:72;s:26:\"system.entity_autocomplete\";i:73;s:16:\"system.csrftoken\";i:74;s:30:\"entity.taxonomy_term.edit_form\";i:75;s:32:\"entity.taxonomy_term.delete_form\";i:76;s:10:\"token.tree\";i:77;s:16:\"toolbar.subtrees\";i:78;s:13:\"user.register\";i:79;s:11:\"user.logout\";i:80;s:19:\"user.logout.confirm\";i:81;s:9:\"user.pass\";i:82;s:9:\"user.page\";i:83;s:9:\"user.edit\";i:84;s:10:\"user.login\";i:85;s:19:\"user.cancel_confirm\";i:86;s:16:\"user.reset.login\";i:87;s:10:\"user.reset\";i:88;s:15:\"user.reset.form\";i:89;s:31:\"user.well-known.change_password\";i:90;s:24:\"entity.webform.canonical\";i:91;s:28:\"entity.webform.access_denied\";i:92;s:32:\"entity.webform.assets.javascript\";i:93;s:25:\"entity.webform.assets.css\";i:94;s:27:\"entity.webform.confirmation\";i:95;s:31:\"entity.webform.user.submissions\";i:96;s:26:\"entity.webform.user.drafts\";i:97;s:30:\"entity.webform.user.submission\";i:98;s:35:\"entity.webform.user.submission.edit\";i:99;s:37:\"entity.webform.user.submission.delete\";i:100;s:40:\"entity.webform.user.submission.duplicate\";i:101;s:24:\"entity.webform.test_form\";i:102;s:30:\"entity.webform_submission.user\";i:103;s:28:\"webform.element.autocomplete\";i:104;s:29:\"webform.element.message.close\";i:105;s:21:\"view.frontpage.feed_1\";i:106;s:21:\"view.frontpage.page_1\";i:107;s:25:\"view.taxonomy_term.feed_1\";i:108;s:25:\"view.taxonomy_term.page_1\";i:109;s:10:\"views.ajax\";i:110;s:23:\"entity.file.delete_form\";i:111;s:21:\"entity.media.add_page\";i:112;s:21:\"entity.media.add_form\";i:113;s:22:\"entity.media.canonical\";i:114;s:22:\"entity.media.edit_form\";i:115;s:24:\"entity.media.delete_form\";i:116;s:33:\"entity.media.delete_multiple_form\";i:117;s:28:\"entity.media.version_history\";i:118;s:21:\"entity.media.revision\";i:119;s:33:\"entity.media.revision_revert_form\";i:120;s:33:\"entity.media.revision_delete_form\";i:121;s:21:\"entity.node.canonical\";i:122;s:23:\"entity.node.delete_form\";i:123;s:21:\"entity.node.edit_form\";i:124;s:36:\"entity.taxonomy_term.version_history\";i:125;s:29:\"entity.taxonomy_term.revision\";i:126;s:41:\"entity.taxonomy_term.revision_revert_form\";i:127;s:41:\"entity.taxonomy_term.revision_delete_form\";i:128;s:21:\"entity.user.canonical\";i:129;s:21:\"entity.user.edit_form\";i:130;s:23:\"entity.user.cancel_form\";i:131;s:35:\"layout_builder.overrides.media.view\";i:132;s:46:\"layout_builder.overrides.media.discard_changes\";i:133;s:37:\"layout_builder.overrides.media.revert\";i:134;s:34:\"layout_builder.overrides.node.view\";i:135;s:45:\"layout_builder.overrides.node.discard_changes\";i:136;s:36:\"layout_builder.overrides.node.revert\";i:137;s:43:\"layout_builder.overrides.taxonomy_term.view\";i:138;s:54:\"layout_builder.overrides.taxonomy_term.discard_changes\";i:139;s:45:\"layout_builder.overrides.taxonomy_term.revert\";i:140;s:34:\"layout_builder.overrides.user.view\";i:141;s:45:\"layout_builder.overrides.user.discard_changes\";i:142;s:36:\"layout_builder.overrides.user.revert\";i:143;s:30:\"entity.taxonomy_term.canonical\";}'),
('state',	'system.cron_key',	's:74:\"mIb7PNAPdNyZhb-434gv9k6jukDqkFjL9Gtz5lywrR1yKCfM7nLXBkhDBlz7agypi0FSaMaHNg\";'),
('state',	'system.cron_last',	'i:1723018766;'),
('state',	'system.private_key',	's:74:\"rilhq0y8fp7k8NOFyN2fk6_6aWWONPhklmrHeV0qe6BFA3YROJItB7sQYpuGTk7J0WwvU2BpEA\";'),
('state',	'system.profile.files',	'a:18:{s:10:\"demo_umami\";s:44:\"core/profiles/demo_umami/demo_umami.info.yml\";s:4:\"fast\";s:27:\"profiles/fast/fast.info.yml\";s:7:\"minimal\";s:38:\"core/profiles/minimal/minimal.info.yml\";s:23:\"nightwatch_a11y_testing\";s:70:\"core/profiles/nightwatch_a11y_testing/nightwatch_a11y_testing.info.yml\";s:18:\"nightwatch_testing\";s:60:\"core/profiles/nightwatch_testing/nightwatch_testing.info.yml\";s:8:\"standard\";s:40:\"core/profiles/standard/standard.info.yml\";s:25:\"test_language_negotiation\";s:74:\"core/profiles/test_language_negotiation/test_language_negotiation.info.yml\";s:7:\"testing\";s:38:\"core/profiles/testing/testing.info.yml\";s:21:\"testing_config_import\";s:66:\"core/profiles/testing_config_import/testing_config_import.info.yml\";s:24:\"testing_config_overrides\";s:72:\"core/profiles/testing_config_overrides/testing_config_overrides.info.yml\";s:40:\"testing_install_profile_all_dependencies\";s:104:\"core/profiles/testing_install_profile_all_dependencies/testing_install_profile_all_dependencies.info.yml\";s:36:\"testing_install_profile_dependencies\";s:96:\"core/profiles/testing_install_profile_dependencies/testing_install_profile_dependencies.info.yml\";s:28:\"testing_missing_dependencies\";s:80:\"core/profiles/testing_missing_dependencies/testing_missing_dependencies.info.yml\";s:20:\"testing_multilingual\";s:64:\"core/profiles/testing_multilingual/testing_multilingual.info.yml\";s:33:\"testing_multilingual_with_english\";s:90:\"core/profiles/testing_multilingual_with_english/testing_multilingual_with_english.info.yml\";s:20:\"testing_requirements\";s:64:\"core/profiles/testing_requirements/testing_requirements.info.yml\";s:19:\"testing_site_config\";s:62:\"core/profiles/testing_site_config/testing_site_config.info.yml\";s:21:\"testing_themes_blocks\";s:66:\"core/profiles/testing_themes_blocks/testing_themes_blocks.info.yml\";}'),
('state',	'twig_extension_hash_prefix',	'a:2:{s:19:\"twig_extension_hash\";s:43:\"D55ZXC3G3iQnRaTIP5PA7Fm1xXmLIr7ei3mu8CVhVtk\";s:17:\"twig_cache_prefix\";s:13:\"66b45eb3a7b56\";}'),
('state',	'update.last_check',	'i:1723018806;'),
('state',	'update.last_email_notification',	'i:1723018766;'),
('state',	'views.view_route_names',	'a:15:{s:13:\"watchdog.page\";s:14:\"dblog.overview\";s:24:\"user_admin_people.page_1\";s:22:\"entity.user.collection\";s:20:\"taxonomy_term.page_1\";s:30:\"entity.taxonomy_term.canonical\";s:15:\"redirect.page_1\";s:13:\"redirect.list\";s:21:\"media.media_page_list\";s:23:\"entity.media.collection\";s:14:\"content.page_1\";s:20:\"system.admin_content\";s:20:\"block_content.page_1\";s:31:\"entity.block_content.collection\";s:12:\"files.page_1\";s:17:\"view.files.page_1\";s:12:\"files.page_2\";s:17:\"view.files.page_2\";s:16:\"frontpage.feed_1\";s:21:\"view.frontpage.feed_1\";s:16:\"frontpage.page_1\";s:21:\"view.frontpage.page_1\";s:18:\"media_library.page\";s:23:\"view.media_library.page\";s:20:\"media_library.widget\";s:25:\"view.media_library.widget\";s:26:\"media_library.widget_table\";s:31:\"view.media_library.widget_table\";s:20:\"taxonomy_term.feed_1\";s:25:\"view.taxonomy_term.feed_1\";}'),
('state',	'webform.element.message',	'a:0:{}'),
('state',	'webform.version',	's:5:\"6.2.7\";'),
('system.schema',	'admin_toolbar',	'i:8002;'),
('system.schema',	'admin_toolbar_tools',	'i:8202;'),
('system.schema',	'announcements_feed',	'i:8000;'),
('system.schema',	'automated_cron',	'i:8000;'),
('system.schema',	'big_pipe',	'i:8000;'),
('system.schema',	'block',	'i:8003;'),
('system.schema',	'block_content',	'i:10300;'),
('system.schema',	'block_field',	'i:8001;'),
('system.schema',	'breakpoint',	'i:8000;'),
('system.schema',	'ckeditor5',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack_auto_image',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack_find_and_replace',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack_font',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack_highlight',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack_indent_block',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack_page_break',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack_select_all',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack_templates',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack_text_transformation',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack_todo_document_list',	'i:8000;'),
('system.schema',	'ckeditor5_plugin_pack_word_count',	'i:8000;'),
('system.schema',	'ckeditor5_premium_features_fullscreen',	'i:8000;'),
('system.schema',	'config',	'i:8000;'),
('system.schema',	'config_ignore',	'i:8302;'),
('system.schema',	'contact',	'i:8000;'),
('system.schema',	'contextual',	'i:8000;'),
('system.schema',	'datetime',	'i:8000;'),
('system.schema',	'dblog',	'i:10101;'),
('system.schema',	'dynamic_page_cache',	'i:8000;'),
('system.schema',	'ebt_accordion',	'i:9102;'),
('system.schema',	'ebt_basic_button',	'i:8000;'),
('system.schema',	'ebt_block',	'i:8000;'),
('system.schema',	'ebt_bootstrap_button',	'i:9101;'),
('system.schema',	'ebt_carousel',	'i:9102;'),
('system.schema',	'ebt_columns',	'i:8000;'),
('system.schema',	'ebt_core',	'i:9101;'),
('system.schema',	'ebt_countdown',	'i:8000;'),
('system.schema',	'ebt_counter',	'i:9103;'),
('system.schema',	'ebt_cta',	'i:9201;'),
('system.schema',	'ebt_hero',	'i:8000;'),
('system.schema',	'ebt_image',	'i:8000;'),
('system.schema',	'ebt_image_gallery',	'i:9101;'),
('system.schema',	'ebt_micromodal',	'i:9001;'),
('system.schema',	'ebt_quote',	'i:9101;'),
('system.schema',	'ebt_slick_slider',	'i:9101;'),
('system.schema',	'ebt_slideshow',	'i:9102;'),
('system.schema',	'ebt_stats',	'i:8000;'),
('system.schema',	'ebt_tabs',	'i:9102;'),
('system.schema',	'ebt_text',	'i:9101;'),
('system.schema',	'ebt_tiles',	'i:8000;'),
('system.schema',	'ebt_timeline',	'i:9112;'),
('system.schema',	'ebt_video',	'i:8000;'),
('system.schema',	'ebt_video_and_image_gallery',	'i:8000;'),
('system.schema',	'ebt_views',	'i:9001;'),
('system.schema',	'ebt_webform',	'i:9101;'),
('system.schema',	'ebt_webform_popup',	'i:8000;'),
('system.schema',	'editor',	'i:8001;'),
('system.schema',	'entity_reference_revisions',	'i:8000;'),
('system.schema',	'fast',	'i:8000;'),
('system.schema',	'field',	'i:8500;'),
('system.schema',	'field_group',	'i:8302;'),
('system.schema',	'field_ui',	'i:8000;'),
('system.schema',	'file',	'i:8700;'),
('system.schema',	'filter',	'i:8000;'),
('system.schema',	'glightbox',	'i:8000;'),
('system.schema',	'glightbox_media_video',	'i:8000;'),
('system.schema',	'google_analytics',	'i:8401;'),
('system.schema',	'help',	'i:10200;'),
('system.schema',	'history',	'i:10100;'),
('system.schema',	'image',	'i:8201;'),
('system.schema',	'jquery_ui',	'i:8000;'),
('system.schema',	'jquery_ui_accordion',	'i:8000;'),
('system.schema',	'jquery_ui_tabs',	'i:8000;'),
('system.schema',	'layout_builder',	'i:8602;'),
('system.schema',	'layout_discovery',	'i:8000;'),
('system.schema',	'link',	'i:8000;'),
('system.schema',	'linkit',	'i:8503;'),
('system.schema',	'media',	'i:8700;'),
('system.schema',	'media_library',	'i:8704;'),
('system.schema',	'media_library_form_element',	'i:8000;'),
('system.schema',	'menu_link_content',	'i:8601;'),
('system.schema',	'menu_ui',	'i:8000;'),
('system.schema',	'metatag',	'i:8109;'),
('system.schema',	'node',	'i:8700;'),
('system.schema',	'options',	'i:8000;'),
('system.schema',	'page_cache',	'i:8000;'),
('system.schema',	'paragraphs',	'i:8022;'),
('system.schema',	'path',	'i:8200;'),
('system.schema',	'pathauto',	'i:8108;'),
('system.schema',	'path_alias',	'i:8000;'),
('system.schema',	'profile_switcher',	'i:8000;'),
('system.schema',	'redirect',	'i:8109;'),
('system.schema',	'search',	'i:8000;'),
('system.schema',	'shortcut',	'i:8000;'),
('system.schema',	'svg_image',	'i:8000;'),
('system.schema',	'system',	'i:10201;'),
('system.schema',	'taxonomy',	'i:10100;'),
('system.schema',	'text',	'i:8000;'),
('system.schema',	'token',	'i:8000;'),
('system.schema',	'toolbar',	'i:8000;'),
('system.schema',	'update',	'i:8001;'),
('system.schema',	'user',	'i:10000;'),
('system.schema',	'views',	'i:8500;'),
('system.schema',	'viewsreference',	'i:8103;'),
('system.schema',	'views_ui',	'i:8000;'),
('system.schema',	'webform',	'i:8637;');

DROP TABLE IF EXISTS `key_value_expire`;
CREATE TABLE `key_value_expire` (
  `collection` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A named collection of key and value pairs.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The key of the key/value pair.',
  `value` longblob NOT NULL COMMENT 'The value of the key/value pair.',
  `expire` int NOT NULL DEFAULT '2147483647' COMMENT 'The time since Unix epoch in seconds when this item expires. Defaults to the maximum possible time.',
  PRIMARY KEY (`collection`,`name`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Generic key/value storage table with an expiration.';

INSERT INTO `key_value_expire` (`collection`, `name`, `value`, `expire`) VALUES
('announcements_feed',	'announcements',	'a:7:{i:1;a:7:{s:2:\"id\";s:7:\"3427138\";s:5:\"title\";s:52:\"You\'re invited to DrupalCon Portland | 6-9 May, 2024\";s:12:\"content_html\";s:384:\"<p>DrupalCon is an event for developers, marketers/content editors, site owners, and the Drupal-curious to join with the community. You\'ll find incredible keynotes, session content from expert speakers who have helped to build Drupal, networking opportunities with your peers, fun social events, and the chance to deepen your connection by contributing to the open source project.</p>\";s:3:\"url\";s:96:\"https://www.drupal.org/about/announcements/blog/youre-invited-to-drupalcon-portland-6-9-may-2024\";s:13:\"date_modified\";s:25:\"2024-03-18T19:40:04+00:00\";s:14:\"date_published\";s:25:\"2024-03-11T16:49:53+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:2;a:7:{s:2:\"id\";s:7:\"3408836\";s:5:\"title\";s:28:\"Drupal 10.2 is now available\";s:12:\"content_html\";s:378:\"<p>The <a href=\"https://www.drupal.org/project/drupal/releases/10.2.0\">second feature release of Drupal 10</a> improves content modeling, block management, menu and taxonomy organization, and permission administration. New options to sanitize file names make it possible to clean up the names of uploaded files, and media item revisions now have a dedicated user interface.</p>\n\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-2-0\";s:13:\"date_modified\";s:25:\"2024-01-25T18:24:28+00:00\";s:14:\"date_published\";s:25:\"2023-12-15T18:27:47+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:3;a:7:{s:2:\"id\";s:7:\"3403229\";s:5:\"title\";s:75:\"Drupal 10 will be supported until the release of Drupal 12 in mid-late 2026\";s:12:\"content_html\";s:190:\"<p>Announcing a new major release schedule with long term support for Drupal 10 until mid-late 2026. Drupal 11 will be released in 2024 and work on the dedicated branch starts this week.</p>\";s:3:\"url\";s:103:\"https://www.drupal.org/blog/drupal-10-will-be-supported-until-the-release-of-drupal-12-in-mid-late-2026\";s:13:\"date_modified\";s:25:\"2024-01-25T18:31:05+00:00\";s:14:\"date_published\";s:25:\"2023-11-22T07:13:55+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:5;a:7:{s:2:\"id\";s:7:\"3368367\";s:5:\"title\";s:28:\"Drupal 10.1 is now available\";s:12:\"content_html\";s:257:\"<p>This first feature release of Drupal 10 is packed with amazing improvements! It makes customizing the look of your site easier, adds support for decoupled navigation, improves content modeling and editing, block management, performance and many more.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-1-0\";s:13:\"date_modified\";s:25:\"2023-10-30T16:22:24+00:00\";s:14:\"date_published\";s:25:\"2023-06-22T09:11:30+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:6;a:7:{s:2:\"id\";s:7:\"3347976\";s:5:\"title\";s:37:\"Contribute to Drupal and the Open Web\";s:12:\"content_html\";s:146:\"<p>Drupal is an open source project. But what does that mean? How can you as a site-owner participate in the project of building a better web?</p>\";s:3:\"url\";s:85:\"https://www.drupal.org/about/announcements/blog/contribute-to-drupal-and-the-open-web\";s:13:\"date_modified\";s:25:\"2023-03-14T19:43:12+00:00\";s:14:\"date_published\";s:25:\"2023-03-14T19:39:44+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:7;a:7:{s:2:\"id\";s:7:\"3343486\";s:5:\"title\";s:43:\"What to expect from the Announcements feed?\";s:12:\"content_html\";s:197:\"<p>Drupal is introducing a new project Announcements feature so that you can see news and updates about the Drupal project and community directly in your Drupal dashboard. Learn what to expect.</p>\";s:3:\"url\";s:90:\"https://www.drupal.org/about/announcements/blog/what-to-expect-from-the-announcements-feed\";s:13:\"date_modified\";s:25:\"2023-02-21T19:45:53+00:00\";s:14:\"date_published\";s:25:\"2023-02-21T19:45:53+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}i:8;a:7:{s:2:\"id\";s:7:\"3327047\";s:5:\"title\";s:26:\"Drupal 10.0.0 is available\";s:12:\"content_html\";s:296:\"<p>Thanks to 2129 contributors from 616 organizations resolving 4083 issues in the past two and a half years, Drupal 10.0.0 is available today! This new version sets Drupal up for continued stability and security for the longer term. All new features will be added to Drupal 10 going forward.</p>\";s:3:\"url\";s:41:\"https://www.drupal.org/blog/drupal-10-0-0\";s:13:\"date_modified\";s:25:\"2023-10-30T16:21:38+00:00\";s:14:\"date_published\";s:25:\"2022-12-15T17:43:23+00:00\";s:10:\"_drupalorg\";a:2:{s:8:\"featured\";b:0;s:7:\"version\";s:5:\">=7.0\";}}}',	1723105166),
('system',	'advisories_response',	'a:0:{}',	1723040366),
('update_available_releases',	'admin_toolbar',	'a:10:{s:5:\"title\";s:13:\"Admin Toolbar\";s:10:\"short_name\";s:13:\"admin_toolbar\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"3.4.,3.5.\";s:18:\"composer_namespace\";s:20:\"drupal/admin_toolbar\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/admin_toolbar\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:54:{s:5:\"3.5.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.5.0\";s:7:\"version\";s:5:\"3.5.0\";s:3:\"tag\";s:5:\"3.5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.5.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.5.0.tar.gz\";s:4:\"date\";s:10:\"1722639094\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";}s:5:\"3.4.2\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.4.2\";s:7:\"version\";s:5:\"3.4.2\";s:3:\"tag\";s:5:\"3.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.4.2.tar.gz\";s:4:\"date\";s:10:\"1696006154\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.4.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.4.1\";s:7:\"version\";s:5:\"3.4.1\";s:3:\"tag\";s:5:\"3.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.4.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.4.1.tar.gz\";s:4:\"date\";s:10:\"1684944156\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.4.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.4.0\";s:7:\"version\";s:5:\"3.4.0\";s:3:\"tag\";s:5:\"3.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.4.0.tar.gz\";s:4:\"date\";s:10:\"1683730335\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.3.2\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.3.2\";s:7:\"version\";s:5:\"3.3.2\";s:3:\"tag\";s:5:\"3.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.3.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.3.2.tar.gz\";s:4:\"date\";s:10:\"1683055364\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.3.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.3.1\";s:7:\"version\";s:5:\"3.3.1\";s:3:\"tag\";s:5:\"3.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.3.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.3.1.tar.gz\";s:4:\"date\";s:10:\"1682689245\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"3.3.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.3.0\";s:7:\"version\";s:5:\"3.3.0\";s:3:\"tag\";s:5:\"3.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.3.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.3.0.tar.gz\";s:4:\"date\";s:10:\"1669567837\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"3.2.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.2.1\";s:7:\"version\";s:5:\"3.2.1\";s:3:\"tag\";s:5:\"3.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.2.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.2.1.tar.gz\";s:4:\"date\";s:10:\"1665044276\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.2.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.2.0\";s:7:\"version\";s:5:\"3.2.0\";s:3:\"tag\";s:5:\"3.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.2.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.2.0.tar.gz\";s:4:\"date\";s:10:\"1664981657\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.1.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.1.1\";s:7:\"version\";s:5:\"3.1.1\";s:3:\"tag\";s:5:\"3.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.1.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.1.1.tar.gz\";s:4:\"date\";s:10:\"1658801841\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:19:\"^8.8.0 || ^9 || ^10\";}s:5:\"3.1.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.1.0\";s:7:\"version\";s:5:\"3.1.0\";s:3:\"tag\";s:5:\"3.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.1.0.tar.gz\";s:4:\"date\";s:10:\"1643097060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:19:\"^8.8.0 || ^9 || ^10\";}s:5:\"3.0.3\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.3\";s:7:\"version\";s:5:\"3.0.3\";s:3:\"tag\";s:5:\"3.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.3.tar.gz\";s:4:\"date\";s:10:\"1632322068\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.0.2\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.2\";s:7:\"version\";s:5:\"3.0.2\";s:3:\"tag\";s:5:\"3.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.2.tar.gz\";s:4:\"date\";s:10:\"1629882675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.0.1\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.1\";s:7:\"version\";s:5:\"3.0.1\";s:3:\"tag\";s:5:\"3.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.1.tar.gz\";s:4:\"date\";s:10:\"1622644077\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:5:\"3.0.0\";a:11:{s:4:\"name\";s:19:\"admin_toolbar 3.0.0\";s:7:\"version\";s:5:\"3.0.0\";s:3:\"tag\";s:5:\"3.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/admin_toolbar/releases/3.0.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.0.0.tar.gz\";s:4:\"date\";s:10:\"1611311186\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1629883381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1601998853\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1592535597\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1585017179\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.8.0 || ^9.0\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1584986458\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:14:\"^8.7.7 || ^9.0\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1572370984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-2.0-beta2\";a:11:{s:4:\"name\";s:27:\"admin_toolbar 8.x-2.0-beta2\";s:7:\"version\";s:13:\"8.x-2.0-beta2\";s:3:\"tag\";s:13:\"8.x-2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.0-beta2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1567506785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:27:\"admin_toolbar 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1562269081\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.27\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.27\";s:7:\"version\";s:8:\"8.x-1.27\";s:3:\"tag\";s:8:\"8.x-1.27\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.27\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.27.tar.gz\";s:4:\"date\";s:10:\"1558552081\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.26\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.26\";s:7:\"version\";s:8:\"8.x-1.26\";s:3:\"tag\";s:8:\"8.x-1.26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.26\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.26.tar.gz\";s:4:\"date\";s:10:\"1549218480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.25\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.25\";s:7:\"version\";s:8:\"8.x-1.25\";s:3:\"tag\";s:8:\"8.x-1.25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.25\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.25.tar.gz\";s:4:\"date\";s:10:\"1542915180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.24\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.24\";s:7:\"version\";s:8:\"8.x-1.24\";s:3:\"tag\";s:8:\"8.x-1.24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.24\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.24.tar.gz\";s:4:\"date\";s:10:\"1527522480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.23\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.23\";s:7:\"version\";s:8:\"8.x-1.23\";s:3:\"tag\";s:8:\"8.x-1.23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.23\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.23.tar.gz\";s:4:\"date\";s:10:\"1517936581\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.22\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.22\";s:7:\"version\";s:8:\"8.x-1.22\";s:3:\"tag\";s:8:\"8.x-1.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.22\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.22.tar.gz\";s:4:\"date\";s:10:\"1514888585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.21\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.21\";s:7:\"version\";s:8:\"8.x-1.21\";s:3:\"tag\";s:8:\"8.x-1.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.21\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.21.tar.gz\";s:4:\"date\";s:10:\"1511190785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.20\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.20\";s:7:\"version\";s:8:\"8.x-1.20\";s:3:\"tag\";s:8:\"8.x-1.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.20\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.20.tar.gz\";s:4:\"date\";s:10:\"1505199844\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.19\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.19\";s:7:\"version\";s:8:\"8.x-1.19\";s:3:\"tag\";s:8:\"8.x-1.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.19\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.19.tar.gz\";s:4:\"date\";s:10:\"1491487683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.18\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.18\";s:7:\"version\";s:8:\"8.x-1.18\";s:3:\"tag\";s:8:\"8.x-1.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.18\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.18.tar.gz\";s:4:\"date\";s:10:\"1480614184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.17\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.17\";s:7:\"version\";s:8:\"8.x-1.17\";s:3:\"tag\";s:8:\"8.x-1.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.17\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.17.tar.gz\";s:4:\"date\";s:10:\"1472585039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.16\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.16\";s:7:\"version\";s:8:\"8.x-1.16\";s:3:\"tag\";s:8:\"8.x-1.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.16\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.16.tar.gz\";s:4:\"date\";s:10:\"1469715839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.15\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1464016832\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.14\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1454942939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.13\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1454405939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.12\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1454402339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.11\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1449833341\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:22:\"admin_toolbar 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.10\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1445350439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.9\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1438248239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.8\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1437400139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.7\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1434972483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.6\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1433331481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1433329681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1432141381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1432129285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1432129285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1432048381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1431018181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"3.x-dev\";a:11:{s:4:\"name\";s:21:\"admin_toolbar 3.x-dev\";s:7:\"version\";s:7:\"3.x-dev\";s:3:\"tag\";s:3:\"3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/admin_toolbar/releases/3.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/admin_toolbar-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722637137\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.5 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:25:\"admin_toolbar 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-2.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1649739022\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.8.0 || ^9\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:25:\"admin_toolbar 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/admin_toolbar/releases/8.x-1.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/admin_toolbar-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1567701780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}}s:10:\"last_fetch\";i:1723018802;}',	1723105202),
('update_available_releases',	'block_field',	'a:10:{s:5:\"title\";s:11:\"Block field\";s:10:\"short_name\";s:11:\"block_field\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:18:\"drupal/block_field\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/block_field\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:13:{s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1667511464\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1658858536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1621950813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1588279781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1536732480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1533866285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1525303380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1511317688\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1487611082\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1464034139\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1464016832\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:26:\"block_field 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/block_field/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1463668739\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"block_field 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/block_field/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/block_field-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721425360\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018802;}',	1723105202),
('update_available_releases',	'ckeditor5_plugin_pack',	'a:10:{s:5:\"title\";s:22:\"CKEditor 5 Plugin Pack\";s:10:\"short_name\";s:21:\"ckeditor5_plugin_pack\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.2.\";s:18:\"composer_namespace\";s:28:\"drupal/ckeditor5_plugin_pack\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:52:\"https://www.drupal.org/project/ckeditor5_plugin_pack\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:4:{s:5:\"1.2.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.2.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1722415813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.1.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.1.0\";s:7:\"version\";s:5:\"1.1.0\";s:3:\"tag\";s:5:\"1.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.1.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.1.0.tar.gz\";s:4:\"date\";s:10:\"1718271916\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.0.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1714466054\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:27:\"ckeditor5_plugin_pack 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ckeditor5_plugin_pack/releases/1.0.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ckeditor5_plugin_pack-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1713945391\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018802;}',	1723105202),
('update_available_releases',	'ckeditor5_premium_features',	'a:10:{s:5:\"title\";s:27:\"CKEditor 5 Premium Features\";s:10:\"short_name\";s:26:\"ckeditor5_premium_features\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"1.2.,1.3.\";s:18:\"composer_namespace\";s:33:\"drupal/ckeditor5_premium_features\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:57:\"https://www.drupal.org/project/ckeditor5_premium_features\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:19:{s:5:\"1.3.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.3.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1722416832\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:20:\"^9.4 || ^10.0 || ^11\";}s:5:\"1.2.9\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.9\";s:7:\"version\";s:5:\"1.2.9\";s:3:\"tag\";s:5:\"1.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.9\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.9.tar.gz\";s:4:\"date\";s:10:\"1718272066\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.8\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.8\";s:7:\"version\";s:5:\"1.2.8\";s:3:\"tag\";s:5:\"1.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.8\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.8.tar.gz\";s:4:\"date\";s:10:\"1713960338\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.7\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.7\";s:7:\"version\";s:5:\"1.2.7\";s:3:\"tag\";s:5:\"1.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.7\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.7.tar.gz\";s:4:\"date\";s:10:\"1713946256\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}s:5:\"1.2.6\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.6\";s:7:\"version\";s:5:\"1.2.6\";s:3:\"tag\";s:5:\"1.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.6\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.6.tar.gz\";s:4:\"date\";s:10:\"1709550478\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.5\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.5\";s:7:\"version\";s:5:\"1.2.5\";s:3:\"tag\";s:5:\"1.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.5\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.5.tar.gz\";s:4:\"date\";s:10:\"1706087373\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.4\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.4\";s:7:\"version\";s:5:\"1.2.4\";s:3:\"tag\";s:5:\"1.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.4\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.4.tar.gz\";s:4:\"date\";s:10:\"1702994815\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.3\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.3\";s:7:\"version\";s:5:\"1.2.3\";s:3:\"tag\";s:5:\"1.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.3\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.3.tar.gz\";s:4:\"date\";s:10:\"1699963145\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.2\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1693384282\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1688647071\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.2.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1687776512\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.1.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.1.1\";s:7:\"version\";s:5:\"1.1.1\";s:3:\"tag\";s:5:\"1.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.1.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.1.1.tar.gz\";s:4:\"date\";s:10:\"1684309128\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.1.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.1.0\";s:7:\"version\";s:5:\"1.1.0\";s:3:\"tag\";s:5:\"1.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.1.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.1.0.tar.gz\";s:4:\"date\";s:10:\"1683814836\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1681894913\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:32:\"ckeditor5_premium_features 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1677662363\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:9:\"1.0.0-rc2\";a:11:{s:4:\"name\";s:36:\"ckeditor5_premium_features 1.0.0-rc2\";s:7:\"version\";s:9:\"1.0.0-rc2\";s:3:\"tag\";s:9:\"1.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-rc2\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1671113465\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:9:\"1.0.0-rc1\";a:11:{s:4:\"name\";s:36:\"ckeditor5_premium_features 1.0.0-rc1\";s:7:\"version\";s:9:\"1.0.0-rc1\";s:3:\"tag\";s:9:\"1.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:76:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-rc1\";s:13:\"download_link\";s:81:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1667227760\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:11:\"1.0.0-beta2\";a:11:{s:4:\"name\";s:38:\"ckeditor5_premium_features 1.0.0-beta2\";s:7:\"version\";s:11:\"1.0.0-beta2\";s:3:\"tag\";s:11:\"1.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-beta2\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1663854316\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:38:\"ckeditor5_premium_features 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/ckeditor5_premium_features/releases/1.0.0-beta1\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/ckeditor5_premium_features-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663684376\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || ^10.0\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018802;}',	1723105202),
('update_available_releases',	'config_ignore',	'a:10:{s:5:\"title\";s:13:\"Config Ignore\";s:10:\"short_name\";s:13:\"config_ignore\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-3.\";s:18:\"composer_namespace\";s:20:\"drupal/config_ignore\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/config_ignore\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:25:{s:7:\"8.x-3.3\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-3.3\";s:7:\"version\";s:7:\"8.x-3.3\";s:3:\"tag\";s:7:\"8.x-3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.3.tar.gz\";s:4:\"date\";s:10:\"1713299496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:24:\"^8.8 || ^9 || ^10 || ^11\";}s:7:\"8.x-3.2\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-3.2\";s:7:\"version\";s:7:\"8.x-3.2\";s:3:\"tag\";s:7:\"8.x-3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.2.tar.gz\";s:4:\"date\";s:10:\"1705226226\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:7:\"8.x-3.1\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-3.1\";s:7:\"version\";s:7:\"8.x-3.1\";s:3:\"tag\";s:7:\"8.x-3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.1.tar.gz\";s:4:\"date\";s:10:\"1699302168\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1698624094\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1697716408\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";}s:13:\"8.x-3.0-beta2\";a:11:{s:4:\"name\";s:27:\"config_ignore 8.x-3.0-beta2\";s:7:\"version\";s:13:\"8.x-3.0-beta2\";s:3:\"tag\";s:13:\"8.x-3.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.0-beta2\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1676045569\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:17:\"^8.8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:13:\"8.x-3.0-beta1\";a:11:{s:4:\"name\";s:27:\"config_ignore 8.x-3.0-beta1\";s:7:\"version\";s:13:\"8.x-3.0-beta1\";s:3:\"tag\";s:13:\"8.x-3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.0-beta1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1627977337\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1676045435\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1608306489\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-2.3-rc1\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-2.3-rc1\";s:7:\"version\";s:11:\"8.x-2.3-rc1\";s:3:\"tag\";s:11:\"8.x-2.3-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.3-rc1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.3-rc1.tar.gz\";s:4:\"date\";s:10:\"1607033836\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1576528386\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1507706044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1494323585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc2\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-2.0-rc2\";s:7:\"version\";s:11:\"8.x-2.0-rc2\";s:3:\"tag\";s:11:\"8.x-2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.0-rc2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1493231943\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1490346183\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1487336284\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1485770283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1485251884\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:21:\"config_ignore 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.0\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1484669883\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1481797383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1480522084\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1480363684\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-3.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1713937215\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:24:\"^8.8 || ^9 || ^10 || ^11\";}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-2.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1662296469\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:15:\"^8 || ^9 || ^10\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:25:\"config_ignore 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/config_ignore/releases/8.x-1.x-dev\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/config_ignore-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1493230443\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018802;}',	1723105202),
('update_available_releases',	'drupal',	'a:9:{s:5:\"title\";s:11:\"Drupal core\";s:10:\"short_name\";s:6:\"drupal\";s:4:\"type\";s:12:\"project_core\";s:18:\"supported_branches\";s:23:\"10.2.,10.3.,10.4.,11.0.\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:37:\"https://www.drupal.org/project/drupal\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:408:{s:6:\"11.0.0\";a:10:{s:4:\"name\";s:13:\"drupal 11.0.0\";s:7:\"version\";s:6:\"11.0.0\";s:3:\"tag\";s:6:\"11.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/11.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-11.0.0.tar.gz\";s:4:\"date\";s:10:\"1722578454\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"11.0.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 11.0.0-rc1\";s:7:\"version\";s:10:\"11.0.0-rc1\";s:3:\"tag\";s:10:\"11.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.0.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1720736512\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"11.0.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 11.0.0-beta1\";s:7:\"version\";s:12:\"11.0.0-beta1\";s:3:\"tag\";s:12:\"11.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/11.0.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1715953266\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"11.0.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 11.0.0-alpha1\";s:7:\"version\";s:13:\"11.0.0-alpha1\";s:3:\"tag\";s:13:\"11.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/11.0.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-11.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1714797816\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"10.3.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.1\";s:7:\"version\";s:6:\"10.3.1\";s:3:\"tag\";s:6:\"10.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.1.tar.gz\";s:4:\"date\";s:10:\"1720094095\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.3.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.3.0\";s:7:\"version\";s:6:\"10.3.0\";s:3:\"tag\";s:6:\"10.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.3.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.3.0.tar.gz\";s:4:\"date\";s:10:\"1718911125\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.3.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.3.0-rc1\";s:7:\"version\";s:10:\"10.3.0-rc1\";s:3:\"tag\";s:10:\"10.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.3.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1717621189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.3.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.3.0-beta1\";s:7:\"version\";s:12:\"10.3.0-beta1\";s:3:\"tag\";s:12:\"10.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.3.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1715953149\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"10.2.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.7\";s:7:\"version\";s:6:\"10.2.7\";s:3:\"tag\";s:6:\"10.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.7.tar.gz\";s:4:\"date\";s:10:\"1717660024\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.6\";s:7:\"version\";s:6:\"10.2.6\";s:3:\"tag\";s:6:\"10.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.6.tar.gz\";s:4:\"date\";s:10:\"1714597701\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.5\";s:7:\"version\";s:6:\"10.2.5\";s:3:\"tag\";s:6:\"10.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.5.tar.gz\";s:4:\"date\";s:10:\"1712130945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.4\";s:7:\"version\";s:6:\"10.2.4\";s:3:\"tag\";s:6:\"10.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.4.tar.gz\";s:4:\"date\";s:10:\"1709715366\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.3\";s:7:\"version\";s:6:\"10.2.3\";s:3:\"tag\";s:6:\"10.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.3.tar.gz\";s:4:\"date\";s:10:\"1707347611\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.2\";s:7:\"version\";s:6:\"10.2.2\";s:3:\"tag\";s:6:\"10.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.2.tar.gz\";s:4:\"date\";s:10:\"1705511786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.1\";s:7:\"version\";s:6:\"10.2.1\";s:3:\"tag\";s:6:\"10.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.1.tar.gz\";s:4:\"date\";s:10:\"1704448164\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.2.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.2.0\";s:7:\"version\";s:6:\"10.2.0\";s:3:\"tag\";s:6:\"10.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.2.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.2.0.tar.gz\";s:4:\"date\";s:10:\"1702681674\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.2.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.2.0-rc1\";s:7:\"version\";s:10:\"10.2.0-rc1\";s:3:\"tag\";s:10:\"10.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.2.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1701450971\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.2.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.2.0-beta1\";s:7:\"version\";s:12:\"10.2.0-beta1\";s:3:\"tag\";s:12:\"10.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.2.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1700578716\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.2.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.2.0-alpha1\";s:7:\"version\";s:13:\"10.2.0-alpha1\";s:3:\"tag\";s:13:\"10.2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.2.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1699048959\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"10.1.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.8\";s:7:\"version\";s:6:\"10.1.8\";s:3:\"tag\";s:6:\"10.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.8.tar.gz\";s:4:\"date\";s:10:\"1705512711\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.7\";s:7:\"version\";s:6:\"10.1.7\";s:3:\"tag\";s:6:\"10.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.7.tar.gz\";s:4:\"date\";s:10:\"1701857745\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.6\";s:7:\"version\";s:6:\"10.1.6\";s:3:\"tag\";s:6:\"10.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.6.tar.gz\";s:4:\"date\";s:10:\"1698841286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.5\";s:7:\"version\";s:6:\"10.1.5\";s:3:\"tag\";s:6:\"10.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.5.tar.gz\";s:4:\"date\";s:10:\"1696456362\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.4\";s:7:\"version\";s:6:\"10.1.4\";s:3:\"tag\";s:6:\"10.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.4.tar.gz\";s:4:\"date\";s:10:\"1695227262\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.3\";s:7:\"version\";s:6:\"10.1.3\";s:3:\"tag\";s:6:\"10.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.3.tar.gz\";s:4:\"date\";s:10:\"1694101052\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.2\";s:7:\"version\";s:6:\"10.1.2\";s:3:\"tag\";s:6:\"10.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.2.tar.gz\";s:4:\"date\";s:10:\"1690972078\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.1\";s:7:\"version\";s:6:\"10.1.1\";s:3:\"tag\";s:6:\"10.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.1.tar.gz\";s:4:\"date\";s:10:\"1688632960\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.1.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.1.0\";s:7:\"version\";s:6:\"10.1.0\";s:3:\"tag\";s:6:\"10.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.1.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.1.0.tar.gz\";s:4:\"date\";s:10:\"1687424272\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.1.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.1.0-rc1\";s:7:\"version\";s:10:\"10.1.0-rc1\";s:3:\"tag\";s:10:\"10.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.1.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1686244833\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.1.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.1.0-beta1\";s:7:\"version\";s:12:\"10.1.0-beta1\";s:3:\"tag\";s:12:\"10.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.1.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1684130534\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.1.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.1.0-alpha1\";s:7:\"version\";s:13:\"10.1.0-alpha1\";s:3:\"tag\";s:13:\"10.1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.1.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1682694475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:7:\"10.0.11\";a:10:{s:4:\"name\";s:14:\"drupal 10.0.11\";s:7:\"version\";s:7:\"10.0.11\";s:3:\"tag\";s:7:\"10.0.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.0.11\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.0.11.tar.gz\";s:4:\"date\";s:10:\"1695228927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:7:\"10.0.10\";a:10:{s:4:\"name\";s:14:\"drupal 10.0.10\";s:7:\"version\";s:7:\"10.0.10\";s:3:\"tag\";s:7:\"10.0.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/drupal/releases/10.0.10\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/drupal-10.0.10.tar.gz\";s:4:\"date\";s:10:\"1688549719\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.9\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.9\";s:7:\"version\";s:6:\"10.0.9\";s:3:\"tag\";s:6:\"10.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.9.tar.gz\";s:4:\"date\";s:10:\"1683108606\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.8\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.8\";s:7:\"version\";s:6:\"10.0.8\";s:3:\"tag\";s:6:\"10.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.8.tar.gz\";s:4:\"date\";s:10:\"1681921539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.7\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.7\";s:7:\"version\";s:6:\"10.0.7\";s:3:\"tag\";s:6:\"10.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.7.tar.gz\";s:4:\"date\";s:10:\"1679678060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.6\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.6\";s:7:\"version\";s:6:\"10.0.6\";s:3:\"tag\";s:6:\"10.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.6.tar.gz\";s:4:\"date\";s:10:\"1679664982\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.5\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.5\";s:7:\"version\";s:6:\"10.0.5\";s:3:\"tag\";s:6:\"10.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.5.tar.gz\";s:4:\"date\";s:10:\"1678901067\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.4\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.4\";s:7:\"version\";s:6:\"10.0.4\";s:3:\"tag\";s:6:\"10.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.4.tar.gz\";s:4:\"date\";s:10:\"1677681486\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.3\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.3\";s:7:\"version\";s:6:\"10.0.3\";s:3:\"tag\";s:6:\"10.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.3.tar.gz\";s:4:\"date\";s:10:\"1675276709\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.2\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.2\";s:7:\"version\";s:6:\"10.0.2\";s:3:\"tag\";s:6:\"10.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.2.tar.gz\";s:4:\"date\";s:10:\"1674065542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.1\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.1\";s:7:\"version\";s:6:\"10.0.1\";s:3:\"tag\";s:6:\"10.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.1.tar.gz\";s:4:\"date\";s:10:\"1672847780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"10.0.0\";a:10:{s:4:\"name\";s:13:\"drupal 10.0.0\";s:7:\"version\";s:6:\"10.0.0\";s:3:\"tag\";s:6:\"10.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/10.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-10.0.0.tar.gz\";s:4:\"date\";s:10:\"1671125939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:10:\"10.0.0-rc3\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc3\";s:7:\"version\";s:10:\"10.0.0-rc3\";s:3:\"tag\";s:10:\"10.0.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1670591784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:10:\"10.0.0-rc2\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc2\";s:7:\"version\";s:10:\"10.0.0-rc2\";s:3:\"tag\";s:10:\"10.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1670320927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:10:\"10.0.0-rc1\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.0-rc1\";s:7:\"version\";s:10:\"10.0.0-rc1\";s:3:\"tag\";s:10:\"10.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1668612993\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"10.0.0-beta2\";a:10:{s:4:\"name\";s:19:\"drupal 10.0.0-beta2\";s:7:\"version\";s:12:\"10.0.0-beta2\";s:3:\"tag\";s:12:\"10.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.0.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1664462663\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"10.0.0-beta1\";a:10:{s:4:\"name\";s:19:\"drupal 10.0.0-beta1\";s:7:\"version\";s:12:\"10.0.0-beta1\";s:3:\"tag\";s:12:\"10.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/10.0.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663358020\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha7\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha7\";s:7:\"version\";s:13:\"10.0.0-alpha7\";s:3:\"tag\";s:13:\"10.0.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha7\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1659633851\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha6\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha6\";s:7:\"version\";s:13:\"10.0.0-alpha6\";s:3:\"tag\";s:13:\"10.0.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha6\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1657218740\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha5\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha5\";s:7:\"version\";s:13:\"10.0.0-alpha5\";s:3:\"tag\";s:13:\"10.0.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha5\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1654722993\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha4\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha4\";s:7:\"version\";s:13:\"10.0.0-alpha4\";s:3:\"tag\";s:13:\"10.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1651875601\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha3\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha3\";s:7:\"version\";s:13:\"10.0.0-alpha3\";s:3:\"tag\";s:13:\"10.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1649887793\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha2\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha2\";s:7:\"version\";s:13:\"10.0.0-alpha2\";s:3:\"tag\";s:13:\"10.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1645204305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"10.0.0-alpha1\";a:10:{s:4:\"name\";s:20:\"drupal 10.0.0-alpha1\";s:7:\"version\";s:13:\"10.0.0-alpha1\";s:3:\"tag\";s:13:\"10.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/10.0.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-10.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1643404041\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.5.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.5.11\";s:7:\"version\";s:6:\"9.5.11\";s:3:\"tag\";s:6:\"9.5.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.5.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.5.11.tar.gz\";s:4:\"date\";s:10:\"1695228016\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.5.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.5.10\";s:7:\"version\";s:6:\"9.5.10\";s:3:\"tag\";s:6:\"9.5.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.5.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.5.10.tar.gz\";s:4:\"date\";s:10:\"1688550984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.9\";s:7:\"version\";s:5:\"9.5.9\";s:3:\"tag\";s:5:\"9.5.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.9.tar.gz\";s:4:\"date\";s:10:\"1683121532\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.8\";s:7:\"version\";s:5:\"9.5.8\";s:3:\"tag\";s:5:\"9.5.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.8.tar.gz\";s:4:\"date\";s:10:\"1681922649\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.7\";s:7:\"version\";s:5:\"9.5.7\";s:3:\"tag\";s:5:\"9.5.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.7.tar.gz\";s:4:\"date\";s:10:\"1679677448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.6\";s:7:\"version\";s:5:\"9.5.6\";s:3:\"tag\";s:5:\"9.5.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.6.tar.gz\";s:4:\"date\";s:10:\"1679664389\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.5\";s:7:\"version\";s:5:\"9.5.5\";s:3:\"tag\";s:5:\"9.5.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.5.tar.gz\";s:4:\"date\";s:10:\"1678902101\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.4\";s:7:\"version\";s:5:\"9.5.4\";s:3:\"tag\";s:5:\"9.5.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.4.tar.gz\";s:4:\"date\";s:10:\"1677680813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.3\";s:7:\"version\";s:5:\"9.5.3\";s:3:\"tag\";s:5:\"9.5.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.3.tar.gz\";s:4:\"date\";s:10:\"1675281829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.2\";s:7:\"version\";s:5:\"9.5.2\";s:3:\"tag\";s:5:\"9.5.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.2.tar.gz\";s:4:\"date\";s:10:\"1674066112\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.1\";s:7:\"version\";s:5:\"9.5.1\";s:3:\"tag\";s:5:\"9.5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.1.tar.gz\";s:4:\"date\";s:10:\"1672849046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.5.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.5.0\";s:7:\"version\";s:5:\"9.5.0\";s:3:\"tag\";s:5:\"9.5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.5.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.5.0.tar.gz\";s:4:\"date\";s:10:\"1671115839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.5.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.0-rc2\";s:7:\"version\";s:9:\"9.5.0-rc2\";s:3:\"tag\";s:9:\"9.5.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1670593040\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.5.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.0-rc1\";s:7:\"version\";s:9:\"9.5.0-rc1\";s:3:\"tag\";s:9:\"9.5.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1668611189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.5.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.5.0-beta2\";s:7:\"version\";s:11:\"9.5.0-beta2\";s:3:\"tag\";s:11:\"9.5.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.5.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1664463958\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.5.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.5.0-beta1\";s:7:\"version\";s:11:\"9.5.0-beta1\";s:3:\"tag\";s:11:\"9.5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.5.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1663358587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"9.4.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.15\";s:7:\"version\";s:6:\"9.4.15\";s:3:\"tag\";s:6:\"9.4.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.15.tar.gz\";s:4:\"date\";s:10:\"1683122076\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.14\";s:7:\"version\";s:6:\"9.4.14\";s:3:\"tag\";s:6:\"9.4.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.14.tar.gz\";s:4:\"date\";s:10:\"1681922120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.13\";s:7:\"version\";s:6:\"9.4.13\";s:3:\"tag\";s:6:\"9.4.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.13.tar.gz\";s:4:\"date\";s:10:\"1679665413\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.12\";s:7:\"version\";s:6:\"9.4.12\";s:3:\"tag\";s:6:\"9.4.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.12.tar.gz\";s:4:\"date\";s:10:\"1678901516\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.11\";s:7:\"version\";s:6:\"9.4.11\";s:3:\"tag\";s:6:\"9.4.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.11.tar.gz\";s:4:\"date\";s:10:\"1675282255\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.4.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.4.10\";s:7:\"version\";s:6:\"9.4.10\";s:3:\"tag\";s:6:\"9.4.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.4.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.4.10.tar.gz\";s:4:\"date\";s:10:\"1674066615\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.9\";s:7:\"version\";s:5:\"9.4.9\";s:3:\"tag\";s:5:\"9.4.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.9.tar.gz\";s:4:\"date\";s:10:\"1670421053\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.8\";s:7:\"version\";s:5:\"9.4.8\";s:3:\"tag\";s:5:\"9.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.8.tar.gz\";s:4:\"date\";s:10:\"1665072393\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.7\";s:7:\"version\";s:5:\"9.4.7\";s:3:\"tag\";s:5:\"9.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.7.tar.gz\";s:4:\"date\";s:10:\"1664383239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.6\";s:7:\"version\";s:5:\"9.4.6\";s:3:\"tag\";s:5:\"9.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.6.tar.gz\";s:4:\"date\";s:10:\"1663681319\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.5\";s:7:\"version\";s:5:\"9.4.5\";s:3:\"tag\";s:5:\"9.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.5.tar.gz\";s:4:\"date\";s:10:\"1659545453\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.4\";s:7:\"version\";s:5:\"9.4.4\";s:3:\"tag\";s:5:\"9.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.4.tar.gz\";s:4:\"date\";s:10:\"1659037490\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.3\";s:7:\"version\";s:5:\"9.4.3\";s:3:\"tag\";s:5:\"9.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.3.tar.gz\";s:4:\"date\";s:10:\"1658333415\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.2\";s:7:\"version\";s:5:\"9.4.2\";s:3:\"tag\";s:5:\"9.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.2.tar.gz\";s:4:\"date\";s:10:\"1657157309\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.1\";s:7:\"version\";s:5:\"9.4.1\";s:3:\"tag\";s:5:\"9.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.1.tar.gz\";s:4:\"date\";s:10:\"1655845511\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.4.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.4.0\";s:7:\"version\";s:5:\"9.4.0\";s:3:\"tag\";s:5:\"9.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.4.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.4.0.tar.gz\";s:4:\"date\";s:10:\"1655311138\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.4.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.0-rc2\";s:7:\"version\";s:9:\"9.4.0-rc2\";s:3:\"tag\";s:9:\"9.4.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1654890055\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.4.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.0-rc1\";s:7:\"version\";s:9:\"9.4.0-rc1\";s:3:\"tag\";s:9:\"9.4.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1654740019\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.4.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.4.0-beta1\";s:7:\"version\";s:11:\"9.4.0-beta1\";s:3:\"tag\";s:11:\"9.4.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.4.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1653938214\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.4.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.4.0-alpha1\";s:7:\"version\";s:12:\"9.4.0-alpha1\";s:3:\"tag\";s:12:\"9.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.4.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1651875606\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.3.22\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.22\";s:7:\"version\";s:6:\"9.3.22\";s:3:\"tag\";s:6:\"9.3.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.22\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.22.tar.gz\";s:4:\"date\";s:10:\"1664382666\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.21\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.21\";s:7:\"version\";s:6:\"9.3.21\";s:3:\"tag\";s:6:\"9.3.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.21\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.21.tar.gz\";s:4:\"date\";s:10:\"1659544886\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.20\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.20\";s:7:\"version\";s:6:\"9.3.20\";s:3:\"tag\";s:6:\"9.3.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.20.tar.gz\";s:4:\"date\";s:10:\"1659037977\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.19\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.19\";s:7:\"version\";s:6:\"9.3.19\";s:3:\"tag\";s:6:\"9.3.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.19.tar.gz\";s:4:\"date\";s:10:\"1658333887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.18\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.18\";s:7:\"version\";s:6:\"9.3.18\";s:3:\"tag\";s:6:\"9.3.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.18.tar.gz\";s:4:\"date\";s:10:\"1657238772\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.17\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.17\";s:7:\"version\";s:6:\"9.3.17\";s:3:\"tag\";s:6:\"9.3.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.17.tar.gz\";s:4:\"date\";s:10:\"1655846622\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.16\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.16\";s:7:\"version\";s:6:\"9.3.16\";s:3:\"tag\";s:6:\"9.3.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.16.tar.gz\";s:4:\"date\";s:10:\"1654888736\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.15\";s:7:\"version\";s:6:\"9.3.15\";s:3:\"tag\";s:6:\"9.3.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.15.tar.gz\";s:4:\"date\";s:10:\"1654098765\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.14\";s:7:\"version\";s:6:\"9.3.14\";s:3:\"tag\";s:6:\"9.3.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.14.tar.gz\";s:4:\"date\";s:10:\"1653506291\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.13\";s:7:\"version\";s:6:\"9.3.13\";s:3:\"tag\";s:6:\"9.3.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.13.tar.gz\";s:4:\"date\";s:10:\"1652261874\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.12\";s:7:\"version\";s:6:\"9.3.12\";s:3:\"tag\";s:6:\"9.3.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.12.tar.gz\";s:4:\"date\";s:10:\"1650467536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.11\";s:7:\"version\";s:6:\"9.3.11\";s:3:\"tag\";s:6:\"9.3.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.11.tar.gz\";s:4:\"date\";s:10:\"1649897391\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.3.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.3.10\";s:7:\"version\";s:6:\"9.3.10\";s:3:\"tag\";s:6:\"9.3.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.3.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.3.10.tar.gz\";s:4:\"date\";s:10:\"1649890098\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.9\";s:7:\"version\";s:5:\"9.3.9\";s:3:\"tag\";s:5:\"9.3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.9.tar.gz\";s:4:\"date\";s:10:\"1647899360\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.8\";s:7:\"version\";s:5:\"9.3.8\";s:3:\"tag\";s:5:\"9.3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.8.tar.gz\";s:4:\"date\";s:10:\"1647446914\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.7\";s:7:\"version\";s:5:\"9.3.7\";s:3:\"tag\";s:5:\"9.3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.7.tar.gz\";s:4:\"date\";s:10:\"1646300599\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.6\";s:7:\"version\";s:5:\"9.3.6\";s:3:\"tag\";s:5:\"9.3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.6.tar.gz\";s:4:\"date\";s:10:\"1645029460\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.5\";s:7:\"version\";s:5:\"9.3.5\";s:3:\"tag\";s:5:\"9.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.5.tar.gz\";s:4:\"date\";s:10:\"1644011676\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.4\";s:7:\"version\";s:5:\"9.3.4\";s:3:\"tag\";s:5:\"9.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.4.tar.gz\";s:4:\"date\";s:10:\"1643832805\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.3\";s:7:\"version\";s:5:\"9.3.3\";s:3:\"tag\";s:5:\"9.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.3.tar.gz\";s:4:\"date\";s:10:\"1642607769\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.2\";s:7:\"version\";s:5:\"9.3.2\";s:3:\"tag\";s:5:\"9.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.2.tar.gz\";s:4:\"date\";s:10:\"1641351799\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.1\";s:7:\"version\";s:5:\"9.3.1\";s:3:\"tag\";s:5:\"9.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.1.tar.gz\";s:4:\"date\";s:10:\"1641342679\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.3.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.3.0\";s:7:\"version\";s:5:\"9.3.0\";s:3:\"tag\";s:5:\"9.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.3.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.3.0.tar.gz\";s:4:\"date\";s:10:\"1639051276\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.3.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.3.0-rc1\";s:7:\"version\";s:9:\"9.3.0-rc1\";s:3:\"tag\";s:9:\"9.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.3.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1637959424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta3\";s:7:\"version\";s:11:\"9.3.0-beta3\";s:3:\"tag\";s:11:\"9.3.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1637764182\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta2\";s:7:\"version\";s:11:\"9.3.0-beta2\";s:3:\"tag\";s:11:\"9.3.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1637196496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.3.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.3.0-beta1\";s:7:\"version\";s:11:\"9.3.0-beta1\";s:3:\"tag\";s:11:\"9.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.3.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1636746050\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.3.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.3.0-alpha1\";s:7:\"version\";s:12:\"9.3.0-alpha1\";s:3:\"tag\";s:12:\"9.3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.3.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1635510285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.2.21\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.21\";s:7:\"version\";s:6:\"9.2.21\";s:3:\"tag\";s:6:\"9.2.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.21\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.21.tar.gz\";s:4:\"date\";s:10:\"1654889475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.20\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.20\";s:7:\"version\";s:6:\"9.2.20\";s:3:\"tag\";s:6:\"9.2.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.20.tar.gz\";s:4:\"date\";s:10:\"1653507225\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.19\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.19\";s:7:\"version\";s:6:\"9.2.19\";s:3:\"tag\";s:6:\"9.2.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.19.tar.gz\";s:4:\"date\";s:10:\"1652306637\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.18\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.18\";s:7:\"version\";s:6:\"9.2.18\";s:3:\"tag\";s:6:\"9.2.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.18.tar.gz\";s:4:\"date\";s:10:\"1650466972\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.17\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.17\";s:7:\"version\";s:6:\"9.2.17\";s:3:\"tag\";s:6:\"9.2.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.17.tar.gz\";s:4:\"date\";s:10:\"1649898006\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.16\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.16\";s:7:\"version\";s:6:\"9.2.16\";s:3:\"tag\";s:6:\"9.2.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.16.tar.gz\";s:4:\"date\";s:10:\"1647898826\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.15\";s:7:\"version\";s:6:\"9.2.15\";s:3:\"tag\";s:6:\"9.2.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.15.tar.gz\";s:4:\"date\";s:10:\"1647447411\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.14\";s:7:\"version\";s:6:\"9.2.14\";s:3:\"tag\";s:6:\"9.2.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.14.tar.gz\";s:4:\"date\";s:10:\"1647027629\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.13\";s:7:\"version\";s:6:\"9.2.13\";s:3:\"tag\";s:6:\"9.2.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.13.tar.gz\";s:4:\"date\";s:10:\"1645029955\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.12\";s:7:\"version\";s:6:\"9.2.12\";s:3:\"tag\";s:6:\"9.2.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.12.tar.gz\";s:4:\"date\";s:10:\"1644012448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.11\";s:7:\"version\";s:6:\"9.2.11\";s:3:\"tag\";s:6:\"9.2.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.11.tar.gz\";s:4:\"date\";s:10:\"1642608353\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.2.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.2.10\";s:7:\"version\";s:6:\"9.2.10\";s:3:\"tag\";s:6:\"9.2.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.2.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.2.10.tar.gz\";s:4:\"date\";s:10:\"1637765544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.9\";s:7:\"version\";s:5:\"9.2.9\";s:3:\"tag\";s:5:\"9.2.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.9.tar.gz\";s:4:\"date\";s:10:\"1637184936\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.8\";s:7:\"version\";s:5:\"9.2.8\";s:3:\"tag\";s:5:\"9.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.8.tar.gz\";s:4:\"date\";s:10:\"1635961216\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.7\";s:7:\"version\";s:5:\"9.2.7\";s:3:\"tag\";s:5:\"9.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.7.tar.gz\";s:4:\"date\";s:10:\"1633544267\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.6\";s:7:\"version\";s:5:\"9.2.6\";s:3:\"tag\";s:5:\"9.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.6.tar.gz\";s:4:\"date\";s:10:\"1631721555\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.5\";s:7:\"version\";s:5:\"9.2.5\";s:3:\"tag\";s:5:\"9.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.5.tar.gz\";s:4:\"date\";s:10:\"1630534729\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.4\";s:7:\"version\";s:5:\"9.2.4\";s:3:\"tag\";s:5:\"9.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.4.tar.gz\";s:4:\"date\";s:10:\"1628791178\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.3\";s:7:\"version\";s:5:\"9.2.3\";s:3:\"tag\";s:5:\"9.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.3.tar.gz\";s:4:\"date\";s:10:\"1627997922\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.2\";s:7:\"version\";s:5:\"9.2.2\";s:3:\"tag\";s:5:\"9.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.2.tar.gz\";s:4:\"date\";s:10:\"1626882385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.1\";s:7:\"version\";s:5:\"9.2.1\";s:3:\"tag\";s:5:\"9.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.1.tar.gz\";s:4:\"date\";s:10:\"1625664286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.2.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.2.0\";s:7:\"version\";s:5:\"9.2.0\";s:3:\"tag\";s:5:\"9.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.2.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.2.0.tar.gz\";s:4:\"date\";s:10:\"1623847798\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.2.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.2.0-rc1\";s:7:\"version\";s:9:\"9.2.0-rc1\";s:3:\"tag\";s:9:\"9.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.2.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1623080867\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta3\";s:7:\"version\";s:11:\"9.2.0-beta3\";s:3:\"tag\";s:11:\"9.2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1622207568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta2\";s:7:\"version\";s:11:\"9.2.0-beta2\";s:3:\"tag\";s:11:\"9.2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1622068611\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.2.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.2.0-beta1\";s:7:\"version\";s:11:\"9.2.0-beta1\";s:3:\"tag\";s:11:\"9.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.2.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1621506248\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.2.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.2.0-alpha1\";s:7:\"version\";s:12:\"9.2.0-alpha1\";s:3:\"tag\";s:12:\"9.2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.2.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1620291652\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.1.15\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.15\";s:7:\"version\";s:6:\"9.1.15\";s:3:\"tag\";s:6:\"9.1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.15.tar.gz\";s:4:\"date\";s:10:\"1637766681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.14\";s:7:\"version\";s:6:\"9.1.14\";s:3:\"tag\";s:6:\"9.1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.14.tar.gz\";s:4:\"date\";s:10:\"1637185450\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.13\";s:7:\"version\";s:6:\"9.1.13\";s:3:\"tag\";s:6:\"9.1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.13.tar.gz\";s:4:\"date\";s:10:\"1631722011\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.12\";s:7:\"version\";s:6:\"9.1.12\";s:3:\"tag\";s:6:\"9.1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.12.tar.gz\";s:4:\"date\";s:10:\"1628791786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.11\";s:7:\"version\";s:6:\"9.1.11\";s:3:\"tag\";s:6:\"9.1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.11.tar.gz\";s:4:\"date\";s:10:\"1626882849\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.1.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.1.10\";s:7:\"version\";s:6:\"9.1.10\";s:3:\"tag\";s:6:\"9.1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.1.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.1.10.tar.gz\";s:4:\"date\";s:10:\"1622828120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.9\";s:7:\"version\";s:5:\"9.1.9\";s:3:\"tag\";s:5:\"9.1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.9.tar.gz\";s:4:\"date\";s:10:\"1622056478\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.8\";s:7:\"version\";s:5:\"9.1.8\";s:3:\"tag\";s:5:\"9.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.8.tar.gz\";s:4:\"date\";s:10:\"1620214182\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.7\";s:7:\"version\";s:5:\"9.1.7\";s:3:\"tag\";s:5:\"9.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.7.tar.gz\";s:4:\"date\";s:10:\"1619022156\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.6\";s:7:\"version\";s:5:\"9.1.6\";s:3:\"tag\";s:5:\"9.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.6.tar.gz\";s:4:\"date\";s:10:\"1617795446\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.5\";s:7:\"version\";s:5:\"9.1.5\";s:3:\"tag\";s:5:\"9.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.5.tar.gz\";s:4:\"date\";s:10:\"1614869503\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.4\";s:7:\"version\";s:5:\"9.1.4\";s:3:\"tag\";s:5:\"9.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.4.tar.gz\";s:4:\"date\";s:10:\"1612380948\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.3\";s:7:\"version\";s:5:\"9.1.3\";s:3:\"tag\";s:5:\"9.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.3.tar.gz\";s:4:\"date\";s:10:\"1611161215\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.2\";s:7:\"version\";s:5:\"9.1.2\";s:3:\"tag\";s:5:\"9.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.2.tar.gz\";s:4:\"date\";s:10:\"1609984407\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.1\";s:7:\"version\";s:5:\"9.1.1\";s:3:\"tag\";s:5:\"9.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.1.tar.gz\";s:4:\"date\";s:10:\"1609979034\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.1.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.1.0\";s:7:\"version\";s:5:\"9.1.0\";s:3:\"tag\";s:5:\"9.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.1.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.1.0.tar.gz\";s:4:\"date\";s:10:\"1606933254\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.1.0-rc3\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc3\";s:7:\"version\";s:9:\"9.1.0-rc3\";s:3:\"tag\";s:9:\"9.1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1606357271\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.1.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc2\";s:7:\"version\";s:9:\"9.1.0-rc2\";s:3:\"tag\";s:9:\"9.1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1606332982\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"9.1.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.0-rc1\";s:7:\"version\";s:9:\"9.1.0-rc1\";s:3:\"tag\";s:9:\"9.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1605722782\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.1.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.1.0-beta1\";s:7:\"version\";s:11:\"9.1.0-beta1\";s:3:\"tag\";s:11:\"9.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.1.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1604672644\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.1.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.1.0-alpha1\";s:7:\"version\";s:12:\"9.1.0-alpha1\";s:3:\"tag\";s:12:\"9.1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.1.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1603466665\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"9.0.14\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.14\";s:7:\"version\";s:6:\"9.0.14\";s:3:\"tag\";s:6:\"9.0.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.14.tar.gz\";s:4:\"date\";s:10:\"1622055778\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.13\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.13\";s:7:\"version\";s:6:\"9.0.13\";s:3:\"tag\";s:6:\"9.0.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.13.tar.gz\";s:4:\"date\";s:10:\"1620218506\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.12\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.12\";s:7:\"version\";s:6:\"9.0.12\";s:3:\"tag\";s:6:\"9.0.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.12.tar.gz\";s:4:\"date\";s:10:\"1619020951\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.11\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.11\";s:7:\"version\";s:6:\"9.0.11\";s:3:\"tag\";s:6:\"9.0.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.11.tar.gz\";s:4:\"date\";s:10:\"1611161749\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"9.0.10\";a:10:{s:4:\"name\";s:13:\"drupal 9.0.10\";s:7:\"version\";s:6:\"9.0.10\";s:3:\"tag\";s:6:\"9.0.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/9.0.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-9.0.10.tar.gz\";s:4:\"date\";s:10:\"1607029536\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.9\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.9\";s:7:\"version\";s:5:\"9.0.9\";s:3:\"tag\";s:5:\"9.0.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.9.tar.gz\";s:4:\"date\";s:10:\"1606359757\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.8\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.8\";s:7:\"version\";s:5:\"9.0.8\";s:3:\"tag\";s:5:\"9.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.8.tar.gz\";s:4:\"date\";s:10:\"1605720638\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.7\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.7\";s:7:\"version\";s:5:\"9.0.7\";s:3:\"tag\";s:5:\"9.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.7.tar.gz\";s:4:\"date\";s:10:\"1602100055\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.6\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.6\";s:7:\"version\";s:5:\"9.0.6\";s:3:\"tag\";s:5:\"9.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.6.tar.gz\";s:4:\"date\";s:10:\"1600275813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.5\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.5\";s:7:\"version\";s:5:\"9.0.5\";s:3:\"tag\";s:5:\"9.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.5.tar.gz\";s:4:\"date\";s:10:\"1599167739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.4\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.4\";s:7:\"version\";s:5:\"9.0.4\";s:3:\"tag\";s:5:\"9.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.4.tar.gz\";s:4:\"date\";s:10:\"1599046734\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.3\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.3\";s:7:\"version\";s:5:\"9.0.3\";s:3:\"tag\";s:5:\"9.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.3.tar.gz\";s:4:\"date\";s:10:\"1596664575\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.2\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.2\";s:7:\"version\";s:5:\"9.0.2\";s:3:\"tag\";s:5:\"9.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.2.tar.gz\";s:4:\"date\";s:10:\"1594237418\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.1\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.1\";s:7:\"version\";s:5:\"9.0.1\";s:3:\"tag\";s:5:\"9.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.1.tar.gz\";s:4:\"date\";s:10:\"1592417721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"9.0.0\";a:10:{s:4:\"name\";s:12:\"drupal 9.0.0\";s:7:\"version\";s:5:\"9.0.0\";s:3:\"tag\";s:5:\"9.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/9.0.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-9.0.0.tar.gz\";s:4:\"date\";s:10:\"1591221685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"9.0.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 9.0.0-rc1\";s:7:\"version\";s:9:\"9.0.0-rc1\";s:3:\"tag\";s:9:\"9.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.0.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1590187579\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta3\";s:7:\"version\";s:11:\"9.0.0-beta3\";s:3:\"tag\";s:11:\"9.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1589587936\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta2\";s:7:\"version\";s:11:\"9.0.0-beta2\";s:3:\"tag\";s:11:\"9.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1585597395\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"9.0.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 9.0.0-beta1\";s:7:\"version\";s:11:\"9.0.0-beta1\";s:3:\"tag\";s:11:\"9.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/9.0.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1584734060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"9.0.0-alpha2\";a:10:{s:4:\"name\";s:19:\"drupal 9.0.0-alpha2\";s:7:\"version\";s:12:\"9.0.0-alpha2\";s:3:\"tag\";s:12:\"9.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.0.0-alpha2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1583349043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:12:\"9.0.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 9.0.0-alpha1\";s:7:\"version\";s:12:\"9.0.0-alpha1\";s:3:\"tag\";s:12:\"9.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/9.0.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-9.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1581447927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.9.20\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.20\";s:7:\"version\";s:6:\"8.9.20\";s:3:\"tag\";s:6:\"8.9.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.20\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.20.tar.gz\";s:4:\"date\";s:10:\"1637185966\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.19\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.19\";s:7:\"version\";s:6:\"8.9.19\";s:3:\"tag\";s:6:\"8.9.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.19\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.19.tar.gz\";s:4:\"date\";s:10:\"1631722431\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.18\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.18\";s:7:\"version\";s:6:\"8.9.18\";s:3:\"tag\";s:6:\"8.9.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.18.tar.gz\";s:4:\"date\";s:10:\"1628792296\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.17\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.17\";s:7:\"version\";s:6:\"8.9.17\";s:3:\"tag\";s:6:\"8.9.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.17.tar.gz\";s:4:\"date\";s:10:\"1626883324\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.16\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.16\";s:7:\"version\";s:6:\"8.9.16\";s:3:\"tag\";s:6:\"8.9.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.16.tar.gz\";s:4:\"date\";s:10:\"1622058087\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.15\";s:7:\"version\";s:6:\"8.9.15\";s:3:\"tag\";s:6:\"8.9.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.15.tar.gz\";s:4:\"date\";s:10:\"1620216983\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.14\";s:7:\"version\";s:6:\"8.9.14\";s:3:\"tag\";s:6:\"8.9.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.14.tar.gz\";s:4:\"date\";s:10:\"1619021518\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.13\";s:7:\"version\";s:6:\"8.9.13\";s:3:\"tag\";s:6:\"8.9.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.13.tar.gz\";s:4:\"date\";s:10:\"1611162272\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.12\";s:7:\"version\";s:6:\"8.9.12\";s:3:\"tag\";s:6:\"8.9.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.12.tar.gz\";s:4:\"date\";s:10:\"1609977009\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.11\";s:7:\"version\";s:6:\"8.9.11\";s:3:\"tag\";s:6:\"8.9.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.11.tar.gz\";s:4:\"date\";s:10:\"1607030087\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.9.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.9.10\";s:7:\"version\";s:6:\"8.9.10\";s:3:\"tag\";s:6:\"8.9.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.9.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.9.10.tar.gz\";s:4:\"date\";s:10:\"1606360301\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.9\";s:7:\"version\";s:5:\"8.9.9\";s:3:\"tag\";s:5:\"8.9.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.9.tar.gz\";s:4:\"date\";s:10:\"1605721120\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.8\";s:7:\"version\";s:5:\"8.9.8\";s:3:\"tag\";s:5:\"8.9.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.8.tar.gz\";s:4:\"date\";s:10:\"1604595269\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.7\";s:7:\"version\";s:5:\"8.9.7\";s:3:\"tag\";s:5:\"8.9.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.7.tar.gz\";s:4:\"date\";s:10:\"1602100507\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.6\";s:7:\"version\";s:5:\"8.9.6\";s:3:\"tag\";s:5:\"8.9.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.6.tar.gz\";s:4:\"date\";s:10:\"1600276267\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.5\";s:7:\"version\";s:5:\"8.9.5\";s:3:\"tag\";s:5:\"8.9.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.5.tar.gz\";s:4:\"date\";s:10:\"1599168205\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.4\";s:7:\"version\";s:5:\"8.9.4\";s:3:\"tag\";s:5:\"8.9.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.4.tar.gz\";s:4:\"date\";s:10:\"1599047691\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.3\";s:7:\"version\";s:5:\"8.9.3\";s:3:\"tag\";s:5:\"8.9.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.3.tar.gz\";s:4:\"date\";s:10:\"1596665051\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.2\";s:7:\"version\";s:5:\"8.9.2\";s:3:\"tag\";s:5:\"8.9.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.2.tar.gz\";s:4:\"date\";s:10:\"1594237961\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.1\";s:7:\"version\";s:5:\"8.9.1\";s:3:\"tag\";s:5:\"8.9.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.1.tar.gz\";s:4:\"date\";s:10:\"1592418237\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.9.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.9.0\";s:7:\"version\";s:5:\"8.9.0\";s:3:\"tag\";s:5:\"8.9.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.9.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.9.0.tar.gz\";s:4:\"date\";s:10:\"1591204117\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.9.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.9.0-rc1\";s:7:\"version\";s:9:\"8.9.0-rc1\";s:3:\"tag\";s:9:\"8.9.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.9.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1590189096\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta3\";s:7:\"version\";s:11:\"8.9.0-beta3\";s:3:\"tag\";s:11:\"8.9.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1589746375\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta2\";s:7:\"version\";s:11:\"8.9.0-beta2\";s:3:\"tag\";s:11:\"8.9.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1585863226\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.9.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.9.0-beta1\";s:7:\"version\";s:11:\"8.9.0-beta1\";s:3:\"tag\";s:11:\"8.9.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.9.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.9.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1585263710\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"8.8.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.12\";s:7:\"version\";s:6:\"8.8.12\";s:3:\"tag\";s:6:\"8.8.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.12.tar.gz\";s:4:\"date\";s:10:\"1606360866\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.8.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.11\";s:7:\"version\";s:6:\"8.8.11\";s:3:\"tag\";s:6:\"8.8.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.11.tar.gz\";s:4:\"date\";s:10:\"1605721628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.8.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.8.10\";s:7:\"version\";s:6:\"8.8.10\";s:3:\"tag\";s:6:\"8.8.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.8.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.8.10.tar.gz\";s:4:\"date\";s:10:\"1600276704\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.9\";s:7:\"version\";s:5:\"8.8.9\";s:3:\"tag\";s:5:\"8.8.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.9.tar.gz\";s:4:\"date\";s:10:\"1599168716\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.8\";s:7:\"version\";s:5:\"8.8.8\";s:3:\"tag\";s:5:\"8.8.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.8.tar.gz\";s:4:\"date\";s:10:\"1592418750\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.7\";s:7:\"version\";s:5:\"8.8.7\";s:3:\"tag\";s:5:\"8.8.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.7.tar.gz\";s:4:\"date\";s:10:\"1591203837\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.6\";s:7:\"version\";s:5:\"8.8.6\";s:3:\"tag\";s:5:\"8.8.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.6.tar.gz\";s:4:\"date\";s:10:\"1589989060\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.5\";s:7:\"version\";s:5:\"8.8.5\";s:3:\"tag\";s:5:\"8.8.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.5.tar.gz\";s:4:\"date\";s:10:\"1585861530\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.4\";s:7:\"version\";s:5:\"8.8.4\";s:3:\"tag\";s:5:\"8.8.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.4.tar.gz\";s:4:\"date\";s:10:\"1584560524\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.3\";s:7:\"version\";s:5:\"8.8.3\";s:3:\"tag\";s:5:\"8.8.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.3.tar.gz\";s:4:\"date\";s:10:\"1583347094\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.2\";s:7:\"version\";s:5:\"8.8.2\";s:3:\"tag\";s:5:\"8.8.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.2.tar.gz\";s:4:\"date\";s:10:\"1580598849\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.1\";s:7:\"version\";s:5:\"8.8.1\";s:3:\"tag\";s:5:\"8.8.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.1.tar.gz\";s:4:\"date\";s:10:\"1576695785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.8.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.8.0\";s:7:\"version\";s:5:\"8.8.0\";s:3:\"tag\";s:5:\"8.8.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.8.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.8.0.tar.gz\";s:4:\"date\";s:10:\"1575450481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.8.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.8.0-rc1\";s:7:\"version\";s:9:\"8.8.0-rc1\";s:3:\"tag\";s:9:\"8.8.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.8.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1574462580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.8.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.8.0-beta1\";s:7:\"version\";s:11:\"8.8.0-beta1\";s:3:\"tag\";s:11:\"8.8.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.8.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1573256280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.8.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.8.0-alpha1\";s:7:\"version\";s:12:\"8.8.0-alpha1\";s:3:\"tag\";s:12:\"8.8.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.8.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.8.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1571355784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.7.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.14\";s:7:\"version\";s:6:\"8.7.14\";s:3:\"tag\";s:6:\"8.7.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.14.tar.gz\";s:4:\"date\";s:10:\"1589988665\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.13\";s:7:\"version\";s:6:\"8.7.13\";s:3:\"tag\";s:6:\"8.7.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.13.tar.gz\";s:4:\"date\";s:10:\"1585861883\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.12\";s:7:\"version\";s:6:\"8.7.12\";s:3:\"tag\";s:6:\"8.7.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.12.tar.gz\";s:4:\"date\";s:10:\"1584552250\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.11\";s:7:\"version\";s:6:\"8.7.11\";s:3:\"tag\";s:6:\"8.7.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.11.tar.gz\";s:4:\"date\";s:10:\"1576695785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.7.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.7.10\";s:7:\"version\";s:6:\"8.7.10\";s:3:\"tag\";s:6:\"8.7.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.7.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.7.10.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.9\";s:7:\"version\";s:5:\"8.7.9\";s:3:\"tag\";s:5:\"8.7.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.9.tar.gz\";s:4:\"date\";s:10:\"1573063387\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.8\";s:7:\"version\";s:5:\"8.7.8\";s:3:\"tag\";s:5:\"8.7.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.8.tar.gz\";s:4:\"date\";s:10:\"1570044484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.7\";s:7:\"version\";s:5:\"8.7.7\";s:3:\"tag\";s:5:\"8.7.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.7.tar.gz\";s:4:\"date\";s:10:\"1567593185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.6\";s:7:\"version\";s:5:\"8.7.6\";s:3:\"tag\";s:5:\"8.7.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.6.tar.gz\";s:4:\"date\";s:10:\"1565206385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.5\";s:7:\"version\";s:5:\"8.7.5\";s:3:\"tag\";s:5:\"8.7.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.5.tar.gz\";s:4:\"date\";s:10:\"1563380885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.4\";s:7:\"version\";s:5:\"8.7.4\";s:3:\"tag\";s:5:\"8.7.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.4.tar.gz\";s:4:\"date\";s:10:\"1562225587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.3\";s:7:\"version\";s:5:\"8.7.3\";s:3:\"tag\";s:5:\"8.7.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.3.tar.gz\";s:4:\"date\";s:10:\"1559762581\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.2\";s:7:\"version\";s:5:\"8.7.2\";s:3:\"tag\";s:5:\"8.7.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.2.tar.gz\";s:4:\"date\";s:10:\"1558597086\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.1\";s:7:\"version\";s:5:\"8.7.1\";s:3:\"tag\";s:5:\"8.7.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.1.tar.gz\";s:4:\"date\";s:10:\"1557335588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.7.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.7.0\";s:7:\"version\";s:5:\"8.7.0\";s:3:\"tag\";s:5:\"8.7.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.7.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.7.0.tar.gz\";s:4:\"date\";s:10:\"1556737085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.7.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.7.0-rc1\";s:7:\"version\";s:9:\"8.7.0-rc1\";s:3:\"tag\";s:9:\"8.7.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.7.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1555603385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.7.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.7.0-beta2\";s:7:\"version\";s:11:\"8.7.0-beta2\";s:3:\"tag\";s:11:\"8.7.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.7.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1554684784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.7.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.7.0-beta1\";s:7:\"version\";s:11:\"8.7.0-beta1\";s:3:\"tag\";s:11:\"8.7.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.7.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1553881681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.7.0-alpha2\";a:10:{s:4:\"name\";s:19:\"drupal 8.7.0-alpha2\";s:7:\"version\";s:12:\"8.7.0-alpha2\";s:3:\"tag\";s:12:\"8.7.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.7.0-alpha2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1553106180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:12:\"8.7.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.7.0-alpha1\";s:7:\"version\";s:12:\"8.7.0-alpha1\";s:3:\"tag\";s:12:\"8.7.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.7.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.7.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1552602484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.6.18\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.18\";s:7:\"version\";s:6:\"8.6.18\";s:3:\"tag\";s:6:\"8.6.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.18\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.18.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.17\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.17\";s:7:\"version\";s:6:\"8.6.17\";s:3:\"tag\";s:6:\"8.6.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.17\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.17.tar.gz\";s:4:\"date\";s:10:\"1560756785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.16\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.16\";s:7:\"version\";s:6:\"8.6.16\";s:3:\"tag\";s:6:\"8.6.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.16\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.16.tar.gz\";s:4:\"date\";s:10:\"1557335588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.15\";s:7:\"version\";s:6:\"8.6.15\";s:3:\"tag\";s:6:\"8.6.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.15.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.14\";s:7:\"version\";s:6:\"8.6.14\";s:3:\"tag\";s:6:\"8.6.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.14.tar.gz\";s:4:\"date\";s:10:\"1554688384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.13\";s:7:\"version\";s:6:\"8.6.13\";s:3:\"tag\";s:6:\"8.6.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.13.tar.gz\";s:4:\"date\";s:10:\"1553099584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.12\";s:7:\"version\";s:6:\"8.6.12\";s:3:\"tag\";s:6:\"8.6.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.12.tar.gz\";s:4:\"date\";s:10:\"1552601584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.11\";s:7:\"version\";s:6:\"8.6.11\";s:3:\"tag\";s:6:\"8.6.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.11.tar.gz\";s:4:\"date\";s:10:\"1552511584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.6.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.6.10\";s:7:\"version\";s:6:\"8.6.10\";s:3:\"tag\";s:6:\"8.6.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.6.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.6.10.tar.gz\";s:4:\"date\";s:10:\"1550691784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.9\";s:7:\"version\";s:5:\"8.6.9\";s:3:\"tag\";s:5:\"8.6.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.9.tar.gz\";s:4:\"date\";s:10:\"1549628580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.8\";s:7:\"version\";s:5:\"8.6.8\";s:3:\"tag\";s:5:\"8.6.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.8.tar.gz\";s:4:\"date\";s:10:\"1549466580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.7\";s:7:\"version\";s:5:\"8.6.7\";s:3:\"tag\";s:5:\"8.6.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.7.tar.gz\";s:4:\"date\";s:10:\"1547682180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.6\";s:7:\"version\";s:5:\"8.6.6\";s:3:\"tag\";s:5:\"8.6.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.6.tar.gz\";s:4:\"date\";s:10:\"1547663557\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.5\";s:7:\"version\";s:5:\"8.6.5\";s:3:\"tag\";s:5:\"8.6.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.5.tar.gz\";s:4:\"date\";s:10:\"1546467485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.4\";s:7:\"version\";s:5:\"8.6.4\";s:3:\"tag\";s:5:\"8.6.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.4.tar.gz\";s:4:\"date\";s:10:\"1544011681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.3\";s:7:\"version\";s:5:\"8.6.3\";s:3:\"tag\";s:5:\"8.6.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.3.tar.gz\";s:4:\"date\";s:10:\"1541602684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.2\";s:7:\"version\";s:5:\"8.6.2\";s:3:\"tag\";s:5:\"8.6.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.2.tar.gz\";s:4:\"date\";s:10:\"1539816180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.1\";s:7:\"version\";s:5:\"8.6.1\";s:3:\"tag\";s:5:\"8.6.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.1.tar.gz\";s:4:\"date\";s:10:\"1536585780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.6.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.6.0\";s:7:\"version\";s:5:\"8.6.0\";s:3:\"tag\";s:5:\"8.6.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.6.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.6.0.tar.gz\";s:4:\"date\";s:10:\"1536186480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.6.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.6.0-rc1\";s:7:\"version\";s:9:\"8.6.0-rc1\";s:3:\"tag\";s:9:\"8.6.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.6.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1534532580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.6.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.6.0-beta2\";s:7:\"version\";s:11:\"8.6.0-beta2\";s:3:\"tag\";s:11:\"8.6.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.6.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1533298080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.6.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.6.0-beta1\";s:7:\"version\";s:11:\"8.6.0-beta1\";s:3:\"tag\";s:11:\"8.6.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.6.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1533270485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.6.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.6.0-alpha1\";s:7:\"version\";s:12:\"8.6.0-alpha1\";s:3:\"tag\";s:12:\"8.6.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.6.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.6.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1532033881\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:6:\"8.5.15\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.15\";s:7:\"version\";s:6:\"8.5.15\";s:3:\"tag\";s:6:\"8.5.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.15\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.15.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.14\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.14\";s:7:\"version\";s:6:\"8.5.14\";s:3:\"tag\";s:6:\"8.5.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.14\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.14.tar.gz\";s:4:\"date\";s:10:\"1553099584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.13\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.13\";s:7:\"version\";s:6:\"8.5.13\";s:3:\"tag\";s:6:\"8.5.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.13\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.13.tar.gz\";s:4:\"date\";s:10:\"1552601584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.12\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.12\";s:7:\"version\";s:6:\"8.5.12\";s:3:\"tag\";s:6:\"8.5.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.12\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.12.tar.gz\";s:4:\"date\";s:10:\"1552511584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.11\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.11\";s:7:\"version\";s:6:\"8.5.11\";s:3:\"tag\";s:6:\"8.5.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.11\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.11.tar.gz\";s:4:\"date\";s:10:\"1550691784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:6:\"8.5.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.5.10\";s:7:\"version\";s:6:\"8.5.10\";s:3:\"tag\";s:6:\"8.5.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.5.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.5.10.tar.gz\";s:4:\"date\";s:10:\"1547682180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.9\";s:7:\"version\";s:5:\"8.5.9\";s:3:\"tag\";s:5:\"8.5.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.9.tar.gz\";s:4:\"date\";s:10:\"1547663557\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.8\";s:7:\"version\";s:5:\"8.5.8\";s:3:\"tag\";s:5:\"8.5.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.8.tar.gz\";s:4:\"date\";s:10:\"1539816180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.7\";s:7:\"version\";s:5:\"8.5.7\";s:3:\"tag\";s:5:\"8.5.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.7.tar.gz\";s:4:\"date\";s:10:\"1536187080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.6\";s:7:\"version\";s:5:\"8.5.6\";s:3:\"tag\";s:5:\"8.5.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.6.tar.gz\";s:4:\"date\";s:10:\"1533156780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.5\";s:7:\"version\";s:5:\"8.5.5\";s:3:\"tag\";s:5:\"8.5.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.5.tar.gz\";s:4:\"date\";s:10:\"1530738820\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.4\";s:7:\"version\";s:5:\"8.5.4\";s:3:\"tag\";s:5:\"8.5.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.4.tar.gz\";s:4:\"date\";s:10:\"1528319584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.3\";s:7:\"version\";s:5:\"8.5.3\";s:3:\"tag\";s:5:\"8.5.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.3.tar.gz\";s:4:\"date\";s:10:\"1524672780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.2\";s:7:\"version\";s:5:\"8.5.2\";s:3:\"tag\";s:5:\"8.5.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.2.tar.gz\";s:4:\"date\";s:10:\"1524073147\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.1\";s:7:\"version\";s:5:\"8.5.1\";s:3:\"tag\";s:5:\"8.5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.1.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.5.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.5.0\";s:7:\"version\";s:5:\"8.5.0\";s:3:\"tag\";s:5:\"8.5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.5.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.5.0.tar.gz\";s:4:\"date\";s:10:\"1520457780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.5.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.5.0-rc1\";s:7:\"version\";s:9:\"8.5.0-rc1\";s:3:\"tag\";s:9:\"8.5.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.5.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1519234680\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";i:2;s:9:\"Bug fixes\";i:3;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.5.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.5.0-beta1\";s:7:\"version\";s:11:\"8.5.0-beta1\";s:3:\"tag\";s:11:\"8.5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.5.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1518211380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.5.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.5.0-alpha1\";s:7:\"version\";s:12:\"8.5.0-alpha1\";s:3:\"tag\";s:12:\"8.5.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.5.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.5.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1516320484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.4.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.8\";s:7:\"version\";s:5:\"8.4.8\";s:3:\"tag\";s:5:\"8.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.8.tar.gz\";s:4:\"date\";s:10:\"1524672780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.7\";s:7:\"version\";s:5:\"8.4.7\";s:3:\"tag\";s:5:\"8.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.7.tar.gz\";s:4:\"date\";s:10:\"1524073147\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.6\";s:7:\"version\";s:5:\"8.4.6\";s:3:\"tag\";s:5:\"8.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.6.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.5\";s:7:\"version\";s:5:\"8.4.5\";s:3:\"tag\";s:5:\"8.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.5.tar.gz\";s:4:\"date\";s:10:\"1519234680\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.4\";s:7:\"version\";s:5:\"8.4.4\";s:3:\"tag\";s:5:\"8.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.4.tar.gz\";s:4:\"date\";s:10:\"1515021185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.3\";s:7:\"version\";s:5:\"8.4.3\";s:3:\"tag\";s:5:\"8.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.3.tar.gz\";s:4:\"date\";s:10:\"1512600784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.2\";s:7:\"version\";s:5:\"8.4.2\";s:3:\"tag\";s:5:\"8.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.2.tar.gz\";s:4:\"date\";s:10:\"1509719885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.1\";s:7:\"version\";s:5:\"8.4.1\";s:3:\"tag\";s:5:\"8.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.1.tar.gz\";s:4:\"date\";s:10:\"1509562384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.4.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.4.0\";s:7:\"version\";s:5:\"8.4.0\";s:3:\"tag\";s:5:\"8.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.4.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.4.0.tar.gz\";s:4:\"date\";s:10:\"1507146244\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.4.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.0-rc2\";s:7:\"version\";s:9:\"8.4.0-rc2\";s:3:\"tag\";s:9:\"8.4.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1505911444\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.4.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.0-rc1\";s:7:\"version\";s:9:\"8.4.0-rc1\";s:3:\"tag\";s:9:\"8.4.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1504733043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.4.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.4.0-beta1\";s:7:\"version\";s:11:\"8.4.0-beta1\";s:3:\"tag\";s:11:\"8.4.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.4.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1502992144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.4.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.4.0-alpha1\";s:7:\"version\";s:12:\"8.4.0-alpha1\";s:3:\"tag\";s:12:\"8.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.4.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1501790944\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.3.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.9\";s:7:\"version\";s:5:\"8.3.9\";s:3:\"tag\";s:5:\"8.3.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.9.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.8\";s:7:\"version\";s:5:\"8.3.8\";s:3:\"tag\";s:5:\"8.3.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.8.tar.gz\";s:4:\"date\";s:10:\"1520881985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";i:2;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.7\";s:7:\"version\";s:5:\"8.3.7\";s:3:\"tag\";s:5:\"8.3.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.7.tar.gz\";s:4:\"date\";s:10:\"1502903903\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.6\";s:7:\"version\";s:5:\"8.3.6\";s:3:\"tag\";s:5:\"8.3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.6.tar.gz\";s:4:\"date\";s:10:\"1501688043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.5\";s:7:\"version\";s:5:\"8.3.5\";s:3:\"tag\";s:5:\"8.3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.5.tar.gz\";s:4:\"date\";s:10:\"1499274843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.4\";s:7:\"version\";s:5:\"8.3.4\";s:3:\"tag\";s:5:\"8.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.4.tar.gz\";s:4:\"date\";s:10:\"1498069442\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.3\";s:7:\"version\";s:5:\"8.3.3\";s:3:\"tag\";s:5:\"8.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.3.tar.gz\";s:4:\"date\";s:10:\"1496858041\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.2\";s:7:\"version\";s:5:\"8.3.2\";s:3:\"tag\";s:5:\"8.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.2.tar.gz\";s:4:\"date\";s:10:\"1493834585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.1\";s:7:\"version\";s:5:\"8.3.1\";s:3:\"tag\";s:5:\"8.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.1.tar.gz\";s:4:\"date\";s:10:\"1492622946\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.3.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.3.0\";s:7:\"version\";s:5:\"8.3.0\";s:3:\"tag\";s:5:\"8.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.3.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.3.0.tar.gz\";s:4:\"date\";s:10:\"1491439084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.3.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.0-rc2\";s:7:\"version\";s:9:\"8.3.0-rc2\";s:3:\"tag\";s:9:\"8.3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1489613583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.3.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.0-rc1\";s:7:\"version\";s:9:\"8.3.0-rc1\";s:3:\"tag\";s:9:\"8.3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1488383284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.3.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.3.0-beta1\";s:7:\"version\";s:11:\"8.3.0-beta1\";s:3:\"tag\";s:11:\"8.3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.3.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1487175783\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.3.0-alpha1\";a:10:{s:4:\"name\";s:19:\"drupal 8.3.0-alpha1\";s:7:\"version\";s:12:\"8.3.0-alpha1\";s:3:\"tag\";s:12:\"8.3.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.3.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.3.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1485968583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:5:\"8.2.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.8\";s:7:\"version\";s:5:\"8.2.8\";s:3:\"tag\";s:5:\"8.2.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.8.tar.gz\";s:4:\"date\";s:10:\"1492622852\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.7\";s:7:\"version\";s:5:\"8.2.7\";s:3:\"tag\";s:5:\"8.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.7.tar.gz\";s:4:\"date\";s:10:\"1489609638\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.6\";s:7:\"version\";s:5:\"8.2.6\";s:3:\"tag\";s:5:\"8.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.6.tar.gz\";s:4:\"date\";s:10:\"1485975485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.5\";s:7:\"version\";s:5:\"8.2.5\";s:3:\"tag\";s:5:\"8.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.5.tar.gz\";s:4:\"date\";s:10:\"1483529942\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.4\";s:7:\"version\";s:5:\"8.2.4\";s:3:\"tag\";s:5:\"8.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.4.tar.gz\";s:4:\"date\";s:10:\"1481136784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.3\";s:7:\"version\";s:5:\"8.2.3\";s:3:\"tag\";s:5:\"8.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.3.tar.gz\";s:4:\"date\";s:10:\"1479322439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.2\";s:7:\"version\";s:5:\"8.2.2\";s:3:\"tag\";s:5:\"8.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.2.tar.gz\";s:4:\"date\";s:10:\"1478106542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.1\";s:7:\"version\";s:5:\"8.2.1\";s:3:\"tag\";s:5:\"8.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.1.tar.gz\";s:4:\"date\";s:10:\"1476181439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.2.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.2.0\";s:7:\"version\";s:5:\"8.2.0\";s:3:\"tag\";s:5:\"8.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.2.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.2.0.tar.gz\";s:4:\"date\";s:10:\"1475660639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.2.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.0-rc2\";s:7:\"version\";s:9:\"8.2.0-rc2\";s:3:\"tag\";s:9:\"8.2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1474484358\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.2.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.0-rc1\";s:7:\"version\";s:9:\"8.2.0-rc1\";s:3:\"tag\";s:9:\"8.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1473285089\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta3\";s:7:\"version\";s:11:\"8.2.0-beta3\";s:3:\"tag\";s:11:\"8.2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1472222475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta2\";s:7:\"version\";s:11:\"8.2.0-beta2\";s:3:\"tag\";s:11:\"8.2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1471710839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.2.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.2.0-beta1\";s:7:\"version\";s:11:\"8.2.0-beta1\";s:3:\"tag\";s:11:\"8.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.2.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1470230639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:6:\"8.1.10\";a:10:{s:4:\"name\";s:13:\"drupal 8.1.10\";s:7:\"version\";s:6:\"8.1.10\";s:3:\"tag\";s:6:\"8.1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/drupal/releases/8.1.10\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/drupal-8.1.10.tar.gz\";s:4:\"date\";s:10:\"1474478939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.9\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.9\";s:7:\"version\";s:5:\"8.1.9\";s:3:\"tag\";s:5:\"8.1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.9\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.9.tar.gz\";s:4:\"date\";s:10:\"1473276313\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.8\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.8\";s:7:\"version\";s:5:\"8.1.8\";s:3:\"tag\";s:5:\"8.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.8\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.8.tar.gz\";s:4:\"date\";s:10:\"1470233647\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.7\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.7\";s:7:\"version\";s:5:\"8.1.7\";s:3:\"tag\";s:5:\"8.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.7\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.7.tar.gz\";s:4:\"date\";s:10:\"1468855358\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.6\";s:7:\"version\";s:5:\"8.1.6\";s:3:\"tag\";s:5:\"8.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.6.tar.gz\";s:4:\"date\";s:10:\"1468242539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.5\";s:7:\"version\";s:5:\"8.1.5\";s:3:\"tag\";s:5:\"8.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.5.tar.gz\";s:4:\"date\";s:10:\"1467884639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.4\";s:7:\"version\";s:5:\"8.1.4\";s:3:\"tag\";s:5:\"8.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.4.tar.gz\";s:4:\"date\";s:10:\"1467810839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.3\";s:7:\"version\";s:5:\"8.1.3\";s:3:\"tag\";s:5:\"8.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.3.tar.gz\";s:4:\"date\";s:10:\"1466021480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.2\";s:7:\"version\";s:5:\"8.1.2\";s:3:\"tag\";s:5:\"8.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.2.tar.gz\";s:4:\"date\";s:10:\"1464824339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.1\";s:7:\"version\";s:5:\"8.1.1\";s:3:\"tag\";s:5:\"8.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.1.tar.gz\";s:4:\"date\";s:10:\"1462361039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.1.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.1.0\";s:7:\"version\";s:5:\"8.1.0\";s:3:\"tag\";s:5:\"8.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.1.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.1.0.tar.gz\";s:4:\"date\";s:10:\"1461118190\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.1.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.1.0-rc1\";s:7:\"version\";s:9:\"8.1.0-rc1\";s:3:\"tag\";s:9:\"8.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.1.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1459976639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:11:\"8.1.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.1.0-beta2\";s:7:\"version\";s:11:\"8.1.0-beta2\";s:3:\"tag\";s:11:\"8.1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.1.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1458699840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.1.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.1.0-beta1\";s:7:\"version\";s:11:\"8.1.0-beta1\";s:3:\"tag\";s:11:\"8.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.1.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1456975758\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:5:\"8.0.6\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.6\";s:7:\"version\";s:5:\"8.0.6\";s:3:\"tag\";s:5:\"8.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.6\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.6.tar.gz\";s:4:\"date\";s:10:\"1459900439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.5\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.5\";s:7:\"version\";s:5:\"8.0.5\";s:3:\"tag\";s:5:\"8.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.5\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.5.tar.gz\";s:4:\"date\";s:10:\"1456914839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.4\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.4\";s:7:\"version\";s:5:\"8.0.4\";s:3:\"tag\";s:5:\"8.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.4.tar.gz\";s:4:\"date\";s:10:\"1456341749\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.3\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.3\";s:7:\"version\";s:5:\"8.0.3\";s:3:\"tag\";s:5:\"8.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.3.tar.gz\";s:4:\"date\";s:10:\"1454489043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.2\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.2\";s:7:\"version\";s:5:\"8.0.2\";s:3:\"tag\";s:5:\"8.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.2.tar.gz\";s:4:\"date\";s:10:\"1452119939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.1\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.1\";s:7:\"version\";s:5:\"8.0.1\";s:3:\"tag\";s:5:\"8.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.1.tar.gz\";s:4:\"date\";s:10:\"1449066839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:5:\"8.0.0\";a:10:{s:4:\"name\";s:12:\"drupal 8.0.0\";s:7:\"version\";s:5:\"8.0.0\";s:3:\"tag\";s:5:\"8.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/drupal/releases/8.0.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/drupal-8.0.0.tar.gz\";s:4:\"date\";s:10:\"1447941840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";}s:9:\"8.0.0-rc4\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc4\";s:7:\"version\";s:9:\"8.0.0-rc4\";s:3:\"tag\";s:9:\"8.0.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc4\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1447413840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc3\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc3\";s:7:\"version\";s:9:\"8.0.0-rc3\";s:3:\"tag\";s:9:\"8.0.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1446633239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc2\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc2\";s:7:\"version\";s:9:\"8.0.0-rc2\";s:3:\"tag\";s:9:\"8.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1445468639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:9:\"8.0.0-rc1\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.0-rc1\";s:7:\"version\";s:9:\"8.0.0-rc1\";s:3:\"tag\";s:9:\"8.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1444253039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta16\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta16\";s:7:\"version\";s:12:\"8.0.0-beta16\";s:3:\"tag\";s:12:\"8.0.0-beta16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta16\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta16.tar.gz\";s:4:\"date\";s:10:\"1443746640\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta15\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta15\";s:7:\"version\";s:12:\"8.0.0-beta15\";s:3:\"tag\";s:12:\"8.0.0-beta15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta15\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta15.tar.gz\";s:4:\"date\";s:10:\"1441357140\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta14\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta14\";s:7:\"version\";s:12:\"8.0.0-beta14\";s:3:\"tag\";s:12:\"8.0.0-beta14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta14.tar.gz\";s:4:\"date\";s:10:\"1438593539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta13\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta13\";s:7:\"version\";s:12:\"8.0.0-beta13\";s:3:\"tag\";s:12:\"8.0.0-beta13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta13.tar.gz\";s:4:\"date\";s:10:\"1438194539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta12\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta12\";s:7:\"version\";s:12:\"8.0.0-beta12\";s:3:\"tag\";s:12:\"8.0.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1435601583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta11\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta11\";s:7:\"version\";s:12:\"8.0.0-beta11\";s:3:\"tag\";s:12:\"8.0.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1432758481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:12:\"8.0.0-beta10\";a:10:{s:4:\"name\";s:19:\"drupal 8.0.0-beta10\";s:7:\"version\";s:12:\"8.0.0-beta10\";s:3:\"tag\";s:12:\"8.0.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1430314681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta9\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta9\";s:7:\"version\";s:11:\"8.0.0-beta9\";s:3:\"tag\";s:11:\"8.0.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1427299981\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta7\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta7\";s:7:\"version\";s:11:\"8.0.0-beta7\";s:3:\"tag\";s:11:\"8.0.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1424875381\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta6\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta6\";s:7:\"version\";s:11:\"8.0.0-beta6\";s:3:\"tag\";s:11:\"8.0.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1422443800\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta4\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta4\";s:7:\"version\";s:11:\"8.0.0-beta4\";s:3:\"tag\";s:11:\"8.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1418825280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta3\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta3\";s:7:\"version\";s:11:\"8.0.0-beta3\";s:3:\"tag\";s:11:\"8.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1415797380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta2\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta2\";s:7:\"version\";s:11:\"8.0.0-beta2\";s:3:\"tag\";s:11:\"8.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1413394161\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:8:\"Insecure\";i:1;s:15:\"Security update\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:11:\"8.0.0-beta1\";a:10:{s:4:\"name\";s:18:\"drupal 8.0.0-beta1\";s:7:\"version\";s:11:\"8.0.0-beta1\";s:3:\"tag\";s:11:\"8.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1412147030\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";}s:13:\"8.0.0-alpha15\";a:10:{s:4:\"name\";s:20:\"drupal 8.0.0-alpha15\";s:7:\"version\";s:13:\"8.0.0-alpha15\";s:3:\"tag\";s:13:\"8.0.0-alpha15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/8.0.0-alpha15\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-alpha15.tar.gz\";s:4:\"date\";s:10:\"1411139628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:13:\"8.0.0-alpha14\";a:10:{s:4:\"name\";s:20:\"drupal 8.0.0-alpha14\";s:7:\"version\";s:13:\"8.0.0-alpha14\";s:3:\"tag\";s:13:\"8.0.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/drupal/releases/8.0.0-alpha14\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/drupal-8.0.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1407344628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha13\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha13\";s:7:\"version\";s:11:\"8.0-alpha13\";s:3:\"tag\";s:11:\"8.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha13\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1404296627\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha12\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha12\";s:7:\"version\";s:11:\"8.0-alpha12\";s:3:\"tag\";s:11:\"8.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha12\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1401293627\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha11\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha11\";s:7:\"version\";s:11:\"8.0-alpha11\";s:3:\"tag\";s:11:\"8.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha11\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1398249227\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:11:\"8.0-alpha10\";a:10:{s:4:\"name\";s:18:\"drupal 8.0-alpha10\";s:7:\"version\";s:11:\"8.0-alpha10\";s:3:\"tag\";s:11:\"8.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/drupal/releases/8.0-alpha10\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1395231556\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha9\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha9\";s:7:\"version\";s:10:\"8.0-alpha9\";s:3:\"tag\";s:10:\"8.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha9\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1392806005\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha8\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha8\";s:7:\"version\";s:10:\"8.0-alpha8\";s:3:\"tag\";s:10:\"8.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha8\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1390393105\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha7\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha7\";s:7:\"version\";s:10:\"8.0-alpha7\";s:3:\"tag\";s:10:\"8.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha7\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1387399705\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha6\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha6\";s:7:\"version\";s:10:\"8.0-alpha6\";s:3:\"tag\";s:10:\"8.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1385153305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha5\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha5\";s:7:\"version\";s:10:\"8.0-alpha5\";s:3:\"tag\";s:10:\"8.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1384850305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha4\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha4\";s:7:\"version\";s:10:\"8.0-alpha4\";s:3:\"tag\";s:10:\"8.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1382092313\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:12:\"New features\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha3\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha3\";s:7:\"version\";s:10:\"8.0-alpha3\";s:3:\"tag\";s:10:\"8.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1378303307\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:12:\"New features\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"8.0-alpha2\";a:10:{s:4:\"name\";s:17:\"drupal 8.0-alpha2\";s:7:\"version\";s:10:\"8.0-alpha2\";s:3:\"tag\";s:10:\"8.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/8.0-alpha2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-8.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1372069563\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";}s:10:\"11.0.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 11.0.x-dev\";s:7:\"version\";s:10:\"11.0.x-dev\";s:3:\"tag\";s:6:\"11.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/11.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-11.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722992395\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:8:\"11.x-dev\";a:10:{s:4:\"name\";s:15:\"drupal 11.x-dev\";s:7:\"version\";s:8:\"11.x-dev\";s:3:\"tag\";s:4:\"11.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/drupal/releases/11.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/drupal-11.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722992834\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:10:\"10.4.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.4.x-dev\";s:7:\"version\";s:10:\"10.4.x-dev\";s:3:\"tag\";s:6:\"10.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.4.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722901731\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.3.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.3.x-dev\";s:7:\"version\";s:10:\"10.3.x-dev\";s:3:\"tag\";s:6:\"10.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.3.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722901284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.2.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.2.x-dev\";s:7:\"version\";s:10:\"10.2.x-dev\";s:3:\"tag\";s:6:\"10.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.2.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1717659333\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.1.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.1.x-dev\";s:7:\"version\";s:10:\"10.1.x-dev\";s:3:\"tag\";s:6:\"10.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.1.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1713001795\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:10:\"10.0.x-dev\";a:10:{s:4:\"name\";s:17:\"drupal 10.0.x-dev\";s:7:\"version\";s:10:\"10.0.x-dev\";s:3:\"tag\";s:6:\"10.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/drupal/releases/10.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/drupal-10.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1696930730\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"9.5.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.5.x-dev\";s:7:\"version\";s:9:\"9.5.x-dev\";s:3:\"tag\";s:5:\"9.5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.5.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1701801362\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.4.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.4.x-dev\";s:7:\"version\";s:9:\"9.4.x-dev\";s:3:\"tag\";s:5:\"9.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.4.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1683123227\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.3.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.3.x-dev\";s:7:\"version\";s:9:\"9.3.x-dev\";s:3:\"tag\";s:5:\"9.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.3.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1664385919\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"9.2.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.2.x-dev\";s:7:\"version\";s:9:\"9.2.x-dev\";s:3:\"tag\";s:5:\"9.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.2.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1654891907\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.1.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.1.x-dev\";s:7:\"version\";s:9:\"9.1.x-dev\";s:3:\"tag\";s:5:\"9.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.1.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1637766277\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"9.0.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 9.0.x-dev\";s:7:\"version\";s:9:\"9.0.x-dev\";s:3:\"tag\";s:5:\"9.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/9.0.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-9.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1622063424\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.9.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.9.x-dev\";s:7:\"version\";s:9:\"8.9.x-dev\";s:3:\"tag\";s:5:\"8.9.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.9.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.9.x-dev.tar.gz\";s:4:\"date\";s:10:\"1637188625\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.8.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.8.x-dev\";s:7:\"version\";s:9:\"8.8.x-dev\";s:3:\"tag\";s:5:\"8.8.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.8.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.8.x-dev.tar.gz\";s:4:\"date\";s:10:\"1606364994\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.7.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.7.x-dev\";s:7:\"version\";s:9:\"8.7.x-dev\";s:3:\"tag\";s:5:\"8.7.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.7.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.7.x-dev.tar.gz\";s:4:\"date\";s:10:\"1589987612\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.6.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.6.x-dev\";s:7:\"version\";s:9:\"8.6.x-dev\";s:3:\"tag\";s:5:\"8.6.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.6.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.6.x-dev.tar.gz\";s:4:\"date\";s:10:\"1573687985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}s:9:\"8.5.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.5.x-dev\";s:7:\"version\";s:9:\"8.5.x-dev\";s:3:\"tag\";s:5:\"8.5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.5.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1555533181\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.4.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.4.x-dev\";s:7:\"version\";s:9:\"8.4.x-dev\";s:3:\"tag\";s:5:\"8.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.4.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1533047880\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.3.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.3.x-dev\";s:7:\"version\";s:9:\"8.3.x-dev\";s:3:\"tag\";s:5:\"8.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.3.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1522263480\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.2.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.2.x-dev\";s:7:\"version\";s:9:\"8.2.x-dev\";s:3:\"tag\";s:5:\"8.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.2.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1492624982\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.1.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.1.x-dev\";s:7:\"version\";s:9:\"8.1.x-dev\";s:3:\"tag\";s:5:\"8.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.1.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1474478393\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}s:9:\"8.0.x-dev\";a:10:{s:4:\"name\";s:16:\"drupal 8.0.x-dev\";s:7:\"version\";s:9:\"8.0.x-dev\";s:3:\"tag\";s:5:\"8.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/drupal/releases/8.0.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/drupal-8.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1459900439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";}}s:10:\"last_fetch\";i:1723018802;}',	1723105202),
('update_available_releases',	'ebt_accordion',	'a:10:{s:5:\"title\";s:40:\"Extra Block Types (EBT): Accordion / FAQ\";s:10:\"short_name\";s:13:\"ebt_accordion\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:20:\"drupal/ebt_accordion\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ebt_accordion\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:20:{s:5:\"1.4.6\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.4.6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1718776362\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.4.5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1714474504\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.4.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1697704088\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.4.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1691259045\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1678016548\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.4.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1675846651\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1675770205\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.3.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1658239218\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.3.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644246133\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.2.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1641046893\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.2.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1640866711\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.2\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.0.2\";s:7:\"version\";s:5:\"1.0.2\";s:3:\"tag\";s:5:\"1.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.0.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.0.2.tar.gz\";s:4:\"date\";s:10:\"1612006312\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.0.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1611930382\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:19:\"ebt_accordion 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_accordion/releases/1.0.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1611664842\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:25:\"ebt_accordion 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/ebt_accordion/releases/1.0.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1610448829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha3\";a:11:{s:4:\"name\";s:26:\"ebt_accordion 1.0.0-alpha3\";s:7:\"version\";s:12:\"1.0.0-alpha3\";s:3:\"tag\";s:12:\"1.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_accordion/releases/1.0.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1610302670\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha2\";a:11:{s:4:\"name\";s:26:\"ebt_accordion 1.0.0-alpha2\";s:7:\"version\";s:12:\"1.0.0-alpha2\";s:3:\"tag\";s:12:\"1.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_accordion/releases/1.0.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1610279844\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha1\";a:11:{s:4:\"name\";s:26:\"ebt_accordion 1.0.0-alpha1\";s:7:\"version\";s:12:\"1.0.0-alpha1\";s:3:\"tag\";s:12:\"1.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_accordion/releases/1.0.0-alpha1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1610198076\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:23:\"ebt_accordion 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_accordion/releases/1.4.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407077\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:23:\"ebt_accordion 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_accordion/releases/1.3.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_accordion-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1675338733\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}}s:10:\"last_fetch\";i:1723018802;}',	1723105202),
('update_available_releases',	'ebt_basic_button',	'a:10:{s:5:\"title\";s:37:\"Extra Block Types (EBT): Basic Button\";s:10:\"short_name\";s:16:\"ebt_basic_button\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:23:\"drupal/ebt_basic_button\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:47:\"https://www.drupal.org/project/ebt_basic_button\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:20:{s:6:\"1.4.10\";a:11:{s:4:\"name\";s:23:\"ebt_basic_button 1.4.10\";s:7:\"version\";s:6:\"1.4.10\";s:3:\"tag\";s:6:\"1.4.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.10\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.10.tar.gz\";s:4:\"date\";s:10:\"1720600397\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.9\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.4.9\";s:7:\"version\";s:5:\"1.4.9\";s:3:\"tag\";s:5:\"1.4.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.9\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.9.tar.gz\";s:4:\"date\";s:10:\"1720420043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.8\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.4.8\";s:7:\"version\";s:5:\"1.4.8\";s:3:\"tag\";s:5:\"1.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.8\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.8.tar.gz\";s:4:\"date\";s:10:\"1697706006\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.7\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.4.7\";s:7:\"version\";s:5:\"1.4.7\";s:3:\"tag\";s:5:\"1.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.7.tar.gz\";s:4:\"date\";s:10:\"1677752947\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.6\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1677050634\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1676811831\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1676802246\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1676625806\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1676373473\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1675845902\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1675773840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.3.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1658239647\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.3.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644246610\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.3\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.2.3\";s:7:\"version\";s:5:\"1.2.3\";s:3:\"tag\";s:5:\"1.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.2.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.2.3.tar.gz\";s:4:\"date\";s:10:\"1642693059\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.2.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1642417989\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.2.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1642164821\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:22:\"ebt_basic_button 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_basic_button/releases/1.2.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1642162749\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:26:\"ebt_basic_button 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_basic_button/releases/1.4.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407149\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:26:\"ebt_basic_button 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_basic_button/releases/1.3.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1673964817\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:9:\"1.2.x-dev\";a:11:{s:4:\"name\";s:26:\"ebt_basic_button 1.2.x-dev\";s:7:\"version\";s:9:\"1.2.x-dev\";s:3:\"tag\";s:5:\"1.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_basic_button/releases/1.2.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_basic_button-1.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1643103635\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}}s:10:\"last_fetch\";i:1723018802;}',	1723105202),
('update_available_releases',	'ebt_block',	'a:10:{s:5:\"title\";s:30:\"Extra Block Types (EBT): Block\";s:10:\"short_name\";s:9:\"ebt_block\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ebt_block\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ebt_block\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:4:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ebt_block 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_block/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_block-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721030624\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ebt_block 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_block/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_block-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1709312682\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ebt_block 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_block/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_block-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1709288770\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ebt_block 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_block/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_block-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407171\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018803;}',	1723105203),
('update_available_releases',	'ebt_bootstrap_button',	'a:10:{s:5:\"title\";s:41:\"Extra Block Types (EBT): Bootstrap Button\";s:10:\"short_name\";s:20:\"ebt_bootstrap_button\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:27:\"drupal/ebt_bootstrap_button\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:51:\"https://www.drupal.org/project/ebt_bootstrap_button\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:15:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.4.3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721030742\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.4.2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1697706093\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.4.1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1676625939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.4.0\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1675775011\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.3.1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1658239717\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.3.0\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644246748\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.6\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.2.6\";s:7:\"version\";s:5:\"1.2.6\";s:3:\"tag\";s:5:\"1.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.2.6\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.2.6.tar.gz\";s:4:\"date\";s:10:\"1642961451\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.5\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.2.5\";s:7:\"version\";s:5:\"1.2.5\";s:3:\"tag\";s:5:\"1.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.2.5\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.2.5.tar.gz\";s:4:\"date\";s:10:\"1642959211\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.4\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.2.4\";s:7:\"version\";s:5:\"1.2.4\";s:3:\"tag\";s:5:\"1.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.2.4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.2.4.tar.gz\";s:4:\"date\";s:10:\"1642928527\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.3\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.2.3\";s:7:\"version\";s:5:\"1.2.3\";s:3:\"tag\";s:5:\"1.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.2.3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.2.3.tar.gz\";s:4:\"date\";s:10:\"1642928255\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.2.2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1642927730\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.2.1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1642927591\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:26:\"ebt_bootstrap_button 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.2.0\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1642696283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:30:\"ebt_bootstrap_button 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.4.x-dev\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407197\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:30:\"ebt_bootstrap_button 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/ebt_bootstrap_button/releases/1.3.x-dev\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/ebt_bootstrap_button-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1669749499\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}}s:10:\"last_fetch\";i:1723018803;}',	1723105203),
('update_available_releases',	'ebt_carousel',	'a:10:{s:5:\"title\";s:33:\"Extra Block Types (EBT): Carousel\";s:10:\"short_name\";s:12:\"ebt_carousel\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:19:\"drupal/ebt_carousel\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:43:\"https://www.drupal.org/project/ebt_carousel\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:17:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.4.4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722407795\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.4.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1714477265\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.4.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1697706234\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.4.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1679207024\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.4.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1675775151\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.2\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.3.2\";s:7:\"version\";s:5:\"1.3.2\";s:3:\"tag\";s:5:\"1.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.3.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.3.2.tar.gz\";s:4:\"date\";s:10:\"1658239891\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.3.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1644333802\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.3.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644246878\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.2.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1641046910\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.2.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1640866952\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.2\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.0.2\";s:7:\"version\";s:5:\"1.0.2\";s:3:\"tag\";s:5:\"1.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.0.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.0.2.tar.gz\";s:4:\"date\";s:10:\"1638098665\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.0.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1614592798\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:18:\"ebt_carousel 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_carousel/releases/1.0.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1612257008\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha1\";a:11:{s:4:\"name\";s:25:\"ebt_carousel 1.0.0-alpha1\";s:7:\"version\";s:12:\"1.0.0-alpha1\";s:3:\"tag\";s:12:\"1.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/ebt_carousel/releases/1.0.0-alpha1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1611489787\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:22:\"ebt_carousel 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_carousel/releases/1.4.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407287\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:22:\"ebt_carousel 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_carousel/releases/1.3.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1669749888\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:22:\"ebt_carousel 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_carousel/releases/1.0.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_carousel-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1640804083\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018803;}',	1723105203),
('update_available_releases',	'ebt_columns',	'a:10:{s:5:\"title\";s:44:\"Extra Block Types (EBT): Columns / Container\";s:10:\"short_name\";s:11:\"ebt_columns\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:18:\"drupal/ebt_columns\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/ebt_columns\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:3:{s:5:\"1.4.1\";a:11:{s:4:\"name\";s:17:\"ebt_columns 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_columns/releases/1.4.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_columns-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721031645\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:17:\"ebt_columns 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_columns/releases/1.4.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_columns-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1710923318\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:21:\"ebt_columns 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ebt_columns/releases/1.4.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ebt_columns-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722192109\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018803;}',	1723105203),
('update_available_releases',	'ebt_core',	'a:10:{s:5:\"title\";s:29:\"Extra Block Types (EBT): Core\";s:10:\"short_name\";s:8:\"ebt_core\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"1.4.,2.0.\";s:18:\"composer_namespace\";s:15:\"drupal/ebt_core\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ebt_core\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:40:{s:6:\"1.4.26\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.26\";s:7:\"version\";s:6:\"1.4.26\";s:3:\"tag\";s:6:\"1.4.26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.26\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.26.tar.gz\";s:4:\"date\";s:10:\"1721241689\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.25\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.25\";s:7:\"version\";s:6:\"1.4.25\";s:3:\"tag\";s:6:\"1.4.25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.25\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.25.tar.gz\";s:4:\"date\";s:10:\"1718775723\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:6:\"1.4.24\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.24\";s:7:\"version\";s:6:\"1.4.24\";s:3:\"tag\";s:6:\"1.4.24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.24\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.24.tar.gz\";s:4:\"date\";s:10:\"1714924023\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:6:\"1.4.23\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.23\";s:7:\"version\";s:6:\"1.4.23\";s:3:\"tag\";s:6:\"1.4.23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.23\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.23.tar.gz\";s:4:\"date\";s:10:\"1713714035\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:6:\"1.4.22\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.22\";s:7:\"version\";s:6:\"1.4.22\";s:3:\"tag\";s:6:\"1.4.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.22\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.22.tar.gz\";s:4:\"date\";s:10:\"1711531178\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:6:\"1.4.21\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.21\";s:7:\"version\";s:6:\"1.4.21\";s:3:\"tag\";s:6:\"1.4.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.21\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.21.tar.gz\";s:4:\"date\";s:10:\"1709312336\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:6:\"1.4.20\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.20\";s:7:\"version\";s:6:\"1.4.20\";s:3:\"tag\";s:6:\"1.4.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.20\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.20.tar.gz\";s:4:\"date\";s:10:\"1709285435\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:6:\"1.4.19\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.19\";s:7:\"version\";s:6:\"1.4.19\";s:3:\"tag\";s:6:\"1.4.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.19\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.19.tar.gz\";s:4:\"date\";s:10:\"1709282819\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:6:\"1.4.18\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.18\";s:7:\"version\";s:6:\"1.4.18\";s:3:\"tag\";s:6:\"1.4.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.18\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.18.tar.gz\";s:4:\"date\";s:10:\"1709281434\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:6:\"1.4.17\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.17\";s:7:\"version\";s:6:\"1.4.17\";s:3:\"tag\";s:6:\"1.4.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.17\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.17.tar.gz\";s:4:\"date\";s:10:\"1708886966\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:6:\"1.4.16\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.16\";s:7:\"version\";s:6:\"1.4.16\";s:3:\"tag\";s:6:\"1.4.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.16\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.16.tar.gz\";s:4:\"date\";s:10:\"1708007148\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:6:\"1.4.14\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.14\";s:7:\"version\";s:6:\"1.4.14\";s:3:\"tag\";s:6:\"1.4.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.14\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.14.tar.gz\";s:4:\"date\";s:10:\"1707168636\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:6:\"1.4.13\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.13\";s:7:\"version\";s:6:\"1.4.13\";s:3:\"tag\";s:6:\"1.4.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.13\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.13.tar.gz\";s:4:\"date\";s:10:\"1705872985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:6:\"1.4.12\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.12\";s:7:\"version\";s:6:\"1.4.12\";s:3:\"tag\";s:6:\"1.4.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.12\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.12.tar.gz\";s:4:\"date\";s:10:\"1697704043\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:6:\"1.4.11\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.11\";s:7:\"version\";s:6:\"1.4.11\";s:3:\"tag\";s:6:\"1.4.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.11\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.11.tar.gz\";s:4:\"date\";s:10:\"1686139069\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:6:\"1.4.10\";a:11:{s:4:\"name\";s:15:\"ebt_core 1.4.10\";s:7:\"version\";s:6:\"1.4.10\";s:3:\"tag\";s:6:\"1.4.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_core/releases/1.4.10\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.10.tar.gz\";s:4:\"date\";s:10:\"1681735914\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.9\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.4.9\";s:7:\"version\";s:5:\"1.4.9\";s:3:\"tag\";s:5:\"1.4.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.4.9\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.9.tar.gz\";s:4:\"date\";s:10:\"1679607656\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.8\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.4.8\";s:7:\"version\";s:5:\"1.4.8\";s:3:\"tag\";s:5:\"1.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.4.8\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.8.tar.gz\";s:4:\"date\";s:10:\"1676811368\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.7\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.4.7\";s:7:\"version\";s:5:\"1.4.7\";s:3:\"tag\";s:5:\"1.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.4.7\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.7.tar.gz\";s:4:\"date\";s:10:\"1676802045\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.6\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.4.6\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1676625553\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.4.5\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1676373092\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.4.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1676020468\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1675769879\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1671811885\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1665757417\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1661072199\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.4\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.3.4\";s:7:\"version\";s:5:\"1.3.4\";s:3:\"tag\";s:5:\"1.3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.3.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.3.4.tar.gz\";s:4:\"date\";s:10:\"1658239997\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.3\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.3.3\";s:7:\"version\";s:5:\"1.3.3\";s:3:\"tag\";s:5:\"1.3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.3.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.3.3.tar.gz\";s:4:\"date\";s:10:\"1644584664\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.2\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.3.2\";s:7:\"version\";s:5:\"1.3.2\";s:3:\"tag\";s:5:\"1.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.3.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.3.2.tar.gz\";s:4:\"date\";s:10:\"1644489665\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.3.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1644305677\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.3.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644246439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.3\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.2.3\";s:7:\"version\";s:5:\"1.2.3\";s:3:\"tag\";s:5:\"1.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.2.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.2.3.tar.gz\";s:4:\"date\";s:10:\"1643274357\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.2.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1641035191\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.2.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1640866627\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:14:\"ebt_core 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_core/releases/1.0.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_core-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1612257258\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha3\";a:11:{s:4:\"name\";s:21:\"ebt_core 1.0.0-alpha3\";s:7:\"version\";s:12:\"1.0.0-alpha3\";s:3:\"tag\";s:12:\"1.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ebt_core/releases/1.0.0-alpha3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ebt_core-1.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1610302714\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha1\";a:11:{s:4:\"name\";s:21:\"ebt_core 1.0.0-alpha1\";s:7:\"version\";s:12:\"1.0.0-alpha1\";s:3:\"tag\";s:12:\"1.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ebt_core/releases/1.0.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ebt_core-1.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1610279404\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:9:\"2.0.x-dev\";a:11:{s:4:\"name\";s:18:\"ebt_core 2.0.x-dev\";s:7:\"version\";s:9:\"2.0.x-dev\";s:3:\"tag\";s:5:\"2.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_core/releases/2.0.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_core-2.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1708886676\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:18:\"ebt_core 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_core/releases/1.4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_core-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407519\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:18:\"ebt_core 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_core/releases/1.3.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_core-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1710076360\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}}s:10:\"last_fetch\";i:1723018803;}',	1723105203),
('update_available_releases',	'ebt_countdown',	'a:10:{s:5:\"title\";s:34:\"Extra Block Types (EBT): Countdown\";s:10:\"short_name\";s:13:\"ebt_countdown\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:20:\"drupal/ebt_countdown\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ebt_countdown\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:5:\"1.4.5\";a:11:{s:4:\"name\";s:19:\"ebt_countdown 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_countdown/releases/1.4.5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_countdown-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1721031711\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:19:\"ebt_countdown 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_countdown/releases/1.4.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_countdown-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1697706236\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:19:\"ebt_countdown 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_countdown/releases/1.4.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_countdown-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1679922731\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:19:\"ebt_countdown 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_countdown/releases/1.4.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_countdown-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1677343694\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:19:\"ebt_countdown 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_countdown/releases/1.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_countdown-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1677061460\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:23:\"ebt_countdown 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_countdown/releases/1.4.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_countdown-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407525\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018803;}',	1723105203),
('update_available_releases',	'ebt_counter',	'a:10:{s:5:\"title\";s:32:\"Extra Block Types (EBT): Counter\";s:10:\"short_name\";s:11:\"ebt_counter\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:18:\"drupal/ebt_counter\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/ebt_counter\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:7:{s:5:\"1.4.5\";a:11:{s:4:\"name\";s:17:\"ebt_counter 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_counter/releases/1.4.5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_counter-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1722407875\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:17:\"ebt_counter 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_counter/releases/1.4.4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_counter-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1718562735\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:17:\"ebt_counter 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_counter/releases/1.4.3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_counter-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1714477790\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:17:\"ebt_counter 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_counter/releases/1.4.2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_counter-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1697706246\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:17:\"ebt_counter 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_counter/releases/1.4.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_counter-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1675775305\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:17:\"ebt_counter 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_counter/releases/1.4.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_counter-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1671812021\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:21:\"ebt_counter 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ebt_counter/releases/1.4.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ebt_counter-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407532\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018803;}',	1723105203),
('update_available_releases',	'ebt_cta',	'a:10:{s:5:\"title\";s:39:\"Extra Block Types (EBT): Call to Action\";s:10:\"short_name\";s:7:\"ebt_cta\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:14:\"drupal/ebt_cta\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:38:\"https://www.drupal.org/project/ebt_cta\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:11:{s:5:\"1.4.9\";a:11:{s:4:\"name\";s:13:\"ebt_cta 1.4.9\";s:7:\"version\";s:5:\"1.4.9\";s:3:\"tag\";s:5:\"1.4.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ebt_cta/releases/1.4.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ebt_cta-1.4.9.tar.gz\";s:4:\"date\";s:10:\"1722407920\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.8\";a:11:{s:4:\"name\";s:13:\"ebt_cta 1.4.8\";s:7:\"version\";s:5:\"1.4.8\";s:3:\"tag\";s:5:\"1.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ebt_cta/releases/1.4.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ebt_cta-1.4.8.tar.gz\";s:4:\"date\";s:10:\"1720982756\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.7\";a:11:{s:4:\"name\";s:13:\"ebt_cta 1.4.7\";s:7:\"version\";s:5:\"1.4.7\";s:3:\"tag\";s:5:\"1.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ebt_cta/releases/1.4.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ebt_cta-1.4.7.tar.gz\";s:4:\"date\";s:10:\"1720980129\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:13:\"ebt_cta 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ebt_cta/releases/1.4.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ebt_cta-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1697706087\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:13:\"ebt_cta 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ebt_cta/releases/1.4.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ebt_cta-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1682421721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:13:\"ebt_cta 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ebt_cta/releases/1.4.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ebt_cta-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1678087474\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:13:\"ebt_cta 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ebt_cta/releases/1.4.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ebt_cta-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1675775451\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.2\";a:11:{s:4:\"name\";s:13:\"ebt_cta 1.3.2\";s:7:\"version\";s:5:\"1.3.2\";s:3:\"tag\";s:5:\"1.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ebt_cta/releases/1.3.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ebt_cta-1.3.2.tar.gz\";s:4:\"date\";s:10:\"1658239810\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:13:\"ebt_cta 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/ebt_cta/releases/1.3.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/ebt_cta-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644584748\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:17:\"ebt_cta 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_cta/releases/1.4.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_cta-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407555\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:17:\"ebt_cta 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_cta/releases/1.3.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_cta-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1669749607\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018804;}',	1723105204),
('update_available_releases',	'ebt_hero',	'a:10:{s:5:\"title\";s:29:\"Extra Block Types (EBT): Hero\";s:10:\"short_name\";s:8:\"ebt_hero\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:15:\"drupal/ebt_hero\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ebt_hero\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ebt_hero 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_hero/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_hero-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1722407968\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:14:\"ebt_hero 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_hero/releases/1.4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_hero-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1720603672\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ebt_hero 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_hero/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_hero-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1720419749\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ebt_hero 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_hero/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_hero-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1719056369\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:14:\"ebt_hero 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_hero/releases/1.0.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_hero-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1717957235\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:18:\"ebt_hero 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_hero/releases/1.4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_hero-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407559\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}}s:10:\"last_fetch\";i:1723018804;}',	1723105204),
('update_available_releases',	'ebt_image',	'a:10:{s:5:\"title\";s:30:\"Extra Block Types (EBT): Image\";s:10:\"short_name\";s:9:\"ebt_image\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ebt_image\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ebt_image\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.9\";a:11:{s:4:\"name\";s:15:\"ebt_image 1.4.9\";s:7:\"version\";s:5:\"1.4.9\";s:3:\"tag\";s:5:\"1.4.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_image/releases/1.4.9\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_image-1.4.9.tar.gz\";s:4:\"date\";s:10:\"1722408021\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.8\";a:11:{s:4:\"name\";s:15:\"ebt_image 1.4.8\";s:7:\"version\";s:5:\"1.4.8\";s:3:\"tag\";s:5:\"1.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_image/releases/1.4.8\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_image-1.4.8.tar.gz\";s:4:\"date\";s:10:\"1721031770\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.7\";a:11:{s:4:\"name\";s:15:\"ebt_image 1.4.7\";s:7:\"version\";s:5:\"1.4.7\";s:3:\"tag\";s:5:\"1.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_image/releases/1.4.7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_image-1.4.7.tar.gz\";s:4:\"date\";s:10:\"1708353093\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.6\";a:11:{s:4:\"name\";s:15:\"ebt_image 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_image/releases/1.4.6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_image-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1697706344\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:15:\"ebt_image 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_image/releases/1.4.5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_image-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1678357988\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ebt_image 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_image/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_image-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1678264694\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ebt_image 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_image/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_image-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1678234323\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ebt_image 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_image/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_image-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1677428664\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ebt_image 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_image/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_image-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407560\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}}s:10:\"last_fetch\";i:1723018804;}',	1723105204),
('update_available_releases',	'ebt_image_gallery',	'a:10:{s:5:\"title\";s:38:\"Extra Block Types (EBT): Image Gallery\";s:10:\"short_name\";s:17:\"ebt_image_gallery\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:24:\"drupal/ebt_image_gallery\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:48:\"https://www.drupal.org/project/ebt_image_gallery\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.6\";a:11:{s:4:\"name\";s:23:\"ebt_image_gallery 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_image_gallery/releases/1.4.6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_image_gallery-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1722409053\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:23:\"ebt_image_gallery 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_image_gallery/releases/1.4.5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_image_gallery-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1713943853\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:23:\"ebt_image_gallery 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_image_gallery/releases/1.4.4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_image_gallery-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1701349467\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:23:\"ebt_image_gallery 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_image_gallery/releases/1.4.3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_image_gallery-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1697706269\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:23:\"ebt_image_gallery 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_image_gallery/releases/1.4.2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_image_gallery-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1677674438\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:23:\"ebt_image_gallery 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_image_gallery/releases/1.4.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_image_gallery-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1675775579\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:23:\"ebt_image_gallery 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_image_gallery/releases/1.4.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_image_gallery-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1669647909\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:30:\"ebt_image_gallery 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/ebt_image_gallery/releases/1.4.0-alpha1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/ebt_image_gallery-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1669126456\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:27:\"ebt_image_gallery 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ebt_image_gallery/releases/1.4.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ebt_image_gallery-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407560\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}}s:10:\"last_fetch\";i:1723018804;}',	1723105204),
('update_available_releases',	'ebt_micromodal',	'a:10:{s:5:\"title\";s:35:\"Extra Block Types (EBT): Micromodal\";s:10:\"short_name\";s:14:\"ebt_micromodal\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:21:\"drupal/ebt_micromodal\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:45:\"https://www.drupal.org/project/ebt_micromodal\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:5:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:20:\"ebt_micromodal 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ebt_micromodal/releases/1.4.2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ebt_micromodal-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721028607\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:20:\"ebt_micromodal 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ebt_micromodal/releases/1.4.1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ebt_micromodal-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1697706270\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:20:\"ebt_micromodal 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ebt_micromodal/releases/1.4.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ebt_micromodal-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1686233798\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:20:\"ebt_micromodal 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ebt_micromodal/releases/1.0.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ebt_micromodal-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1684742331\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:24:\"ebt_micromodal 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/ebt_micromodal/releases/1.4.x-dev\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/ebt_micromodal-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721028390\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}}s:10:\"last_fetch\";i:1723018804;}',	1723105204),
('update_available_releases',	'ebt_quote',	'a:10:{s:5:\"title\";s:30:\"Extra Block Types (EBT): Quote\";s:10:\"short_name\";s:9:\"ebt_quote\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ebt_quote\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ebt_quote\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.7\";a:11:{s:4:\"name\";s:15:\"ebt_quote 1.4.7\";s:7:\"version\";s:5:\"1.4.7\";s:3:\"tag\";s:5:\"1.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_quote/releases/1.4.7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_quote-1.4.7.tar.gz\";s:4:\"date\";s:10:\"1722409196\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.6\";a:11:{s:4:\"name\";s:15:\"ebt_quote 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_quote/releases/1.4.6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_quote-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1721031824\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:15:\"ebt_quote 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_quote/releases/1.4.5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_quote-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1697706276\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:15:\"ebt_quote 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_quote/releases/1.4.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_quote-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1679817607\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ebt_quote 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_quote/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_quote-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1679816727\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ebt_quote 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_quote/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_quote-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1676209593\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ebt_quote 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_quote/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_quote-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1675775704\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ebt_quote 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_quote/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_quote-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1665756428\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ebt_quote 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_quote/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_quote-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407593\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}}s:10:\"last_fetch\";i:1723018804;}',	1723105204),
('update_available_releases',	'ebt_slick_slider',	'a:10:{s:5:\"title\";s:37:\"Extra Block Types (EBT): Slick Slider\";s:10:\"short_name\";s:16:\"ebt_slick_slider\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:23:\"drupal/ebt_slick_slider\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:47:\"https://www.drupal.org/project/ebt_slick_slider\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:12:{s:5:\"1.4.7\";a:11:{s:4:\"name\";s:22:\"ebt_slick_slider 1.4.7\";s:7:\"version\";s:5:\"1.4.7\";s:3:\"tag\";s:5:\"1.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.4.7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.4.7.tar.gz\";s:4:\"date\";s:10:\"1722409255\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.6\";a:11:{s:4:\"name\";s:22:\"ebt_slick_slider 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.4.6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1714477916\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:22:\"ebt_slick_slider 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.4.5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1697706298\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:22:\"ebt_slick_slider 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.4.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1687776582\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:22:\"ebt_slick_slider 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.4.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1679909539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:22:\"ebt_slick_slider 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.4.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1675775786\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:22:\"ebt_slick_slider 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.4.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1665500004\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.2\";a:11:{s:4:\"name\";s:22:\"ebt_slick_slider 1.3.2\";s:7:\"version\";s:5:\"1.3.2\";s:3:\"tag\";s:5:\"1.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.3.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.3.2.tar.gz\";s:4:\"date\";s:10:\"1665500061\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:22:\"ebt_slick_slider 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.3.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1658240070\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:22:\"ebt_slick_slider 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.3.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1654008799\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:26:\"ebt_slick_slider 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.4.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407596\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:26:\"ebt_slick_slider 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_slick_slider/releases/1.3.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_slick_slider-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1669750358\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018804;}',	1723105204),
('update_available_releases',	'ebt_slideshow',	'a:10:{s:5:\"title\";s:34:\"Extra Block Types (EBT): Slideshow\";s:10:\"short_name\";s:13:\"ebt_slideshow\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:20:\"drupal/ebt_slideshow\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:44:\"https://www.drupal.org/project/ebt_slideshow\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:22:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.4.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722409330\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.4.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1714488300\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.4.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1697706351\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.4.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1682331788\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.4.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1675775984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.2\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.3.2\";s:7:\"version\";s:5:\"1.3.2\";s:3:\"tag\";s:5:\"1.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.3.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.3.2.tar.gz\";s:4:\"date\";s:10:\"1658240241\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.3.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1644333910\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.3.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644247053\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.2.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1641046928\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.2.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1640867655\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.2\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.0.2\";s:7:\"version\";s:5:\"1.0.2\";s:3:\"tag\";s:5:\"1.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.0.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.0.2.tar.gz\";s:4:\"date\";s:10:\"1638036758\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.0.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1614592773\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:19:\"ebt_slideshow 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_slideshow/releases/1.0.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1614590274\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta2\";a:11:{s:4:\"name\";s:25:\"ebt_slideshow 1.0.0-beta2\";s:7:\"version\";s:11:\"1.0.0-beta2\";s:3:\"tag\";s:11:\"1.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/ebt_slideshow/releases/1.0.0-beta2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1611054834\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:25:\"ebt_slideshow 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/ebt_slideshow/releases/1.0.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1610877170\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha5\";a:11:{s:4:\"name\";s:26:\"ebt_slideshow 1.0.0-alpha5\";s:7:\"version\";s:12:\"1.0.0-alpha5\";s:3:\"tag\";s:12:\"1.0.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_slideshow/releases/1.0.0-alpha5\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.0.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1610736687\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha4\";a:11:{s:4:\"name\";s:26:\"ebt_slideshow 1.0.0-alpha4\";s:7:\"version\";s:12:\"1.0.0-alpha4\";s:3:\"tag\";s:12:\"1.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_slideshow/releases/1.0.0-alpha4\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1610734737\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha3\";a:11:{s:4:\"name\";s:26:\"ebt_slideshow 1.0.0-alpha3\";s:7:\"version\";s:12:\"1.0.0-alpha3\";s:3:\"tag\";s:12:\"1.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_slideshow/releases/1.0.0-alpha3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1610733732\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha2\";a:11:{s:4:\"name\";s:26:\"ebt_slideshow 1.0.0-alpha2\";s:7:\"version\";s:12:\"1.0.0-alpha2\";s:3:\"tag\";s:12:\"1.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/ebt_slideshow/releases/1.0.0-alpha2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1610732681\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:23:\"ebt_slideshow 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_slideshow/releases/1.4.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407599\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:23:\"ebt_slideshow 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_slideshow/releases/1.3.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1675338145\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:23:\"ebt_slideshow 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_slideshow/releases/1.0.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_slideshow-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1640804106\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018804;}',	1723105204),
('update_available_releases',	'ebt_stats',	'a:10:{s:5:\"title\";s:30:\"Extra Block Types (EBT): Stats\";s:10:\"short_name\";s:9:\"ebt_stats\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ebt_stats\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ebt_stats\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ebt_stats 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_stats/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_stats-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1714488379\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ebt_stats 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_stats/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_stats-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1697706360\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ebt_stats 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_stats/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_stats-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1675776117\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ebt_stats 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_stats/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_stats-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1665757092\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ebt_stats 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_stats/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_stats-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1665407768\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ebt_stats 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_stats/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_stats-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407623\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018804;}',	1723105204),
('update_available_releases',	'ebt_tabs',	'a:10:{s:5:\"title\";s:29:\"Extra Block Types (EBT): Tabs\";s:10:\"short_name\";s:8:\"ebt_tabs\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:15:\"drupal/ebt_tabs\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ebt_tabs\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:29:{s:5:\"1.4.8\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.4.8\";s:7:\"version\";s:5:\"1.4.8\";s:3:\"tag\";s:5:\"1.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.4.8\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.4.8.tar.gz\";s:4:\"date\";s:10:\"1722409431\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.7\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.4.7\";s:7:\"version\";s:5:\"1.4.7\";s:3:\"tag\";s:5:\"1.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.4.7\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.4.7.tar.gz\";s:4:\"date\";s:10:\"1721031913\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.6\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.4.6\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1697706378\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.4.5\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1686118118\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.4.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1678030628\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1677346677\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1675846471\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1675771006\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.2\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.3.2\";s:7:\"version\";s:5:\"1.3.2\";s:3:\"tag\";s:5:\"1.3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.3.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.3.2.tar.gz\";s:4:\"date\";s:10:\"1658240422\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.3.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1646247608\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.3.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644247168\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.2.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1641046945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.2.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1640867912\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.3\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.0.3\";s:7:\"version\";s:5:\"1.0.3\";s:3:\"tag\";s:5:\"1.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.3.tar.gz\";s:4:\"date\";s:10:\"1613475198\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.2\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.0.2\";s:7:\"version\";s:5:\"1.0.2\";s:3:\"tag\";s:5:\"1.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.2.tar.gz\";s:4:\"date\";s:10:\"1613474896\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1613474813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:14:\"ebt_tabs 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1611591462\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta6\";a:11:{s:4:\"name\";s:20:\"ebt_tabs 1.0.0-beta6\";s:7:\"version\";s:11:\"1.0.0-beta6\";s:3:\"tag\";s:11:\"1.0.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.0-beta6\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1610460656\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta5\";a:11:{s:4:\"name\";s:20:\"ebt_tabs 1.0.0-beta5\";s:7:\"version\";s:11:\"1.0.0-beta5\";s:3:\"tag\";s:11:\"1.0.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.0-beta5\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1610459959\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta4\";a:11:{s:4:\"name\";s:20:\"ebt_tabs 1.0.0-beta4\";s:7:\"version\";s:11:\"1.0.0-beta4\";s:3:\"tag\";s:11:\"1.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.0-beta4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1610448777\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta3\";a:11:{s:4:\"name\";s:20:\"ebt_tabs 1.0.0-beta3\";s:7:\"version\";s:11:\"1.0.0-beta3\";s:3:\"tag\";s:11:\"1.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.0-beta3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1610302695\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"1.0.0-beta2\";a:11:{s:4:\"name\";s:20:\"ebt_tabs 1.0.0-beta2\";s:7:\"version\";s:11:\"1.0.0-beta2\";s:3:\"tag\";s:11:\"1.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.0-beta2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1610279615\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:20:\"ebt_tabs 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.0-beta1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1610122447\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha3\";a:11:{s:4:\"name\";s:21:\"ebt_tabs 1.0.0-alpha3\";s:7:\"version\";s:12:\"1.0.0-alpha3\";s:3:\"tag\";s:12:\"1.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.0-alpha3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1609953410\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:12:\"1.0.0-alpha2\";a:11:{s:4:\"name\";s:21:\"ebt_tabs 1.0.0-alpha2\";s:7:\"version\";s:12:\"1.0.0-alpha2\";s:3:\"tag\";s:12:\"1.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.0-alpha2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1609952196\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:12:\"1.0.0-alpha1\";a:11:{s:4:\"name\";s:21:\"ebt_tabs 1.0.0-alpha1\";s:7:\"version\";s:12:\"1.0.0-alpha1\";s:3:\"tag\";s:12:\"1.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1609950981\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:18:\"ebt_tabs 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_tabs/releases/1.4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407627\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:18:\"ebt_tabs 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_tabs/releases/1.3.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1675337592\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:18:\"ebt_tabs 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_tabs/releases/1.0.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_tabs-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1640804180\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018804;}',	1723105204),
('update_available_releases',	'ebt_text',	'a:10:{s:5:\"title\";s:29:\"Extra Block Types (EBT): Text\";s:10:\"short_name\";s:8:\"ebt_text\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:15:\"drupal/ebt_text\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/ebt_text\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:10:{s:5:\"1.4.3\";a:11:{s:4:\"name\";s:14:\"ebt_text 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_text/releases/1.4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_text-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721031961\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:14:\"ebt_text 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_text/releases/1.4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_text-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1697706390\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:14:\"ebt_text 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_text/releases/1.4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_text-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1675776206\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:14:\"ebt_text 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_text/releases/1.4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_text-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1671003323\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:14:\"ebt_text 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_text/releases/1.3.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_text-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1658240516\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:14:\"ebt_text 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_text/releases/1.3.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_text-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644247299\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:14:\"ebt_text 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_text/releases/1.2.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_text-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1641046960\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:14:\"ebt_text 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/ebt_text/releases/1.0.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/ebt_text-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1641032565\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:18:\"ebt_text 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_text/releases/1.4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_text-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407627\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:18:\"ebt_text 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_text/releases/1.3.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_text-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1669750755\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}}s:10:\"last_fetch\";i:1723018805;}',	1723105205),
('update_available_releases',	'ebt_tiles',	'a:10:{s:5:\"title\";s:30:\"Extra Block Types (EBT): Tiles\";s:10:\"short_name\";s:9:\"ebt_tiles\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ebt_tiles\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ebt_tiles\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:7:{s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ebt_tiles 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_tiles/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_tiles-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1714488860\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ebt_tiles 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_tiles/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_tiles-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699794392\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:22:\"ebt_tiles 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_tiles/releases/1.4.0-alpha4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_tiles-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697706394\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:22:\"ebt_tiles 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_tiles/releases/1.4.0-alpha3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_tiles-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696078789\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha2\";a:11:{s:4:\"name\";s:22:\"ebt_tiles 1.4.0-alpha2\";s:7:\"version\";s:12:\"1.4.0-alpha2\";s:3:\"tag\";s:12:\"1.4.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_tiles/releases/1.4.0-alpha2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_tiles-1.4.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1695888421\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ebt_tiles 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_tiles/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_tiles-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1695188713\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ebt_tiles 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_tiles/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_tiles-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407660\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018805;}',	1723105205),
('update_available_releases',	'ebt_timeline',	'a:10:{s:5:\"title\";s:33:\"Extra Block Types (EBT): Timeline\";s:10:\"short_name\";s:12:\"ebt_timeline\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:19:\"drupal/ebt_timeline\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:43:\"https://www.drupal.org/project/ebt_timeline\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:12:{s:5:\"1.4.5\";a:11:{s:4:\"name\";s:18:\"ebt_timeline 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_timeline/releases/1.4.5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1722409545\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:18:\"ebt_timeline 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_timeline/releases/1.4.4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1714489068\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:18:\"ebt_timeline 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_timeline/releases/1.4.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1708026643\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:18:\"ebt_timeline 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_timeline/releases/1.4.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1697706407\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:18:\"ebt_timeline 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_timeline/releases/1.4.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1675776330\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:18:\"ebt_timeline 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_timeline/releases/1.3.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1658240576\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:18:\"ebt_timeline 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_timeline/releases/1.3.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644247598\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.2\";a:11:{s:4:\"name\";s:18:\"ebt_timeline 1.2.2\";s:7:\"version\";s:5:\"1.2.2\";s:3:\"tag\";s:5:\"1.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_timeline/releases/1.2.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.2.2.tar.gz\";s:4:\"date\";s:10:\"1641046975\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:18:\"ebt_timeline 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/ebt_timeline/releases/1.2.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1640868096\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"1.0.0-alpha1\";a:11:{s:4:\"name\";s:25:\"ebt_timeline 1.0.0-alpha1\";s:7:\"version\";s:12:\"1.0.0-alpha1\";s:3:\"tag\";s:12:\"1.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/ebt_timeline/releases/1.0.0-alpha1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1612191685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:22:\"ebt_timeline 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_timeline/releases/1.4.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407672\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:22:\"ebt_timeline 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_timeline/releases/1.3.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_timeline-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1669750868\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}}s:10:\"last_fetch\";i:1723018805;}',	1723105205),
('update_available_releases',	'ebt_video',	'a:10:{s:5:\"title\";s:30:\"Extra Block Types (EBT): Video\";s:10:\"short_name\";s:9:\"ebt_video\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ebt_video\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ebt_video\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:5:\"1.4.4\";a:11:{s:4:\"name\";s:15:\"ebt_video 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_video/releases/1.4.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_video-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1722409606\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:15:\"ebt_video 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_video/releases/1.4.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_video-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1721032025\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:15:\"ebt_video 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_video/releases/1.4.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_video-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1705524011\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ebt_video 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_video/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_video-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1701349382\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ebt_video 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_video/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_video-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1699794472\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha4\";a:11:{s:4:\"name\";s:22:\"ebt_video 1.4.0-alpha4\";s:7:\"version\";s:12:\"1.4.0-alpha4\";s:3:\"tag\";s:12:\"1.4.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_video/releases/1.4.0-alpha4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_video-1.4.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1697706417\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:12:\"1.4.0-alpha3\";a:11:{s:4:\"name\";s:22:\"ebt_video 1.4.0-alpha3\";s:7:\"version\";s:12:\"1.4.0-alpha3\";s:3:\"tag\";s:12:\"1.4.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_video/releases/1.4.0-alpha3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_video-1.4.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1696687114\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.4.0-alpha1\";a:11:{s:4:\"name\";s:22:\"ebt_video 1.4.0-alpha1\";s:7:\"version\";s:12:\"1.4.0-alpha1\";s:3:\"tag\";s:12:\"1.4.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/ebt_video/releases/1.4.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/ebt_video-1.4.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1695281590\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ebt_video 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_video/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_video-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407676\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018805;}',	1723105205),
('update_available_releases',	'ebt_video_and_image_gallery',	'a:10:{s:5:\"title\";s:48:\"Extra Block Types (EBT): Video and Image Gallery\";s:10:\"short_name\";s:27:\"ebt_video_and_image_gallery\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:34:\"drupal/ebt_video_and_image_gallery\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:58:\"https://www.drupal.org/project/ebt_video_and_image_gallery\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:11:{s:6:\"1.4.10\";a:11:{s:4:\"name\";s:34:\"ebt_video_and_image_gallery 1.4.10\";s:7:\"version\";s:6:\"1.4.10\";s:3:\"tag\";s:6:\"1.4.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/ebt_video_and_image_gallery/releases/1.4.10\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/ebt_video_and_image_gallery-1.4.10.tar.gz\";s:4:\"date\";s:10:\"1722409721\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.9\";a:11:{s:4:\"name\";s:33:\"ebt_video_and_image_gallery 1.4.9\";s:7:\"version\";s:5:\"1.4.9\";s:3:\"tag\";s:5:\"1.4.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ebt_video_and_image_gallery/releases/1.4.9\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ebt_video_and_image_gallery-1.4.9.tar.gz\";s:4:\"date\";s:10:\"1714489196\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.8\";a:11:{s:4:\"name\";s:33:\"ebt_video_and_image_gallery 1.4.8\";s:7:\"version\";s:5:\"1.4.8\";s:3:\"tag\";s:5:\"1.4.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ebt_video_and_image_gallery/releases/1.4.8\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ebt_video_and_image_gallery-1.4.8.tar.gz\";s:4:\"date\";s:10:\"1713944505\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.7\";a:11:{s:4:\"name\";s:33:\"ebt_video_and_image_gallery 1.4.7\";s:7:\"version\";s:5:\"1.4.7\";s:3:\"tag\";s:5:\"1.4.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ebt_video_and_image_gallery/releases/1.4.7\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ebt_video_and_image_gallery-1.4.7.tar.gz\";s:4:\"date\";s:10:\"1697706419\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.6\";a:11:{s:4:\"name\";s:33:\"ebt_video_and_image_gallery 1.4.6\";s:7:\"version\";s:5:\"1.4.6\";s:3:\"tag\";s:5:\"1.4.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ebt_video_and_image_gallery/releases/1.4.6\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ebt_video_and_image_gallery-1.4.6.tar.gz\";s:4:\"date\";s:10:\"1696687146\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.5\";a:11:{s:4:\"name\";s:33:\"ebt_video_and_image_gallery 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ebt_video_and_image_gallery/releases/1.4.5\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ebt_video_and_image_gallery-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1696151208\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:33:\"ebt_video_and_image_gallery 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ebt_video_and_image_gallery/releases/1.4.4\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ebt_video_and_image_gallery-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1696150947\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:33:\"ebt_video_and_image_gallery 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ebt_video_and_image_gallery/releases/1.4.3\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ebt_video_and_image_gallery-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1696149491\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:33:\"ebt_video_and_image_gallery 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ebt_video_and_image_gallery/releases/1.4.2\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ebt_video_and_image_gallery-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1695324913\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:33:\"ebt_video_and_image_gallery 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:73:\"https://www.drupal.org/project/ebt_video_and_image_gallery/releases/1.4.1\";s:13:\"download_link\";s:78:\"https://ftp.drupal.org/files/projects/ebt_video_and_image_gallery-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1695312486\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:37:\"ebt_video_and_image_gallery 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:77:\"https://www.drupal.org/project/ebt_video_and_image_gallery/releases/1.4.x-dev\";s:13:\"download_link\";s:82:\"https://ftp.drupal.org/files/projects/ebt_video_and_image_gallery-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407676\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}}s:10:\"last_fetch\";i:1723018805;}',	1723105205),
('update_available_releases',	'ebt_views',	'a:10:{s:5:\"title\";s:30:\"Extra Block Types (EBT): Views\";s:10:\"short_name\";s:9:\"ebt_views\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:16:\"drupal/ebt_views\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/ebt_views\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:3:{s:5:\"1.4.1\";a:11:{s:4:\"name\";s:15:\"ebt_views 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_views/releases/1.4.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_views-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1721032086\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:15:\"ebt_views 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/ebt_views/releases/1.4.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/ebt_views-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1705612941\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:19:\"ebt_views 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/ebt_views/releases/1.4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/ebt_views-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407678\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018805;}',	1723105205),
('update_available_releases',	'ebt_webform',	'a:10:{s:5:\"title\";s:32:\"Extra Block Types (EBT): Webform\";s:10:\"short_name\";s:11:\"ebt_webform\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:18:\"drupal/ebt_webform\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/ebt_webform\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:8:{s:5:\"1.4.2\";a:11:{s:4:\"name\";s:17:\"ebt_webform 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_webform/releases/1.4.2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_webform-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1721032147\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:17:\"ebt_webform 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_webform/releases/1.4.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_webform-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1697706442\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.0\";a:11:{s:4:\"name\";s:17:\"ebt_webform 1.4.0\";s:7:\"version\";s:5:\"1.4.0\";s:3:\"tag\";s:5:\"1.4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_webform/releases/1.4.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_webform-1.4.0.tar.gz\";s:4:\"date\";s:10:\"1675776445\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:17:\"ebt_webform 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_webform/releases/1.3.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_webform-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1658240647\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:17:\"ebt_webform 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_webform/releases/1.3.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_webform-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644248351\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:17:\"ebt_webform 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/ebt_webform/releases/1.2.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/ebt_webform-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1642513688\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:21:\"ebt_webform 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ebt_webform/releases/1.4.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ebt_webform-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722409890\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:21:\"ebt_webform 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/ebt_webform/releases/1.3.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/ebt_webform-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1669751008\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}}s:10:\"last_fetch\";i:1723018805;}',	1723105205),
('update_available_releases',	'ebt_webform_popup',	'a:10:{s:5:\"title\";s:38:\"Extra Block Types (EBT): Webform Popup\";s:10:\"short_name\";s:17:\"ebt_webform_popup\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.4.\";s:18:\"composer_namespace\";s:24:\"drupal/ebt_webform_popup\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:48:\"https://www.drupal.org/project/ebt_webform_popup\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:11:{s:5:\"1.4.5\";a:11:{s:4:\"name\";s:23:\"ebt_webform_popup 1.4.5\";s:7:\"version\";s:5:\"1.4.5\";s:3:\"tag\";s:5:\"1.4.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_webform_popup/releases/1.4.5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_webform_popup-1.4.5.tar.gz\";s:4:\"date\";s:10:\"1719328567\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.4\";a:11:{s:4:\"name\";s:23:\"ebt_webform_popup 1.4.4\";s:7:\"version\";s:5:\"1.4.4\";s:3:\"tag\";s:5:\"1.4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_webform_popup/releases/1.4.4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_webform_popup-1.4.4.tar.gz\";s:4:\"date\";s:10:\"1718979889\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.4.3\";a:11:{s:4:\"name\";s:23:\"ebt_webform_popup 1.4.3\";s:7:\"version\";s:5:\"1.4.3\";s:3:\"tag\";s:5:\"1.4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_webform_popup/releases/1.4.3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_webform_popup-1.4.3.tar.gz\";s:4:\"date\";s:10:\"1697706450\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:5:\"1.4.2\";a:11:{s:4:\"name\";s:23:\"ebt_webform_popup 1.4.2\";s:7:\"version\";s:5:\"1.4.2\";s:3:\"tag\";s:5:\"1.4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_webform_popup/releases/1.4.2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_webform_popup-1.4.2.tar.gz\";s:4:\"date\";s:10:\"1678087574\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.4.1\";a:11:{s:4:\"name\";s:23:\"ebt_webform_popup 1.4.1\";s:7:\"version\";s:5:\"1.4.1\";s:3:\"tag\";s:5:\"1.4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_webform_popup/releases/1.4.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_webform_popup-1.4.1.tar.gz\";s:4:\"date\";s:10:\"1675776570\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.3.1\";a:11:{s:4:\"name\";s:23:\"ebt_webform_popup 1.3.1\";s:7:\"version\";s:5:\"1.3.1\";s:3:\"tag\";s:5:\"1.3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_webform_popup/releases/1.3.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_webform_popup-1.3.1.tar.gz\";s:4:\"date\";s:10:\"1658240782\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.3.0\";a:11:{s:4:\"name\";s:23:\"ebt_webform_popup 1.3.0\";s:7:\"version\";s:5:\"1.3.0\";s:3:\"tag\";s:5:\"1.3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_webform_popup/releases/1.3.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_webform_popup-1.3.0.tar.gz\";s:4:\"date\";s:10:\"1644248406\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.1\";a:11:{s:4:\"name\";s:23:\"ebt_webform_popup 1.2.1\";s:7:\"version\";s:5:\"1.2.1\";s:3:\"tag\";s:5:\"1.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_webform_popup/releases/1.2.1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_webform_popup-1.2.1.tar.gz\";s:4:\"date\";s:10:\"1643273235\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"1.2.0\";a:11:{s:4:\"name\";s:23:\"ebt_webform_popup 1.2.0\";s:7:\"version\";s:5:\"1.2.0\";s:3:\"tag\";s:5:\"1.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/ebt_webform_popup/releases/1.2.0\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/ebt_webform_popup-1.2.0.tar.gz\";s:4:\"date\";s:10:\"1643104226\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:9:\"1.4.x-dev\";a:11:{s:4:\"name\";s:27:\"ebt_webform_popup 1.4.x-dev\";s:7:\"version\";s:9:\"1.4.x-dev\";s:3:\"tag\";s:5:\"1.4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ebt_webform_popup/releases/1.4.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ebt_webform_popup-1.4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722407730\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:9:\"1.3.x-dev\";a:11:{s:4:\"name\";s:27:\"ebt_webform_popup 1.3.x-dev\";s:7:\"version\";s:9:\"1.3.x-dev\";s:3:\"tag\";s:5:\"1.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/ebt_webform_popup/releases/1.3.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/ebt_webform_popup-1.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1669751097\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}}s:10:\"last_fetch\";i:1723018805;}',	1723105205),
('update_available_releases',	'entity_reference_revisions',	'a:10:{s:5:\"title\";s:26:\"Entity Reference Revisions\";s:10:\"short_name\";s:26:\"entity_reference_revisions\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:33:\"drupal/entity_reference_revisions\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:57:\"https://www.drupal.org/project/entity_reference_revisions\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:18:{s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:35:\"entity_reference_revisions 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:75:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.12\";s:13:\"download_link\";s:80:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1722804497\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:35:\"entity_reference_revisions 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:75:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.11\";s:13:\"download_link\";s:80:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1705140721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:35:\"entity_reference_revisions 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:75:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.10\";s:13:\"download_link\";s:80:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1660664712\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:9:\"^9 || ^10\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.9\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1614805871\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.8\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1583961846\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.7\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1570284187\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.6\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1539588781\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.5\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1527241084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.4\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1515143885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.3\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1495814284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.2\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1485790085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.1\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1485526384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:34:\"entity_reference_revisions 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1469725439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc7\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc7\";s:7:\"version\";s:11:\"8.x-1.0-rc7\";s:3:\"tag\";s:11:\"8.x-1.0-rc7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc7\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc7.tar.gz\";s:4:\"date\";s:10:\"1464727139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc6\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc6\";s:7:\"version\";s:11:\"8.x-1.0-rc6\";s:3:\"tag\";s:11:\"8.x-1.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc6\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1460582040\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1447766339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1444419239\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:38:\"entity_reference_revisions 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/entity_reference_revisions/releases/8.x-1.x-dev\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/entity_reference_revisions-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722630009\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:16:\"^9 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018805;}',	1723105205),
('update_available_releases',	'field_group',	'a:10:{s:5:\"title\";s:11:\"Field Group\";s:10:\"short_name\";s:11:\"field_group\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-3.\";s:18:\"composer_namespace\";s:18:\"drupal/field_group\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:42:\"https://www.drupal.org/project/field_group\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:17:{s:7:\"8.x-3.6\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.6\";s:7:\"version\";s:7:\"8.x-3.6\";s:3:\"tag\";s:7:\"8.x-3.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.6.tar.gz\";s:4:\"date\";s:10:\"1722672510\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:7:\"8.x-3.5\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.5\";s:7:\"version\";s:7:\"8.x-3.5\";s:3:\"tag\";s:7:\"8.x-3.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.5.tar.gz\";s:4:\"date\";s:10:\"1722630494\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:7:\"8.x-3.4\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.4\";s:7:\"version\";s:7:\"8.x-3.4\";s:3:\"tag\";s:7:\"8.x-3.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.4.tar.gz\";s:4:\"date\";s:10:\"1667241979\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:7:\"8.x-3.3\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.3\";s:7:\"version\";s:7:\"8.x-3.3\";s:3:\"tag\";s:7:\"8.x-3.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.3.tar.gz\";s:4:\"date\";s:10:\"1663516404\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.2\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.2\";s:7:\"version\";s:7:\"8.x-3.2\";s:3:\"tag\";s:7:\"8.x-3.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.2.tar.gz\";s:4:\"date\";s:10:\"1628513585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.1\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.1\";s:7:\"version\";s:7:\"8.x-3.1\";s:3:\"tag\";s:7:\"8.x-3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.1.tar.gz\";s:4:\"date\";s:10:\"1591772567\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-3.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1580250787\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:11:\"8.x-3.0-rc2\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.0-rc2\";s:7:\"version\";s:11:\"8.x-3.0-rc2\";s:3:\"tag\";s:11:\"8.x-3.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-rc2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1574200085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.0-rc1\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.0-rc1\";s:7:\"version\";s:11:\"8.x-3.0-rc1\";s:3:\"tag\";s:11:\"8.x-3.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-rc1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1558647185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-3.0-beta1\";a:11:{s:4:\"name\";s:25:\"field_group 8.x-3.0-beta1\";s:7:\"version\";s:13:\"8.x-3.0-beta1\";s:3:\"tag\";s:13:\"8.x-3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/field_group/releases/8.x-3.0-beta1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1510352284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:19:\"field_group 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/field_group/releases/8.x-1.0\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1510352885\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc6\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc6\";s:7:\"version\";s:11:\"8.x-1.0-rc6\";s:3:\"tag\";s:11:\"8.x-1.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc6\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1480365484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1480288380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1449771240\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1447385940\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-3.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722672400\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:23:\"field_group 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/field_group/releases/8.x-1.x-dev\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/field_group-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1570214888\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'glightbox',	'a:10:{s:5:\"title\";s:9:\"GLightbox\";s:10:\"short_name\";s:9:\"glightbox\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.0.\";s:18:\"composer_namespace\";s:16:\"drupal/glightbox\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/glightbox\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:10:{s:5:\"1.0.7\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.7\";s:7:\"version\";s:5:\"1.0.7\";s:3:\"tag\";s:5:\"1.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.7.tar.gz\";s:4:\"date\";s:10:\"1713942568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.6\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.6\";s:7:\"version\";s:5:\"1.0.6\";s:3:\"tag\";s:5:\"1.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.6.tar.gz\";s:4:\"date\";s:10:\"1712003661\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.5\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.5\";s:7:\"version\";s:5:\"1.0.5\";s:3:\"tag\";s:5:\"1.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.5.tar.gz\";s:4:\"date\";s:10:\"1712002850\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.4\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.4\";s:7:\"version\";s:5:\"1.0.4\";s:3:\"tag\";s:5:\"1.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.4.tar.gz\";s:4:\"date\";s:10:\"1704707152\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.2\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.2\";s:7:\"version\";s:5:\"1.0.2\";s:3:\"tag\";s:5:\"1.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.2.tar.gz\";s:4:\"date\";s:10:\"1697006475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.1\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1690874897\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:15:\"glightbox 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/glightbox/releases/1.0.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1670673111\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:11:\"1.0.0-beta1\";a:11:{s:4:\"name\";s:21:\"glightbox 1.0.0-beta1\";s:7:\"version\";s:11:\"1.0.0-beta1\";s:3:\"tag\";s:11:\"1.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/glightbox/releases/1.0.0-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1669550449\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.0.0-alpha1\";a:11:{s:4:\"name\";s:22:\"glightbox 1.0.0-alpha1\";s:7:\"version\";s:12:\"1.0.0-alpha1\";s:3:\"tag\";s:12:\"1.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/glightbox/releases/1.0.0-alpha1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/glightbox-1.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1669124562\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:19:\"glightbox 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/glightbox/releases/1.0.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/glightbox-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1713265171\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'glightbox_media_video',	'a:10:{s:5:\"title\";s:21:\"GLightbox Media Video\";s:10:\"short_name\";s:21:\"glightbox_media_video\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"1.0.\";s:18:\"composer_namespace\";s:28:\"drupal/glightbox_media_video\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:52:\"https://www.drupal.org/project/glightbox_media_video\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:5:{s:5:\"1.0.1\";a:11:{s:4:\"name\";s:27:\"glightbox_media_video 1.0.1\";s:7:\"version\";s:5:\"1.0.1\";s:3:\"tag\";s:5:\"1.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.1.tar.gz\";s:4:\"date\";s:10:\"1713942578\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:5:\"1.0.0\";a:11:{s:4:\"name\";s:27:\"glightbox_media_video 1.0.0\";s:7:\"version\";s:5:\"1.0.0\";s:3:\"tag\";s:5:\"1.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.0.tar.gz\";s:4:\"date\";s:10:\"1705421893\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.0.0-alpha3\";a:11:{s:4:\"name\";s:34:\"glightbox_media_video 1.0.0-alpha3\";s:7:\"version\";s:12:\"1.0.0-alpha3\";s:3:\"tag\";s:12:\"1.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.0-alpha3\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1697395686\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:12:\"1.0.0-alpha2\";a:11:{s:4:\"name\";s:34:\"glightbox_media_video 1.0.0-alpha2\";s:7:\"version\";s:12:\"1.0.0-alpha2\";s:3:\"tag\";s:12:\"1.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.0-alpha2\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1694768486\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}s:9:\"1.0.x-dev\";a:11:{s:4:\"name\";s:31:\"glightbox_media_video 1.0.x-dev\";s:7:\"version\";s:9:\"1.0.x-dev\";s:3:\"tag\";s:5:\"1.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/glightbox_media_video/releases/1.0.x-dev\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/glightbox_media_video-1.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1713265199\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'google_analytics',	'a:10:{s:5:\"title\";s:16:\"Google Analytics\";s:10:\"short_name\";s:16:\"google_analytics\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"4.0.\";s:18:\"composer_namespace\";s:23:\"drupal/google_analytics\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:47:\"https://www.drupal.org/project/google_analytics\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:17:{s:5:\"4.0.2\";a:11:{s:4:\"name\";s:22:\"google_analytics 4.0.2\";s:7:\"version\";s:5:\"4.0.2\";s:3:\"tag\";s:5:\"4.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/google_analytics/releases/4.0.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/google_analytics-4.0.2.tar.gz\";s:4:\"date\";s:10:\"1662768595\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"4.0.1\";a:11:{s:4:\"name\";s:22:\"google_analytics 4.0.1\";s:7:\"version\";s:5:\"4.0.1\";s:3:\"tag\";s:5:\"4.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/google_analytics/releases/4.0.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/google_analytics-4.0.1.tar.gz\";s:4:\"date\";s:10:\"1662768475\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.9 || ^9\";}s:5:\"4.0.0\";a:11:{s:4:\"name\";s:22:\"google_analytics 4.0.0\";s:7:\"version\";s:5:\"4.0.0\";s:3:\"tag\";s:5:\"4.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/google_analytics/releases/4.0.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/google_analytics-4.0.0.tar.gz\";s:4:\"date\";s:10:\"1634230238\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.9 || ^9\";}s:12:\"4.0.0-alpha1\";a:11:{s:4:\"name\";s:29:\"google_analytics 4.0.0-alpha1\";s:7:\"version\";s:12:\"4.0.0-alpha1\";s:3:\"tag\";s:12:\"4.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/google_analytics/releases/4.0.0-alpha1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/google_analytics-4.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1631862579\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.9 || ^9\";}s:7:\"8.x-3.1\";a:11:{s:4:\"name\";s:24:\"google_analytics 8.x-3.1\";s:7:\"version\";s:7:\"8.x-3.1\";s:3:\"tag\";s:7:\"8.x-3.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/google_analytics/releases/8.x-3.1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-3.1.tar.gz\";s:4:\"date\";s:10:\"1591298584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.6 || ^9\";}s:7:\"8.x-3.0\";a:11:{s:4:\"name\";s:24:\"google_analytics 8.x-3.0\";s:7:\"version\";s:7:\"8.x-3.0\";s:3:\"tag\";s:7:\"8.x-3.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/google_analytics/releases/8.x-3.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-3.0.tar.gz\";s:4:\"date\";s:10:\"1548968580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-3.0-beta1\";a:11:{s:4:\"name\";s:30:\"google_analytics 8.x-3.0-beta1\";s:7:\"version\";s:13:\"8.x-3.0-beta1\";s:3:\"tag\";s:13:\"8.x-3.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:70:\"https://www.drupal.org/project/google_analytics/releases/8.x-3.0-beta1\";s:13:\"download_link\";s:75:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-3.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1531469320\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-2.5\";a:11:{s:4:\"name\";s:24:\"google_analytics 8.x-2.5\";s:7:\"version\";s:7:\"8.x-2.5\";s:3:\"tag\";s:7:\"8.x-2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/google_analytics/releases/8.x-2.5\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-2.5.tar.gz\";s:4:\"date\";s:10:\"1591298496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.8.6 || ^9\";}s:7:\"8.x-2.4\";a:11:{s:4:\"name\";s:24:\"google_analytics 8.x-2.4\";s:7:\"version\";s:7:\"8.x-2.4\";s:3:\"tag\";s:7:\"8.x-2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/google_analytics/releases/8.x-2.4\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-2.4.tar.gz\";s:4:\"date\";s:10:\"1548968580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.3\";a:11:{s:4:\"name\";s:24:\"google_analytics 8.x-2.3\";s:7:\"version\";s:7:\"8.x-2.3\";s:3:\"tag\";s:7:\"8.x-2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/google_analytics/releases/8.x-2.3\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-2.3.tar.gz\";s:4:\"date\";s:10:\"1531469021\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.2\";a:11:{s:4:\"name\";s:24:\"google_analytics 8.x-2.2\";s:7:\"version\";s:7:\"8.x-2.2\";s:3:\"tag\";s:7:\"8.x-2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/google_analytics/releases/8.x-2.2\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-2.2.tar.gz\";s:4:\"date\";s:10:\"1506372845\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.1\";a:11:{s:4:\"name\";s:24:\"google_analytics 8.x-2.1\";s:7:\"version\";s:7:\"8.x-2.1\";s:3:\"tag\";s:7:\"8.x-2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/google_analytics/releases/8.x-2.1\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-2.1.tar.gz\";s:4:\"date\";s:10:\"1470779939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-2.0\";a:11:{s:4:\"name\";s:24:\"google_analytics 8.x-2.0\";s:7:\"version\";s:7:\"8.x-2.0\";s:3:\"tag\";s:7:\"8.x-2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/google_analytics/releases/8.x-2.0\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-2.0.tar.gz\";s:4:\"date\";s:10:\"1461443639\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.0-rc1\";a:11:{s:4:\"name\";s:28:\"google_analytics 8.x-2.0-rc1\";s:7:\"version\";s:11:\"8.x-2.0-rc1\";s:3:\"tag\";s:11:\"8.x-2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/google_analytics/releases/8.x-2.0-rc1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1448200439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"4.x-dev\";a:11:{s:4:\"name\";s:24:\"google_analytics 4.x-dev\";s:7:\"version\";s:7:\"4.x-dev\";s:3:\"tag\";s:3:\"4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:64:\"https://www.drupal.org/project/google_analytics/releases/4.x-dev\";s:13:\"download_link\";s:69:\"https://ftp.drupal.org/files/projects/google_analytics-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1674677998\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:11:\"8.x-3.x-dev\";a:11:{s:4:\"name\";s:28:\"google_analytics 8.x-3.x-dev\";s:7:\"version\";s:11:\"8.x-3.x-dev\";s:3:\"tag\";s:7:\"8.x-3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/google_analytics/releases/8.x-3.x-dev\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1655498468\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:9:\">=8.9 <11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:28:\"google_analytics 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/google_analytics/releases/8.x-2.x-dev\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/google_analytics-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1655498032\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\">=8.9 < 11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'jquery_ui',	'a:10:{s:5:\"title\";s:9:\"jQuery UI\";s:10:\"short_name\";s:9:\"jquery_ui\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:16:\"drupal/jquery_ui\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/jquery_ui\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:9:{s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.7\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1717002098\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1668521197\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1668437968\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1582149957\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1582044456\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1571251084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1571242084\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:17:\"jquery_ui 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1568823185\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:21:\"jquery_ui 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/jquery_ui/releases/8.x-1.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/jquery_ui-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1716994751\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'jquery_ui_accordion',	'a:10:{s:5:\"title\";s:19:\"jQuery UI Accordion\";s:10:\"short_name\";s:19:\"jquery_ui_accordion\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"2.0.,2.1.\";s:18:\"composer_namespace\";s:26:\"drupal/jquery_ui_accordion\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:50:\"https://www.drupal.org/project/jquery_ui_accordion\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:6:{s:5:\"2.1.0\";a:11:{s:4:\"name\";s:25:\"jquery_ui_accordion 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/jquery_ui_accordion/releases/2.1.0\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1717015495\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:25:\"jquery_ui_accordion 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/jquery_ui_accordion/releases/2.0.0\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1670871459\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:27:\"jquery_ui_accordion 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jquery_ui_accordion/releases/8.x-1.1\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1584106477\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:27:\"jquery_ui_accordion 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jquery_ui_accordion/releases/8.x-1.0\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1568740983\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:27:\"jquery_ui_accordion 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:67:\"https://www.drupal.org/project/jquery_ui_accordion/releases/2.x-dev\";s:13:\"download_link\";s:72:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1717012942\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:31:\"jquery_ui_accordion 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:71:\"https://www.drupal.org/project/jquery_ui_accordion/releases/8.x-1.x-dev\";s:13:\"download_link\";s:76:\"https://ftp.drupal.org/files/projects/jquery_ui_accordion-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1584102992\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'jquery_ui_tabs',	'a:10:{s:5:\"title\";s:14:\"jQuery UI Tabs\";s:10:\"short_name\";s:14:\"jquery_ui_tabs\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"2.1.\";s:18:\"composer_namespace\";s:21:\"drupal/jquery_ui_tabs\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:45:\"https://www.drupal.org/project/jquery_ui_tabs\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:5:{s:5:\"2.1.0\";a:11:{s:4:\"name\";s:20:\"jquery_ui_tabs 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/jquery_ui_tabs/releases/2.1.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1719935962\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:20:\"jquery_ui_tabs 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/jquery_ui_tabs/releases/2.0.0\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1670948528\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:22:\"jquery_ui_tabs 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jquery_ui_tabs/releases/8.x-1.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1590102797\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:22:\"jquery_ui_tabs 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/jquery_ui_tabs/releases/8.x-1.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1568819887\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:26:\"jquery_ui_tabs 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/jquery_ui_tabs/releases/8.x-1.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/jquery_ui_tabs-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1590102633\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'linkit',	'a:10:{s:5:\"title\";s:6:\"Linkit\";s:10:\"short_name\";s:6:\"linkit\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:14:\"6.0.,6.1.,7.0.\";s:18:\"composer_namespace\";s:13:\"drupal/linkit\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:37:\"https://www.drupal.org/project/linkit\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:41:{s:12:\"7.0.0-alpha1\";a:11:{s:4:\"name\";s:19:\"linkit 7.0.0-alpha1\";s:7:\"version\";s:12:\"7.0.0-alpha1\";s:3:\"tag\";s:12:\"7.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/linkit/releases/7.0.0-alpha1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/linkit-7.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1715887209\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^11 || ^10.1\";s:5:\"terms\";a:0:{}}s:5:\"6.1.4\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.4\";s:7:\"version\";s:5:\"6.1.4\";s:3:\"tag\";s:5:\"6.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.4\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.4.tar.gz\";s:4:\"date\";s:10:\"1715203830\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.1.3\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.3\";s:7:\"version\";s:5:\"6.1.3\";s:3:\"tag\";s:5:\"6.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.3\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.3.tar.gz\";s:4:\"date\";s:10:\"1710519126\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.1.2\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.2\";s:7:\"version\";s:5:\"6.1.2\";s:3:\"tag\";s:5:\"6.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.2.tar.gz\";s:4:\"date\";s:10:\"1696865454\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.1.1\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.1\";s:7:\"version\";s:5:\"6.1.1\";s:3:\"tag\";s:5:\"6.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.1.tar.gz\";s:4:\"date\";s:10:\"1696099840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.1.0\";a:11:{s:4:\"name\";s:12:\"linkit 6.1.0\";s:7:\"version\";s:5:\"6.1.0\";s:3:\"tag\";s:5:\"6.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.1.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.1.0.tar.gz\";s:4:\"date\";s:10:\"1688747800\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:9:\"6.1.0-rc2\";a:11:{s:4:\"name\";s:16:\"linkit 6.1.0-rc2\";s:7:\"version\";s:9:\"6.1.0-rc2\";s:3:\"tag\";s:9:\"6.1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.1.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1688055727\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:9:\"6.1.0-rc1\";a:11:{s:4:\"name\";s:16:\"linkit 6.1.0-rc1\";s:7:\"version\";s:9:\"6.1.0-rc1\";s:3:\"tag\";s:9:\"6.1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.1.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1681070586\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.0.2\";a:11:{s:4:\"name\";s:12:\"linkit 6.0.2\";s:7:\"version\";s:5:\"6.0.2\";s:3:\"tag\";s:5:\"6.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.0.2\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.0.2.tar.gz\";s:4:\"date\";s:10:\"1696865395\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";}s:5:\"6.0.1\";a:11:{s:4:\"name\";s:12:\"linkit 6.0.1\";s:7:\"version\";s:5:\"6.0.1\";s:3:\"tag\";s:5:\"6.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.0.1\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.0.1.tar.gz\";s:4:\"date\";s:10:\"1696099905\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";}s:5:\"6.0.0\";a:11:{s:4:\"name\";s:12:\"linkit 6.0.0\";s:7:\"version\";s:5:\"6.0.0\";s:3:\"tag\";s:5:\"6.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:52:\"https://www.drupal.org/project/linkit/releases/6.0.0\";s:13:\"download_link\";s:57:\"https://ftp.drupal.org/files/projects/linkit-6.0.0.tar.gz\";s:4:\"date\";s:10:\"1688748025\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";s:5:\"terms\";a:0:{}}s:9:\"6.0.0-rc2\";a:11:{s:4:\"name\";s:16:\"linkit 6.0.0-rc2\";s:7:\"version\";s:9:\"6.0.0-rc2\";s:3:\"tag\";s:9:\"6.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.0.0-rc2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1688055675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";}s:9:\"6.0.0-rc1\";a:11:{s:4:\"name\";s:16:\"linkit 6.0.0-rc1\";s:7:\"version\";s:9:\"6.0.0-rc1\";s:3:\"tag\";s:9:\"6.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.0.0-rc1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1681070405\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";}s:11:\"6.0.0-beta4\";a:11:{s:4:\"name\";s:18:\"linkit 6.0.0-beta4\";s:7:\"version\";s:11:\"6.0.0-beta4\";s:3:\"tag\";s:11:\"6.0.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/6.0.0-beta4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1678030708\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:11:\"6.0.0-beta3\";a:11:{s:4:\"name\";s:18:\"linkit 6.0.0-beta3\";s:7:\"version\";s:11:\"6.0.0-beta3\";s:3:\"tag\";s:11:\"6.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/6.0.0-beta3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1632848771\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.0.0-beta2\";a:11:{s:4:\"name\";s:18:\"linkit 6.0.0-beta2\";s:7:\"version\";s:11:\"6.0.0-beta2\";s:3:\"tag\";s:11:\"6.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/6.0.0-beta2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1608957496\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.0.0-beta1\";a:11:{s:4:\"name\";s:18:\"linkit 6.0.0-beta1\";s:7:\"version\";s:11:\"6.0.0-beta1\";s:3:\"tag\";s:11:\"6.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/6.0.0-beta1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-6.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1591971462\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-5.0-beta13\";a:11:{s:4:\"name\";s:21:\"linkit 8.x-5.0-beta13\";s:7:\"version\";s:14:\"8.x-5.0-beta13\";s:3:\"tag\";s:14:\"8.x-5.0-beta13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta13\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta13.tar.gz\";s:4:\"date\";s:10:\"1632848792\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-5.0-beta12\";a:11:{s:4:\"name\";s:21:\"linkit 8.x-5.0-beta12\";s:7:\"version\";s:14:\"8.x-5.0-beta12\";s:3:\"tag\";s:14:\"8.x-5.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta12\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1608957625\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-5.0-beta11\";a:11:{s:4:\"name\";s:21:\"linkit 8.x-5.0-beta11\";s:7:\"version\";s:14:\"8.x-5.0-beta11\";s:3:\"tag\";s:14:\"8.x-5.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta11\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1591971693\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-5.0-beta10\";a:11:{s:4:\"name\";s:21:\"linkit 8.x-5.0-beta10\";s:7:\"version\";s:14:\"8.x-5.0-beta10\";s:3:\"tag\";s:14:\"8.x-5.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta10\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1573783085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta9\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta9\";s:7:\"version\";s:13:\"8.x-5.0-beta9\";s:3:\"tag\";s:13:\"8.x-5.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta9\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1562194985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta8\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta8\";s:7:\"version\";s:13:\"8.x-5.0-beta8\";s:3:\"tag\";s:13:\"8.x-5.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta8\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1545966784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta7\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta7\";s:7:\"version\";s:13:\"8.x-5.0-beta7\";s:3:\"tag\";s:13:\"8.x-5.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta7\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1520552585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta6\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta6\";s:7:\"version\";s:13:\"8.x-5.0-beta6\";s:3:\"tag\";s:13:\"8.x-5.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta6\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1505341745\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta5\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta5\";s:7:\"version\";s:13:\"8.x-5.0-beta5\";s:3:\"tag\";s:13:\"8.x-5.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta5\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1490224383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta4\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta4\";s:7:\"version\";s:13:\"8.x-5.0-beta4\";s:3:\"tag\";s:13:\"8.x-5.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1483883642\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta3\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta3\";s:7:\"version\";s:13:\"8.x-5.0-beta3\";s:3:\"tag\";s:13:\"8.x-5.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1474147139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta2\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta2\";s:7:\"version\";s:13:\"8.x-5.0-beta2\";s:3:\"tag\";s:13:\"8.x-5.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1468708139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta1\";a:11:{s:4:\"name\";s:20:\"linkit 8.x-5.0-beta1\";s:7:\"version\";s:13:\"8.x-5.0-beta1\";s:3:\"tag\";s:13:\"8.x-5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-beta1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1468032240\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-alpha1\";a:11:{s:4:\"name\";s:21:\"linkit 8.x-5.0-alpha1\";s:7:\"version\";s:14:\"8.x-5.0-alpha1\";s:3:\"tag\";s:14:\"8.x-5.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/linkit/releases/8.x-5.0-alpha1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1462227194\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-4.4\";a:11:{s:4:\"name\";s:14:\"linkit 8.x-4.4\";s:7:\"version\";s:7:\"8.x-4.4\";s:3:\"tag\";s:7:\"8.x-4.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/8.x-4.4\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.4.tar.gz\";s:4:\"date\";s:10:\"1632848667\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-4.3\";a:11:{s:4:\"name\";s:14:\"linkit 8.x-4.3\";s:7:\"version\";s:7:\"8.x-4.3\";s:3:\"tag\";s:7:\"8.x-4.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/8.x-4.3\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.3.tar.gz\";s:4:\"date\";s:10:\"1490127184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-4.2\";a:11:{s:4:\"name\";s:14:\"linkit 8.x-4.2\";s:7:\"version\";s:7:\"8.x-4.2\";s:3:\"tag\";s:7:\"8.x-4.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/8.x-4.2\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.2.tar.gz\";s:4:\"date\";s:10:\"1483883342\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-4.1\";a:11:{s:4:\"name\";s:14:\"linkit 8.x-4.1\";s:7:\"version\";s:7:\"8.x-4.1\";s:3:\"tag\";s:7:\"8.x-4.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/8.x-4.1\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.1.tar.gz\";s:4:\"date\";s:10:\"1455051539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-4.0\";a:11:{s:4:\"name\";s:14:\"linkit 8.x-4.0\";s:7:\"version\";s:7:\"8.x-4.0\";s:3:\"tag\";s:7:\"8.x-4.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/8.x-4.0\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.0.tar.gz\";s:4:\"date\";s:10:\"1452407039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"7.x-dev\";a:11:{s:4:\"name\";s:14:\"linkit 7.x-dev\";s:7:\"version\";s:7:\"7.x-dev\";s:3:\"tag\";s:3:\"7.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/linkit/releases/7.x-dev\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/linkit-7.x-dev.tar.gz\";s:4:\"date\";s:10:\"1719269297\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^11 || ^10.1\";s:5:\"terms\";a:0:{}}s:9:\"6.1.x-dev\";a:11:{s:4:\"name\";s:16:\"linkit 6.1.x-dev\";s:7:\"version\";s:9:\"6.1.x-dev\";s:3:\"tag\";s:5:\"6.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.1.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1719268989\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";s:5:\"terms\";a:0:{}}s:9:\"6.0.x-dev\";a:11:{s:4:\"name\";s:16:\"linkit 6.0.x-dev\";s:7:\"version\";s:9:\"6.0.x-dev\";s:3:\"tag\";s:5:\"6.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/linkit/releases/6.0.x-dev\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/linkit-6.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1696865222\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:13:\"^9.4 || <10.1\";s:5:\"terms\";a:0:{}}s:11:\"8.x-5.x-dev\";a:11:{s:4:\"name\";s:18:\"linkit 8.x-5.x-dev\";s:7:\"version\";s:11:\"8.x-5.x-dev\";s:3:\"tag\";s:7:\"8.x-5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/8.x-5.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-8.x-5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1651431912\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-4.x-dev\";a:11:{s:4:\"name\";s:18:\"linkit 8.x-4.x-dev\";s:7:\"version\";s:11:\"8.x-4.x-dev\";s:3:\"tag\";s:7:\"8.x-4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/linkit/releases/8.x-4.x-dev\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/linkit-8.x-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1632848383\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'media_library_form_element',	'a:10:{s:5:\"title\";s:30:\"Media Library Form API Element\";s:10:\"short_name\";s:26:\"media_library_form_element\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"2.0.,2.1.\";s:18:\"composer_namespace\";s:33:\"drupal/media_library_form_element\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:57:\"https://www.drupal.org/project/media_library_form_element\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:27:{s:5:\"2.1.0\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.1.0\";s:7:\"version\";s:5:\"2.1.0\";s:3:\"tag\";s:5:\"2.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.1.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.1.0.tar.gz\";s:4:\"date\";s:10:\"1719852877\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.3\";}s:5:\"2.0.6\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.6\";s:7:\"version\";s:5:\"2.0.6\";s:3:\"tag\";s:5:\"2.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.6\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.6.tar.gz\";s:4:\"date\";s:10:\"1674048931\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.5\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.5\";s:7:\"version\";s:5:\"2.0.5\";s:3:\"tag\";s:5:\"2.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.5\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.5.tar.gz\";s:4:\"date\";s:10:\"1673542646\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:5:\"2.0.4\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.4\";s:7:\"version\";s:5:\"2.0.4\";s:3:\"tag\";s:5:\"2.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.4\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.4.tar.gz\";s:4:\"date\";s:10:\"1659257104\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"2.0.3\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.3\";s:7:\"version\";s:5:\"2.0.3\";s:3:\"tag\";s:5:\"2.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.3\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.3.tar.gz\";s:4:\"date\";s:10:\"1608021997\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"2.0.1\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.1\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1607696048\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:32:\"media_library_form_element 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:72:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.0\";s:13:\"download_link\";s:77:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1592564249\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"2.0.0-alpha1\";a:11:{s:4:\"name\";s:39:\"media_library_form_element 2.0.0-alpha1\";s:7:\"version\";s:12:\"2.0.0-alpha1\";s:3:\"tag\";s:12:\"2.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:79:\"https://www.drupal.org/project/media_library_form_element/releases/2.0.0-alpha1\";s:13:\"download_link\";s:84:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1592563784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.3\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1608023001\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.2\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1607703376\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.1\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1607699562\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta5\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta5\";s:7:\"version\";s:13:\"8.x-1.0-beta5\";s:3:\"tag\";s:13:\"8.x-1.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta5\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1592562569\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta4\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta4\";s:7:\"version\";s:13:\"8.x-1.0-beta4\";s:3:\"tag\";s:13:\"8.x-1.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta4\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1592560499\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1592039969\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1589988383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:40:\"media_library_form_element 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:80:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:85:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1588247675\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha9\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha9\";s:7:\"version\";s:14:\"8.x-1.0-alpha9\";s:3:\"tag\";s:14:\"8.x-1.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha9\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1588244814\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1587107544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1580121481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1578740587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1578645188\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1576831688\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1576246080\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1575558480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:41:\"media_library_form_element 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:81:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:86:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1571816584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:34:\"media_library_form_element 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:74:\"https://www.drupal.org/project/media_library_form_element/releases/2.x-dev\";s:13:\"download_link\";s:79:\"https://ftp.drupal.org/files/projects/media_library_form_element-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1719851570\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.3\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:38:\"media_library_form_element 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:78:\"https://www.drupal.org/project/media_library_form_element/releases/8.x-1.x-dev\";s:13:\"download_link\";s:83:\"https://ftp.drupal.org/files/projects/media_library_form_element-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1608021762\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'metatag',	'a:10:{s:5:\"title\";s:7:\"Metatag\";s:10:\"short_name\";s:7:\"metatag\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:11:\"2.0.,8.x-1.\";s:18:\"composer_namespace\";s:14:\"drupal/metatag\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:38:\"https://www.drupal.org/project/metatag\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:46:{s:5:\"2.0.2\";a:11:{s:4:\"name\";s:13:\"metatag 2.0.2\";s:7:\"version\";s:5:\"2.0.2\";s:3:\"tag\";s:5:\"2.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/metatag/releases/2.0.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/metatag-2.0.2.tar.gz\";s:4:\"date\";s:10:\"1722869772\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";}s:5:\"2.0.1\";a:11:{s:4:\"name\";s:13:\"metatag 2.0.1\";s:7:\"version\";s:5:\"2.0.1\";s:3:\"tag\";s:5:\"2.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/metatag/releases/2.0.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/metatag-2.0.1.tar.gz\";s:4:\"date\";s:10:\"1722843615\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";}s:5:\"2.0.0\";a:11:{s:4:\"name\";s:13:\"metatag 2.0.0\";s:7:\"version\";s:5:\"2.0.0\";s:3:\"tag\";s:5:\"2.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/metatag/releases/2.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/metatag-2.0.0.tar.gz\";s:4:\"date\";s:10:\"1687856982\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"2.0.0-rc2\";a:11:{s:4:\"name\";s:17:\"metatag 2.0.0-rc2\";s:7:\"version\";s:9:\"2.0.0-rc2\";s:3:\"tag\";s:9:\"2.0.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/metatag/releases/2.0.0-rc2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/metatag-2.0.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1685470335\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"2.0.0-rc1\";a:11:{s:4:\"name\";s:17:\"metatag 2.0.0-rc1\";s:7:\"version\";s:9:\"2.0.0-rc1\";s:3:\"tag\";s:9:\"2.0.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/metatag/releases/2.0.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/metatag-2.0.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1685126939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:8:\"8.x-1.26\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.26\";s:7:\"version\";s:8:\"8.x-1.26\";s:3:\"tag\";s:8:\"8.x-1.26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.26\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.26.tar.gz\";s:4:\"date\";s:10:\"1687856123\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.25\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.25\";s:7:\"version\";s:8:\"8.x-1.25\";s:3:\"tag\";s:8:\"8.x-1.25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.25\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.25.tar.gz\";s:4:\"date\";s:10:\"1685541226\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.24\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.24\";s:7:\"version\";s:8:\"8.x-1.24\";s:3:\"tag\";s:8:\"8.x-1.24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.24\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.24.tar.gz\";s:4:\"date\";s:10:\"1685125893\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.23\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.23\";s:7:\"version\";s:8:\"8.x-1.23\";s:3:\"tag\";s:8:\"8.x-1.23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.23\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.23.tar.gz\";s:4:\"date\";s:10:\"1683896256\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.22\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.22\";s:7:\"version\";s:8:\"8.x-1.22\";s:3:\"tag\";s:8:\"8.x-1.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.22\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.22.tar.gz\";s:4:\"date\";s:10:\"1664472818\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.21\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.21\";s:7:\"version\";s:8:\"8.x-1.21\";s:3:\"tag\";s:8:\"8.x-1.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.21\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.21.tar.gz\";s:4:\"date\";s:10:\"1657971667\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:8:\"8.x-1.20\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.20\";s:7:\"version\";s:8:\"8.x-1.20\";s:3:\"tag\";s:8:\"8.x-1.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.20\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.20.tar.gz\";s:4:\"date\";s:10:\"1657649277\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:8:\"8.x-1.19\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.19\";s:7:\"version\";s:8:\"8.x-1.19\";s:3:\"tag\";s:8:\"8.x-1.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.19\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.19.tar.gz\";s:4:\"date\";s:10:\"1641496014\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:8:\"8.x-1.18\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.18\";s:7:\"version\";s:8:\"8.x-1.18\";s:3:\"tag\";s:8:\"8.x-1.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.18\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.18.tar.gz\";s:4:\"date\";s:10:\"1640098931\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:8:\"8.x-1.17\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.17\";s:7:\"version\";s:8:\"8.x-1.17\";s:3:\"tag\";s:8:\"8.x-1.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.17\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.17.tar.gz\";s:4:\"date\";s:10:\"1640019321\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^9\";}s:8:\"8.x-1.16\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.16\";s:7:\"version\";s:8:\"8.x-1.16\";s:3:\"tag\";s:8:\"8.x-1.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.16\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.16.tar.gz\";s:4:\"date\";s:10:\"1615820867\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.15\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1607188979\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.14\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1597183852\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.13\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1587476385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.12\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1585576513\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.11\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1576870683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:16:\"metatag 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/metatag/releases/8.x-1.10\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1567099985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.9\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1563985988\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.8\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1550683382\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1535726393\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1534867985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1522344484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1513888384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1506714244\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1501553646\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1496286243\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:15:\"metatag 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/metatag/releases/8.x-1.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1485901983\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-beta12\";a:11:{s:4:\"name\";s:22:\"metatag 8.x-1.0-beta12\";s:7:\"version\";s:14:\"8.x-1.0-beta12\";s:3:\"tag\";s:14:\"8.x-1.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta12\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1483477143\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-beta11\";a:11:{s:4:\"name\";s:22:\"metatag 8.x-1.0-beta11\";s:7:\"version\";s:14:\"8.x-1.0-beta11\";s:3:\"tag\";s:14:\"8.x-1.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta11\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1477928941\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-beta10\";a:11:{s:4:\"name\";s:22:\"metatag 8.x-1.0-beta10\";s:7:\"version\";s:14:\"8.x-1.0-beta10\";s:3:\"tag\";s:14:\"8.x-1.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta10\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1471888739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta9\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta9\";s:7:\"version\";s:13:\"8.x-1.0-beta9\";s:3:\"tag\";s:13:\"8.x-1.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta9\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1464897839\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta8\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta8\";s:7:\"version\";s:13:\"8.x-1.0-beta8\";s:3:\"tag\";s:13:\"8.x-1.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta8\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1463224445\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta7\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta7\";s:7:\"version\";s:13:\"8.x-1.0-beta7\";s:3:\"tag\";s:13:\"8.x-1.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta7\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1459708139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta6\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta6\";s:7:\"version\";s:13:\"8.x-1.0-beta6\";s:3:\"tag\";s:13:\"8.x-1.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta6\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1459610941\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta5\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta5\";s:7:\"version\";s:13:\"8.x-1.0-beta5\";s:3:\"tag\";s:13:\"8.x-1.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1457723339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta4\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta4\";s:7:\"version\";s:13:\"8.x-1.0-beta4\";s:3:\"tag\";s:13:\"8.x-1.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1454780939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta3\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta3\";s:7:\"version\";s:13:\"8.x-1.0-beta3\";s:3:\"tag\";s:13:\"8.x-1.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1449616139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1448302443\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:21:\"metatag 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/metatag/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1447944840\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"2.0.x-dev\";a:11:{s:4:\"name\";s:17:\"metatag 2.0.x-dev\";s:7:\"version\";s:9:\"2.0.x-dev\";s:3:\"tag\";s:5:\"2.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/metatag/releases/2.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/metatag-2.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722869643\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:19:\"metatag 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/metatag/releases/8.x-1.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/metatag-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722272637\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'paragraphs',	'a:10:{s:5:\"title\";s:10:\"Paragraphs\";s:10:\"short_name\";s:10:\"paragraphs\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:17:\"drupal/paragraphs\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:41:\"https://www.drupal.org/project/paragraphs\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:23:{s:8:\"8.x-1.17\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.17\";s:7:\"version\";s:8:\"8.x-1.17\";s:3:\"tag\";s:8:\"8.x-1.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.17\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.17.tar.gz\";s:4:\"date\";s:10:\"1705234146\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.16\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.16\";s:7:\"version\";s:8:\"8.x-1.16\";s:3:\"tag\";s:8:\"8.x-1.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.16\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.16.tar.gz\";s:4:\"date\";s:10:\"1694007797\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.15\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1661440897\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.14\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1650520869\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.13\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1646121716\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.12\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1590061335\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.11\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1581850829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:19:\"paragraphs 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.10\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1572617586\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.9\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1565881389\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.8\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1553618281\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.7\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1553087589\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.6\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1550669584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.5\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1541001780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.4\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1540628880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.3\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1527502684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.2\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1505802544\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.1\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1487331784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:18:\"paragraphs 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1469725739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc5\";a:11:{s:4:\"name\";s:22:\"paragraphs 8.x-1.0-rc5\";s:7:\"version\";s:11:\"8.x-1.0-rc5\";s:3:\"tag\";s:11:\"8.x-1.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-rc5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1464728039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc4\";a:11:{s:4:\"name\";s:22:\"paragraphs 8.x-1.0-rc4\";s:7:\"version\";s:11:\"8.x-1.0-rc4\";s:3:\"tag\";s:11:\"8.x-1.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-rc4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1447766339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:25:\"paragraphs 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1421889780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:25:\"paragraphs 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:65:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:70:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1421790180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:22:\"paragraphs 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/paragraphs/releases/8.x-1.x-dev\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/paragraphs-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722984764\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^10.2 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'pathauto',	'a:10:{s:5:\"title\";s:8:\"Pathauto\";s:10:\"short_name\";s:8:\"pathauto\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:15:\"drupal/pathauto\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/pathauto\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:23:{s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:17:\"pathauto 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/pathauto/releases/8.x-1.13\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1722507672\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:17:\"pathauto 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/pathauto/releases/8.x-1.12\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1696776683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:17:\"pathauto 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/pathauto/releases/8.x-1.11\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1659472548\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:17:\"pathauto 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/pathauto/releases/8.x-1.10\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1650806739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.9\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1644822949\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.8\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1588103046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.7\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1587898105\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.6\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1575467285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.6-beta1\";a:11:{s:4:\"name\";s:22:\"pathauto 8.x-1.6-beta1\";s:7:\"version\";s:13:\"8.x-1.6-beta1\";s:3:\"tag\";s:13:\"8.x-1.6-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/pathauto/releases/8.x-1.6-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.6-beta1.tar.gz\";s:4:\"date\";s:10:\"1573505285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.6-alpha1\";a:11:{s:4:\"name\";s:23:\"pathauto 8.x-1.6-alpha1\";s:7:\"version\";s:14:\"8.x-1.6-alpha1\";s:3:\"tag\";s:14:\"8.x-1.6-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/pathauto/releases/8.x-1.6-alpha1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.6-alpha1.tar.gz\";s:4:\"date\";s:10:\"1571587984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.5\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1570828084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.4\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1554239887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1536407884\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1524421084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1520092685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:16:\"pathauto 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1493468044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:20:\"pathauto 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1485702484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:22:\"pathauto 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1484781483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:22:\"pathauto 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1474313339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:23:\"pathauto 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1461007694\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:23:\"pathauto 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1456529339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:23:\"pathauto 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/pathauto/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1453413539\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:20:\"pathauto 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/pathauto/releases/8.x-1.x-dev\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/pathauto-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722507274\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.4 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'redirect',	'a:10:{s:5:\"title\";s:8:\"Redirect\";s:10:\"short_name\";s:8:\"redirect\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:15:\"drupal/redirect\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:39:\"https://www.drupal.org/project/redirect\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:17:{s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.9\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1693393506\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.8\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1661806955\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.7\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1639380488\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.6\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1589312204\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.5\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1576656784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.4\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1561757585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.3\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1539682684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.2\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1525419785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.1\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1520897880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:16:\"redirect 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/redirect/releases/8.x-1.0\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1513767485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:22:\"redirect 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1501443542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:23:\"redirect 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1492182542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:23:\"redirect 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1487092684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:23:\"redirect 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1486078383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:23:\"redirect 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1481901483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:23:\"redirect 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:63:\"https://www.drupal.org/project/redirect/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:68:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1460041522\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:20:\"redirect 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/redirect/releases/8.x-1.x-dev\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/redirect-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1716196019\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'svg_image',	'a:10:{s:5:\"title\";s:9:\"Svg Image\";s:10:\"short_name\";s:9:\"svg_image\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:4:\"3.0.\";s:18:\"composer_namespace\";s:16:\"drupal/svg_image\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:40:\"https://www.drupal.org/project/svg_image\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:22:{s:5:\"3.0.2\";a:11:{s:4:\"name\";s:15:\"svg_image 3.0.2\";s:7:\"version\";s:5:\"3.0.2\";s:3:\"tag\";s:5:\"3.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/svg_image/releases/3.0.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/svg_image-3.0.2.tar.gz\";s:4:\"date\";s:10:\"1698471266\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:5:\"3.0.1\";a:11:{s:4:\"name\";s:15:\"svg_image 3.0.1\";s:7:\"version\";s:5:\"3.0.1\";s:3:\"tag\";s:5:\"3.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/svg_image/releases/3.0.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/svg_image-3.0.1.tar.gz\";s:4:\"date\";s:10:\"1676292042\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:8:\"8.x-1.16\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.16\";s:7:\"version\";s:8:\"8.x-1.16\";s:3:\"tag\";s:8:\"8.x-1.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.16\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.16.tar.gz\";s:4:\"date\";s:10:\"1647314248\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.15\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1629259130\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.14\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1591251834\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.13\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1585379082\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.12\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1585212808\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.11\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1585194882\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:18:\"svg_image 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:58:\"https://www.drupal.org/project/svg_image/releases/8.x-1.10\";s:13:\"download_link\";s:63:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1585150271\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.9\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1548492180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.8\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1516678385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.7\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1508989144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.6\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1508940244\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.5\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1508939044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1508930344\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1505705046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1503124445\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1497798542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:17:\"svg_image 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/8.x-1.0\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1497798242\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"3.x-dev\";a:11:{s:4:\"name\";s:17:\"svg_image 3.x-dev\";s:7:\"version\";s:7:\"3.x-dev\";s:3:\"tag\";s:3:\"3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/3.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1703577248\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:7:\"2.x-dev\";a:11:{s:4:\"name\";s:17:\"svg_image 2.x-dev\";s:7:\"version\";s:7:\"2.x-dev\";s:3:\"tag\";s:3:\"2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/svg_image/releases/2.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/svg_image-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1628735183\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:21:\"svg_image 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/svg_image/releases/8.x-1.x-dev\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/svg_image-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1698470956\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'token',	'a:10:{s:5:\"title\";s:5:\"Token\";s:10:\"short_name\";s:5:\"token\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-1.\";s:18:\"composer_namespace\";s:12:\"drupal/token\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:36:\"https://www.drupal.org/project/token\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:22:{s:8:\"8.x-1.15\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.15\";s:7:\"version\";s:8:\"8.x-1.15\";s:3:\"tag\";s:8:\"8.x-1.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.15\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.15.tar.gz\";s:4:\"date\";s:10:\"1722206211\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";}s:8:\"8.x-1.14\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.14\";s:7:\"version\";s:8:\"8.x-1.14\";s:3:\"tag\";s:8:\"8.x-1.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.14\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.14.tar.gz\";s:4:\"date\";s:10:\"1713009399\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:8:\"8.x-1.13\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.13\";s:7:\"version\";s:8:\"8.x-1.13\";s:3:\"tag\";s:8:\"8.x-1.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.13\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.13.tar.gz\";s:4:\"date\";s:10:\"1697885927\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:8:\"8.x-1.12\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.12\";s:7:\"version\";s:8:\"8.x-1.12\";s:3:\"tag\";s:8:\"8.x-1.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.12\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.12.tar.gz\";s:4:\"date\";s:10:\"1688015262\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:8:\"8.x-1.11\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.11\";s:7:\"version\";s:8:\"8.x-1.11\";s:3:\"tag\";s:8:\"8.x-1.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.11\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.11.tar.gz\";s:4:\"date\";s:10:\"1659471813\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.2 || ^10\";}s:8:\"8.x-1.10\";a:11:{s:4:\"name\";s:14:\"token 8.x-1.10\";s:7:\"version\";s:8:\"8.x-1.10\";s:3:\"tag\";s:8:\"8.x-1.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:54:\"https://www.drupal.org/project/token/releases/8.x-1.10\";s:13:\"download_link\";s:59:\"https://ftp.drupal.org/files/projects/token-8.x-1.10.tar.gz\";s:4:\"date\";s:10:\"1638619775\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.9\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.9\";s:7:\"version\";s:7:\"8.x-1.9\";s:3:\"tag\";s:7:\"8.x-1.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.9\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.9.tar.gz\";s:4:\"date\";s:10:\"1608284866\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1607552423\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1587893588\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1577708583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1537557481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1536408480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1527232684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1527112080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1513810384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:13:\"token 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/token/releases/8.x-1.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/token-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1493466843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:17:\"token 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/token/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/token-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1483290542\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:19:\"token 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/token/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/token-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1474367039\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:19:\"token 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/token/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/token-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1470864453\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:20:\"token 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/token/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/token-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1453363739\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:20:\"token 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/token/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/token-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1450961339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:17:\"token 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/token/releases/8.x-1.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/token-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722205260\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.2 || ^10 || ^11\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'viewsreference',	'a:10:{s:5:\"title\";s:21:\"Views Reference Field\";s:10:\"short_name\";s:14:\"viewsreference\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:6:\"8.x-2.\";s:18:\"composer_namespace\";s:21:\"drupal/viewsreference\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:45:\"https://www.drupal.org/project/viewsreference\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:40:{s:13:\"8.x-2.0-beta9\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta9\";s:7:\"version\";s:13:\"8.x-2.0-beta9\";s:3:\"tag\";s:13:\"8.x-2.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta9\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1722575139\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:13:\"8.x-2.0-beta8\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta8\";s:7:\"version\";s:13:\"8.x-2.0-beta8\";s:3:\"tag\";s:13:\"8.x-2.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta8\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1717030540\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:13:\"8.x-2.0-beta7\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta7\";s:7:\"version\";s:13:\"8.x-2.0-beta7\";s:3:\"tag\";s:13:\"8.x-2.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta7\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1698849225\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta6\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta6\";s:7:\"version\";s:13:\"8.x-2.0-beta6\";s:3:\"tag\";s:13:\"8.x-2.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta6\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1691400463\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta5\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta5\";s:7:\"version\";s:13:\"8.x-2.0-beta5\";s:3:\"tag\";s:13:\"8.x-2.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta5\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1691399238\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta4\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta4\";s:7:\"version\";s:13:\"8.x-2.0-beta4\";s:3:\"tag\";s:13:\"8.x-2.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta4\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1664821610\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";}s:13:\"8.x-2.0-beta3\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta3\";s:7:\"version\";s:13:\"8.x-2.0-beta3\";s:3:\"tag\";s:13:\"8.x-2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta3\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1658840434\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:13:\"8.x-2.0-beta2\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta2\";s:7:\"version\";s:13:\"8.x-2.0-beta2\";s:3:\"tag\";s:13:\"8.x-2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1597235052\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:13:\"8.x-2.0-beta1\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-2.0-beta1\";s:7:\"version\";s:13:\"8.x-2.0-beta1\";s:3:\"tag\";s:13:\"8.x-2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-beta1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1595873106\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-2.0-alpha7\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha7\";s:7:\"version\";s:14:\"8.x-2.0-alpha7\";s:3:\"tag\";s:14:\"8.x-2.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha7\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1588510059\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:14:\"8.x-2.0-alpha6\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha6\";s:7:\"version\";s:14:\"8.x-2.0-alpha6\";s:3:\"tag\";s:14:\"8.x-2.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha6\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1576373887\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha5\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha5\";s:7:\"version\";s:14:\"8.x-2.0-alpha5\";s:3:\"tag\";s:14:\"8.x-2.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha5\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1574807584\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha4\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha4\";s:7:\"version\";s:14:\"8.x-2.0-alpha4\";s:3:\"tag\";s:14:\"8.x-2.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1515706384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha3\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha3\";s:7:\"version\";s:14:\"8.x-2.0-alpha3\";s:3:\"tag\";s:14:\"8.x-2.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1510927385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha2\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha2\";s:7:\"version\";s:14:\"8.x-2.0-alpha2\";s:3:\"tag\";s:14:\"8.x-2.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1508957945\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-2.0-alpha1\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-2.0-alpha1\";s:7:\"version\";s:14:\"8.x-2.0-alpha1\";s:3:\"tag\";s:14:\"8.x-2.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.0-alpha1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1508408044\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:12:\"New features\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.8\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.8\";s:7:\"version\";s:7:\"8.x-1.8\";s:3:\"tag\";s:7:\"8.x-1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.8\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.8.tar.gz\";s:4:\"date\";s:10:\"1652694596\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"8.x-1.7\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.7\";s:7:\"version\";s:7:\"8.x-1.7\";s:3:\"tag\";s:7:\"8.x-1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.7\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.7.tar.gz\";s:4:\"date\";s:10:\"1610571201\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.6\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.6\";s:7:\"version\";s:7:\"8.x-1.6\";s:3:\"tag\";s:7:\"8.x-1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.6.tar.gz\";s:4:\"date\";s:10:\"1601529306\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.5\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.5\";s:7:\"version\";s:7:\"8.x-1.5\";s:3:\"tag\";s:7:\"8.x-1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.5.tar.gz\";s:4:\"date\";s:10:\"1601512918\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:7:\"8.x-1.4\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.4\";s:7:\"version\";s:7:\"8.x-1.4\";s:3:\"tag\";s:7:\"8.x-1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.4.tar.gz\";s:4:\"date\";s:10:\"1544740080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.3\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.3\";s:7:\"version\";s:7:\"8.x-1.3\";s:3:\"tag\";s:7:\"8.x-1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.3.tar.gz\";s:4:\"date\";s:10:\"1544678580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.2\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.2\";s:7:\"version\";s:7:\"8.x-1.2\";s:3:\"tag\";s:7:\"8.x-1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.2.tar.gz\";s:4:\"date\";s:10:\"1515538984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.1\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.1\";s:7:\"version\";s:7:\"8.x-1.1\";s:3:\"tag\";s:7:\"8.x-1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.1.tar.gz\";s:4:\"date\";s:10:\"1515464888\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-1.0\";a:11:{s:4:\"name\";s:22:\"viewsreference 8.x-1.0\";s:7:\"version\";s:7:\"8.x-1.0\";s:3:\"tag\";s:7:\"8.x-1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0.tar.gz\";s:4:\"date\";s:10:\"1502947144\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc3\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.0-rc3\";s:7:\"version\";s:11:\"8.x-1.0-rc3\";s:3:\"tag\";s:11:\"8.x-1.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-rc3\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1500699843\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";s:5:\"terms\";a:0:{}}s:11:\"8.x-1.0-rc2\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.0-rc2\";s:7:\"version\";s:11:\"8.x-1.0-rc2\";s:3:\"tag\";s:11:\"8.x-1.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-rc2\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1500437042\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-1.0-rc1\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.0-rc1\";s:7:\"version\";s:11:\"8.x-1.0-rc1\";s:3:\"tag\";s:11:\"8.x-1.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-rc1\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1500319442\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta2\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-1.0-beta2\";s:7:\"version\";s:13:\"8.x-1.0-beta2\";s:3:\"tag\";s:13:\"8.x-1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-beta2\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1500074043\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-1.0-beta1\";a:11:{s:4:\"name\";s:28:\"viewsreference 8.x-1.0-beta1\";s:7:\"version\";s:13:\"8.x-1.0-beta1\";s:3:\"tag\";s:13:\"8.x-1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:68:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-beta1\";s:13:\"download_link\";s:73:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1497764942\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha8\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha8\";s:7:\"version\";s:14:\"8.x-1.0-alpha8\";s:3:\"tag\";s:14:\"8.x-1.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha8\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1482381184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha7\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha7\";s:7:\"version\";s:14:\"8.x-1.0-alpha7\";s:3:\"tag\";s:14:\"8.x-1.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha7\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1480293783\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha6\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha6\";s:7:\"version\";s:14:\"8.x-1.0-alpha6\";s:3:\"tag\";s:14:\"8.x-1.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha6\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1480270680\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha5\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha5\";s:7:\"version\";s:14:\"8.x-1.0-alpha5\";s:3:\"tag\";s:14:\"8.x-1.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha5\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1478134740\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha4\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha4\";s:7:\"version\";s:14:\"8.x-1.0-alpha4\";s:3:\"tag\";s:14:\"8.x-1.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha4\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1477682339\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha3\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha3\";s:7:\"version\";s:14:\"8.x-1.0-alpha3\";s:3:\"tag\";s:14:\"8.x-1.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha3\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1473627239\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha2\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha2\";s:7:\"version\";s:14:\"8.x-1.0-alpha2\";s:3:\"tag\";s:14:\"8.x-1.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha2\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1473283439\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-1.0-alpha1\";a:11:{s:4:\"name\";s:29:\"viewsreference 8.x-1.0-alpha1\";s:7:\"version\";s:14:\"8.x-1.0-alpha1\";s:3:\"tag\";s:14:\"8.x-1.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:69:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.0-alpha1\";s:13:\"download_link\";s:74:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1473023939\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-2.x-dev\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-2.x-dev\";s:7:\"version\";s:11:\"8.x-2.x-dev\";s:3:\"tag\";s:7:\"8.x-2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-2.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1720723533\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:18:\"^9.3 || ^10 || ^11\";}s:11:\"8.x-1.x-dev\";a:11:{s:4:\"name\";s:26:\"viewsreference 8.x-1.x-dev\";s:7:\"version\";s:11:\"8.x-1.x-dev\";s:3:\"tag\";s:7:\"8.x-1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:66:\"https://www.drupal.org/project/viewsreference/releases/8.x-1.x-dev\";s:13:\"download_link\";s:71:\"https://ftp.drupal.org/files/projects/viewsreference-8.x-1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1691455445\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.3 || ^10\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206),
('update_available_releases',	'webform',	'a:10:{s:5:\"title\";s:7:\"Webform\";s:10:\"short_name\";s:7:\"webform\";s:4:\"type\";s:14:\"project_module\";s:18:\"supported_branches\";s:9:\"6.2.,6.3.\";s:18:\"composer_namespace\";s:14:\"drupal/webform\";s:14:\"project_status\";s:9:\"published\";s:4:\"link\";s:38:\"https://www.drupal.org/project/webform\";s:5:\"terms\";s:0:\"\";s:8:\"releases\";a:195:{s:5:\"6.2.7\";a:11:{s:4:\"name\";s:13:\"webform 6.2.7\";s:7:\"version\";s:5:\"6.2.7\";s:3:\"tag\";s:5:\"6.2.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.7.tar.gz\";s:4:\"date\";s:10:\"1721425228\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.2.6\";a:11:{s:4:\"name\";s:13:\"webform 6.2.6\";s:7:\"version\";s:5:\"6.2.6\";s:3:\"tag\";s:5:\"6.2.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.6.tar.gz\";s:4:\"date\";s:10:\"1721424721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:5:\"6.2.5\";a:11:{s:4:\"name\";s:13:\"webform 6.2.5\";s:7:\"version\";s:5:\"6.2.5\";s:3:\"tag\";s:5:\"6.2.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.5.tar.gz\";s:4:\"date\";s:10:\"1721065379\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.2.4\";a:11:{s:4:\"name\";s:13:\"webform 6.2.4\";s:7:\"version\";s:5:\"6.2.4\";s:3:\"tag\";s:5:\"6.2.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.4.tar.gz\";s:4:\"date\";s:10:\"1721054262\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:9:\"6.2.4-rc1\";a:11:{s:4:\"name\";s:17:\"webform 6.2.4-rc1\";s:7:\"version\";s:9:\"6.2.4-rc1\";s:3:\"tag\";s:9:\"6.2.4-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.4-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.4-rc1.tar.gz\";s:4:\"date\";s:10:\"1719495514\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.1\";}s:5:\"6.2.3\";a:11:{s:4:\"name\";s:13:\"webform 6.2.3\";s:7:\"version\";s:5:\"6.2.3\";s:3:\"tag\";s:5:\"6.2.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.3.tar.gz\";s:4:\"date\";s:10:\"1719330022\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:5:\"6.2.2\";a:11:{s:4:\"name\";s:13:\"webform 6.2.2\";s:7:\"version\";s:5:\"6.2.2\";s:3:\"tag\";s:5:\"6.2.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.2.tar.gz\";s:4:\"date\";s:10:\"1701948363\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:5:\"6.2.1\";a:11:{s:4:\"name\";s:13:\"webform 6.2.1\";s:7:\"version\";s:5:\"6.2.1\";s:3:\"tag\";s:5:\"6.2.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.1.tar.gz\";s:4:\"date\";s:10:\"1701862848\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:5:\"6.2.0\";a:11:{s:4:\"name\";s:13:\"webform 6.2.0\";s:7:\"version\";s:5:\"6.2.0\";s:3:\"tag\";s:5:\"6.2.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.2.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.2.0.tar.gz\";s:4:\"date\";s:10:\"1698674300\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"6.2.0-rc4\";a:11:{s:4:\"name\";s:17:\"webform 6.2.0-rc4\";s:7:\"version\";s:9:\"6.2.0-rc4\";s:3:\"tag\";s:9:\"6.2.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.0-rc4\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1698417151\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"6.2.0-rc3\";a:11:{s:4:\"name\";s:17:\"webform 6.2.0-rc3\";s:7:\"version\";s:9:\"6.2.0-rc3\";s:3:\"tag\";s:9:\"6.2.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.0-rc3\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1698075159\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"6.2.0-rc2\";a:11:{s:4:\"name\";s:17:\"webform 6.2.0-rc2\";s:7:\"version\";s:9:\"6.2.0-rc2\";s:3:\"tag\";s:9:\"6.2.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.0-rc2\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1697463934\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:9:\"6.2.0-rc1\";a:11:{s:4:\"name\";s:17:\"webform 6.2.0-rc1\";s:7:\"version\";s:9:\"6.2.0-rc1\";s:3:\"tag\";s:9:\"6.2.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.0-rc1\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1696976940\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:11:\"6.2.0-beta7\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta7\";s:7:\"version\";s:11:\"6.2.0-beta7\";s:3:\"tag\";s:11:\"6.2.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta7\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1696543693\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:11:\"6.2.0-beta6\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta6\";s:7:\"version\";s:11:\"6.2.0-beta6\";s:3:\"tag\";s:11:\"6.2.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1686598812\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:11:\"6.2.0-beta5\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta5\";s:7:\"version\";s:11:\"6.2.0-beta5\";s:3:\"tag\";s:11:\"6.2.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1673535773\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";}s:11:\"6.2.0-beta4\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta4\";s:7:\"version\";s:11:\"6.2.0-beta4\";s:3:\"tag\";s:11:\"6.2.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1672758935\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:11:\"^9.4 || ^10\";s:5:\"terms\";a:0:{}}s:11:\"6.2.0-beta3\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta3\";s:7:\"version\";s:11:\"6.2.0-beta3\";s:3:\"tag\";s:11:\"6.2.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1663937872\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^9.4\";}s:11:\"6.2.0-beta2\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta2\";s:7:\"version\";s:11:\"6.2.0-beta2\";s:3:\"tag\";s:11:\"6.2.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1644940970\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:11:\"6.2.0-beta1\";a:11:{s:4:\"name\";s:19:\"webform 6.2.0-beta1\";s:7:\"version\";s:11:\"6.2.0-beta1\";s:3:\"tag\";s:11:\"6.2.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.2.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.2.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1640795829\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^9.2\";}s:5:\"6.1.8\";a:11:{s:4:\"name\";s:13:\"webform 6.1.8\";s:7:\"version\";s:5:\"6.1.8\";s:3:\"tag\";s:5:\"6.1.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.8.tar.gz\";s:4:\"date\";s:10:\"1698673929\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.3\";}s:5:\"6.1.7\";a:11:{s:4:\"name\";s:13:\"webform 6.1.7\";s:7:\"version\";s:5:\"6.1.7\";s:3:\"tag\";s:5:\"6.1.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.7.tar.gz\";s:4:\"date\";s:10:\"1696976671\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.3\";}s:5:\"6.1.6\";a:11:{s:4:\"name\";s:13:\"webform 6.1.6\";s:7:\"version\";s:5:\"6.1.6\";s:3:\"tag\";s:5:\"6.1.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.6.tar.gz\";s:4:\"date\";s:10:\"1696543413\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.3\";}s:5:\"6.1.5\";a:11:{s:4:\"name\";s:13:\"webform 6.1.5\";s:7:\"version\";s:5:\"6.1.5\";s:3:\"tag\";s:5:\"6.1.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.5.tar.gz\";s:4:\"date\";s:10:\"1686599078\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^9.3\";}s:5:\"6.1.4\";a:11:{s:4:\"name\";s:13:\"webform 6.1.4\";s:7:\"version\";s:5:\"6.1.4\";s:3:\"tag\";s:5:\"6.1.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.4.tar.gz\";s:4:\"date\";s:10:\"1673535467\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.1.4-beta2\";a:11:{s:4:\"name\";s:19:\"webform 6.1.4-beta2\";s:7:\"version\";s:11:\"6.1.4-beta2\";s:3:\"tag\";s:11:\"6.1.4-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.1.4-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.1.4-beta2.tar.gz\";s:4:\"date\";s:10:\"1672758568\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:11:\"6.1.4-beta1\";a:11:{s:4:\"name\";s:19:\"webform 6.1.4-beta1\";s:7:\"version\";s:11:\"6.1.4-beta1\";s:3:\"tag\";s:11:\"6.1.4-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.1.4-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.1.4-beta1.tar.gz\";s:4:\"date\";s:10:\"1663937578\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.1.3\";a:11:{s:4:\"name\";s:13:\"webform 6.1.3\";s:7:\"version\";s:5:\"6.1.3\";s:3:\"tag\";s:5:\"6.1.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.3.tar.gz\";s:4:\"date\";s:10:\"1644940723\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.1.3-beta1\";a:11:{s:4:\"name\";s:19:\"webform 6.1.3-beta1\";s:7:\"version\";s:11:\"6.1.3-beta1\";s:3:\"tag\";s:11:\"6.1.3-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.1.3-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.1.3-beta1.tar.gz\";s:4:\"date\";s:10:\"1640795631\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.1.2\";a:11:{s:4:\"name\";s:13:\"webform 6.1.2\";s:7:\"version\";s:5:\"6.1.2\";s:3:\"tag\";s:5:\"6.1.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.2.tar.gz\";s:4:\"date\";s:10:\"1638917151\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.1.1\";a:11:{s:4:\"name\";s:13:\"webform 6.1.1\";s:7:\"version\";s:5:\"6.1.1\";s:3:\"tag\";s:5:\"6.1.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.1.tar.gz\";s:4:\"date\";s:10:\"1638398898\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.1.0\";a:11:{s:4:\"name\";s:13:\"webform 6.1.0\";s:7:\"version\";s:5:\"6.1.0\";s:3:\"tag\";s:5:\"6.1.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.1.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.1.0.tar.gz\";s:4:\"date\";s:10:\"1635676666\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.1.0-beta2\";a:11:{s:4:\"name\";s:19:\"webform 6.1.0-beta2\";s:7:\"version\";s:11:\"6.1.0-beta2\";s:3:\"tag\";s:11:\"6.1.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.1.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.1.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1629904016\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.1.0-beta1\";a:11:{s:4:\"name\";s:19:\"webform 6.1.0-beta1\";s:7:\"version\";s:11:\"6.1.0-beta1\";s:3:\"tag\";s:11:\"6.1.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.1.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.1.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1626269425\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.8\";a:11:{s:4:\"name\";s:13:\"webform 6.0.8\";s:7:\"version\";s:5:\"6.0.8\";s:3:\"tag\";s:5:\"6.0.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.8\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.8.tar.gz\";s:4:\"date\";s:10:\"1673535119\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.7\";a:11:{s:4:\"name\";s:13:\"webform 6.0.7\";s:7:\"version\";s:5:\"6.0.7\";s:3:\"tag\";s:5:\"6.0.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.7\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.7.tar.gz\";s:4:\"date\";s:10:\"1644940479\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.6\";a:11:{s:4:\"name\";s:13:\"webform 6.0.6\";s:7:\"version\";s:5:\"6.0.6\";s:3:\"tag\";s:5:\"6.0.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.6\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.6.tar.gz\";s:4:\"date\";s:10:\"1638916646\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.5\";a:11:{s:4:\"name\";s:13:\"webform 6.0.5\";s:7:\"version\";s:5:\"6.0.5\";s:3:\"tag\";s:5:\"6.0.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.5\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.5.tar.gz\";s:4:\"date\";s:10:\"1629903941\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.4\";a:11:{s:4:\"name\";s:13:\"webform 6.0.4\";s:7:\"version\";s:5:\"6.0.4\";s:3:\"tag\";s:5:\"6.0.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.4\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.4.tar.gz\";s:4:\"date\";s:10:\"1624461046\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.3\";a:11:{s:4:\"name\";s:13:\"webform 6.0.3\";s:7:\"version\";s:5:\"6.0.3\";s:3:\"tag\";s:5:\"6.0.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.3\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.3.tar.gz\";s:4:\"date\";s:10:\"1620250254\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.2\";a:11:{s:4:\"name\";s:13:\"webform 6.0.2\";s:7:\"version\";s:5:\"6.0.2\";s:3:\"tag\";s:5:\"6.0.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.2\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.2.tar.gz\";s:4:\"date\";s:10:\"1614711149\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.1\";a:11:{s:4:\"name\";s:13:\"webform 6.0.1\";s:7:\"version\";s:5:\"6.0.1\";s:3:\"tag\";s:5:\"6.0.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.1\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.1.tar.gz\";s:4:\"date\";s:10:\"1612453373\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:5:\"6.0.0\";a:11:{s:4:\"name\";s:13:\"webform 6.0.0\";s:7:\"version\";s:5:\"6.0.0\";s:3:\"tag\";s:5:\"6.0.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:53:\"https://www.drupal.org/project/webform/releases/6.0.0\";s:13:\"download_link\";s:58:\"https://ftp.drupal.org/files/projects/webform-6.0.0.tar.gz\";s:4:\"date\";s:10:\"1608855845\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.0.0-beta3\";a:11:{s:4:\"name\";s:19:\"webform 6.0.0-beta3\";s:7:\"version\";s:11:\"6.0.0-beta3\";s:3:\"tag\";s:11:\"6.0.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.0.0-beta3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.0.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1608425493\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.0.0-beta2\";a:11:{s:4:\"name\";s:19:\"webform 6.0.0-beta2\";s:7:\"version\";s:11:\"6.0.0-beta2\";s:3:\"tag\";s:11:\"6.0.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.0.0-beta2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.0.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1606687841\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:11:\"6.0.0-beta1\";a:11:{s:4:\"name\";s:19:\"webform 6.0.0-beta1\";s:7:\"version\";s:11:\"6.0.0-beta1\";s:3:\"tag\";s:11:\"6.0.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/6.0.0-beta1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-6.0.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1606179568\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha21\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha21\";s:7:\"version\";s:13:\"6.0.0-alpha21\";s:3:\"tag\";s:13:\"6.0.0-alpha21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha21\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha21.tar.gz\";s:4:\"date\";s:10:\"1604531929\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha20\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha20\";s:7:\"version\";s:13:\"6.0.0-alpha20\";s:3:\"tag\";s:13:\"6.0.0-alpha20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha20\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha20.tar.gz\";s:4:\"date\";s:10:\"1601919730\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha19\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha19\";s:7:\"version\";s:13:\"6.0.0-alpha19\";s:3:\"tag\";s:13:\"6.0.0-alpha19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha19\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha19.tar.gz\";s:4:\"date\";s:10:\"1601647879\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha18\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha18\";s:7:\"version\";s:13:\"6.0.0-alpha18\";s:3:\"tag\";s:13:\"6.0.0-alpha18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha18\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha18.tar.gz\";s:4:\"date\";s:10:\"1601385862\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha17\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha17\";s:7:\"version\";s:13:\"6.0.0-alpha17\";s:3:\"tag\";s:13:\"6.0.0-alpha17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha17\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha17.tar.gz\";s:4:\"date\";s:10:\"1600376449\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha16\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha16\";s:7:\"version\";s:13:\"6.0.0-alpha16\";s:3:\"tag\";s:13:\"6.0.0-alpha16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha16\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha16.tar.gz\";s:4:\"date\";s:10:\"1599851828\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha15\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha15\";s:7:\"version\";s:13:\"6.0.0-alpha15\";s:3:\"tag\";s:13:\"6.0.0-alpha15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha15\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha15.tar.gz\";s:4:\"date\";s:10:\"1599240333\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha14\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha14\";s:7:\"version\";s:13:\"6.0.0-alpha14\";s:3:\"tag\";s:13:\"6.0.0-alpha14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha14\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha14.tar.gz\";s:4:\"date\";s:10:\"1597828848\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha13\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha13\";s:7:\"version\";s:13:\"6.0.0-alpha13\";s:3:\"tag\";s:13:\"6.0.0-alpha13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha13\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha13.tar.gz\";s:4:\"date\";s:10:\"1597166474\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha12\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha12\";s:7:\"version\";s:13:\"6.0.0-alpha12\";s:3:\"tag\";s:13:\"6.0.0-alpha12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha12\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha12.tar.gz\";s:4:\"date\";s:10:\"1595283358\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha11\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha11\";s:7:\"version\";s:13:\"6.0.0-alpha11\";s:3:\"tag\";s:13:\"6.0.0-alpha11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha11\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha11.tar.gz\";s:4:\"date\";s:10:\"1594713947\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:13:\"6.0.0-alpha10\";a:11:{s:4:\"name\";s:21:\"webform 6.0.0-alpha10\";s:7:\"version\";s:13:\"6.0.0-alpha10\";s:3:\"tag\";s:13:\"6.0.0-alpha10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha10\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha10.tar.gz\";s:4:\"date\";s:10:\"1594241841\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha9\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha9\";s:7:\"version\";s:12:\"6.0.0-alpha9\";s:3:\"tag\";s:12:\"6.0.0-alpha9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha9\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha9.tar.gz\";s:4:\"date\";s:10:\"1593681225\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha8\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha8\";s:7:\"version\";s:12:\"6.0.0-alpha8\";s:3:\"tag\";s:12:\"6.0.0-alpha8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha8\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha8.tar.gz\";s:4:\"date\";s:10:\"1593034684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha7\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha7\";s:7:\"version\";s:12:\"6.0.0-alpha7\";s:3:\"tag\";s:12:\"6.0.0-alpha7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha7\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha7.tar.gz\";s:4:\"date\";s:10:\"1592841350\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha6\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha6\";s:7:\"version\";s:12:\"6.0.0-alpha6\";s:3:\"tag\";s:12:\"6.0.0-alpha6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha6\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha6.tar.gz\";s:4:\"date\";s:10:\"1592616296\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha5\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha5\";s:7:\"version\";s:12:\"6.0.0-alpha5\";s:3:\"tag\";s:12:\"6.0.0-alpha5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha5\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha5.tar.gz\";s:4:\"date\";s:10:\"1592495851\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha4\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha4\";s:7:\"version\";s:12:\"6.0.0-alpha4\";s:3:\"tag\";s:12:\"6.0.0-alpha4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha4\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha4.tar.gz\";s:4:\"date\";s:10:\"1591273787\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha3\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha3\";s:7:\"version\";s:12:\"6.0.0-alpha3\";s:3:\"tag\";s:12:\"6.0.0-alpha3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha3\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha3.tar.gz\";s:4:\"date\";s:10:\"1591199141\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:12:\"6.0.0-alpha2\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha2\";s:7:\"version\";s:12:\"6.0.0-alpha2\";s:3:\"tag\";s:12:\"6.0.0-alpha2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha2\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha2.tar.gz\";s:4:\"date\";s:10:\"1590971769\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:12:\"6.0.0-alpha1\";a:11:{s:4:\"name\";s:20:\"webform 6.0.0-alpha1\";s:7:\"version\";s:12:\"6.0.0-alpha1\";s:3:\"tag\";s:12:\"6.0.0-alpha1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/6.0.0-alpha1\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-6.0.0-alpha1.tar.gz\";s:4:\"date\";s:10:\"1590950600\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:61:\"Alpha releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:8:\"^8 || ^9\";}s:8:\"8.x-5.31\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.31\";s:7:\"version\";s:8:\"8.x-5.31\";s:3:\"tag\";s:8:\"8.x-5.31\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.31\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.31.tar.gz\";s:4:\"date\";s:10:\"1638915771\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.30\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.30\";s:7:\"version\";s:8:\"8.x-5.30\";s:3:\"tag\";s:8:\"8.x-5.30\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.30\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.30.tar.gz\";s:4:\"date\";s:10:\"1638915163\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:15:\"Security update\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.29\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.29\";s:7:\"version\";s:8:\"8.x-5.29\";s:3:\"tag\";s:8:\"8.x-5.29\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.29\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.29.tar.gz\";s:4:\"date\";s:10:\"1635676451\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.28\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.28\";s:7:\"version\";s:8:\"8.x-5.28\";s:3:\"tag\";s:8:\"8.x-5.28\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.28\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.28.tar.gz\";s:4:\"date\";s:10:\"1629903873\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:4:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:12:\"New features\";i:3;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.28-beta1\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.28-beta1\";s:7:\"version\";s:14:\"8.x-5.28-beta1\";s:3:\"tag\";s:14:\"8.x-5.28-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.28-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.28-beta1.tar.gz\";s:4:\"date\";s:10:\"1626269167\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.27\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.27\";s:7:\"version\";s:8:\"8.x-5.27\";s:3:\"tag\";s:8:\"8.x-5.27\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.27\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.27.tar.gz\";s:4:\"date\";s:10:\"1624460854\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.26\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.26\";s:7:\"version\";s:8:\"8.x-5.26\";s:3:\"tag\";s:8:\"8.x-5.26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.26\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.26.tar.gz\";s:4:\"date\";s:10:\"1620250064\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.25\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.25\";s:7:\"version\";s:8:\"8.x-5.25\";s:3:\"tag\";s:8:\"8.x-5.25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.25\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.25.tar.gz\";s:4:\"date\";s:10:\"1614711099\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.24\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.24\";s:7:\"version\";s:8:\"8.x-5.24\";s:3:\"tag\";s:8:\"8.x-5.24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.24\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.24.tar.gz\";s:4:\"date\";s:10:\"1612453175\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.23\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.23\";s:7:\"version\";s:8:\"8.x-5.23\";s:3:\"tag\";s:8:\"8.x-5.23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.23\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.23.tar.gz\";s:4:\"date\";s:10:\"1608855643\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.23-beta4\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.23-beta4\";s:7:\"version\";s:14:\"8.x-5.23-beta4\";s:3:\"tag\";s:14:\"8.x-5.23-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.23-beta4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.23-beta4.tar.gz\";s:4:\"date\";s:10:\"1608425252\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.23-beta3\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.23-beta3\";s:7:\"version\";s:14:\"8.x-5.23-beta3\";s:3:\"tag\";s:14:\"8.x-5.23-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.23-beta3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.23-beta3.tar.gz\";s:4:\"date\";s:10:\"1606687658\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.23-beta2\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.23-beta2\";s:7:\"version\";s:14:\"8.x-5.23-beta2\";s:3:\"tag\";s:14:\"8.x-5.23-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.23-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.23-beta2.tar.gz\";s:4:\"date\";s:10:\"1606179294\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.23-beta1\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.23-beta1\";s:7:\"version\";s:14:\"8.x-5.23-beta1\";s:3:\"tag\";s:14:\"8.x-5.23-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.23-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.23-beta1.tar.gz\";s:4:\"date\";s:10:\"1604531721\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.22\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.22\";s:7:\"version\";s:8:\"8.x-5.22\";s:3:\"tag\";s:8:\"8.x-5.22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.22\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.22.tar.gz\";s:4:\"date\";s:10:\"1601919522\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.21\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.21\";s:7:\"version\";s:8:\"8.x-5.21\";s:3:\"tag\";s:8:\"8.x-5.21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.21\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.21.tar.gz\";s:4:\"date\";s:10:\"1601385690\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.20\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.20\";s:7:\"version\";s:8:\"8.x-5.20\";s:3:\"tag\";s:8:\"8.x-5.20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.20\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20.tar.gz\";s:4:\"date\";s:10:\"1599851752\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta6\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta6\";s:7:\"version\";s:14:\"8.x-5.20-beta6\";s:3:\"tag\";s:14:\"8.x-5.20-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta6\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta6.tar.gz\";s:4:\"date\";s:10:\"1599240197\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta5\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta5\";s:7:\"version\";s:14:\"8.x-5.20-beta5\";s:3:\"tag\";s:14:\"8.x-5.20-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta5\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta5.tar.gz\";s:4:\"date\";s:10:\"1597828670\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta4\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta4\";s:7:\"version\";s:14:\"8.x-5.20-beta4\";s:3:\"tag\";s:14:\"8.x-5.20-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta4\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta4.tar.gz\";s:4:\"date\";s:10:\"1597166399\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta3\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta3\";s:7:\"version\";s:14:\"8.x-5.20-beta3\";s:3:\"tag\";s:14:\"8.x-5.20-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta3\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta3.tar.gz\";s:4:\"date\";s:10:\"1595283192\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta2\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta2\";s:7:\"version\";s:14:\"8.x-5.20-beta2\";s:3:\"tag\";s:14:\"8.x-5.20-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta2.tar.gz\";s:4:\"date\";s:10:\"1594713787\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.20-beta1\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.20-beta1\";s:7:\"version\";s:14:\"8.x-5.20-beta1\";s:3:\"tag\";s:14:\"8.x-5.20-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.20-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.20-beta1.tar.gz\";s:4:\"date\";s:10:\"1594241756\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.19\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.19\";s:7:\"version\";s:8:\"8.x-5.19\";s:3:\"tag\";s:8:\"8.x-5.19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.19\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.19.tar.gz\";s:4:\"date\";s:10:\"1593681136\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.18\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.18\";s:7:\"version\";s:8:\"8.x-5.18\";s:3:\"tag\";s:8:\"8.x-5.18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.18\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.18.tar.gz\";s:4:\"date\";s:10:\"1593034084\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.17\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.17\";s:7:\"version\";s:8:\"8.x-5.17\";s:3:\"tag\";s:8:\"8.x-5.17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.17\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.17.tar.gz\";s:4:\"date\";s:10:\"1592841189\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:14:\"8.x-5.17-beta1\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.17-beta1\";s:7:\"version\";s:14:\"8.x-5.17-beta1\";s:3:\"tag\";s:14:\"8.x-5.17-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.17-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.17-beta1.tar.gz\";s:4:\"date\";s:10:\"1592495751\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.16\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.16\";s:7:\"version\";s:8:\"8.x-5.16\";s:3:\"tag\";s:8:\"8.x-5.16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.16\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.16.tar.gz\";s:4:\"date\";s:10:\"1591198998\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:4:\"^8.8\";}s:8:\"8.x-5.15\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.15\";s:7:\"version\";s:8:\"8.x-5.15\";s:3:\"tag\";s:8:\"8.x-5.15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.15\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.15.tar.gz\";s:4:\"date\";s:10:\"1590971702\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^8\";}s:8:\"8.x-5.14\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.14\";s:7:\"version\";s:8:\"8.x-5.14\";s:3:\"tag\";s:8:\"8.x-5.14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.14\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.14.tar.gz\";s:4:\"date\";s:10:\"1590950034\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^8\";}s:14:\"8.x-5.14-beta2\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.14-beta2\";s:7:\"version\";s:14:\"8.x-5.14-beta2\";s:3:\"tag\";s:14:\"8.x-5.14-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.14-beta2\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.14-beta2.tar.gz\";s:4:\"date\";s:10:\"1590499309\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:14:\"8.x-5.14-beta1\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.14-beta1\";s:7:\"version\";s:14:\"8.x-5.14-beta1\";s:3:\"tag\";s:14:\"8.x-5.14-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.14-beta1\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.14-beta1.tar.gz\";s:4:\"date\";s:10:\"1590275692\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";}s:8:\"8.x-5.13\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.13\";s:7:\"version\";s:8:\"8.x-5.13\";s:3:\"tag\";s:8:\"8.x-5.13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.13\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.13.tar.gz\";s:4:\"date\";s:10:\"1589661354\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-5.12\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.12\";s:7:\"version\";s:8:\"8.x-5.12\";s:3:\"tag\";s:8:\"8.x-5.12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.12\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.12.tar.gz\";s:4:\"date\";s:10:\"1589372278\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:15:\"Security update\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-5.11\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.11\";s:7:\"version\";s:8:\"8.x-5.11\";s:3:\"tag\";s:8:\"8.x-5.11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.11\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.11.tar.gz\";s:4:\"date\";s:10:\"1588690387\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:15:\"Security update\";i:1;s:9:\"Bug fixes\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:8:\"8.x-5.10\";a:11:{s:4:\"name\";s:16:\"webform 8.x-5.10\";s:7:\"version\";s:8:\"8.x-5.10\";s:3:\"tag\";s:8:\"8.x-5.10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:56:\"https://www.drupal.org/project/webform/releases/8.x-5.10\";s:13:\"download_link\";s:61:\"https://ftp.drupal.org/files/projects/webform-8.x-5.10.tar.gz\";s:4:\"date\";s:10:\"1588090448\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-5.9\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.9\";s:7:\"version\";s:7:\"8.x-5.9\";s:3:\"tag\";s:7:\"8.x-5.9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.9\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.9.tar.gz\";s:4:\"date\";s:10:\"1584560013\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:13:\"8.x-5.9-beta2\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.9-beta2\";s:7:\"version\";s:13:\"8.x-5.9-beta2\";s:3:\"tag\";s:13:\"8.x-5.9-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.9-beta2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.9-beta2.tar.gz\";s:4:\"date\";s:10:\"1582899185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:13:\"8.x-5.9-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.9-beta1\";s:7:\"version\";s:13:\"8.x-5.9-beta1\";s:3:\"tag\";s:13:\"8.x-5.9-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.9-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.9-beta1.tar.gz\";s:4:\"date\";s:10:\"1581626310\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:12:\"^8.7.7 || ^9\";}s:7:\"8.x-5.8\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.8\";s:7:\"version\";s:7:\"8.x-5.8\";s:3:\"tag\";s:7:\"8.x-5.8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.8\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.8.tar.gz\";s:4:\"date\";s:10:\"1579637587\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^8\";}s:7:\"8.x-5.7\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.7\";s:7:\"version\";s:7:\"8.x-5.7\";s:3:\"tag\";s:7:\"8.x-5.7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.7\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.7.tar.gz\";s:4:\"date\";s:10:\"1579208583\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:2:\"^8\";}s:13:\"8.x-5.7-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.7-beta1\";s:7:\"version\";s:13:\"8.x-5.7-beta1\";s:3:\"tag\";s:13:\"8.x-5.7-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.7-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.7-beta1.tar.gz\";s:4:\"date\";s:10:\"1578341283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:2:\"^8\";}s:7:\"8.x-5.6\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.6\";s:7:\"version\";s:7:\"8.x-5.6\";s:3:\"tag\";s:7:\"8.x-5.6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.6\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.6.tar.gz\";s:4:\"date\";s:10:\"1575331086\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.6-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.6-beta1\";s:7:\"version\";s:13:\"8.x-5.6-beta1\";s:3:\"tag\";s:13:\"8.x-5.6-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.6-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.6-beta1.tar.gz\";s:4:\"date\";s:10:\"1574077985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.5\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.5\";s:7:\"version\";s:7:\"8.x-5.5\";s:3:\"tag\";s:7:\"8.x-5.5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.5\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.5.tar.gz\";s:4:\"date\";s:10:\"1572377284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.5-rc2\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.5-rc2\";s:7:\"version\";s:11:\"8.x-5.5-rc2\";s:3:\"tag\";s:11:\"8.x-5.5-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.5-rc2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.5-rc2.tar.gz\";s:4:\"date\";s:10:\"1570176784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.5-rc1\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.5-rc1\";s:7:\"version\";s:11:\"8.x-5.5-rc1\";s:3:\"tag\";s:11:\"8.x-5.5-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.5-rc1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.5-rc1.tar.gz\";s:4:\"date\";s:10:\"1569445386\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.5-beta2\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.5-beta2\";s:7:\"version\";s:13:\"8.x-5.5-beta2\";s:3:\"tag\";s:13:\"8.x-5.5-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.5-beta2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.5-beta2.tar.gz\";s:4:\"date\";s:10:\"1568992985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.5-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.5-beta1\";s:7:\"version\";s:13:\"8.x-5.5-beta1\";s:3:\"tag\";s:13:\"8.x-5.5-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.5-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.5-beta1.tar.gz\";s:4:\"date\";s:10:\"1567698485\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.4\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.4\";s:7:\"version\";s:7:\"8.x-5.4\";s:3:\"tag\";s:7:\"8.x-5.4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.4\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.4.tar.gz\";s:4:\"date\";s:10:\"1566209286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.4-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.4-beta1\";s:7:\"version\";s:13:\"8.x-5.4-beta1\";s:3:\"tag\";s:13:\"8.x-5.4-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.4-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.4-beta1.tar.gz\";s:4:\"date\";s:10:\"1565332985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.3\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.3\";s:7:\"version\";s:7:\"8.x-5.3\";s:3:\"tag\";s:7:\"8.x-5.3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.3\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3.tar.gz\";s:4:\"date\";s:10:\"1563460085\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.3-rc3\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.3-rc3\";s:7:\"version\";s:11:\"8.x-5.3-rc3\";s:3:\"tag\";s:11:\"8.x-5.3-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.3-rc3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-rc3.tar.gz\";s:4:\"date\";s:10:\"1562013184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.3-rc2\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.3-rc2\";s:7:\"version\";s:11:\"8.x-5.3-rc2\";s:3:\"tag\";s:11:\"8.x-5.3-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.3-rc2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-rc2.tar.gz\";s:4:\"date\";s:10:\"1561474385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.3-rc1\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.3-rc1\";s:7:\"version\";s:11:\"8.x-5.3-rc1\";s:3:\"tag\";s:11:\"8.x-5.3-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.3-rc1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-rc1.tar.gz\";s:4:\"date\";s:10:\"1559676185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.3-beta3\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.3-beta3\";s:7:\"version\";s:13:\"8.x-5.3-beta3\";s:3:\"tag\";s:13:\"8.x-5.3-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.3-beta3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-beta3.tar.gz\";s:4:\"date\";s:10:\"1558032481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.3-beta2\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.3-beta2\";s:7:\"version\";s:13:\"8.x-5.3-beta2\";s:3:\"tag\";s:13:\"8.x-5.3-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.3-beta2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-beta2.tar.gz\";s:4:\"date\";s:10:\"1557417193\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.3-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.3-beta1\";s:7:\"version\";s:13:\"8.x-5.3-beta1\";s:3:\"tag\";s:13:\"8.x-5.3-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.3-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.3-beta1.tar.gz\";s:4:\"date\";s:10:\"1556736481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.2\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.2\";s:7:\"version\";s:7:\"8.x-5.2\";s:3:\"tag\";s:7:\"8.x-5.2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.2\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.2.tar.gz\";s:4:\"date\";s:10:\"1553768585\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.2-rc3\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.2-rc3\";s:7:\"version\";s:11:\"8.x-5.2-rc3\";s:3:\"tag\";s:11:\"8.x-5.2-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.2-rc3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.2-rc3.tar.gz\";s:4:\"date\";s:10:\"1552733285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.2-rc2\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.2-rc2\";s:7:\"version\";s:11:\"8.x-5.2-rc2\";s:3:\"tag\";s:11:\"8.x-5.2-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.2-rc2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.2-rc2.tar.gz\";s:4:\"date\";s:10:\"1551880385\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.2-rc1\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.2-rc1\";s:7:\"version\";s:11:\"8.x-5.2-rc1\";s:3:\"tag\";s:11:\"8.x-5.2-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.2-rc1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.2-rc1.tar.gz\";s:4:\"date\";s:10:\"1551829980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.2-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.2-beta1\";s:7:\"version\";s:13:\"8.x-5.2-beta1\";s:3:\"tag\";s:13:\"8.x-5.2-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.2-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.2-beta1.tar.gz\";s:4:\"date\";s:10:\"1548435780\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.1\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.1\";s:7:\"version\";s:7:\"8.x-5.1\";s:3:\"tag\";s:7:\"8.x-5.1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.1\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.1.tar.gz\";s:4:\"date\";s:10:\"1546458480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:7:\"8.x-5.0\";a:11:{s:4:\"name\";s:15:\"webform 8.x-5.0\";s:7:\"version\";s:7:\"8.x-5.0\";s:3:\"tag\";s:7:\"8.x-5.0\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/8.x-5.0\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0.tar.gz\";s:4:\"date\";s:10:\"1545656285\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:44:\"Covered by Drupal\'s security advisory policy\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc31\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc31\";s:7:\"version\";s:12:\"8.x-5.0-rc31\";s:3:\"tag\";s:12:\"8.x-5.0-rc31\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc31\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc31.tar.gz\";s:4:\"date\";s:10:\"1545138180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc30\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc30\";s:7:\"version\";s:12:\"8.x-5.0-rc30\";s:3:\"tag\";s:12:\"8.x-5.0-rc30\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc30\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc30.tar.gz\";s:4:\"date\";s:10:\"1544990880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc29\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc29\";s:7:\"version\";s:12:\"8.x-5.0-rc29\";s:3:\"tag\";s:12:\"8.x-5.0-rc29\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc29\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc29.tar.gz\";s:4:\"date\";s:10:\"1544223180\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc28\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc28\";s:7:\"version\";s:12:\"8.x-5.0-rc28\";s:3:\"tag\";s:12:\"8.x-5.0-rc28\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc28\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc28.tar.gz\";s:4:\"date\";s:10:\"1544218081\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc27\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc27\";s:7:\"version\";s:12:\"8.x-5.0-rc27\";s:3:\"tag\";s:12:\"8.x-5.0-rc27\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc27\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc27.tar.gz\";s:4:\"date\";s:10:\"1543520280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc26\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc26\";s:7:\"version\";s:12:\"8.x-5.0-rc26\";s:3:\"tag\";s:12:\"8.x-5.0-rc26\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc26\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc26.tar.gz\";s:4:\"date\";s:10:\"1541466481\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc25\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc25\";s:7:\"version\";s:12:\"8.x-5.0-rc25\";s:3:\"tag\";s:12:\"8.x-5.0-rc25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc25\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc25.tar.gz\";s:4:\"date\";s:10:\"1541452980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc24\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc24\";s:7:\"version\";s:12:\"8.x-5.0-rc24\";s:3:\"tag\";s:12:\"8.x-5.0-rc24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc24\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc24.tar.gz\";s:4:\"date\";s:10:\"1540255380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc23\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc23\";s:7:\"version\";s:12:\"8.x-5.0-rc23\";s:3:\"tag\";s:12:\"8.x-5.0-rc23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc23\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc23.tar.gz\";s:4:\"date\";s:10:\"1540052580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc22\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc22\";s:7:\"version\";s:12:\"8.x-5.0-rc22\";s:3:\"tag\";s:12:\"8.x-5.0-rc22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc22\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc22.tar.gz\";s:4:\"date\";s:10:\"1538482685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc21\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc21\";s:7:\"version\";s:12:\"8.x-5.0-rc21\";s:3:\"tag\";s:12:\"8.x-5.0-rc21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc21\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc21.tar.gz\";s:4:\"date\";s:10:\"1536405484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc20\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc20\";s:7:\"version\";s:12:\"8.x-5.0-rc20\";s:3:\"tag\";s:12:\"8.x-5.0-rc20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc20\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc20.tar.gz\";s:4:\"date\";s:10:\"1536336480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc19\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc19\";s:7:\"version\";s:12:\"8.x-5.0-rc19\";s:3:\"tag\";s:12:\"8.x-5.0-rc19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc19\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc19.tar.gz\";s:4:\"date\";s:10:\"1536257580\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc18\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc18\";s:7:\"version\";s:12:\"8.x-5.0-rc18\";s:3:\"tag\";s:12:\"8.x-5.0-rc18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc18\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc18.tar.gz\";s:4:\"date\";s:10:\"1533682980\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc17\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc17\";s:7:\"version\";s:12:\"8.x-5.0-rc17\";s:3:\"tag\";s:12:\"8.x-5.0-rc17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc17\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc17.tar.gz\";s:4:\"date\";s:10:\"1533563280\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc16\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc16\";s:7:\"version\";s:12:\"8.x-5.0-rc16\";s:3:\"tag\";s:12:\"8.x-5.0-rc16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc16\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc16.tar.gz\";s:4:\"date\";s:10:\"1530298420\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc15\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc15\";s:7:\"version\";s:12:\"8.x-5.0-rc15\";s:3:\"tag\";s:12:\"8.x-5.0-rc15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc15\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc15.tar.gz\";s:4:\"date\";s:10:\"1528795685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc14\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc14\";s:7:\"version\";s:12:\"8.x-5.0-rc14\";s:3:\"tag\";s:12:\"8.x-5.0-rc14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc14\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc14.tar.gz\";s:4:\"date\";s:10:\"1528277284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc13\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc13\";s:7:\"version\";s:12:\"8.x-5.0-rc13\";s:3:\"tag\";s:12:\"8.x-5.0-rc13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc13\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc13.tar.gz\";s:4:\"date\";s:10:\"1528137480\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc12\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc12\";s:7:\"version\";s:12:\"8.x-5.0-rc12\";s:3:\"tag\";s:12:\"8.x-5.0-rc12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc12\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc12.tar.gz\";s:4:\"date\";s:10:\"1524706684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc11\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc11\";s:7:\"version\";s:12:\"8.x-5.0-rc11\";s:3:\"tag\";s:12:\"8.x-5.0-rc11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc11\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc11.tar.gz\";s:4:\"date\";s:10:\"1524229380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:12:\"8.x-5.0-rc10\";a:11:{s:4:\"name\";s:20:\"webform 8.x-5.0-rc10\";s:7:\"version\";s:12:\"8.x-5.0-rc10\";s:3:\"tag\";s:12:\"8.x-5.0-rc10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:60:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc10\";s:13:\"download_link\";s:65:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc10.tar.gz\";s:4:\"date\";s:10:\"1523291284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc9\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc9\";s:7:\"version\";s:11:\"8.x-5.0-rc9\";s:3:\"tag\";s:11:\"8.x-5.0-rc9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc9\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc9.tar.gz\";s:4:\"date\";s:10:\"1523115484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc8\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc8\";s:7:\"version\";s:11:\"8.x-5.0-rc8\";s:3:\"tag\";s:11:\"8.x-5.0-rc8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc8\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc8.tar.gz\";s:4:\"date\";s:10:\"1522698184\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc7\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc7\";s:7:\"version\";s:11:\"8.x-5.0-rc7\";s:3:\"tag\";s:11:\"8.x-5.0-rc7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc7\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc7.tar.gz\";s:4:\"date\";s:10:\"1521829380\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc6\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc6\";s:7:\"version\";s:11:\"8.x-5.0-rc6\";s:3:\"tag\";s:11:\"8.x-5.0-rc6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc6\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc6.tar.gz\";s:4:\"date\";s:10:\"1521230880\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc5\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc5\";s:7:\"version\";s:11:\"8.x-5.0-rc5\";s:3:\"tag\";s:11:\"8.x-5.0-rc5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc5\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc5.tar.gz\";s:4:\"date\";s:10:\"1521041284\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc4\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc4\";s:7:\"version\";s:11:\"8.x-5.0-rc4\";s:3:\"tag\";s:11:\"8.x-5.0-rc4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc4\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc4.tar.gz\";s:4:\"date\";s:10:\"1520964784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc3\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc3\";s:7:\"version\";s:11:\"8.x-5.0-rc3\";s:3:\"tag\";s:11:\"8.x-5.0-rc3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc3\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc3.tar.gz\";s:4:\"date\";s:10:\"1517746080\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc2\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc2\";s:7:\"version\";s:11:\"8.x-5.0-rc2\";s:3:\"tag\";s:11:\"8.x-5.0-rc2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc2\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc2.tar.gz\";s:4:\"date\";s:10:\"1517359384\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:11:\"8.x-5.0-rc1\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.0-rc1\";s:7:\"version\";s:11:\"8.x-5.0-rc1\";s:3:\"tag\";s:11:\"8.x-5.0-rc1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.0-rc1\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-rc1.tar.gz\";s:4:\"date\";s:10:\"1514196484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:58:\"RC releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta25\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta25\";s:7:\"version\";s:14:\"8.x-5.0-beta25\";s:3:\"tag\";s:14:\"8.x-5.0-beta25\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta25\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta25.tar.gz\";s:4:\"date\";s:10:\"1513003985\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta24\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta24\";s:7:\"version\";s:14:\"8.x-5.0-beta24\";s:3:\"tag\";s:14:\"8.x-5.0-beta24\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta24\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta24.tar.gz\";s:4:\"date\";s:10:\"1510867685\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta23\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta23\";s:7:\"version\";s:14:\"8.x-5.0-beta23\";s:3:\"tag\";s:14:\"8.x-5.0-beta23\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta23\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta23.tar.gz\";s:4:\"date\";s:10:\"1509673984\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta22\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta22\";s:7:\"version\";s:14:\"8.x-5.0-beta22\";s:3:\"tag\";s:14:\"8.x-5.0-beta22\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta22\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta22.tar.gz\";s:4:\"date\";s:10:\"1509576185\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta21\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta21\";s:7:\"version\";s:14:\"8.x-5.0-beta21\";s:3:\"tag\";s:14:\"8.x-5.0-beta21\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta21\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta21.tar.gz\";s:4:\"date\";s:10:\"1509363484\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta20\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta20\";s:7:\"version\";s:14:\"8.x-5.0-beta20\";s:3:\"tag\";s:14:\"8.x-5.0-beta20\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta20\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta20.tar.gz\";s:4:\"date\";s:10:\"1509357785\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta19\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta19\";s:7:\"version\";s:14:\"8.x-5.0-beta19\";s:3:\"tag\";s:14:\"8.x-5.0-beta19\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta19\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta19.tar.gz\";s:4:\"date\";s:10:\"1506634743\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta18\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta18\";s:7:\"version\";s:14:\"8.x-5.0-beta18\";s:3:\"tag\";s:14:\"8.x-5.0-beta18\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta18\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta18.tar.gz\";s:4:\"date\";s:10:\"1505244243\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta17\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta17\";s:7:\"version\";s:14:\"8.x-5.0-beta17\";s:3:\"tag\";s:14:\"8.x-5.0-beta17\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta17\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta17.tar.gz\";s:4:\"date\";s:10:\"1505089745\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta16\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta16\";s:7:\"version\";s:14:\"8.x-5.0-beta16\";s:3:\"tag\";s:14:\"8.x-5.0-beta16\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta16\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta16.tar.gz\";s:4:\"date\";s:10:\"1502154844\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta15\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta15\";s:7:\"version\";s:14:\"8.x-5.0-beta15\";s:3:\"tag\";s:14:\"8.x-5.0-beta15\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta15\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta15.tar.gz\";s:4:\"date\";s:10:\"1498873444\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta14\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta14\";s:7:\"version\";s:14:\"8.x-5.0-beta14\";s:3:\"tag\";s:14:\"8.x-5.0-beta14\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta14\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta14.tar.gz\";s:4:\"date\";s:10:\"1498698843\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta13\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta13\";s:7:\"version\";s:14:\"8.x-5.0-beta13\";s:3:\"tag\";s:14:\"8.x-5.0-beta13\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta13\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta13.tar.gz\";s:4:\"date\";s:10:\"1496265842\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta12\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta12\";s:7:\"version\";s:14:\"8.x-5.0-beta12\";s:3:\"tag\";s:14:\"8.x-5.0-beta12\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta12\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta12.tar.gz\";s:4:\"date\";s:10:\"1492798443\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta11\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta11\";s:7:\"version\";s:14:\"8.x-5.0-beta11\";s:3:\"tag\";s:14:\"8.x-5.0-beta11\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta11\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta11.tar.gz\";s:4:\"date\";s:10:\"1491471183\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:14:\"8.x-5.0-beta10\";a:11:{s:4:\"name\";s:22:\"webform 8.x-5.0-beta10\";s:7:\"version\";s:14:\"8.x-5.0-beta10\";s:3:\"tag\";s:14:\"8.x-5.0-beta10\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:62:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta10\";s:13:\"download_link\";s:67:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta10.tar.gz\";s:4:\"date\";s:10:\"1491362286\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta9\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta9\";s:7:\"version\";s:13:\"8.x-5.0-beta9\";s:3:\"tag\";s:13:\"8.x-5.0-beta9\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta9\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta9.tar.gz\";s:4:\"date\";s:10:\"1488753784\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta8\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta8\";s:7:\"version\";s:13:\"8.x-5.0-beta8\";s:3:\"tag\";s:13:\"8.x-5.0-beta8\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta8\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta8.tar.gz\";s:4:\"date\";s:10:\"1488739683\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta7\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta7\";s:7:\"version\";s:13:\"8.x-5.0-beta7\";s:3:\"tag\";s:13:\"8.x-5.0-beta7\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta7\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta7.tar.gz\";s:4:\"date\";s:10:\"1487143684\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta6\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta6\";s:7:\"version\";s:13:\"8.x-5.0-beta6\";s:3:\"tag\";s:13:\"8.x-5.0-beta6\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta6\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta6.tar.gz\";s:4:\"date\";s:10:\"1487025483\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta5\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta5\";s:7:\"version\";s:13:\"8.x-5.0-beta5\";s:3:\"tag\";s:13:\"8.x-5.0-beta5\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta5\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta5.tar.gz\";s:4:\"date\";s:10:\"1485776283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta4\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta4\";s:7:\"version\";s:13:\"8.x-5.0-beta4\";s:3:\"tag\";s:13:\"8.x-5.0-beta4\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta4\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta4.tar.gz\";s:4:\"date\";s:10:\"1482752282\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta3\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta3\";s:7:\"version\";s:13:\"8.x-5.0-beta3\";s:3:\"tag\";s:13:\"8.x-5.0-beta3\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta3\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta3.tar.gz\";s:4:\"date\";s:10:\"1482316383\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:3:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";i:2;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta2\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta2\";s:7:\"version\";s:13:\"8.x-5.0-beta2\";s:3:\"tag\";s:13:\"8.x-5.0-beta2\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta2\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta2.tar.gz\";s:4:\"date\";s:10:\"1481192283\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:13:\"8.x-5.0-beta1\";a:11:{s:4:\"name\";s:21:\"webform 8.x-5.0-beta1\";s:7:\"version\";s:13:\"8.x-5.0-beta1\";s:3:\"tag\";s:13:\"8.x-5.0-beta1\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:61:\"https://www.drupal.org/project/webform/releases/8.x-5.0-beta1\";s:13:\"download_link\";s:66:\"https://ftp.drupal.org/files/projects/webform-8.x-5.0-beta1.tar.gz\";s:4:\"date\";s:10:\"1481140089\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:8:\"Insecure\";}}s:8:\"security\";s:60:\"Beta releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:3:\"8.x\";}s:9:\"6.3.x-dev\";a:11:{s:4:\"name\";s:17:\"webform 6.3.x-dev\";s:7:\"version\";s:9:\"6.3.x-dev\";s:3:\"tag\";s:5:\"6.3.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.3.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.3.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722697597\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:1:{i:0;s:9:\"Bug fixes\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.3\";}s:9:\"6.2.x-dev\";a:11:{s:4:\"name\";s:17:\"webform 6.2.x-dev\";s:7:\"version\";s:9:\"6.2.x-dev\";s:3:\"tag\";s:5:\"6.2.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.2.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.2.x-dev.tar.gz\";s:4:\"date\";s:10:\"1721068834\";s:5:\"files\";s:0:\"\";s:5:\"terms\";a:1:{s:12:\"Release type\";a:2:{i:0;s:9:\"Bug fixes\";i:1;s:12:\"New features\";}}s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.2\";}s:9:\"6.1.x-dev\";a:11:{s:4:\"name\";s:17:\"webform 6.1.x-dev\";s:7:\"version\";s:9:\"6.1.x-dev\";s:3:\"tag\";s:5:\"6.1.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.1.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.1.x-dev.tar.gz\";s:4:\"date\";s:10:\"1698357330\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^9.3\";s:5:\"terms\";a:0:{}}s:9:\"6.0.x-dev\";a:11:{s:4:\"name\";s:17:\"webform 6.0.x-dev\";s:7:\"version\";s:9:\"6.0.x-dev\";s:3:\"tag\";s:5:\"6.0.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:57:\"https://www.drupal.org/project/webform/releases/6.0.x-dev\";s:13:\"download_link\";s:62:\"https://ftp.drupal.org/files/projects/webform-6.0.x-dev.tar.gz\";s:4:\"date\";s:10:\"1644873671\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:10:\"^8.8 || ^9\";s:5:\"terms\";a:0:{}}s:7:\"6.x-dev\";a:11:{s:4:\"name\";s:15:\"webform 6.x-dev\";s:7:\"version\";s:7:\"6.x-dev\";s:3:\"tag\";s:3:\"6.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:55:\"https://www.drupal.org/project/webform/releases/6.x-dev\";s:13:\"download_link\";s:60:\"https://ftp.drupal.org/files/projects/webform-6.x-dev.tar.gz\";s:4:\"date\";s:10:\"1722698147\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:5:\"^10.3\";s:5:\"terms\";a:0:{}}s:11:\"8.x-5.x-dev\";a:11:{s:4:\"name\";s:19:\"webform 8.x-5.x-dev\";s:7:\"version\";s:11:\"8.x-5.x-dev\";s:3:\"tag\";s:7:\"8.x-5.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-5.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-5.x-dev.tar.gz\";s:4:\"date\";s:10:\"1638915617\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:18:\"core_compatibility\";s:4:\"^8.8\";s:5:\"terms\";a:0:{}}s:11:\"8.x-4.x-dev\";a:10:{s:4:\"name\";s:19:\"webform 8.x-4.x-dev\";s:7:\"version\";s:11:\"8.x-4.x-dev\";s:3:\"tag\";s:7:\"8.x-4.x\";s:6:\"status\";s:9:\"published\";s:12:\"release_link\";s:59:\"https://www.drupal.org/project/webform/releases/8.x-4.x-dev\";s:13:\"download_link\";s:64:\"https://ftp.drupal.org/files/projects/webform-8.x-4.x-dev.tar.gz\";s:4:\"date\";s:10:\"1480317483\";s:5:\"files\";s:0:\"\";s:8:\"security\";s:59:\"Dev releases are not covered by Drupal security advisories.\";s:5:\"terms\";a:0:{}}}s:10:\"last_fetch\";i:1723018806;}',	1723105206);

DROP TABLE IF EXISTS `media`;
CREATE TABLE `media` (
  `mid` int unsigned NOT NULL AUTO_INCREMENT,
  `vid` int unsigned DEFAULT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`mid`),
  UNIQUE KEY `media_field__uuid__value` (`uuid`),
  UNIQUE KEY `media__vid` (`vid`),
  KEY `media_field__bundle__target_id` (`bundle`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for media entities.';


DROP TABLE IF EXISTS `media__field_media_audio_file`;
CREATE TABLE `media__field_media_audio_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_audio_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_audio_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_audio_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_audio_file_target_id` (`field_media_audio_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_audio_file.';


DROP TABLE IF EXISTS `media__field_media_document`;
CREATE TABLE `media__field_media_document` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_document_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_document_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_document_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_document_target_id` (`field_media_document_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_document.';


DROP TABLE IF EXISTS `media__field_media_image`;
CREATE TABLE `media__field_media_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_media_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_media_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_media_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_image_target_id` (`field_media_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_image.';


DROP TABLE IF EXISTS `media__field_media_oembed_video`;
CREATE TABLE `media__field_media_oembed_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_oembed_video_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_oembed_video.';


DROP TABLE IF EXISTS `media__field_media_video_file`;
CREATE TABLE `media__field_media_video_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_video_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_video_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_video_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_video_file_target_id` (`field_media_video_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for media field field_media_video_file.';


DROP TABLE IF EXISTS `media_field_data`;
CREATE TABLE `media_field_data` (
  `mid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `name` varchar(255) DEFAULT NULL,
  `thumbnail__target_id` int unsigned DEFAULT NULL COMMENT 'The ID of the file entity.',
  `thumbnail__alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `thumbnail__title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `thumbnail__width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `thumbnail__height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  `created` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`mid`,`langcode`),
  KEY `media__id__default_langcode__langcode` (`mid`,`default_langcode`,`langcode`),
  KEY `media__vid` (`vid`),
  KEY `media_field__bundle__target_id` (`bundle`),
  KEY `media_field__uid__target_id` (`uid`),
  KEY `media_field__thumbnail__target_id` (`thumbnail__target_id`),
  KEY `media__status_bundle` (`status`,`bundle`,`mid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for media entities.';


DROP TABLE IF EXISTS `media_field_revision`;
CREATE TABLE `media_field_revision` (
  `mid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `name` varchar(255) DEFAULT NULL,
  `thumbnail__target_id` int unsigned DEFAULT NULL COMMENT 'The ID of the file entity.',
  `thumbnail__alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `thumbnail__title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `thumbnail__width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `thumbnail__height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  `created` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`,`langcode`),
  KEY `media__id__default_langcode__langcode` (`mid`,`default_langcode`,`langcode`),
  KEY `media_field__uid__target_id` (`uid`),
  KEY `media_field__thumbnail__target_id` (`thumbnail__target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for media entities.';


DROP TABLE IF EXISTS `media_revision`;
CREATE TABLE `media_revision` (
  `mid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`),
  KEY `media__mid` (`mid`),
  KEY `media_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for media entities.';


DROP TABLE IF EXISTS `media_revision__field_media_audio_file`;
CREATE TABLE `media_revision__field_media_audio_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_audio_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_audio_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_audio_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_audio_file_target_id` (`field_media_audio_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_audio…';


DROP TABLE IF EXISTS `media_revision__field_media_document`;
CREATE TABLE `media_revision__field_media_document` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_document_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_document_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_document_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_document_target_id` (`field_media_document_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media…';


DROP TABLE IF EXISTS `media_revision__field_media_image`;
CREATE TABLE `media_revision__field_media_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_media_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_media_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_media_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_image_target_id` (`field_media_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_image.';


DROP TABLE IF EXISTS `media_revision__field_media_oembed_video`;
CREATE TABLE `media_revision__field_media_oembed_video` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_oembed_video_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_oembed…';


DROP TABLE IF EXISTS `media_revision__field_media_video_file`;
CREATE TABLE `media_revision__field_media_video_file` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_media_video_file_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_media_video_file_display` tinyint unsigned DEFAULT '1' COMMENT 'Flag to control whether this file should be displayed when viewing content.',
  `field_media_video_file_description` text COMMENT 'A description of the file.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_media_video_file_target_id` (`field_media_video_file_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for media field field_media_video…';


DROP TABLE IF EXISTS `menu_link_content`;
CREATE TABLE `menu_link_content` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `menu_link_content_field__uuid__value` (`uuid`),
  UNIQUE KEY `menu_link_content__revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for menu_link_content entities.';


DROP TABLE IF EXISTS `menu_link_content_data`;
CREATE TABLE `menu_link_content_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `bundle` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `enabled` tinyint NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `description` varchar(255) DEFAULT NULL,
  `menu_name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `external` tinyint DEFAULT NULL,
  `rediscover` tinyint DEFAULT NULL,
  `weight` int DEFAULT NULL,
  `expanded` tinyint DEFAULT NULL,
  `parent` varchar(255) DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `menu_link_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `menu_link_content__revision_id` (`revision_id`),
  KEY `menu_link_content_field__link__uri` (`link__uri`(30)),
  KEY `menu_link_content__enabled_bundle` (`enabled`,`bundle`,`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for menu_link_content entities.';


DROP TABLE IF EXISTS `menu_link_content_field_revision`;
CREATE TABLE `menu_link_content_field_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `enabled` tinyint NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `description` varchar(255) DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `external` tinyint DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `menu_link_content__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `menu_link_content_field__link__uri` (`link__uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for menu_link_content entities.';


DROP TABLE IF EXISTS `menu_link_content_revision`;
CREATE TABLE `menu_link_content_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `menu_link_content__id` (`id`),
  KEY `menu_link_content__ef029a1897` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for menu_link_content entities.';


DROP TABLE IF EXISTS `menu_tree`;
CREATE TABLE `menu_tree` (
  `menu_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The menu name. All links with the same menu name (such as ''tools'') are part of the same menu.',
  `mlid` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'The menu link ID (mlid) is the integer primary key.',
  `id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'Unique machine name: the plugin ID.',
  `parent` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The plugin ID for the parent of this link.',
  `route_name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The machine name of a defined Symfony Route this menu link represents.',
  `route_param_key` varchar(255) DEFAULT NULL COMMENT 'An encoded string of route parameters for loading by route.',
  `route_parameters` longblob COMMENT 'Serialized array of route parameters of this menu link.',
  `url` varchar(255) NOT NULL DEFAULT '' COMMENT 'The external path this link points to (when not using a route).',
  `title` longblob COMMENT 'The serialized title for the link. May be a TranslatableMarkup.',
  `description` longblob COMMENT 'The serialized description of this link - used for admin pages and title attribute. May be a TranslatableMarkup.',
  `class` text COMMENT 'The class for this link plugin.',
  `options` longblob COMMENT 'A serialized array of URL options, such as a query string or HTML attributes.',
  `provider` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'system' COMMENT 'The name of the module that generated this link.',
  `enabled` smallint NOT NULL DEFAULT '1' COMMENT 'A flag for whether the link should be rendered in menus. (0 = a disabled menu link that may be shown on admin screens, 1 = a normal, visible link)',
  `discovered` smallint NOT NULL DEFAULT '0' COMMENT 'A flag for whether the link was discovered, so can be purged on rebuild',
  `expanded` smallint NOT NULL DEFAULT '0' COMMENT 'Flag for whether this link should be rendered as expanded in menus - expanded links always have their child links displayed, instead of only when the link is in the active trail (1 = expanded, 0 = not expanded)',
  `weight` int NOT NULL DEFAULT '0' COMMENT 'Link weight among links in the same menu at the same depth.',
  `metadata` longblob COMMENT 'A serialized array of data that may be used by the plugin instance.',
  `has_children` smallint NOT NULL DEFAULT '0' COMMENT 'Flag indicating whether any enabled links have this link as a parent (1 = enabled children exist, 0 = no enabled children).',
  `depth` smallint NOT NULL DEFAULT '0' COMMENT 'The depth relative to the top level. A link with empty parent will have depth == 1.',
  `p1` int unsigned NOT NULL DEFAULT '0' COMMENT 'The first mlid in the materialized path. If N = depth, then pN must equal the mlid. If depth > 1 then p(N-1) must equal the parent link mlid. All pX where X > depth must equal zero. The columns p1 .. p9 are also called the parents.',
  `p2` int unsigned NOT NULL DEFAULT '0' COMMENT 'The second mlid in the materialized path. See p1.',
  `p3` int unsigned NOT NULL DEFAULT '0' COMMENT 'The third mlid in the materialized path. See p1.',
  `p4` int unsigned NOT NULL DEFAULT '0' COMMENT 'The fourth mlid in the materialized path. See p1.',
  `p5` int unsigned NOT NULL DEFAULT '0' COMMENT 'The fifth mlid in the materialized path. See p1.',
  `p6` int unsigned NOT NULL DEFAULT '0' COMMENT 'The sixth mlid in the materialized path. See p1.',
  `p7` int unsigned NOT NULL DEFAULT '0' COMMENT 'The seventh mlid in the materialized path. See p1.',
  `p8` int unsigned NOT NULL DEFAULT '0' COMMENT 'The eighth mlid in the materialized path. See p1.',
  `p9` int unsigned NOT NULL DEFAULT '0' COMMENT 'The ninth mlid in the materialized path. See p1.',
  `form_class` varchar(255) DEFAULT NULL COMMENT 'meh',
  PRIMARY KEY (`mlid`),
  UNIQUE KEY `id` (`id`),
  KEY `menu_parents` (`menu_name`,`p1`,`p2`,`p3`,`p4`,`p5`,`p6`,`p7`,`p8`,`p9`),
  KEY `menu_parent_expand_child` (`menu_name`,`expanded`,`has_children`,`parent`(16)),
  KEY `route_values` (`route_name`(32),`route_param_key`(16))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Contains the menu tree hierarchy.';

INSERT INTO `menu_tree` (`menu_name`, `mlid`, `id`, `parent`, `route_name`, `route_param_key`, `route_parameters`, `url`, `title`, `description`, `class`, `options`, `provider`, `enabled`, `discovered`, `expanded`, `weight`, `metadata`, `has_children`, `depth`, `p1`, `p2`, `p3`, `p4`, `p5`, `p6`, `p7`, `p8`, `p9`, `form_class`) VALUES
('footer',	1,	'contact.site_page',	'',	'contact.site_page',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Contact\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'contact',	1,	1,	0,	0,	'a:0:{}',	0,	1,	1,	0,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('tools',	2,	'filter.tips_all',	'',	'filter.tips_all',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Compose tips\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'filter',	0,	1,	0,	0,	'a:0:{}',	0,	1,	2,	0,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('tools',	3,	'node.add_page',	'',	'node.add_page',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Add content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'node',	1,	1,	0,	0,	'a:0:{}',	0,	1,	3,	0,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('tools',	4,	'search.view',	'',	'search.view',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Search\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'search',	0,	1,	0,	0,	'a:0:{}',	0,	1,	4,	0,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	6,	'system.admin',	'',	'system.admin',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Administration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	9,	'a:0:{}',	1,	1,	6,	0,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	7,	'announcements_feed.announcement',	'system.admin',	'announcements_feed.announcement',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Announcements\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:49:\"Displays announcements from the Drupal community.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'announcements_feed',	1,	1,	0,	10,	'a:0:{}',	0,	2,	6,	7,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	8,	'help.main',	'system.admin',	'help.main',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Help\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Reference for usage, configuration, and modules.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'help',	1,	1,	0,	9,	'a:0:{}',	0,	2,	6,	8,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	9,	'system.admin_content',	'system.admin',	'system.admin_content',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Find and manage content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-10,	'a:0:{}',	1,	2,	6,	9,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	11,	'system.admin_structure',	'system.admin',	'system.admin_structure',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Structure\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Administer blocks, content types, menus, etc.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-8,	'a:0:{}',	1,	2,	6,	11,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	12,	'block.admin_display',	'system.admin_structure',	'block.admin_display',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Block layout\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:79:\"Configure what block content appears in your site\'s sidebars and other regions.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'block',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	11,	12,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	13,	'entity.block_content_type.collection',	'system.admin_structure',	'entity.block_content_type.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Create and manage fields, forms, and display settings for your content blocks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'block_content',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	11,	13,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	15,	'entity.contact_form.collection',	'system.admin_structure',	'entity.contact_form.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Contact forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Create and manage contact forms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'contact',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	11,	15,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	16,	'field_ui.display_mode',	'system.admin_structure',	'field_ui.display_mode',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Display modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:65:\"Configure what displays are available for your content and forms.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'field_ui',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	11,	16,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	17,	'entity.entity_view_mode.collection',	'field_ui.display_mode',	'entity.entity_view_mode.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"View modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Manage custom view modes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'field_ui',	1,	1,	0,	0,	'a:0:{}',	1,	4,	6,	11,	16,	17,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	18,	'entity.entity_form_mode.collection',	'field_ui.display_mode',	'entity.entity_form_mode.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Form modes\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:25:\"Manage custom form modes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'field_ui',	1,	1,	0,	0,	'a:0:{}',	1,	4,	6,	11,	16,	18,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	19,	'entity.menu.collection',	'system.admin_structure',	'entity.menu.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Menus\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Manage menus and menu links.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'menu_ui',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	11,	19,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	20,	'entity.node_type.collection',	'system.admin_structure',	'entity.node_type.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Content types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:71:\"Create and manage fields, forms, and display settings for your content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'node',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	11,	20,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	21,	'entity.taxonomy_vocabulary.collection',	'system.admin_structure',	'entity.taxonomy_vocabulary.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Taxonomy\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:67:\"Manage tagging, categorization, and classification of your content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'taxonomy',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	11,	21,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	22,	'entity.view.collection',	'system.admin_structure',	'entity.view.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"Manage customized lists of content.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'views_ui',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	11,	22,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	23,	'system.themes_page',	'system.admin',	'system.themes_page',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Appearance\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Select and configure themes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-6,	'a:0:{}',	1,	2,	6,	23,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	24,	'system.modules_list',	'system.admin',	'system.modules_list',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Extend\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:53:\"Add and install modules to extend site functionality.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-2,	'a:0:{}',	1,	2,	6,	24,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	25,	'system.admin_config',	'system.admin',	'system.admin_config',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Administer settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	0,	'a:0:{}',	1,	2,	6,	25,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	26,	'system.admin_config_media',	'system.admin_config',	'system.admin_config_media',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-10,	'a:0:{}',	1,	3,	6,	25,	26,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	27,	'entity.image_style.collection',	'system.admin_config_media',	'entity.image_style.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Image styles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Configure styles that can be used for resizing or adjusting images on display.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'image',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	26,	27,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	28,	'system.file_system_settings',	'system.admin_config_media',	'system.file_system_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"File system\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:67:\"Configure the location of uploaded files and how they are accessed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	26,	28,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	29,	'system.image_toolkit_settings',	'system.admin_config_media',	'system.image_toolkit_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Image toolkit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:74:\"Choose which image toolkit to use if you have installed optional toolkits.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	20,	'a:0:{}',	0,	4,	6,	25,	26,	29,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	30,	'system.admin_config_services',	'system.admin_config',	'system.admin_config_services',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Web services\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	25,	30,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	31,	'system.rss_feeds_settings',	'system.admin_config_services',	'system.rss_feeds_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"RSS publishing\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:115:\"Configure the site description, the number of items per feed, and whether feeds should be titles/teasers/full-text.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	30,	31,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	32,	'system.linkset_settings',	'system.admin_config_services',	'system.linkset_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Menu Linkset Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Enable or disable the menu linkset endpoint\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	10,	'a:0:{}',	0,	4,	6,	25,	30,	32,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	33,	'system.admin_config_development',	'system.admin_config',	'system.admin_config_development',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Development\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Configure and use development tools.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-10,	'a:0:{}',	1,	3,	6,	25,	33,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	34,	'config.sync',	'system.admin_config_development',	'config.sync',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Configuration synchronization\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"Import and export your configuration.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'config',	1,	1,	0,	0,	'a:0:{}',	1,	4,	6,	25,	33,	34,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	35,	'system.site_maintenance_mode',	'system.admin_config_development',	'system.site_maintenance_mode',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Maintenance mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:62:\"Take the site offline for updates and other maintenance tasks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-10,	'a:0:{}',	0,	4,	6,	25,	33,	35,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	36,	'system.performance_settings',	'system.admin_config_development',	'system.performance_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Performance\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Configure caching and bandwidth optimization.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-20,	'a:0:{}',	0,	4,	6,	25,	33,	36,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	37,	'system.development_settings',	'system.admin_config_development',	'system.development_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Development settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Configure theme development settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-19,	'a:0:{}',	0,	4,	6,	25,	33,	37,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	38,	'system.logging_settings',	'system.admin_config_development',	'system.logging_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Logging and errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:61:\"Configure the display of error messages and database logging.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-15,	'a:0:{}',	0,	4,	6,	25,	33,	38,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	39,	'system.admin_config_regional',	'system.admin_config',	'system.admin_config_regional',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Region and language\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:59:\"Configure regional settings, localization, and translation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-5,	'a:0:{}',	1,	3,	6,	25,	39,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	40,	'system.regional_settings',	'system.admin_config_regional',	'system.regional_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Regional settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Configure the locale and timezone settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-20,	'a:0:{}',	0,	4,	6,	25,	39,	40,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	41,	'entity.date_format.collection',	'system.admin_config_regional',	'entity.date_format.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:21:\"Date and time formats\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"Configure how dates and times are displayed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-9,	'a:0:{}',	0,	4,	6,	25,	39,	41,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	42,	'system.admin_config_search',	'system.admin_config',	'system.admin_config_search',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Search and metadata\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:64:\"Configure site search, metadata, and search engine optimization.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-10,	'a:0:{}',	1,	3,	6,	25,	42,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	43,	'entity.path_alias.collection',	'system.admin_config_search',	'entity.path_alias.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"URL aliases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Add custom URLs to existing paths.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'path',	1,	1,	0,	-5,	'a:0:{}',	0,	4,	6,	25,	42,	43,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	44,	'entity.search_page.collection',	'system.admin_config_search',	'entity.search_page.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Search pages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:51:\"Configure search pages and search indexing options.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'search',	1,	1,	0,	-10,	'a:0:{}',	0,	4,	6,	25,	42,	44,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	45,	'system.admin_config_system',	'system.admin_config',	'system.admin_config_system',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"System\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:49:\"Configure basic site settings, actions, and cron.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-20,	'a:0:{}',	1,	3,	6,	25,	45,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	46,	'system.site_information_settings',	'system.admin_config_system',	'system.site_information_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Basic site settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:77:\"Change site name, email address, slogan, default front page, and error pages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-20,	'a:0:{}',	0,	4,	6,	25,	45,	46,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	47,	'system.cron_settings',	'system.admin_config_system',	'system.cron_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Cron\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:40:\"Manage automatic site maintenance tasks.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	20,	'a:0:{}',	0,	4,	6,	25,	45,	47,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	48,	'system.admin_config_ui',	'system.admin_config',	'system.admin_config_ui',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"User interface\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:44:\"Configure the administrative user interface.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-15,	'a:0:{}',	1,	3,	6,	25,	48,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	49,	'entity.shortcut_set.collection',	'system.admin_config_ui',	'entity.shortcut_set.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Shortcuts\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Add and modify shortcut sets.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'shortcut',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	48,	49,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	50,	'system.admin_config_workflow',	'system.admin_config',	'system.admin_config_workflow',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Workflow\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"Manage the content workflow.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	5,	'a:0:{}',	0,	3,	6,	25,	50,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	51,	'system.admin_config_content',	'system.admin_config',	'system.admin_config_content',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Content authoring\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"Configure content formatting and authoring.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-15,	'a:0:{}',	1,	3,	6,	25,	51,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	52,	'filter.admin_overview',	'system.admin_config_content',	'filter.admin_overview',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Text formats and editors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:78:\"Select and configure text editors, and how content is filtered when displayed.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'filter',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	51,	52,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	53,	'user.admin_index',	'system.admin_config',	'user.admin_index',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"People\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Configure user accounts.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'user',	1,	1,	0,	-20,	'a:0:{}',	1,	3,	6,	25,	53,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	54,	'entity.user.admin_form',	'user.admin_index',	'entity.user.admin_form',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Account settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:105:\"Configure default user account settings, including fields, registration requirements, and email messages.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'user',	1,	1,	0,	-10,	'a:0:{}',	1,	4,	6,	25,	53,	54,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	55,	'system.admin_reports',	'system.admin',	'system.admin_reports',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Reports\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"View reports, updates, and errors.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	5,	'a:0:{}',	1,	2,	6,	55,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	56,	'dblog.overview',	'system.admin_reports',	'dblog.overview',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Recent log messages\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:43:\"View events that have recently been logged.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'dblog',	1,	1,	0,	-1,	'a:0:{}',	0,	3,	6,	55,	56,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	57,	'dblog.page_not_found',	'system.admin_reports',	'dblog.page_not_found',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"Top \'page not found\' errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"View \'page not found\' errors (404s).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'dblog',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	55,	57,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	58,	'dblog.access_denied',	'system.admin_reports',	'dblog.access_denied',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:26:\"Top \'access denied\' errors\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"View \'access denied\' errors (403s).\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'dblog',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	55,	58,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	59,	'entity.field_storage_config.collection',	'system.admin_reports',	'entity.field_storage_config.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"Field list\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Overview of fields on all entity types.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'field_ui',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	55,	59,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	60,	'system.status',	'system.admin_reports',	'system.status',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Status report\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:48:\"Get a status report about your site\'s operation.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'system',	1,	1,	0,	-60,	'a:0:{}',	0,	3,	6,	55,	60,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	61,	'views_ui.reports_plugins',	'system.admin_reports',	'views_ui.reports_plugins',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Views plugins\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:38:\"Overview of plugins used in all views.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'views_ui',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	55,	61,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	62,	'dblog.search',	'system.admin_reports',	'dblog.search',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Top search phrases\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"View most popular search phrases.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	55,	62,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	63,	'entity.user.collection',	'system.admin',	'entity.user.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"People\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:45:\"Manage user accounts, roles, and permissions.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'user',	1,	1,	0,	4,	'a:0:{}',	1,	2,	6,	63,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('account',	64,	'user.page',	'',	'user.page',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:10:\"My account\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'user',	1,	1,	0,	-10,	'a:0:{}',	0,	1,	64,	0,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('account',	65,	'user.logout',	'',	'',	'',	'a:0:{}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\user\\Plugin\\Menu\\LoginLogoutMenuLink',	'a:0:{}',	'user',	1,	1,	0,	10,	'a:0:{}',	0,	1,	65,	0,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	66,	'update.status',	'system.admin_reports',	'update.status',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Available updates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:82:\"Get a status report about available updates for your installed modules and themes.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'update',	1,	1,	0,	-50,	'a:0:{}',	0,	3,	6,	55,	66,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	67,	'entity.media_type.collection',	'system.admin_structure',	'entity.media_type.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Media types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage media types.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'media',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	11,	67,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	68,	'media.settings',	'system.admin_config_media',	'media.settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Media settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Manage media settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'media',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	26,	68,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	69,	'media_library.settings',	'system.admin_config_media',	'media_library.settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Media Library settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:30:\"Manage Media Library settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'media_library',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	26,	69,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	70,	'admin_toolbar_tools.help',	'system.admin',	'<front>',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Tools\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-100,	'a:0:{}',	1,	2,	6,	70,	0,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	71,	'system.admin_index',	'admin_toolbar_tools.help',	'system.admin_index',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Index\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-100,	'a:0:{}',	0,	3,	6,	70,	71,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	72,	'system.run_cron',	'admin_toolbar_tools.help',	'admin_toolbar.run.cron',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Run cron\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-8,	'a:0:{}',	0,	3,	6,	70,	72,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	73,	'system.db_update',	'admin_toolbar_tools.help',	'system.db_update',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Run updates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-6,	'a:0:{}',	0,	3,	6,	70,	73,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	74,	'admin_toolbar_tools.flush',	'admin_toolbar_tools.help',	'admin_toolbar_tools.flush',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Flush all caches\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-9,	'a:0:{}',	1,	3,	6,	70,	74,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	75,	'admin_toolbar_tools.cssjs',	'admin_toolbar_tools.flush',	'admin_toolbar_tools.cssjs',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:24:\"Flush CSS and JavaScript\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	70,	74,	75,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	76,	'admin_toolbar_tools.plugin',	'admin_toolbar_tools.flush',	'admin_toolbar_tools.plugin',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Flush plugins cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	70,	74,	76,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	77,	'admin_toolbar_tools.flush_static',	'admin_toolbar_tools.flush',	'admin_toolbar_tools.flush_static',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Flush static cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	70,	74,	77,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	78,	'admin_toolbar_tools.flush_menu',	'admin_toolbar_tools.flush',	'admin_toolbar_tools.flush_menu',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Flush routing and links cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	70,	74,	78,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	79,	'admin_toolbar_tools.flush_twig',	'admin_toolbar_tools.flush',	'admin_toolbar_tools.flush_twig',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Flush twig cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	70,	74,	79,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	80,	'admin_toolbar_tools.flush_rendercache',	'admin_toolbar_tools.flush',	'admin_toolbar_tools.flush_rendercache',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Flush render cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	70,	74,	80,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	81,	'admin_toolbar_tools.theme_rebuild',	'admin_toolbar_tools.flush',	'admin_toolbar_tools.theme_rebuild',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:22:\"Rebuild theme registry\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	70,	74,	81,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	82,	'admin_toolbar_tools.extra_links:flush_views',	'admin_toolbar_tools.flush',	'admin_toolbar_tools.flush_views',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Flush views cache\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	70,	74,	82,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	83,	'admin_toolbar_tools.extra_links:user.logout',	'admin_toolbar_tools.help',	'user.logout',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Logout\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	10,	'a:0:{}',	0,	3,	6,	70,	83,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	84,	'admin_toolbar_tools.extra_links:node.add',	'system.admin_content',	'node.add_page',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Add content\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	9,	84,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	85,	'admin_toolbar_tools.extra_links:node.add.article',	'admin_toolbar_tools.extra_links:node.add',	'node.add',	'node_type=article',	'a:1:{s:9:\"node_type\";s:7:\"article\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:7:\"article\";}',	0,	4,	6,	9,	84,	85,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	86,	'admin_toolbar_tools.extra_links:node.add.page',	'admin_toolbar_tools.extra_links:node.add',	'node.add',	'node_type=page',	'a:1:{s:9:\"node_type\";s:4:\"page\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:4:\"page\";}',	0,	4,	6,	9,	84,	86,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	87,	'admin_toolbar_tools.extra_links:media_page',	'system.admin_content',	'entity.media.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	9,	87,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	88,	'admin_toolbar_tools.extra_links:media_library',	'admin_toolbar_tools.extra_links:media_page',	'view.media_library.page',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Media library\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	9,	87,	88,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	89,	'admin_toolbar_tools.extra_links:add_media',	'admin_toolbar_tools.extra_links:media_page',	'entity.media.add_page',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Add media\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	1,	4,	6,	9,	87,	89,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	90,	'admin_toolbar_tools.extra_links:media.add.audio',	'admin_toolbar_tools.extra_links:add_media',	'entity.media.add_form',	'media_type=audio',	'a:1:{s:10:\"media_type\";s:5:\"audio\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"audio\";}',	0,	5,	6,	9,	87,	89,	90,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	91,	'admin_toolbar_tools.extra_links:media.add.document',	'admin_toolbar_tools.extra_links:add_media',	'entity.media.add_form',	'media_type=document',	'a:1:{s:10:\"media_type\";s:8:\"document\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:8:\"document\";}',	0,	5,	6,	9,	87,	89,	91,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	92,	'admin_toolbar_tools.extra_links:media.add.image',	'admin_toolbar_tools.extra_links:add_media',	'entity.media.add_form',	'media_type=image',	'a:1:{s:10:\"media_type\";s:5:\"image\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"image\";}',	0,	5,	6,	9,	87,	89,	92,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	93,	'admin_toolbar_tools.extra_links:media.add.remote_video',	'admin_toolbar_tools.extra_links:add_media',	'entity.media.add_form',	'media_type=remote_video',	'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:12:\"remote_video\";}',	0,	5,	6,	9,	87,	89,	93,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	94,	'admin_toolbar_tools.extra_links:media.add.video',	'admin_toolbar_tools.extra_links:add_media',	'entity.media.add_form',	'media_type=video',	'a:1:{s:10:\"media_type\";s:5:\"video\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"video\";}',	0,	5,	6,	9,	87,	89,	94,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	95,	'admin_toolbar_tools.extra_links:view.files',	'system.admin_content',	'view.files.page_1',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Files\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	9,	95,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	96,	'admin_toolbar_tools.extra_links:block_content.add_page',	'block.admin_display',	'block_content.add_page',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Add custom block\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	12,	96,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	97,	'admin_toolbar_tools.extra_links:entity.block_content.collection',	'block.admin_display',	'entity.block_content.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:20:\"Custom block library\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	12,	97,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	98,	'admin_toolbar_tools.extra_links:entity.block_content_type.collection',	'block.admin_display',	'entity.block_content_type.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Block types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	12,	98,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	99,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=basic',	'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:5:\"basic\";}',	1,	4,	6,	11,	13,	99,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	100,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsbasic',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic',	'entity.block_content.field_ui_fields',	'block_content_type=basic',	'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	99,	100,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	101,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultbasic',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic',	'entity.entity_form_display.block_content.default',	'block_content_type=basic',	'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	99,	101,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	102,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.basic',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic',	'entity.entity_view_display.block_content.default',	'block_content_type=basic',	'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	99,	102,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	103,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.basic',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic',	'entity.block_content_type.entity_permissions_form',	'block_content_type=basic',	'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	99,	103,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	104,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.basic',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.basic',	'entity.block_content_type.delete_form',	'block_content_type=basic',	'a:1:{s:18:\"block_content_type\";s:5:\"basic\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	99,	104,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	111,	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback',	'entity.contact_form.collection',	'entity.contact_form.edit_form',	'contact_form=feedback',	'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"entity_id\";s:8:\"feedback\";}',	1,	4,	6,	11,	15,	111,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	112,	'admin_toolbar_tools.extra_links:entity.contact_message.field_ui_fieldsfeedback',	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback',	'entity.contact_message.field_ui_fields',	'contact_form=feedback',	'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	15,	111,	112,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	113,	'admin_toolbar_tools.extra_links:entity.entity_form_display.contact_message.defaultfeedback',	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback',	'entity.entity_form_display.contact_message.default',	'contact_form=feedback',	'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	15,	111,	113,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	114,	'admin_toolbar_tools.extra_links:entity.entity_view_display.contact_message.default.feedback',	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback',	'entity.entity_view_display.contact_message.default',	'contact_form=feedback',	'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	15,	111,	114,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	115,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.contact_message.default.feedback',	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback',	'entity.contact_form.entity_permissions_form',	'contact_form=feedback',	'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	15,	111,	115,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	116,	'admin_toolbar_tools.extra_links:entity.contact_form.delete_form.feedback',	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.feedback',	'entity.contact_form.delete_form',	'contact_form=feedback',	'a:1:{s:12:\"contact_form\";s:8:\"feedback\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	15,	111,	116,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	117,	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal',	'entity.contact_form.collection',	'entity.contact_form.edit_form',	'contact_form=personal',	'a:1:{s:12:\"contact_form\";s:8:\"personal\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"entity_id\";s:8:\"personal\";}',	1,	4,	6,	11,	15,	117,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	118,	'admin_toolbar_tools.extra_links:entity.contact_message.field_ui_fieldspersonal',	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal',	'entity.contact_message.field_ui_fields',	'contact_form=personal',	'a:1:{s:12:\"contact_form\";s:8:\"personal\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	15,	117,	118,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	119,	'admin_toolbar_tools.extra_links:entity.entity_form_display.contact_message.defaultpersonal',	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal',	'entity.entity_form_display.contact_message.default',	'contact_form=personal',	'a:1:{s:12:\"contact_form\";s:8:\"personal\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	15,	117,	119,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	120,	'admin_toolbar_tools.extra_links:entity.entity_view_display.contact_message.default.personal',	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal',	'entity.entity_view_display.contact_message.default',	'contact_form=personal',	'a:1:{s:12:\"contact_form\";s:8:\"personal\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	15,	117,	120,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	121,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.contact_message.default.personal',	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal',	'entity.contact_form.entity_permissions_form',	'contact_form=personal',	'a:1:{s:12:\"contact_form\";s:8:\"personal\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	15,	117,	121,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	122,	'admin_toolbar_tools.extra_links:entity.contact_form.delete_form.personal',	'admin_toolbar_tools.extra_links:entity.contact_form.edit_form.personal',	'entity.contact_form.delete_form',	'contact_form=personal',	'a:1:{s:12:\"contact_form\";s:8:\"personal\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	15,	117,	122,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	123,	'admin_toolbar_tools.extra_links:contact.form_add',	'entity.contact_form.collection',	'contact.form_add',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Add contact form\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-5,	'a:0:{}',	0,	4,	6,	11,	15,	123,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	124,	'admin_toolbar_tools.extra_links:field_ui.entity_view_mode_add',	'entity.entity_view_mode.collection',	'field_ui.entity_view_mode_add',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Add view mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	11,	16,	17,	124,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	125,	'admin_toolbar_tools.extra_links:field_ui.entity_form_mode_add',	'entity.entity_form_mode.collection',	'field_ui.entity_form_mode_add',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Add form mode\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	11,	16,	18,	125,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	126,	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.document',	'entity.media_type.collection',	'entity.media_type.edit_form',	'media_type=document',	'a:1:{s:10:\"media_type\";s:8:\"document\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:8:\"document\";}',	1,	4,	6,	11,	67,	126,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	127,	'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsdocument',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.document',	'entity.media.field_ui_fields',	'media_type=document',	'a:1:{s:10:\"media_type\";s:8:\"document\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	67,	126,	127,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	128,	'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultdocument',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.document',	'entity.entity_form_display.media.default',	'media_type=document',	'a:1:{s:10:\"media_type\";s:8:\"document\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	67,	126,	128,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	129,	'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.document',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.document',	'entity.entity_view_display.media.default',	'media_type=document',	'a:1:{s:10:\"media_type\";s:8:\"document\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	67,	126,	129,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	130,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.document',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.document',	'entity.media_type.entity_permissions_form',	'media_type=document',	'a:1:{s:10:\"media_type\";s:8:\"document\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	67,	126,	130,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	131,	'admin_toolbar_tools.extra_links:entity.media_type.delete_form.document',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.document',	'entity.media_type.delete_form',	'media_type=document',	'a:1:{s:10:\"media_type\";s:8:\"document\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	67,	126,	131,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	132,	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.video',	'entity.media_type.collection',	'entity.media_type.edit_form',	'media_type=video',	'a:1:{s:10:\"media_type\";s:5:\"video\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"video\";}',	1,	4,	6,	11,	67,	132,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	133,	'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsvideo',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.video',	'entity.media.field_ui_fields',	'media_type=video',	'a:1:{s:10:\"media_type\";s:5:\"video\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	67,	132,	133,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	134,	'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultvideo',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.video',	'entity.entity_form_display.media.default',	'media_type=video',	'a:1:{s:10:\"media_type\";s:5:\"video\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	67,	132,	134,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	135,	'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.video',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.video',	'entity.entity_view_display.media.default',	'media_type=video',	'a:1:{s:10:\"media_type\";s:5:\"video\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	67,	132,	135,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	136,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.video',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.video',	'entity.media_type.entity_permissions_form',	'media_type=video',	'a:1:{s:10:\"media_type\";s:5:\"video\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	67,	132,	136,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	137,	'admin_toolbar_tools.extra_links:entity.media_type.delete_form.video',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.video',	'entity.media_type.delete_form',	'media_type=video',	'a:1:{s:10:\"media_type\";s:5:\"video\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	67,	132,	137,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	138,	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video',	'entity.media_type.collection',	'entity.media_type.edit_form',	'media_type=remote_video',	'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:12:\"remote_video\";}',	1,	4,	6,	11,	67,	138,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	139,	'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsremote_video',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video',	'entity.media.field_ui_fields',	'media_type=remote_video',	'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	67,	138,	139,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	140,	'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultremote_video',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video',	'entity.entity_form_display.media.default',	'media_type=remote_video',	'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	67,	138,	140,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	141,	'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.remote_video',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video',	'entity.entity_view_display.media.default',	'media_type=remote_video',	'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	67,	138,	141,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	142,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.remote_video',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video',	'entity.media_type.entity_permissions_form',	'media_type=remote_video',	'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	67,	138,	142,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	143,	'admin_toolbar_tools.extra_links:entity.media_type.delete_form.remote_video',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.remote_video',	'entity.media_type.delete_form',	'media_type=remote_video',	'a:1:{s:10:\"media_type\";s:12:\"remote_video\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	67,	138,	143,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	144,	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio',	'entity.media_type.collection',	'entity.media_type.edit_form',	'media_type=audio',	'a:1:{s:10:\"media_type\";s:5:\"audio\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"audio\";}',	1,	4,	6,	11,	67,	144,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	145,	'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsaudio',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio',	'entity.media.field_ui_fields',	'media_type=audio',	'a:1:{s:10:\"media_type\";s:5:\"audio\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	67,	144,	145,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	146,	'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultaudio',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio',	'entity.entity_form_display.media.default',	'media_type=audio',	'a:1:{s:10:\"media_type\";s:5:\"audio\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	67,	144,	146,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	147,	'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.audio',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio',	'entity.entity_view_display.media.default',	'media_type=audio',	'a:1:{s:10:\"media_type\";s:5:\"audio\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	67,	144,	147,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	148,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.audio',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio',	'entity.media_type.entity_permissions_form',	'media_type=audio',	'a:1:{s:10:\"media_type\";s:5:\"audio\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	67,	144,	148,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	149,	'admin_toolbar_tools.extra_links:entity.media_type.delete_form.audio',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.audio',	'entity.media_type.delete_form',	'media_type=audio',	'a:1:{s:10:\"media_type\";s:5:\"audio\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	67,	144,	149,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	150,	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.image',	'entity.media_type.collection',	'entity.media_type.edit_form',	'media_type=image',	'a:1:{s:10:\"media_type\";s:5:\"image\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:10:\"media_type\";s:9:\"entity_id\";s:5:\"image\";}',	1,	4,	6,	11,	67,	150,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	151,	'admin_toolbar_tools.extra_links:entity.media.field_ui_fieldsimage',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.image',	'entity.media.field_ui_fields',	'media_type=image',	'a:1:{s:10:\"media_type\";s:5:\"image\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	67,	150,	151,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	152,	'admin_toolbar_tools.extra_links:entity.entity_form_display.media.defaultimage',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.image',	'entity.entity_form_display.media.default',	'media_type=image',	'a:1:{s:10:\"media_type\";s:5:\"image\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	67,	150,	152,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	153,	'admin_toolbar_tools.extra_links:entity.entity_view_display.media.default.image',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.image',	'entity.entity_view_display.media.default',	'media_type=image',	'a:1:{s:10:\"media_type\";s:5:\"image\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	67,	150,	153,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	154,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.media.default.image',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.image',	'entity.media_type.entity_permissions_form',	'media_type=image',	'a:1:{s:10:\"media_type\";s:5:\"image\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	67,	150,	154,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	155,	'admin_toolbar_tools.extra_links:entity.media_type.delete_form.image',	'admin_toolbar_tools.extra_links:entity.media_type.edit_form.image',	'entity.media_type.delete_form',	'media_type=image',	'a:1:{s:10:\"media_type\";s:5:\"image\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	67,	150,	155,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	156,	'admin_toolbar_tools.extra_links:media.type_add',	'entity.media_type.collection',	'entity.media_type.add_form',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Add media type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-2,	'a:0:{}',	0,	4,	6,	11,	67,	156,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	157,	'admin_toolbar_tools.extra_links:entity.menu.add_form',	'entity.menu.collection',	'entity.menu.add_form',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add menu\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-2,	'a:0:{}',	0,	4,	6,	11,	19,	157,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	158,	'admin_toolbar_tools.extra_links:entity.menu.edit_form.admin',	'entity.menu.collection',	'entity.menu.edit_form',	'menu=admin',	'a:1:{s:4:\"menu\";s:5:\"admin\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:5:\"admin\";}',	1,	4,	6,	11,	19,	158,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	159,	'admin_toolbar_tools.extra_links:entity.menu.add_link_form.admin',	'admin_toolbar_tools.extra_links:entity.menu.edit_form.admin',	'entity.menu.add_link_form',	'menu=admin',	'a:1:{s:4:\"menu\";s:5:\"admin\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	11,	19,	158,	159,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	160,	'admin_toolbar_tools.extra_links:entity.menu.edit_form.footer',	'entity.menu.collection',	'entity.menu.edit_form',	'menu=footer',	'a:1:{s:4:\"menu\";s:6:\"footer\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:6:\"footer\";}',	1,	4,	6,	11,	19,	160,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	161,	'admin_toolbar_tools.extra_links:entity.menu.add_link_form.footer',	'admin_toolbar_tools.extra_links:entity.menu.edit_form.footer',	'entity.menu.add_link_form',	'menu=footer',	'a:1:{s:4:\"menu\";s:6:\"footer\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	11,	19,	160,	161,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	162,	'admin_toolbar_tools.extra_links:entity.menu.edit_form.main',	'entity.menu.collection',	'entity.menu.edit_form',	'menu=main',	'a:1:{s:4:\"menu\";s:4:\"main\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:4:\"main\";}',	1,	4,	6,	11,	19,	162,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	163,	'admin_toolbar_tools.extra_links:entity.menu.add_link_form.main',	'admin_toolbar_tools.extra_links:entity.menu.edit_form.main',	'entity.menu.add_link_form',	'menu=main',	'a:1:{s:4:\"menu\";s:4:\"main\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	11,	19,	162,	163,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	164,	'admin_toolbar_tools.extra_links:entity.menu.edit_form.tools',	'entity.menu.collection',	'entity.menu.edit_form',	'menu=tools',	'a:1:{s:4:\"menu\";s:5:\"tools\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:5:\"tools\";}',	1,	4,	6,	11,	19,	164,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	165,	'admin_toolbar_tools.extra_links:entity.menu.add_link_form.tools',	'admin_toolbar_tools.extra_links:entity.menu.edit_form.tools',	'entity.menu.add_link_form',	'menu=tools',	'a:1:{s:4:\"menu\";s:5:\"tools\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	11,	19,	164,	165,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	166,	'admin_toolbar_tools.extra_links:entity.menu.edit_form.account',	'entity.menu.collection',	'entity.menu.edit_form',	'menu=account',	'a:1:{s:4:\"menu\";s:7:\"account\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	4,	'a:2:{s:11:\"entity_type\";s:4:\"menu\";s:9:\"entity_id\";s:7:\"account\";}',	1,	4,	6,	11,	19,	166,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	167,	'admin_toolbar_tools.extra_links:entity.menu.add_link_form.account',	'admin_toolbar_tools.extra_links:entity.menu.edit_form.account',	'entity.menu.add_link_form',	'menu=account',	'a:1:{s:4:\"menu\";s:7:\"account\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add link\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	11,	19,	166,	167,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	168,	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.page',	'entity.node_type.collection',	'entity.node_type.edit_form',	'node_type=page',	'a:1:{s:9:\"node_type\";s:4:\"page\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:4:\"page\";}',	1,	4,	6,	11,	20,	168,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	169,	'admin_toolbar_tools.extra_links:entity.node.field_ui_fieldspage',	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.page',	'entity.node.field_ui_fields',	'node_type=page',	'a:1:{s:9:\"node_type\";s:4:\"page\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	20,	168,	169,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	170,	'admin_toolbar_tools.extra_links:entity.entity_form_display.node.defaultpage',	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.page',	'entity.entity_form_display.node.default',	'node_type=page',	'a:1:{s:9:\"node_type\";s:4:\"page\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	20,	168,	170,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	171,	'admin_toolbar_tools.extra_links:entity.entity_view_display.node.default.page',	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.page',	'entity.entity_view_display.node.default',	'node_type=page',	'a:1:{s:9:\"node_type\";s:4:\"page\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	20,	168,	171,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	172,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.node.default.page',	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.page',	'entity.node_type.entity_permissions_form',	'node_type=page',	'a:1:{s:9:\"node_type\";s:4:\"page\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	20,	168,	172,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	173,	'admin_toolbar_tools.extra_links:entity.node_type.delete_form.page',	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.page',	'entity.node_type.delete_form',	'node_type=page',	'a:1:{s:9:\"node_type\";s:4:\"page\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	20,	168,	173,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	174,	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.article',	'entity.node_type.collection',	'entity.node_type.edit_form',	'node_type=article',	'a:1:{s:9:\"node_type\";s:7:\"article\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:9:\"node_type\";s:9:\"entity_id\";s:7:\"article\";}',	1,	4,	6,	11,	20,	174,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	175,	'admin_toolbar_tools.extra_links:entity.node.field_ui_fieldsarticle',	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.article',	'entity.node.field_ui_fields',	'node_type=article',	'a:1:{s:9:\"node_type\";s:7:\"article\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	20,	174,	175,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	176,	'admin_toolbar_tools.extra_links:entity.entity_form_display.node.defaultarticle',	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.article',	'entity.entity_form_display.node.default',	'node_type=article',	'a:1:{s:9:\"node_type\";s:7:\"article\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	20,	174,	176,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	177,	'admin_toolbar_tools.extra_links:entity.entity_view_display.node.default.article',	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.article',	'entity.entity_view_display.node.default',	'node_type=article',	'a:1:{s:9:\"node_type\";s:7:\"article\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	20,	174,	177,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	178,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.node.default.article',	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.article',	'entity.node_type.entity_permissions_form',	'node_type=article',	'a:1:{s:9:\"node_type\";s:7:\"article\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	20,	174,	178,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	179,	'admin_toolbar_tools.extra_links:entity.node_type.delete_form.article',	'admin_toolbar_tools.extra_links:entity.node_type.edit_form.article',	'entity.node_type.delete_form',	'node_type=article',	'a:1:{s:9:\"node_type\";s:7:\"article\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	20,	174,	179,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	180,	'admin_toolbar_tools.extra_links:node.type_add',	'entity.node_type.collection',	'node.type_add',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Add content type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-2,	'a:0:{}',	0,	4,	6,	11,	20,	180,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	181,	'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags',	'entity.taxonomy_vocabulary.collection',	'entity.taxonomy_vocabulary.overview_form',	'taxonomy_vocabulary=tags',	'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"entity_id\";s:4:\"tags\";}',	1,	4,	6,	11,	21,	181,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	182,	'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.edit_form.tags',	'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags',	'entity.taxonomy_vocabulary.edit_form',	'taxonomy_vocabulary=tags',	'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Edit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	11,	21,	181,	182,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	183,	'admin_toolbar_tools.extra_links:entity.taxonomy_term.field_ui_fieldstags',	'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags',	'entity.taxonomy_term.field_ui_fields',	'taxonomy_vocabulary=tags',	'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	21,	181,	183,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	184,	'admin_toolbar_tools.extra_links:entity.entity_form_display.taxonomy_term.defaulttags',	'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags',	'entity.entity_form_display.taxonomy_term.default',	'taxonomy_vocabulary=tags',	'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	21,	181,	184,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	185,	'admin_toolbar_tools.extra_links:entity.entity_view_display.taxonomy_term.default.tags',	'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags',	'entity.entity_view_display.taxonomy_term.default',	'taxonomy_vocabulary=tags',	'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	21,	181,	185,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	186,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.taxonomy_term.default.tags',	'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags',	'entity.taxonomy_vocabulary.entity_permissions_form',	'taxonomy_vocabulary=tags',	'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	21,	181,	186,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	187,	'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.delete_form.tags',	'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.overview_form.tags',	'entity.taxonomy_vocabulary.delete_form',	'taxonomy_vocabulary=tags',	'a:1:{s:19:\"taxonomy_vocabulary\";s:4:\"tags\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	21,	181,	187,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	188,	'admin_toolbar_tools.extra_links:entity.taxonomy_vocabulary.add_form',	'entity.taxonomy_vocabulary.collection',	'entity.taxonomy_vocabulary.add_form',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Add vocabulary\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-998,	'a:0:{}',	0,	4,	6,	11,	21,	188,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	189,	'admin_toolbar_tools.extra_links:views_ui.add',	'entity.view.collection',	'views_ui.add',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add view\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-5,	'a:0:{}',	0,	4,	6,	11,	22,	189,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	190,	'admin_toolbar_tools.extra_links:views_ui.archive',	'entity.view.collection',	'entity.view.edit_form',	'view=archive',	'a:1:{s:4:\"view\";s:7:\"archive\";}',	'',	's:7:\"Archive\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	190,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	191,	'admin_toolbar_tools.extra_links:views_ui.block_content',	'entity.view.collection',	'entity.view.edit_form',	'view=block_content',	'a:1:{s:4:\"view\";s:13:\"block_content\";}',	'',	's:14:\"Content blocks\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	191,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	194,	'admin_toolbar_tools.extra_links:views_ui.content',	'entity.view.collection',	'entity.view.edit_form',	'view=content',	'a:1:{s:4:\"view\";s:7:\"content\";}',	'',	's:7:\"Content\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	194,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	195,	'admin_toolbar_tools.extra_links:views_ui.content_recent',	'entity.view.collection',	'entity.view.edit_form',	'view=content_recent',	'a:1:{s:4:\"view\";s:14:\"content_recent\";}',	'',	's:14:\"Recent content\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	195,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	196,	'admin_toolbar_tools.extra_links:views_ui.files',	'entity.view.collection',	'entity.view.edit_form',	'view=files',	'a:1:{s:4:\"view\";s:5:\"files\";}',	'',	's:5:\"Files\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	196,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	197,	'admin_toolbar_tools.extra_links:views_ui.frontpage',	'entity.view.collection',	'entity.view.edit_form',	'view=frontpage',	'a:1:{s:4:\"view\";s:9:\"frontpage\";}',	'',	's:9:\"Frontpage\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	197,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	198,	'admin_toolbar_tools.extra_links:views_ui.glossary',	'entity.view.collection',	'entity.view.edit_form',	'view=glossary',	'a:1:{s:4:\"view\";s:8:\"glossary\";}',	'',	's:8:\"Glossary\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	198,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	199,	'admin_toolbar_tools.extra_links:views_ui.media',	'entity.view.collection',	'entity.view.edit_form',	'view=media',	'a:1:{s:4:\"view\";s:5:\"media\";}',	'',	's:5:\"Media\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	199,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	200,	'admin_toolbar_tools.extra_links:views_ui.media_library',	'entity.view.collection',	'entity.view.edit_form',	'view=media_library',	'a:1:{s:4:\"view\";s:13:\"media_library\";}',	'',	's:13:\"Media library\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	200,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	201,	'admin_toolbar_tools.extra_links:views_ui.taxonomy_term',	'entity.view.collection',	'entity.view.edit_form',	'view=taxonomy_term',	'a:1:{s:4:\"view\";s:13:\"taxonomy_term\";}',	'',	's:13:\"Taxonomy term\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	201,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	202,	'admin_toolbar_tools.extra_links:views_ui.user_admin_people',	'entity.view.collection',	'entity.view.edit_form',	'view=user_admin_people',	'a:1:{s:4:\"view\";s:17:\"user_admin_people\";}',	'',	's:6:\"People\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	202,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	203,	'admin_toolbar_tools.extra_links:views_ui.watchdog',	'entity.view.collection',	'entity.view.edit_form',	'view=watchdog',	'a:1:{s:4:\"view\";s:8:\"watchdog\";}',	'',	's:8:\"Watchdog\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	203,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	204,	'admin_toolbar_tools.extra_links:views_ui.who_s_new',	'entity.view.collection',	'entity.view.edit_form',	'view=who_s_new',	'a:1:{s:4:\"view\";s:9:\"who_s_new\";}',	'',	's:9:\"Who\'s new\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	204,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	205,	'admin_toolbar_tools.extra_links:views_ui.who_s_online',	'entity.view.collection',	'entity.view.edit_form',	'view=who_s_online',	'a:1:{s:4:\"view\";s:12:\"who_s_online\";}',	'',	's:18:\"Who\'s online block\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	205,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	206,	'entity.webform.collection',	'system.admin_structure',	'entity.webform.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Webforms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Create webforms and manage submissions.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	11,	206,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	207,	'entity.webform.collection.item',	'entity.webform.collection',	'entity.webform.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	206,	207,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	208,	'entity.webform_submission.collection.item',	'entity.webform.collection',	'entity.webform_submission.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Submissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	20,	'a:0:{}',	1,	4,	6,	11,	206,	208,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	209,	'entity.webform_submission.collection_manage.item',	'entity.webform_submission.collection.item',	'entity.webform_submission.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Manage\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	11,	206,	208,	209,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	210,	'entity.webform_submission.collection_purge.item',	'entity.webform_submission.collection.item',	'entity.webform_submission.collection_purge',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Purge\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	10,	'a:0:{}',	0,	5,	6,	11,	206,	208,	210,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	211,	'webform.options.item',	'entity.webform.collection',	'entity.webform_options.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	30,	'a:0:{}',	1,	4,	6,	11,	206,	211,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	212,	'webform.config.options.item',	'webform.options.item',	'entity.webform_options.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Options\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	11,	206,	211,	212,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	213,	'webform.config.item',	'entity.webform.collection',	'webform.config',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Configuration\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	40,	'a:0:{}',	1,	4,	6,	11,	206,	213,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	214,	'webform.config.forms.item',	'webform.config.item',	'webform.config',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Forms\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	10,	'a:0:{}',	0,	5,	6,	11,	206,	213,	214,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	215,	'webform.config.elements.item',	'webform.config.item',	'webform.config.elements',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Elements\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	20,	'a:0:{}',	0,	5,	6,	11,	206,	213,	215,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	216,	'webform.config.submissions.item',	'webform.config.item',	'webform.config.submissions',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Submissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	40,	'a:0:{}',	0,	5,	6,	11,	206,	213,	216,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	217,	'webform.config.handlers.item',	'webform.config.item',	'webform.config.handlers',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Handlers\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	50,	'a:0:{}',	0,	5,	6,	11,	206,	213,	217,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	218,	'webform.config.variants.item',	'webform.config.item',	'webform.config.variants',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Variants\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	60,	'a:0:{}',	0,	5,	6,	11,	206,	213,	218,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	219,	'webform.config.exporters.item',	'webform.config.item',	'webform.config.exporters',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Exporters\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	70,	'a:0:{}',	0,	5,	6,	11,	206,	213,	219,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	220,	'webform.config.libraries.item',	'webform.config.item',	'webform.config.libraries',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"Libraries\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	80,	'a:0:{}',	0,	5,	6,	11,	206,	213,	220,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	221,	'webform.config.advanced.item',	'webform.config.item',	'webform.config.advanced',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Advanced\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	90,	'a:0:{}',	0,	5,	6,	11,	206,	213,	221,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	222,	'webform.addons.item',	'entity.webform.collection',	'webform.addons',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Add-ons\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	50,	'a:0:{}',	0,	4,	6,	11,	206,	222,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	223,	'webform.help.item',	'entity.webform.collection',	'webform.help',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:4:\"Help\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	60,	'a:0:{}',	0,	4,	6,	11,	206,	223,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	224,	'admin_toolbar_tools.extra_links:update.theme_install',	'system.themes_page',	'update.theme_install',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:17:\"Install new theme\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	23,	224,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	225,	'admin_toolbar_tools.extra_links:update.theme_update',	'system.themes_page',	'update.theme_update',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Update\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	23,	225,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	226,	'admin_toolbar_tools.extra_links:system.theme_settings',	'system.themes_page',	'system.theme_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	23,	226,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	227,	'admin_toolbar_tools.extra_links:system.theme_settings_theme.olivero',	'admin_toolbar_tools.extra_links:system.theme_settings',	'system.theme_settings_theme',	'theme=olivero',	'a:1:{s:5:\"theme\";s:7:\"olivero\";}',	'',	's:7:\"Olivero\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	23,	226,	227,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	228,	'admin_toolbar_tools.extra_links:system.theme_settings_theme.claro',	'admin_toolbar_tools.extra_links:system.theme_settings',	'system.theme_settings_theme',	'theme=claro',	'a:1:{s:5:\"theme\";s:5:\"claro\";}',	'',	's:5:\"Claro\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	23,	226,	228,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	229,	'system.modules_uninstall',	'system.modules_list',	'system.modules_uninstall',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Uninstall module\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	24,	229,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	230,	'admin_toolbar_tools.extra_links:update.module_install',	'system.modules_list',	'update.module_install',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Install new module\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	24,	230,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	231,	'admin_toolbar_tools.extra_links:update.module_update',	'system.modules_list',	'update.module_update',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Update\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	24,	231,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	232,	'admin_toolbar_tools.extra_links:config.import',	'config.sync',	'config.import_full',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Import\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	25,	33,	34,	232,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	233,	'admin_toolbar_tools.extra_links:config.export',	'config.sync',	'config.export_full',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Export\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	25,	33,	34,	233,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	234,	'config_ignore.settings',	'config.sync',	'config_ignore.settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Ignore\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:29:\"Configuration Ignore settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'config_ignore',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	25,	33,	34,	234,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	235,	'admin_toolbar.settings',	'system.admin_config_ui',	'admin_toolbar.settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Admin Toolbar\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:35:\"Configure the Admin Toolbar module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	48,	235,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	236,	'admin_toolbar_tools.settings',	'system.admin_config_ui',	'admin_toolbar_tools.settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Admin Toolbar Tools\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:41:\"Configure the Admin Toolbar Tools module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	48,	236,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	237,	'entity.ckeditor5_template.overview',	'system.admin_config_content',	'entity.ckeditor5_template.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:28:\"CKEditor 5 Content Templates\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:89:\"The template feature allows you to insert predefined content structures into the document\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'ckeditor5_plugin_pack_templates',	1,	1,	0,	32,	'a:0:{}',	0,	4,	6,	25,	51,	237,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	238,	'entity.linkit_profile.collection',	'system.admin_config_content',	'entity.linkit_profile.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Linkit\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:23:\"Manage Linkit profiles.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'linkit',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	51,	238,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	239,	'admin_toolbar_tools.extra_links:entity.user.field_ui_fields_',	'entity.user.admin_form',	'entity.user.field_ui_fields',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	25,	53,	54,	239,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	240,	'admin_toolbar_tools.extra_links:entity.entity_form_display.user.default_',	'entity.user.admin_form',	'entity.entity_form_display.user.default',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	25,	53,	54,	240,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	241,	'admin_toolbar_tools.extra_links:entity.entity_view_display.user.default_',	'entity.user.admin_form',	'entity.entity_view_display.user.default',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	25,	53,	54,	241,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	242,	'admin_toolbar_tools.extra_links:views_ui.field_list',	'entity.field_storage_config.collection',	'views_ui.reports_fields',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Used in views\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	55,	59,	242,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	243,	'webform.reports_plugins',	'system.admin_reports',	'webform.reports_plugins.elements',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Webform plugins\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:47:\"Overview of plugins used by the Webform module.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'webform',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	55,	243,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	244,	'admin_toolbar_tools.extra_links:user.admin_create',	'entity.user.collection',	'user.admin_create',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add user\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	63,	244,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	245,	'admin_toolbar_tools.extra_links:user.admin_permissions',	'entity.user.collection',	'user.admin_permissions',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:11:\"Permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	63,	245,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	246,	'admin_toolbar_tools.extra_links:entity.user_role.collection',	'entity.user.collection',	'entity.user_role.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:5:\"Roles\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	63,	246,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	247,	'admin_toolbar_tools.extra_links:user.role_add',	'admin_toolbar_tools.extra_links:entity.user_role.collection',	'user.role_add',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Add role\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-50,	'a:0:{}',	0,	4,	6,	63,	246,	247,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	248,	'admin_toolbar_tools.extra_links:entity.user_role.edit_form.anonymous',	'admin_toolbar_tools.extra_links:entity.user_role.collection',	'entity.user_role.edit_form',	'user_role=anonymous',	'a:1:{s:9:\"user_role\";s:9:\"anonymous\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:9:\"anonymous\";}',	1,	4,	6,	63,	246,	248,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	249,	'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.anonymous',	'admin_toolbar_tools.extra_links:entity.user_role.edit_form.anonymous',	'entity.user_role.edit_permissions_form',	'user_role=anonymous',	'a:1:{s:9:\"user_role\";s:9:\"anonymous\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	63,	246,	248,	249,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	250,	'admin_toolbar_tools.extra_links:entity.user_role.edit_form.authenticated',	'admin_toolbar_tools.extra_links:entity.user_role.collection',	'entity.user_role.edit_form',	'user_role=authenticated',	'a:1:{s:9:\"user_role\";s:13:\"authenticated\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:13:\"authenticated\";}',	1,	4,	6,	63,	246,	250,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	251,	'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.authenticated',	'admin_toolbar_tools.extra_links:entity.user_role.edit_form.authenticated',	'entity.user_role.edit_permissions_form',	'user_role=authenticated',	'a:1:{s:9:\"user_role\";s:13:\"authenticated\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	63,	246,	250,	251,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	252,	'admin_toolbar_tools.extra_links:entity.user_role.edit_form.content_editor',	'admin_toolbar_tools.extra_links:entity.user_role.collection',	'entity.user_role.edit_form',	'user_role=content_editor',	'a:1:{s:9:\"user_role\";s:14:\"content_editor\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:14:\"content_editor\";}',	1,	4,	6,	63,	246,	252,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	253,	'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.content_editor',	'admin_toolbar_tools.extra_links:entity.user_role.edit_form.content_editor',	'entity.user_role.edit_permissions_form',	'user_role=content_editor',	'a:1:{s:9:\"user_role\";s:14:\"content_editor\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	63,	246,	252,	253,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	254,	'admin_toolbar_tools.extra_links:entity.user_role.delete_form.content_editor',	'admin_toolbar_tools.extra_links:entity.user_role.edit_form.content_editor',	'entity.user_role.delete_form',	'user_role=content_editor',	'a:1:{s:9:\"user_role\";s:14:\"content_editor\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	63,	246,	252,	254,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	255,	'admin_toolbar_tools.extra_links:entity.user_role.edit_form.administrator',	'admin_toolbar_tools.extra_links:entity.user_role.collection',	'entity.user_role.edit_form',	'user_role=administrator',	'a:1:{s:9:\"user_role\";s:13:\"administrator\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:2:{s:11:\"entity_type\";s:9:\"user_role\";s:9:\"entity_id\";s:13:\"administrator\";}',	1,	4,	6,	63,	246,	255,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	256,	'admin_toolbar_tools.extra_links:entity.user_role.edit_permissions_form.administrator',	'admin_toolbar_tools.extra_links:entity.user_role.edit_form.administrator',	'entity.user_role.edit_permissions_form',	'user_role=administrator',	'a:1:{s:9:\"user_role\";s:13:\"administrator\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Edit permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	63,	246,	255,	256,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	257,	'admin_toolbar_tools.extra_links:entity.user_role.delete_form.administrator',	'admin_toolbar_tools.extra_links:entity.user_role.edit_form.administrator',	'entity.user_role.delete_form',	'user_role=administrator',	'a:1:{s:9:\"user_role\";s:13:\"administrator\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	63,	246,	255,	257,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	258,	'admin_toolbar_tools.extra_links:views_ui.webform_submissions',	'entity.view.collection',	'entity.view.edit_form',	'view=webform_submissions',	'a:1:{s:4:\"view\";s:19:\"webform_submissions\";}',	'',	's:19:\"Webform submissions\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	258,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	259,	'google_analytics.admin_settings_form',	'system.admin_config_services',	'google_analytics.admin_settings_form',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:16:\"Google Analytics\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:98:\"Configure tracking behavior to get insights into your website traffic and marketing effectiveness.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'google_analytics',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	30,	259,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	260,	'admin_toolbar_tools.extra_links:views_ui.redirect',	'entity.view.collection',	'entity.view.edit_form',	'view=redirect',	'a:1:{s:4:\"view\";s:8:\"redirect\";}',	'',	's:8:\"Redirect\";',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	22,	260,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	261,	'entity.metatag_defaults.collection',	'system.admin_config_search',	'entity.metatag_defaults.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:7:\"Metatag\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"Configure Metatag defaults.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'metatag',	1,	1,	0,	0,	'a:0:{}',	1,	4,	6,	25,	42,	261,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	262,	'metatag.settings',	'entity.metatag_defaults.collection',	'metatag.settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:27:\"Configure Metatag defaults.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'metatag',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	25,	42,	261,	262,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	263,	'redirect.list',	'system.admin_config_search',	'redirect.list',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"URL redirects\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:39:\"Redirect users from one URL to another.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'redirect',	1,	1,	0,	0,	'a:0:{}',	1,	4,	6,	25,	42,	263,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	264,	'redirect.add',	'redirect.list',	'redirect.add',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:12:\"Add redirect\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'redirect',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	25,	42,	263,	264,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	265,	'redirect.settings',	'redirect.list',	'redirect.settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:8:\"Settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:37:\"Configure behavior for URL redirects.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'redirect',	1,	1,	0,	0,	'a:0:{}',	0,	5,	6,	25,	42,	263,	265,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	266,	'metatag.reports_plugins',	'system.admin_reports',	'metatag.reports_plugins',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Metatag plugins\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:36:\"Overview of plugins used in metatag.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'metatag',	1,	1,	0,	0,	'a:0:{}',	0,	3,	6,	55,	266,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	267,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_accordion',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_accordion',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_accordion\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:13:\"ebt_accordion\";}',	1,	4,	6,	11,	13,	267,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	268,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_accordion',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_accordion',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_accordion',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_accordion\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	267,	268,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	269,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_accordion',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_accordion',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_accordion',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_accordion\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	267,	269,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	270,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_accordion',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_accordion',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_accordion',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_accordion\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	267,	270,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	271,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_accordion',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_accordion',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_accordion',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_accordion\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	267,	271,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	272,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_accordion',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_accordion',	'entity.block_content_type.delete_form',	'block_content_type=ebt_accordion',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_accordion\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	267,	272,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	273,	'entity.paragraphs_type.collection',	'system.admin_structure',	'entity.paragraphs_type.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:15:\"Paragraph types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Create and manage Paragraph types.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'paragraphs',	1,	1,	0,	0,	'a:0:{}',	1,	3,	6,	11,	273,	0,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	274,	'paragraphs.type_add',	'entity.paragraphs_type.collection',	'paragraphs.type_add',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Add paragraph type\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'paragraphs',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	11,	273,	274,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	275,	'entity_reference_revisions.delete_orphans',	'system.admin_config_system',	'entity_reference_revisions.delete_orphans',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:34:\"Delete orphaned composite entities\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:90:\"Delete revisions of entities that are no longer used in Entity Reference Revisions fields.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'entity_reference_revisions',	1,	1,	0,	30,	'a:0:{}',	0,	4,	6,	25,	45,	275,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	276,	'ebt_core.settings',	'system.admin_config_content',	'ebt_core.settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:32:\"Extra Block Types (EBT) settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:71:\"Breakpoints, containers width, colors and other settings for EBT blocks\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'ebt_core',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	51,	276,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	277,	'paragraphs.settings',	'system.admin_config_content',	'paragraphs.settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Paragraphs settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'paragraphs',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	51,	277,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	278,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_accordion',	'entity.paragraphs_type.collection',	'entity.paragraphs_type.edit_form',	'paragraphs_type=ebt_accordion',	'a:1:{s:15:\"paragraphs_type\";s:13:\"ebt_accordion\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:13:\"ebt_accordion\";}',	1,	4,	6,	11,	273,	278,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	279,	'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsebt_accordion',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_accordion',	'entity.paragraph.field_ui_fields',	'paragraphs_type=ebt_accordion',	'a:1:{s:15:\"paragraphs_type\";s:13:\"ebt_accordion\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	273,	278,	279,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	280,	'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultebt_accordion',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_accordion',	'entity.entity_form_display.paragraph.default',	'paragraphs_type=ebt_accordion',	'a:1:{s:15:\"paragraphs_type\";s:13:\"ebt_accordion\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	273,	278,	280,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	281,	'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ebt_accordion',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_accordion',	'entity.entity_view_display.paragraph.default',	'paragraphs_type=ebt_accordion',	'a:1:{s:15:\"paragraphs_type\";s:13:\"ebt_accordion\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	273,	278,	281,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	282,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ebt_accordion',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_accordion',	'entity.paragraphs_type.delete_form',	'paragraphs_type=ebt_accordion',	'a:1:{s:15:\"paragraphs_type\";s:13:\"ebt_accordion\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	273,	278,	282,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	283,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_basic_button',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_basic_button',	'a:1:{s:18:\"block_content_type\";s:16:\"ebt_basic_button\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:16:\"ebt_basic_button\";}',	1,	4,	6,	11,	13,	283,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	284,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_basic_button',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_basic_button',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_basic_button',	'a:1:{s:18:\"block_content_type\";s:16:\"ebt_basic_button\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	283,	284,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	285,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_basic_button',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_basic_button',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_basic_button',	'a:1:{s:18:\"block_content_type\";s:16:\"ebt_basic_button\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	283,	285,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	286,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_basic_button',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_basic_button',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_basic_button',	'a:1:{s:18:\"block_content_type\";s:16:\"ebt_basic_button\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	283,	286,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	287,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_basic_button',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_basic_button',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_basic_button',	'a:1:{s:18:\"block_content_type\";s:16:\"ebt_basic_button\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	283,	287,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	288,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_basic_button',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_basic_button',	'entity.block_content_type.delete_form',	'block_content_type=ebt_basic_button',	'a:1:{s:18:\"block_content_type\";s:16:\"ebt_basic_button\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	283,	288,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	295,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_bootstrap_button',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_bootstrap_button',	'a:1:{s:18:\"block_content_type\";s:20:\"ebt_bootstrap_button\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:20:\"ebt_bootstrap_button\";}',	1,	4,	6,	11,	13,	295,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	296,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_bootstrap_button',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_bootstrap_button',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_bootstrap_button',	'a:1:{s:18:\"block_content_type\";s:20:\"ebt_bootstrap_button\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	295,	296,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	297,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_bootstrap_button',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_bootstrap_button',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_bootstrap_button',	'a:1:{s:18:\"block_content_type\";s:20:\"ebt_bootstrap_button\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	295,	297,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	298,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_bootstrap_button',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_bootstrap_button',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_bootstrap_button',	'a:1:{s:18:\"block_content_type\";s:20:\"ebt_bootstrap_button\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	295,	298,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	299,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_bootstrap_button',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_bootstrap_button',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_bootstrap_button',	'a:1:{s:18:\"block_content_type\";s:20:\"ebt_bootstrap_button\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	295,	299,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	300,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_bootstrap_button',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_bootstrap_button',	'entity.block_content_type.delete_form',	'block_content_type=ebt_bootstrap_button',	'a:1:{s:18:\"block_content_type\";s:20:\"ebt_bootstrap_button\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	295,	300,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	307,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_carousel',	'entity.paragraphs_type.collection',	'entity.paragraphs_type.edit_form',	'paragraphs_type=ebt_carousel',	'a:1:{s:15:\"paragraphs_type\";s:12:\"ebt_carousel\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:12:\"ebt_carousel\";}',	1,	4,	6,	11,	273,	307,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	308,	'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsebt_carousel',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_carousel',	'entity.paragraph.field_ui_fields',	'paragraphs_type=ebt_carousel',	'a:1:{s:15:\"paragraphs_type\";s:12:\"ebt_carousel\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	273,	307,	308,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	309,	'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultebt_carousel',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_carousel',	'entity.entity_form_display.paragraph.default',	'paragraphs_type=ebt_carousel',	'a:1:{s:15:\"paragraphs_type\";s:12:\"ebt_carousel\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	273,	307,	309,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	310,	'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ebt_carousel',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_carousel',	'entity.entity_view_display.paragraph.default',	'paragraphs_type=ebt_carousel',	'a:1:{s:15:\"paragraphs_type\";s:12:\"ebt_carousel\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	273,	307,	310,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	311,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ebt_carousel',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_carousel',	'entity.paragraphs_type.delete_form',	'paragraphs_type=ebt_carousel',	'a:1:{s:15:\"paragraphs_type\";s:12:\"ebt_carousel\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	273,	307,	311,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	312,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_columns',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_columns',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_columns\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:11:\"ebt_columns\";}',	1,	4,	6,	11,	13,	312,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	313,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_columns',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_columns',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_columns',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_columns\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	312,	313,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	314,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_columns',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_columns',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_columns',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_columns\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	312,	314,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	315,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_columns',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_columns',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_columns',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_columns\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	312,	315,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	316,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_columns',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_columns',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_columns',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_columns\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	312,	316,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	317,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_columns',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_columns',	'entity.block_content_type.delete_form',	'block_content_type=ebt_columns',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_columns\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	312,	317,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	318,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_countdown',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_countdown',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_countdown\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:13:\"ebt_countdown\";}',	1,	4,	6,	11,	13,	318,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	319,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_countdown',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_countdown',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_countdown',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_countdown\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	318,	319,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	320,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_countdown',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_countdown',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_countdown',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_countdown\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	318,	320,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	321,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_countdown',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_countdown',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_countdown',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_countdown\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	318,	321,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	322,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_countdown',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_countdown',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_countdown',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_countdown\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	318,	322,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	323,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_countdown',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_countdown',	'entity.block_content_type.delete_form',	'block_content_type=ebt_countdown',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_countdown\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	318,	323,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	330,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_counter_item',	'entity.paragraphs_type.collection',	'entity.paragraphs_type.edit_form',	'paragraphs_type=ebt_counter_item',	'a:1:{s:15:\"paragraphs_type\";s:16:\"ebt_counter_item\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:16:\"ebt_counter_item\";}',	1,	4,	6,	11,	273,	330,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	331,	'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsebt_counter_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_counter_item',	'entity.paragraph.field_ui_fields',	'paragraphs_type=ebt_counter_item',	'a:1:{s:15:\"paragraphs_type\";s:16:\"ebt_counter_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	273,	330,	331,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	332,	'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultebt_counter_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_counter_item',	'entity.entity_form_display.paragraph.default',	'paragraphs_type=ebt_counter_item',	'a:1:{s:15:\"paragraphs_type\";s:16:\"ebt_counter_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	273,	330,	332,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	333,	'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ebt_counter_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_counter_item',	'entity.entity_view_display.paragraph.default',	'paragraphs_type=ebt_counter_item',	'a:1:{s:15:\"paragraphs_type\";s:16:\"ebt_counter_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	273,	330,	333,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	334,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ebt_counter_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_counter_item',	'entity.paragraphs_type.delete_form',	'paragraphs_type=ebt_counter_item',	'a:1:{s:15:\"paragraphs_type\";s:16:\"ebt_counter_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	273,	330,	334,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	335,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_cta',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_cta',	'a:1:{s:18:\"block_content_type\";s:7:\"ebt_cta\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:7:\"ebt_cta\";}',	1,	4,	6,	11,	13,	335,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	336,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_cta',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_cta',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_cta',	'a:1:{s:18:\"block_content_type\";s:7:\"ebt_cta\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	335,	336,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	337,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_cta',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_cta',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_cta',	'a:1:{s:18:\"block_content_type\";s:7:\"ebt_cta\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	335,	337,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	338,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_cta',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_cta',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_cta',	'a:1:{s:18:\"block_content_type\";s:7:\"ebt_cta\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	335,	338,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	339,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_cta',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_cta',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_cta',	'a:1:{s:18:\"block_content_type\";s:7:\"ebt_cta\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	335,	339,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	340,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_cta',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_cta',	'entity.block_content_type.delete_form',	'block_content_type=ebt_cta',	'a:1:{s:18:\"block_content_type\";s:7:\"ebt_cta\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	335,	340,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	341,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_hero',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_hero',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_hero\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:8:\"ebt_hero\";}',	1,	4,	6,	11,	13,	341,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	342,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_hero',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_hero',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_hero',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_hero\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	341,	342,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	343,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_hero',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_hero',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_hero',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_hero\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	341,	343,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	344,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_hero',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_hero',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_hero',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_hero\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	341,	344,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	345,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_hero',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_hero',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_hero',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_hero\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	341,	345,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	346,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_hero',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_hero',	'entity.block_content_type.delete_form',	'block_content_type=ebt_hero',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_hero\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	341,	346,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	347,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_image',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_image\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:9:\"ebt_image\";}',	1,	4,	6,	11,	13,	347,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	348,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_image',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_image',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_image\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	347,	348,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	349,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_image',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_image',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_image\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	347,	349,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	350,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_image',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_image',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_image\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	347,	350,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	351,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_image',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_image',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_image\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	347,	351,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	352,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_image',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image',	'entity.block_content_type.delete_form',	'block_content_type=ebt_image',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_image\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	347,	352,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	353,	'glightbox.admin_settings',	'system.admin_config_media',	'glightbox.admin_settings',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"GLightbox settings\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:33:\"Configure the GLightbox settings.\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'glightbox',	1,	1,	0,	0,	'a:0:{}',	0,	4,	6,	25,	26,	353,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	354,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image_gallery',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_image_gallery',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_image_gallery\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:17:\"ebt_image_gallery\";}',	1,	4,	6,	11,	13,	354,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	355,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_image_gallery',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image_gallery',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_image_gallery',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_image_gallery\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	354,	355,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	356,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_image_gallery',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image_gallery',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_image_gallery',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_image_gallery\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	354,	356,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	357,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_image_gallery',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image_gallery',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_image_gallery',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_image_gallery\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	354,	357,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	358,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_image_gallery',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image_gallery',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_image_gallery',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_image_gallery\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	354,	358,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	359,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_image_gallery',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_image_gallery',	'entity.block_content_type.delete_form',	'block_content_type=ebt_image_gallery',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_image_gallery\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	354,	359,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	360,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_micromodal',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_micromodal',	'a:1:{s:18:\"block_content_type\";s:14:\"ebt_micromodal\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:14:\"ebt_micromodal\";}',	1,	4,	6,	11,	13,	360,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	361,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_micromodal',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_micromodal',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_micromodal',	'a:1:{s:18:\"block_content_type\";s:14:\"ebt_micromodal\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	360,	361,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	362,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_micromodal',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_micromodal',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_micromodal',	'a:1:{s:18:\"block_content_type\";s:14:\"ebt_micromodal\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	360,	362,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	363,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_micromodal',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_micromodal',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_micromodal',	'a:1:{s:18:\"block_content_type\";s:14:\"ebt_micromodal\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	360,	363,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	364,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_micromodal',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_micromodal',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_micromodal',	'a:1:{s:18:\"block_content_type\";s:14:\"ebt_micromodal\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	360,	364,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	365,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_micromodal',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_micromodal',	'entity.block_content_type.delete_form',	'block_content_type=ebt_micromodal',	'a:1:{s:18:\"block_content_type\";s:14:\"ebt_micromodal\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	360,	365,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	366,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_quote',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_quote',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_quote\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:9:\"ebt_quote\";}',	1,	4,	6,	11,	13,	366,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	367,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_quote',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_quote',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_quote',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_quote\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	366,	367,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	368,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_quote',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_quote',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_quote',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_quote\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	366,	368,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	369,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_quote',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_quote',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_quote',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_quote\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	366,	369,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	370,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_quote',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_quote',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_quote',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_quote\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	366,	370,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	371,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_quote',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_quote',	'entity.block_content_type.delete_form',	'block_content_type=ebt_quote',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_quote\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	366,	371,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	378,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_slick_slider',	'entity.paragraphs_type.collection',	'entity.paragraphs_type.edit_form',	'paragraphs_type=ebt_slick_slider',	'a:1:{s:15:\"paragraphs_type\";s:16:\"ebt_slick_slider\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:16:\"ebt_slick_slider\";}',	1,	4,	6,	11,	273,	378,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	379,	'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsebt_slick_slider',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_slick_slider',	'entity.paragraph.field_ui_fields',	'paragraphs_type=ebt_slick_slider',	'a:1:{s:15:\"paragraphs_type\";s:16:\"ebt_slick_slider\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	273,	378,	379,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	380,	'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultebt_slick_slider',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_slick_slider',	'entity.entity_form_display.paragraph.default',	'paragraphs_type=ebt_slick_slider',	'a:1:{s:15:\"paragraphs_type\";s:16:\"ebt_slick_slider\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	273,	378,	380,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	381,	'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ebt_slick_slider',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_slick_slider',	'entity.entity_view_display.paragraph.default',	'paragraphs_type=ebt_slick_slider',	'a:1:{s:15:\"paragraphs_type\";s:16:\"ebt_slick_slider\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	273,	378,	381,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	382,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ebt_slick_slider',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_slick_slider',	'entity.paragraphs_type.delete_form',	'paragraphs_type=ebt_slick_slider',	'a:1:{s:15:\"paragraphs_type\";s:16:\"ebt_slick_slider\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	273,	378,	382,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	383,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_slideshow',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_slideshow',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_slideshow\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:13:\"ebt_slideshow\";}',	1,	4,	6,	11,	13,	383,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	384,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_slideshow',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_slideshow',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_slideshow',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_slideshow\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	383,	384,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	385,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_slideshow',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_slideshow',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_slideshow',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_slideshow\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	383,	385,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	386,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_slideshow',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_slideshow',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_slideshow',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_slideshow\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	383,	386,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	387,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_slideshow',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_slideshow',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_slideshow',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_slideshow\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	383,	387,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	388,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_slideshow',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_slideshow',	'entity.block_content_type.delete_form',	'block_content_type=ebt_slideshow',	'a:1:{s:18:\"block_content_type\";s:13:\"ebt_slideshow\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	383,	388,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	389,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_slideshow',	'entity.paragraphs_type.collection',	'entity.paragraphs_type.edit_form',	'paragraphs_type=ebt_slideshow',	'a:1:{s:15:\"paragraphs_type\";s:13:\"ebt_slideshow\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:13:\"ebt_slideshow\";}',	1,	4,	6,	11,	273,	389,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	390,	'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsebt_slideshow',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_slideshow',	'entity.paragraph.field_ui_fields',	'paragraphs_type=ebt_slideshow',	'a:1:{s:15:\"paragraphs_type\";s:13:\"ebt_slideshow\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	273,	389,	390,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	391,	'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultebt_slideshow',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_slideshow',	'entity.entity_form_display.paragraph.default',	'paragraphs_type=ebt_slideshow',	'a:1:{s:15:\"paragraphs_type\";s:13:\"ebt_slideshow\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	273,	389,	391,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	392,	'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ebt_slideshow',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_slideshow',	'entity.entity_view_display.paragraph.default',	'paragraphs_type=ebt_slideshow',	'a:1:{s:15:\"paragraphs_type\";s:13:\"ebt_slideshow\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	273,	389,	392,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	393,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ebt_slideshow',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_slideshow',	'entity.paragraphs_type.delete_form',	'paragraphs_type=ebt_slideshow',	'a:1:{s:15:\"paragraphs_type\";s:13:\"ebt_slideshow\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	273,	389,	393,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	394,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_stats',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_stats',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_stats\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:9:\"ebt_stats\";}',	1,	4,	6,	11,	13,	394,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	395,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_stats',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_stats',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_stats',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_stats\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	394,	395,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	396,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_stats',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_stats',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_stats',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_stats\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	394,	396,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	397,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_stats',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_stats',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_stats',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_stats\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	394,	397,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	398,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_stats',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_stats',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_stats',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_stats\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	394,	398,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	399,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_stats',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_stats',	'entity.block_content_type.delete_form',	'block_content_type=ebt_stats',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_stats\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	394,	399,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	400,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_stats_item',	'entity.paragraphs_type.collection',	'entity.paragraphs_type.edit_form',	'paragraphs_type=ebt_stats_item',	'a:1:{s:15:\"paragraphs_type\";s:14:\"ebt_stats_item\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:14:\"ebt_stats_item\";}',	1,	4,	6,	11,	273,	400,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	401,	'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsebt_stats_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_stats_item',	'entity.paragraph.field_ui_fields',	'paragraphs_type=ebt_stats_item',	'a:1:{s:15:\"paragraphs_type\";s:14:\"ebt_stats_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	273,	400,	401,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	402,	'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultebt_stats_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_stats_item',	'entity.entity_form_display.paragraph.default',	'paragraphs_type=ebt_stats_item',	'a:1:{s:15:\"paragraphs_type\";s:14:\"ebt_stats_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	273,	400,	402,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	403,	'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ebt_stats_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_stats_item',	'entity.entity_view_display.paragraph.default',	'paragraphs_type=ebt_stats_item',	'a:1:{s:15:\"paragraphs_type\";s:14:\"ebt_stats_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	273,	400,	403,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	404,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ebt_stats_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_stats_item',	'entity.paragraphs_type.delete_form',	'paragraphs_type=ebt_stats_item',	'a:1:{s:15:\"paragraphs_type\";s:14:\"ebt_stats_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	273,	400,	404,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	411,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_tab',	'entity.paragraphs_type.collection',	'entity.paragraphs_type.edit_form',	'paragraphs_type=ebt_tab',	'a:1:{s:15:\"paragraphs_type\";s:7:\"ebt_tab\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:7:\"ebt_tab\";}',	1,	4,	6,	11,	273,	411,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	412,	'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsebt_tab',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_tab',	'entity.paragraph.field_ui_fields',	'paragraphs_type=ebt_tab',	'a:1:{s:15:\"paragraphs_type\";s:7:\"ebt_tab\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	273,	411,	412,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	413,	'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultebt_tab',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_tab',	'entity.entity_form_display.paragraph.default',	'paragraphs_type=ebt_tab',	'a:1:{s:15:\"paragraphs_type\";s:7:\"ebt_tab\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	273,	411,	413,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	414,	'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ebt_tab',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_tab',	'entity.entity_view_display.paragraph.default',	'paragraphs_type=ebt_tab',	'a:1:{s:15:\"paragraphs_type\";s:7:\"ebt_tab\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	273,	411,	414,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	415,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ebt_tab',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_tab',	'entity.paragraphs_type.delete_form',	'paragraphs_type=ebt_tab',	'a:1:{s:15:\"paragraphs_type\";s:7:\"ebt_tab\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	273,	411,	415,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	416,	'admin_toolbar_tools.extra_links:block_content_type.collection',	'entity.block_content_type.collection',	'entity.block_content_type.collection',	'',	'a:0:{}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:9:\"All types\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	-999,	'a:0:{}',	0,	4,	6,	11,	13,	416,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	417,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_text',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_text',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_text\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:8:\"ebt_text\";}',	1,	4,	6,	11,	13,	417,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	418,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_text',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_text',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_text',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_text\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	417,	418,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	419,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_text',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_text',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_text',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_text\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	417,	419,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	420,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_text',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_text',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_text',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_text\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	417,	420,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	421,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_text',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_text',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_text',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_text\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	417,	421,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	422,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_text',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_text',	'entity.block_content_type.delete_form',	'block_content_type=ebt_text',	'a:1:{s:18:\"block_content_type\";s:8:\"ebt_text\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	417,	422,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	423,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_tiles',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_tiles',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_tiles\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:9:\"ebt_tiles\";}',	1,	4,	6,	11,	13,	423,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	424,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_tiles',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_tiles',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_tiles',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_tiles\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	423,	424,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	425,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_tiles',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_tiles',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_tiles',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_tiles\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	423,	425,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	426,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_tiles',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_tiles',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_tiles',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_tiles\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	423,	426,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	427,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_tiles',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_tiles',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_tiles',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_tiles\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	423,	427,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	428,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_tiles',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_tiles',	'entity.block_content_type.delete_form',	'block_content_type=ebt_tiles',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_tiles\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	423,	428,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	429,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_tiles_item',	'entity.paragraphs_type.collection',	'entity.paragraphs_type.edit_form',	'paragraphs_type=ebt_tiles_item',	'a:1:{s:15:\"paragraphs_type\";s:14:\"ebt_tiles_item\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:14:\"ebt_tiles_item\";}',	1,	4,	6,	11,	273,	429,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	430,	'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsebt_tiles_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_tiles_item',	'entity.paragraph.field_ui_fields',	'paragraphs_type=ebt_tiles_item',	'a:1:{s:15:\"paragraphs_type\";s:14:\"ebt_tiles_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	273,	429,	430,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	431,	'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultebt_tiles_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_tiles_item',	'entity.entity_form_display.paragraph.default',	'paragraphs_type=ebt_tiles_item',	'a:1:{s:15:\"paragraphs_type\";s:14:\"ebt_tiles_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	273,	429,	431,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	432,	'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ebt_tiles_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_tiles_item',	'entity.entity_view_display.paragraph.default',	'paragraphs_type=ebt_tiles_item',	'a:1:{s:15:\"paragraphs_type\";s:14:\"ebt_tiles_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	273,	429,	432,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	433,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ebt_tiles_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_tiles_item',	'entity.paragraphs_type.delete_form',	'paragraphs_type=ebt_tiles_item',	'a:1:{s:15:\"paragraphs_type\";s:14:\"ebt_tiles_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	273,	429,	433,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	434,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_timeline',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_timeline',	'a:1:{s:18:\"block_content_type\";s:12:\"ebt_timeline\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:12:\"ebt_timeline\";}',	1,	4,	6,	11,	13,	434,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	435,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_timeline',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_timeline',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_timeline',	'a:1:{s:18:\"block_content_type\";s:12:\"ebt_timeline\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	434,	435,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	436,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_timeline',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_timeline',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_timeline',	'a:1:{s:18:\"block_content_type\";s:12:\"ebt_timeline\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	434,	436,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	437,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_timeline',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_timeline',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_timeline',	'a:1:{s:18:\"block_content_type\";s:12:\"ebt_timeline\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	434,	437,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	438,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_timeline',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_timeline',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_timeline',	'a:1:{s:18:\"block_content_type\";s:12:\"ebt_timeline\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	434,	438,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	439,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_timeline',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_timeline',	'entity.block_content_type.delete_form',	'block_content_type=ebt_timeline',	'a:1:{s:18:\"block_content_type\";s:12:\"ebt_timeline\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	434,	439,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	440,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_timeline',	'entity.paragraphs_type.collection',	'entity.paragraphs_type.edit_form',	'paragraphs_type=ebt_timeline',	'a:1:{s:15:\"paragraphs_type\";s:12:\"ebt_timeline\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:12:\"ebt_timeline\";}',	1,	4,	6,	11,	273,	440,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	441,	'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsebt_timeline',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_timeline',	'entity.paragraph.field_ui_fields',	'paragraphs_type=ebt_timeline',	'a:1:{s:15:\"paragraphs_type\";s:12:\"ebt_timeline\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	273,	440,	441,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	442,	'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultebt_timeline',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_timeline',	'entity.entity_form_display.paragraph.default',	'paragraphs_type=ebt_timeline',	'a:1:{s:15:\"paragraphs_type\";s:12:\"ebt_timeline\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	273,	440,	442,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	443,	'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ebt_timeline',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_timeline',	'entity.entity_view_display.paragraph.default',	'paragraphs_type=ebt_timeline',	'a:1:{s:15:\"paragraphs_type\";s:12:\"ebt_timeline\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	273,	440,	443,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	444,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ebt_timeline',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_timeline',	'entity.paragraphs_type.delete_form',	'paragraphs_type=ebt_timeline',	'a:1:{s:15:\"paragraphs_type\";s:12:\"ebt_timeline\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	273,	440,	444,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	445,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_video_and_image_gallery_item',	'entity.paragraphs_type.collection',	'entity.paragraphs_type.edit_form',	'paragraphs_type=ebt_video_and_image_gallery_item',	'a:1:{s:15:\"paragraphs_type\";s:32:\"ebt_video_and_image_gallery_item\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"entity_id\";s:32:\"ebt_video_and_image_gallery_item\";}',	1,	4,	6,	11,	273,	445,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	446,	'admin_toolbar_tools.extra_links:entity.paragraph.field_ui_fieldsebt_video_and_image_gallery_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_video_and_image_gallery_item',	'entity.paragraph.field_ui_fields',	'paragraphs_type=ebt_video_and_image_gallery_item',	'a:1:{s:15:\"paragraphs_type\";s:32:\"ebt_video_and_image_gallery_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	273,	445,	446,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	447,	'admin_toolbar_tools.extra_links:entity.entity_form_display.paragraph.defaultebt_video_and_image_gallery_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_video_and_image_gallery_item',	'entity.entity_form_display.paragraph.default',	'paragraphs_type=ebt_video_and_image_gallery_item',	'a:1:{s:15:\"paragraphs_type\";s:32:\"ebt_video_and_image_gallery_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	273,	445,	447,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	448,	'admin_toolbar_tools.extra_links:entity.entity_view_display.paragraph.default.ebt_video_and_image_gallery_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_video_and_image_gallery_item',	'entity.entity_view_display.paragraph.default',	'paragraphs_type=ebt_video_and_image_gallery_item',	'a:1:{s:15:\"paragraphs_type\";s:32:\"ebt_video_and_image_gallery_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	273,	445,	448,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	449,	'admin_toolbar_tools.extra_links:entity.paragraphs_type.delete_form.ebt_video_and_image_gallery_item',	'admin_toolbar_tools.extra_links:entity.paragraphs_type.edit_form.ebt_video_and_image_gallery_item',	'entity.paragraphs_type.delete_form',	'paragraphs_type=ebt_video_and_image_gallery_item',	'a:1:{s:15:\"paragraphs_type\";s:32:\"ebt_video_and_image_gallery_item\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	273,	445,	449,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	450,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_views',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_views',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_views\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:9:\"ebt_views\";}',	1,	4,	6,	11,	13,	450,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	451,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_views',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_views',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_views',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_views\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	450,	451,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	452,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_views',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_views',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_views',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_views\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	450,	452,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	453,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_views',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_views',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_views',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_views\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	450,	453,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	454,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_views',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_views',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_views',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_views\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	450,	454,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	455,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_views',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_views',	'entity.block_content_type.delete_form',	'block_content_type=ebt_views',	'a:1:{s:18:\"block_content_type\";s:9:\"ebt_views\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	450,	455,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	456,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_webform',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_webform\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:11:\"ebt_webform\";}',	1,	4,	6,	11,	13,	456,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	457,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_webform',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_webform',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_webform\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	456,	457,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	458,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_webform',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_webform',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_webform\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	456,	458,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	459,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_webform',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_webform',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_webform\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	456,	459,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	460,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_webform',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_webform',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_webform\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	456,	460,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	461,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_webform',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform',	'entity.block_content_type.delete_form',	'block_content_type=ebt_webform',	'a:1:{s:18:\"block_content_type\";s:11:\"ebt_webform\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	456,	461,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	462,	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform_popup',	'entity.block_content_type.collection',	'entity.block_content_type.edit_form',	'block_content_type=ebt_webform_popup',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_webform_popup\";}',	'',	's:0:\"\";',	's:0:\"\";',	'Drupal\\admin_toolbar_tools\\Plugin\\Menu\\MenuLinkEntity',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	0,	'a:2:{s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"entity_id\";s:17:\"ebt_webform_popup\";}',	1,	4,	6,	11,	13,	462,	0,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	463,	'admin_toolbar_tools.extra_links:entity.block_content.field_ui_fieldsebt_webform_popup',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform_popup',	'entity.block_content.field_ui_fields',	'block_content_type=ebt_webform_popup',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_webform_popup\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:13:\"Manage fields\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	1,	'a:0:{}',	0,	5,	6,	11,	13,	462,	463,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	464,	'admin_toolbar_tools.extra_links:entity.entity_form_display.block_content.defaultebt_webform_popup',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform_popup',	'entity.entity_form_display.block_content.default',	'block_content_type=ebt_webform_popup',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_webform_popup\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:19:\"Manage form display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	2,	'a:0:{}',	0,	5,	6,	11,	13,	462,	464,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	465,	'admin_toolbar_tools.extra_links:entity.entity_view_display.block_content.default.ebt_webform_popup',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform_popup',	'entity.entity_view_display.block_content.default',	'block_content_type=ebt_webform_popup',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_webform_popup\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:14:\"Manage display\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	462,	465,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	466,	'admin_toolbar_tools.extra_links:entity.entity_permissions_form.block_content.default.ebt_webform_popup',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform_popup',	'entity.block_content_type.entity_permissions_form',	'block_content_type=ebt_webform_popup',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_webform_popup\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:18:\"Manage permissions\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	3,	'a:0:{}',	0,	5,	6,	11,	13,	462,	466,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm'),
('admin',	467,	'admin_toolbar_tools.extra_links:entity.block_content_type.delete_form.ebt_webform_popup',	'admin_toolbar_tools.extra_links:entity.block_content_type.edit_form.ebt_webform_popup',	'entity.block_content_type.delete_form',	'block_content_type=ebt_webform_popup',	'a:1:{s:18:\"block_content_type\";s:17:\"ebt_webform_popup\";}',	'',	'O:48:\"Drupal\\Core\\StringTranslation\\TranslatableMarkup\":3:{s:9:\"\0*\0string\";s:6:\"Delete\";s:12:\"\0*\0arguments\";a:0:{}s:10:\"\0*\0options\";a:0:{}}',	's:0:\"\";',	'Drupal\\Core\\Menu\\MenuLinkDefault',	'a:0:{}',	'admin_toolbar_tools',	1,	1,	0,	5,	'a:0:{}',	0,	5,	6,	11,	13,	462,	467,	0,	0,	0,	0,	'Drupal\\Core\\Menu\\Form\\MenuLinkDefaultForm');

DROP TABLE IF EXISTS `node`;
CREATE TABLE `node` (
  `nid` int unsigned NOT NULL AUTO_INCREMENT,
  `vid` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`nid`),
  UNIQUE KEY `node_field__uuid__value` (`uuid`),
  UNIQUE KEY `node__vid` (`vid`),
  KEY `node_field__type__target_id` (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for node entities.';

INSERT INTO `node` (`nid`, `vid`, `type`, `uuid`, `langcode`) VALUES
(1,	2,	'page',	'5c1da460-38b3-4999-8a6c-61827d6efcda',	'en');

DROP TABLE IF EXISTS `node__body`;
CREATE TABLE `node__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field body.';

INSERT INTO `node__body` (`bundle`, `deleted`, `entity_id`, `revision_id`, `langcode`, `delta`, `body_value`, `body_summary`, `body_format`) VALUES
('page',	0,	1,	2,	'en',	0,	'<p>Test</p>',	'',	'basic_html');

DROP TABLE IF EXISTS `node__field_image`;
CREATE TABLE `node__field_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_image_target_id` (`field_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field field_image.';


DROP TABLE IF EXISTS `node__field_metatags`;
CREATE TABLE `node__field_metatags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_metatags_value` longtext NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field field_metatags.';


DROP TABLE IF EXISTS `node__field_tags`;
CREATE TABLE `node__field_tags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_tags_target_id` (`field_tags_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field field_tags.';


DROP TABLE IF EXISTS `node__layout_builder__layout`;
CREATE TABLE `node__layout_builder__layout` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `layout_builder__layout_section` blob,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for node field layout_builder__layout.';


DROP TABLE IF EXISTS `node_access`;
CREATE TABLE `node_access` (
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid this record affects.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "language".langcode of this node.',
  `fallback` tinyint unsigned NOT NULL DEFAULT '1' COMMENT 'Boolean indicating whether this record should be used as a fallback if a language condition is not provided.',
  `gid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The grant ID a user must possess in the specified realm to gain this row''s privileges on the node.',
  `realm` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The realm in which the user must possess the grant ID. Modules can define one or more realms by implementing hook_node_grants().',
  `grant_view` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can view this node.',
  `grant_update` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can edit this node.',
  `grant_delete` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'Boolean indicating whether a user with the realm/grant pair can delete this node.',
  PRIMARY KEY (`nid`,`gid`,`realm`,`langcode`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Identifies which realm/grant pairs a user must possess in…';

INSERT INTO `node_access` (`nid`, `langcode`, `fallback`, `gid`, `realm`, `grant_view`, `grant_update`, `grant_delete`) VALUES
(0,	'',	1,	0,	'all',	1,	0,	0);

DROP TABLE IF EXISTS `node_field_data`;
CREATE TABLE `node_field_data` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `title` varchar(255) NOT NULL,
  `created` int NOT NULL,
  `changed` int NOT NULL,
  `promote` tinyint NOT NULL,
  `sticky` tinyint NOT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`nid`,`langcode`),
  KEY `node__id__default_langcode__langcode` (`nid`,`default_langcode`,`langcode`),
  KEY `node__vid` (`vid`),
  KEY `node_field__type__target_id` (`type`),
  KEY `node_field__uid__target_id` (`uid`),
  KEY `node_field__created` (`created`),
  KEY `node_field__changed` (`changed`),
  KEY `node__status_type` (`status`,`type`,`nid`),
  KEY `node__frontpage` (`promote`,`status`,`sticky`,`created`),
  KEY `node__title_type` (`title`(191),`type`(4))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for node entities.';

INSERT INTO `node_field_data` (`nid`, `vid`, `type`, `langcode`, `status`, `uid`, `title`, `created`, `changed`, `promote`, `sticky`, `default_langcode`, `revision_translation_affected`) VALUES
(1,	2,	'page',	'en',	1,	1,	'Langing page',	1722237400,	1722237475,	0,	0,	1,	1);

DROP TABLE IF EXISTS `node_field_revision`;
CREATE TABLE `node_field_revision` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `uid` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  `title` varchar(255) DEFAULT NULL,
  `created` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `promote` tinyint DEFAULT NULL,
  `sticky` tinyint DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`,`langcode`),
  KEY `node__id__default_langcode__langcode` (`nid`,`default_langcode`,`langcode`),
  KEY `node_field__uid__target_id` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for node entities.';

INSERT INTO `node_field_revision` (`nid`, `vid`, `langcode`, `status`, `uid`, `title`, `created`, `changed`, `promote`, `sticky`, `default_langcode`, `revision_translation_affected`) VALUES
(1,	1,	'en',	1,	1,	'Langing page',	1722237400,	1722237452,	0,	0,	1,	1),
(1,	2,	'en',	1,	1,	'Langing page',	1722237400,	1722237475,	0,	0,	1,	1);

DROP TABLE IF EXISTS `node_revision`;
CREATE TABLE `node_revision` (
  `nid` int unsigned NOT NULL,
  `vid` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_timestamp` int DEFAULT NULL,
  `revision_log` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`vid`),
  KEY `node__nid` (`nid`),
  KEY `node_field__langcode` (`langcode`),
  KEY `node_field__revision_uid__target_id` (`revision_uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for node entities.';

INSERT INTO `node_revision` (`nid`, `vid`, `langcode`, `revision_uid`, `revision_timestamp`, `revision_log`, `revision_default`) VALUES
(1,	1,	'en',	1,	1722237452,	NULL,	1),
(1,	2,	'en',	1,	1722237475,	NULL,	1);

DROP TABLE IF EXISTS `node_revision__body`;
CREATE TABLE `node_revision__body` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `body_value` longtext NOT NULL,
  `body_summary` longtext,
  `body_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `body_format` (`body_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field body.';

INSERT INTO `node_revision__body` (`bundle`, `deleted`, `entity_id`, `revision_id`, `langcode`, `delta`, `body_value`, `body_summary`, `body_format`) VALUES
('page',	0,	1,	2,	'en',	0,	'<p>Test</p>',	'',	'basic_html');

DROP TABLE IF EXISTS `node_revision__field_image`;
CREATE TABLE `node_revision__field_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `field_image_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `field_image_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `field_image_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `field_image_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_image_target_id` (`field_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field field_image.';


DROP TABLE IF EXISTS `node_revision__field_metatags`;
CREATE TABLE `node_revision__field_metatags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_metatags_value` longtext NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field field_metatags.';


DROP TABLE IF EXISTS `node_revision__field_tags`;
CREATE TABLE `node_revision__field_tags` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_tags_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_tags_target_id` (`field_tags_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field field_tags.';


DROP TABLE IF EXISTS `node_revision__layout_builder__layout`;
CREATE TABLE `node_revision__layout_builder__layout` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `layout_builder__layout_section` blob,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for node field layout_builder_…';


DROP TABLE IF EXISTS `paragraph__field_ebt_accordion_text`;
CREATE TABLE `paragraph__field_ebt_accordion_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_accordion_text_value` longtext NOT NULL,
  `field_ebt_accordion_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_accordion_text_format` (`field_ebt_accordion_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_accordion_text.';


DROP TABLE IF EXISTS `paragraph__field_ebt_accordion_title`;
CREATE TABLE `paragraph__field_ebt_accordion_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_accordion_title_value` longtext NOT NULL,
  `field_ebt_accordion_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_accordion_title_format` (`field_ebt_accordion_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_accordion_title.';


DROP TABLE IF EXISTS `paragraph__field_ebt_carousel_caption`;
CREATE TABLE `paragraph__field_ebt_carousel_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_carousel_caption_value` longtext NOT NULL,
  `field_ebt_carousel_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_carousel_caption_format` (`field_ebt_carousel_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_carousel_caption.';


DROP TABLE IF EXISTS `paragraph__field_ebt_carousel_image`;
CREATE TABLE `paragraph__field_ebt_carousel_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_carousel_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_carousel_image_target_id` (`field_ebt_carousel_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_carousel_image.';


DROP TABLE IF EXISTS `paragraph__field_ebt_clickable_tile`;
CREATE TABLE `paragraph__field_ebt_clickable_tile` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_clickable_tile_value` tinyint NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_clickable_tile.';


DROP TABLE IF EXISTS `paragraph__field_ebt_counter_description`;
CREATE TABLE `paragraph__field_ebt_counter_description` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_description_value` longtext NOT NULL,
  `field_ebt_counter_description_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_counter_description_format` (`field_ebt_counter_description_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_counter…';


DROP TABLE IF EXISTS `paragraph__field_ebt_counter_icon`;
CREATE TABLE `paragraph__field_ebt_counter_icon` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_icon_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_counter_icon_target_id` (`field_ebt_counter_icon_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_counter_icon.';


DROP TABLE IF EXISTS `paragraph__field_ebt_counter_number`;
CREATE TABLE `paragraph__field_ebt_counter_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_number_value` int NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_counter_number.';


DROP TABLE IF EXISTS `paragraph__field_ebt_counter_title`;
CREATE TABLE `paragraph__field_ebt_counter_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_title_value` longtext NOT NULL,
  `field_ebt_counter_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_counter_title_format` (`field_ebt_counter_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_counter_title.';


DROP TABLE IF EXISTS `paragraph__field_ebt_slick_slider_image`;
CREATE TABLE `paragraph__field_ebt_slick_slider_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slick_slider_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slick_slider_image_target_id` (`field_ebt_slick_slider_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_slick_slider…';


DROP TABLE IF EXISTS `paragraph__field_ebt_slick_slider_link`;
CREATE TABLE `paragraph__field_ebt_slick_slider_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slick_slider_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_slick_slider_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_slick_slider_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slick_slider_link_uri` (`field_ebt_slick_slider_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_slick_slider…';


DROP TABLE IF EXISTS `paragraph__field_ebt_slick_slider_text`;
CREATE TABLE `paragraph__field_ebt_slick_slider_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slick_slider_text_value` longtext NOT NULL,
  `field_ebt_slick_slider_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slick_slider_text_format` (`field_ebt_slick_slider_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_slick_slider…';


DROP TABLE IF EXISTS `paragraph__field_ebt_slideshow_link`;
CREATE TABLE `paragraph__field_ebt_slideshow_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slideshow_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_slideshow_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_slideshow_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slideshow_link_uri` (`field_ebt_slideshow_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_slideshow_link.';


DROP TABLE IF EXISTS `paragraph__field_ebt_slideshow_slide`;
CREATE TABLE `paragraph__field_ebt_slideshow_slide` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slideshow_slide_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slideshow_slide_target_id` (`field_ebt_slideshow_slide_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_slideshow_slide.';


DROP TABLE IF EXISTS `paragraph__field_ebt_slideshow_text`;
CREATE TABLE `paragraph__field_ebt_slideshow_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slideshow_text_value` longtext NOT NULL,
  `field_ebt_slideshow_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slideshow_text_format` (`field_ebt_slideshow_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_slideshow_text.';


DROP TABLE IF EXISTS `paragraph__field_ebt_slideshow_title`;
CREATE TABLE `paragraph__field_ebt_slideshow_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slideshow_title_value` longtext NOT NULL,
  `field_ebt_slideshow_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slideshow_title_format` (`field_ebt_slideshow_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_slideshow_title.';


DROP TABLE IF EXISTS `paragraph__field_ebt_tab_block`;
CREATE TABLE `paragraph__field_ebt_tab_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ebt_tab_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_block_plugin_id` (`field_ebt_tab_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_tab_block.';


DROP TABLE IF EXISTS `paragraph__field_ebt_tab_content`;
CREATE TABLE `paragraph__field_ebt_tab_content` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_content_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_content_value` (`field_ebt_tab_content_value`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_tab_content.';


DROP TABLE IF EXISTS `paragraph__field_ebt_tab_page`;
CREATE TABLE `paragraph__field_ebt_tab_page` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_page_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_page_target_id` (`field_ebt_tab_page_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_tab_page.';


DROP TABLE IF EXISTS `paragraph__field_ebt_tab_text`;
CREATE TABLE `paragraph__field_ebt_tab_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_text_value` longtext NOT NULL,
  `field_ebt_tab_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_text_format` (`field_ebt_tab_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_tab_text.';


DROP TABLE IF EXISTS `paragraph__field_ebt_tab_title`;
CREATE TABLE `paragraph__field_ebt_tab_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_title_value` varchar(1023) NOT NULL,
  `field_ebt_tab_title_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_title_format` (`field_ebt_tab_title_format`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_tab_title.';


DROP TABLE IF EXISTS `paragraph__field_ebt_tab_views`;
CREATE TABLE `paragraph__field_ebt_tab_views` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_views_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_tab_views_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ebt_tab_views_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_views_target_id` (`field_ebt_tab_views_target_id`),
  KEY `field_ebt_tab_views_display_id` (`field_ebt_tab_views_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_tab_views.';


DROP TABLE IF EXISTS `paragraph__field_ebt_tiles_image`;
CREATE TABLE `paragraph__field_ebt_tiles_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tiles_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tiles_image_target_id` (`field_ebt_tiles_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_tiles_image.';


DROP TABLE IF EXISTS `paragraph__field_ebt_tiles_link`;
CREATE TABLE `paragraph__field_ebt_tiles_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tiles_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_tiles_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_tiles_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tiles_link_uri` (`field_ebt_tiles_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_tiles_link.';


DROP TABLE IF EXISTS `paragraph__field_ebt_tiles_text`;
CREATE TABLE `paragraph__field_ebt_tiles_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tiles_text_value` longtext NOT NULL,
  `field_ebt_tiles_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tiles_text_format` (`field_ebt_tiles_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_tiles_text.';


DROP TABLE IF EXISTS `paragraph__field_ebt_tiles_title`;
CREATE TABLE `paragraph__field_ebt_tiles_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tiles_title_value` longtext NOT NULL,
  `field_ebt_tiles_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tiles_title_format` (`field_ebt_tiles_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_tiles_title.';


DROP TABLE IF EXISTS `paragraph__field_ebt_timeline_current`;
CREATE TABLE `paragraph__field_ebt_timeline_current` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_current_value` tinyint NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_timeline_current.';


DROP TABLE IF EXISTS `paragraph__field_ebt_timeline_date`;
CREATE TABLE `paragraph__field_ebt_timeline_date` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_date_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_timeline_date.';


DROP TABLE IF EXISTS `paragraph__field_ebt_timeline_media_image`;
CREATE TABLE `paragraph__field_ebt_timeline_media_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_media_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_timeline_media_image_target_id` (`field_ebt_timeline_media_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_timeline_media…';


DROP TABLE IF EXISTS `paragraph__field_ebt_timeline_text`;
CREATE TABLE `paragraph__field_ebt_timeline_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_text_value` longtext NOT NULL,
  `field_ebt_timeline_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_timeline_text_format` (`field_ebt_timeline_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_timeline_text.';


DROP TABLE IF EXISTS `paragraph__field_ebt_timeline_title`;
CREATE TABLE `paragraph__field_ebt_timeline_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_title_value` varchar(512) NOT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_ebt_timeline_title.';


DROP TABLE IF EXISTS `paragraph__field_gallery_item_description`;
CREATE TABLE `paragraph__field_gallery_item_description` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_gallery_item_description_value` longtext NOT NULL,
  `field_gallery_item_description_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_gallery_item_description_format` (`field_gallery_item_description_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_gallery_item…';


DROP TABLE IF EXISTS `paragraph__field_stats_item_image`;
CREATE TABLE `paragraph__field_stats_item_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_stats_item_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_stats_item_image_target_id` (`field_stats_item_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_stats_item_image.';


DROP TABLE IF EXISTS `paragraph__field_stats_item_link`;
CREATE TABLE `paragraph__field_stats_item_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_stats_item_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_stats_item_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_stats_item_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_stats_item_link_uri` (`field_stats_item_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_stats_item_link.';


DROP TABLE IF EXISTS `paragraph__field_stats_item_number`;
CREATE TABLE `paragraph__field_stats_item_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_stats_item_number_value` longtext NOT NULL,
  `field_stats_item_number_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_stats_item_number_format` (`field_stats_item_number_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_stats_item_number.';


DROP TABLE IF EXISTS `paragraph__field_stats_item_text`;
CREATE TABLE `paragraph__field_stats_item_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_stats_item_text_value` longtext NOT NULL,
  `field_stats_item_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_stats_item_text_format` (`field_stats_item_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_stats_item_text.';


DROP TABLE IF EXISTS `paragraph__field_video_gallery_item`;
CREATE TABLE `paragraph__field_video_gallery_item` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_video_gallery_item_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_video_gallery_item_target_id` (`field_video_gallery_item_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for paragraph field field_video_gallery_item.';


DROP TABLE IF EXISTS `paragraph_r__183d076c00`;
CREATE TABLE `paragraph_r__183d076c00` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_media_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_timeline_media_image_target_id` (`field_ebt_timeline_media_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_r__39b26fa753`;
CREATE TABLE `paragraph_r__39b26fa753` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_gallery_item_description_value` longtext NOT NULL,
  `field_gallery_item_description_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_gallery_item_description_format` (`field_gallery_item_description_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_gallery…';


DROP TABLE IF EXISTS `paragraph_r__b013e92862`;
CREATE TABLE `paragraph_r__b013e92862` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_description_value` longtext NOT NULL,
  `field_ebt_counter_description_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_counter_description_format` (`field_ebt_counter_description_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_accordion_text`;
CREATE TABLE `paragraph_revision__field_ebt_accordion_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_accordion_text_value` longtext NOT NULL,
  `field_ebt_accordion_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_accordion_text_format` (`field_ebt_accordion_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_accordion_title`;
CREATE TABLE `paragraph_revision__field_ebt_accordion_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_accordion_title_value` longtext NOT NULL,
  `field_ebt_accordion_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_accordion_title_format` (`field_ebt_accordion_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_carousel_caption`;
CREATE TABLE `paragraph_revision__field_ebt_carousel_caption` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_carousel_caption_value` longtext NOT NULL,
  `field_ebt_carousel_caption_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_carousel_caption_format` (`field_ebt_carousel_caption_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_carousel_image`;
CREATE TABLE `paragraph_revision__field_ebt_carousel_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_carousel_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_carousel_image_target_id` (`field_ebt_carousel_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_clickable_tile`;
CREATE TABLE `paragraph_revision__field_ebt_clickable_tile` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_clickable_tile_value` tinyint NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_counter_icon`;
CREATE TABLE `paragraph_revision__field_ebt_counter_icon` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_icon_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_counter_icon_target_id` (`field_ebt_counter_icon_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_counter_number`;
CREATE TABLE `paragraph_revision__field_ebt_counter_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_number_value` int NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_counter_title`;
CREATE TABLE `paragraph_revision__field_ebt_counter_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_counter_title_value` longtext NOT NULL,
  `field_ebt_counter_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_counter_title_format` (`field_ebt_counter_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_slick_slider_image`;
CREATE TABLE `paragraph_revision__field_ebt_slick_slider_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slick_slider_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slick_slider_image_target_id` (`field_ebt_slick_slider_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_slick_slider_link`;
CREATE TABLE `paragraph_revision__field_ebt_slick_slider_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slick_slider_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_slick_slider_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_slick_slider_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slick_slider_link_uri` (`field_ebt_slick_slider_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_slick_slider_text`;
CREATE TABLE `paragraph_revision__field_ebt_slick_slider_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slick_slider_text_value` longtext NOT NULL,
  `field_ebt_slick_slider_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slick_slider_text_format` (`field_ebt_slick_slider_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_slideshow_link`;
CREATE TABLE `paragraph_revision__field_ebt_slideshow_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slideshow_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_slideshow_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_slideshow_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slideshow_link_uri` (`field_ebt_slideshow_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_slideshow_slide`;
CREATE TABLE `paragraph_revision__field_ebt_slideshow_slide` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slideshow_slide_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slideshow_slide_target_id` (`field_ebt_slideshow_slide_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_slideshow_text`;
CREATE TABLE `paragraph_revision__field_ebt_slideshow_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slideshow_text_value` longtext NOT NULL,
  `field_ebt_slideshow_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slideshow_text_format` (`field_ebt_slideshow_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_slideshow_title`;
CREATE TABLE `paragraph_revision__field_ebt_slideshow_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_slideshow_title_value` longtext NOT NULL,
  `field_ebt_slideshow_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_slideshow_title_format` (`field_ebt_slideshow_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_tab_block`;
CREATE TABLE `paragraph_revision__field_ebt_tab_block` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_block_plugin_id` varchar(255) NOT NULL COMMENT 'The block plugin id',
  `field_ebt_tab_block_settings` longblob COMMENT 'Serialized array of settings for the block.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_block_plugin_id` (`field_ebt_tab_block_plugin_id`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt_tab…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_tab_content`;
CREATE TABLE `paragraph_revision__field_ebt_tab_content` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_content_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_content_value` (`field_ebt_tab_content_value`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt_tab…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_tab_page`;
CREATE TABLE `paragraph_revision__field_ebt_tab_page` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_page_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_page_target_id` (`field_ebt_tab_page_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt_tab…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_tab_text`;
CREATE TABLE `paragraph_revision__field_ebt_tab_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_text_value` longtext NOT NULL,
  `field_ebt_tab_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_text_format` (`field_ebt_tab_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt_tab…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_tab_title`;
CREATE TABLE `paragraph_revision__field_ebt_tab_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_title_value` varchar(1023) NOT NULL,
  `field_ebt_tab_title_format` varchar(255) DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_title_format` (`field_ebt_tab_title_format`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt_tab…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_tab_views`;
CREATE TABLE `paragraph_revision__field_ebt_tab_views` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tab_views_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `field_ebt_tab_views_display_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL COMMENT 'The ID of the display.',
  `field_ebt_tab_views_data` longtext COMMENT 'Serialized data.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tab_views_target_id` (`field_ebt_tab_views_target_id`),
  KEY `field_ebt_tab_views_display_id` (`field_ebt_tab_views_display_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt_tab…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_tiles_image`;
CREATE TABLE `paragraph_revision__field_ebt_tiles_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tiles_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tiles_image_target_id` (`field_ebt_tiles_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_tiles_link`;
CREATE TABLE `paragraph_revision__field_ebt_tiles_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tiles_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_ebt_tiles_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_ebt_tiles_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tiles_link_uri` (`field_ebt_tiles_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_tiles_text`;
CREATE TABLE `paragraph_revision__field_ebt_tiles_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tiles_text_value` longtext NOT NULL,
  `field_ebt_tiles_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tiles_text_format` (`field_ebt_tiles_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_tiles_title`;
CREATE TABLE `paragraph_revision__field_ebt_tiles_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_tiles_title_value` longtext NOT NULL,
  `field_ebt_tiles_title_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_tiles_title_format` (`field_ebt_tiles_title_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_timeline_current`;
CREATE TABLE `paragraph_revision__field_ebt_timeline_current` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_current_value` tinyint NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_timeline_date`;
CREATE TABLE `paragraph_revision__field_ebt_timeline_date` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_date_value` varchar(255) NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_timeline_text`;
CREATE TABLE `paragraph_revision__field_ebt_timeline_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_text_value` longtext NOT NULL,
  `field_ebt_timeline_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_ebt_timeline_text_format` (`field_ebt_timeline_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_ebt_timeline_title`;
CREATE TABLE `paragraph_revision__field_ebt_timeline_title` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_ebt_timeline_title_value` varchar(512) NOT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_ebt…';


DROP TABLE IF EXISTS `paragraph_revision__field_stats_item_image`;
CREATE TABLE `paragraph_revision__field_stats_item_image` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_stats_item_image_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_stats_item_image_target_id` (`field_stats_item_image_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_stats…';


DROP TABLE IF EXISTS `paragraph_revision__field_stats_item_link`;
CREATE TABLE `paragraph_revision__field_stats_item_link` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_stats_item_link_uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `field_stats_item_link_title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `field_stats_item_link_options` longblob COMMENT 'Serialized array of options for the link.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_stats_item_link_uri` (`field_stats_item_link_uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_stats…';


DROP TABLE IF EXISTS `paragraph_revision__field_stats_item_number`;
CREATE TABLE `paragraph_revision__field_stats_item_number` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_stats_item_number_value` longtext NOT NULL,
  `field_stats_item_number_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_stats_item_number_format` (`field_stats_item_number_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_stats…';


DROP TABLE IF EXISTS `paragraph_revision__field_stats_item_text`;
CREATE TABLE `paragraph_revision__field_stats_item_text` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_stats_item_text_value` longtext NOT NULL,
  `field_stats_item_text_format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_stats_item_text_format` (`field_stats_item_text_format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_stats…';


DROP TABLE IF EXISTS `paragraph_revision__field_video_gallery_item`;
CREATE TABLE `paragraph_revision__field_video_gallery_item` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `field_video_gallery_item_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `field_video_gallery_item_target_id` (`field_video_gallery_item_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for paragraph field field_video…';


DROP TABLE IF EXISTS `paragraphs_item`;
CREATE TABLE `paragraphs_item` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `paragraph_field__uuid__value` (`uuid`),
  UNIQUE KEY `paragraph__revision_id` (`revision_id`),
  KEY `paragraph_field__type__target_id` (`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for paragraph entities.';


DROP TABLE IF EXISTS `paragraphs_item_field_data`;
CREATE TABLE `paragraphs_item_field_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `created` int DEFAULT NULL,
  `parent_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `behavior_settings` longtext,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `paragraph__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `paragraph__revision_id` (`revision_id`),
  KEY `paragraph_field__type__target_id` (`type`),
  KEY `paragraph__status_type` (`status`,`type`,`id`),
  KEY `paragraphs__parent_fields` (`parent_type`,`parent_id`,`parent_field_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for paragraph entities.';


DROP TABLE IF EXISTS `paragraphs_item_revision`;
CREATE TABLE `paragraphs_item_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `paragraph__id` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for paragraph entities.';


DROP TABLE IF EXISTS `paragraphs_item_revision_field_data`;
CREATE TABLE `paragraphs_item_revision_field_data` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `created` int DEFAULT NULL,
  `parent_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `parent_field_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `behavior_settings` longtext,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `paragraph__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `paragraphs__parent_fields` (`parent_type`,`parent_id`,`parent_field_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for paragraph entities.';


DROP TABLE IF EXISTS `path_alias`;
CREATE TABLE `path_alias` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `path` varchar(255) DEFAULT NULL,
  `alias` varchar(255) DEFAULT NULL,
  `status` tinyint NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `path_alias_field__uuid__value` (`uuid`),
  UNIQUE KEY `path_alias__revision_id` (`revision_id`),
  KEY `path_alias__alias_langcode_id_status` (`alias`(191),`langcode`,`id`,`status`),
  KEY `path_alias__path_langcode_id_status` (`path`(191),`langcode`,`id`,`status`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for path_alias entities.';

INSERT INTO `path_alias` (`id`, `revision_id`, `uuid`, `langcode`, `path`, `alias`, `status`) VALUES
(1,	1,	'1236236c-1a43-49bd-a1b8-72a697480837',	'en',	'/webform/contact',	'/form/contact',	1),
(2,	2,	'4d27799e-3a78-41ad-84f7-ae81be974d36',	'und',	'/webform/contact',	'/form/contact',	1),
(3,	3,	'1c5cd2ce-ce36-4baf-a703-4f0a484b71b4',	'en',	'/webform/contact/confirmation',	'/form/contact/confirmation',	1),
(4,	4,	'9f0f54d3-8f69-48df-a235-9fb10ab164c9',	'und',	'/webform/contact/confirmation',	'/form/contact/confirmation',	1),
(5,	5,	'376b5ade-36a5-4af4-aa09-fd3d0c09389d',	'en',	'/webform/contact/submissions',	'/form/contact/submissions',	1),
(6,	6,	'3e49669e-36cf-429f-ad93-90988a662d91',	'und',	'/webform/contact/submissions',	'/form/contact/submissions',	1),
(7,	7,	'9019f98f-c53d-4862-90a2-bd2979de6609',	'en',	'/webform/contact/drafts',	'/form/contact/drafts',	1),
(8,	8,	'280630e4-307d-4a41-81f0-a48c9133ac81',	'und',	'/webform/contact/drafts',	'/form/contact/drafts',	1);

DROP TABLE IF EXISTS `path_alias_revision`;
CREATE TABLE `path_alias_revision` (
  `id` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `path` varchar(255) DEFAULT NULL,
  `alias` varchar(255) DEFAULT NULL,
  `status` tinyint NOT NULL,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `path_alias__id` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for path_alias entities.';

INSERT INTO `path_alias_revision` (`id`, `revision_id`, `langcode`, `path`, `alias`, `status`, `revision_default`) VALUES
(1,	1,	'en',	'/webform/contact',	'/form/contact',	1,	1),
(2,	2,	'und',	'/webform/contact',	'/form/contact',	1,	1),
(3,	3,	'en',	'/webform/contact/confirmation',	'/form/contact/confirmation',	1,	1),
(4,	4,	'und',	'/webform/contact/confirmation',	'/form/contact/confirmation',	1,	1),
(5,	5,	'en',	'/webform/contact/submissions',	'/form/contact/submissions',	1,	1),
(6,	6,	'und',	'/webform/contact/submissions',	'/form/contact/submissions',	1,	1),
(7,	7,	'en',	'/webform/contact/drafts',	'/form/contact/drafts',	1,	1),
(8,	8,	'und',	'/webform/contact/drafts',	'/form/contact/drafts',	1,	1);

DROP TABLE IF EXISTS `queue`;
CREATE TABLE `queue` (
  `item_id` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique item ID.',
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The queue name.',
  `data` longblob COMMENT 'The arbitrary data for the item.',
  `expire` bigint NOT NULL DEFAULT '0' COMMENT 'Timestamp when the claim lease expires on the item.',
  `created` bigint NOT NULL DEFAULT '0' COMMENT 'Timestamp when the item was created.',
  PRIMARY KEY (`item_id`),
  KEY `name_created` (`name`,`created`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores items in queues.';


DROP TABLE IF EXISTS `redirect`;
CREATE TABLE `redirect` (
  `rid` int NOT NULL AUTO_INCREMENT,
  `type` varchar(255) NOT NULL,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `language` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `hash` varchar(64) DEFAULT NULL,
  `uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `redirect_source__path` varchar(2048) DEFAULT NULL COMMENT 'The source path',
  `redirect_source__query` longblob COMMENT 'Serialized array of path queries',
  `redirect_redirect__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `redirect_redirect__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `redirect_redirect__options` longblob COMMENT 'Serialized array of options for the link.',
  `status_code` int DEFAULT NULL,
  `created` int DEFAULT NULL,
  PRIMARY KEY (`rid`),
  UNIQUE KEY `redirect_field__uuid__value` (`uuid`),
  UNIQUE KEY `hash` (`hash`),
  KEY `redirect_field__uid__target_id` (`uid`),
  KEY `redirect_field__redirect_source__path` (`redirect_source__path`(50)),
  KEY `redirect_field__redirect_redirect__uri` (`redirect_redirect__uri`(30)),
  KEY `source_language` (`redirect_source__path`(191),`language`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for redirect entities.';


DROP TABLE IF EXISTS `router`;
CREATE TABLE `router` (
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Machine name of this route',
  `path` varchar(255) NOT NULL DEFAULT '' COMMENT 'The path for this URI',
  `pattern_outline` varchar(255) NOT NULL DEFAULT '' COMMENT 'The pattern',
  `fit` int NOT NULL DEFAULT '0' COMMENT 'A numeric representation of how specific the path is.',
  `route` longblob COMMENT 'A serialized Route object',
  `number_parts` smallint NOT NULL DEFAULT '0' COMMENT 'Number of parts in this router path.',
  PRIMARY KEY (`name`),
  KEY `pattern_outline_parts` (`pattern_outline`(191),`number_parts`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maps paths to various callbacks (access, page and title)';

INSERT INTO `router` (`name`, `path`, `pattern_outline`, `fit`, `route`, `number_parts`) VALUES
('<button>',	'/',	'/',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',	1),
('<current>',	'/<current>',	'/<current>',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/<current>\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:0:{}s:7:\"options\";a:2:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/\\<current\\>$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/<current>\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:10:\"/<current>\";s:8:\"numParts\";i:1;}}',	1),
('<front>',	'/',	'/',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:6:\"_title\";s:4:\"Home\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',	1),
('<nolink>',	'/',	'/',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',	1),
('<none>',	'/',	'/',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:1:\"/\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:0:{}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"_no_path\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:8:\"{^/$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:1:\"/\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:1:\"/\";s:8:\"numParts\";i:1;}}',	1),
('admin_toolbar.run.cron',	'/run-cron',	'/run-cron',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:9:\"/run-cron\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:65:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::runCron\";s:6:\"_title\";s:8:\"Run cron\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/run\\-cron$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/run-cron\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:9:\"/run-cron\";s:8:\"numParts\";i:1;}}',	1),
('admin_toolbar.settings',	'/admin/config/user-interface/admin-toolbar',	'/admin/config/user-interface/admin-toolbar',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/config/user-interface/admin-toolbar\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\admin_toolbar\\Form\\AdminToolbarSettingsForm\";s:6:\"_title\";s:22:\"Admin Toolbar settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/config/user\\-interface/admin\\-toolbar$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/admin-toolbar\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:42:\"/admin/config/user-interface/admin-toolbar\";s:8:\"numParts\";i:4;}}',	4),
('admin_toolbar_tools.cssjs',	'/admin/flush/cssjs',	'/admin/flush/cssjs',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/admin/flush/cssjs\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushJsCss\";s:6:\"_title\";s:24:\"Flush CSS and JavaScript\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/admin/flush/cssjs$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/admin/flush/cssjs\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/admin/flush/cssjs\";s:8:\"numParts\";i:3;}}',	3),
('admin_toolbar_tools.flush',	'/admin/flush',	'/admin/flush',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/admin/flush\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:66:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushAll\";s:6:\"_title\";s:16:\"Flush all caches\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/admin/flush$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/admin/flush\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/admin/flush\";s:8:\"numParts\";i:2;}}',	2),
('admin_toolbar_tools.flush_menu',	'/admin/flush/menu',	'/admin/flush/menu',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/admin/flush/menu\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:67:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushMenu\";s:6:\"_title\";s:4:\"Menu\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/admin/flush/menu$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/flush/menu\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/admin/flush/menu\";s:8:\"numParts\";i:3;}}',	3),
('admin_toolbar_tools.flush_rendercache',	'/admin/flush/rendercache',	'/admin/flush/rendercache',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/flush/rendercache\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:69:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::cacheRender\";s:6:\"_title\";s:12:\"Render cache\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/flush/rendercache$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/flush/rendercache\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/flush/rendercache\";s:8:\"numParts\";i:3;}}',	3),
('admin_toolbar_tools.flush_static',	'/admin/flush/static-caches',	'/admin/flush/static-caches',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/flush/static-caches\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:69:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushStatic\";s:6:\"_title\";s:13:\"Static caches\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/flush/static\\-caches$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/flush/static-caches\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/admin/flush/static-caches\";s:8:\"numParts\";i:3;}}',	3),
('admin_toolbar_tools.flush_twig',	'/admin/flush/twig',	'/admin/flush/twig',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/admin/flush/twig\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:67:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushTwig\";s:6:\"_title\";s:4:\"Twig\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/admin/flush/twig$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/flush/twig\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/admin/flush/twig\";s:8:\"numParts\";i:3;}}',	3),
('admin_toolbar_tools.flush_views',	'/admin/flush/views',	'/admin/flush/views',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/admin/flush/views\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushViews\";s:6:\"_title\";s:5:\"Views\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/admin/flush/views$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/admin/flush/views\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:18:\"/admin/flush/views\";s:8:\"numParts\";i:3;}}',	3),
('admin_toolbar_tools.plugin',	'/admin/flush/plugin',	'/admin/flush/plugin',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/flush/plugin\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:70:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::flushPlugins\";s:6:\"_title\";s:6:\"Plugin\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/flush/plugin$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/flush/plugin\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/flush/plugin\";s:8:\"numParts\";i:3;}}',	3),
('admin_toolbar_tools.settings',	'/admin/config/user-interface/admin-toolbar-tools',	'/admin/config/user-interface/admin-toolbar-tools',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/config/user-interface/admin-toolbar-tools\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:62:\"\\Drupal\\admin_toolbar_tools\\Form\\AdminToolbarToolsSettingsForm\";s:6:\"_title\";s:28:\"Admin Toolbar Tools settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/config/user\\-interface/admin\\-toolbar\\-tools$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:48:\"/admin/config/user-interface/admin-toolbar-tools\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:48:\"/admin/config/user-interface/admin-toolbar-tools\";s:8:\"numParts\";i:4;}}',	4),
('admin_toolbar_tools.theme_rebuild',	'/admin/flush/theme_rebuild',	'/admin/flush/theme_rebuild',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/flush/theme_rebuild\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:70:\"\\Drupal\\admin_toolbar_tools\\Controller\\ToolbarController::themeRebuild\";s:6:\"_title\";s:13:\"Theme Rebuild\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/flush/theme_rebuild$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/flush/theme_rebuild\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/admin/flush/theme_rebuild\";s:8:\"numParts\";i:3;}}',	3),
('announcements_feed.announcement',	'/admin/announcements_feed',	'/admin/announcements_feed',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/announcements_feed\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:74:\"\\Drupal\\announcements_feed\\Controller\\AnnounceController::getAnnouncements\";s:6:\"_title\";s:23:\"Community announcements\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"access announcements\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/announcements_feed$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/announcements_feed\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:25:\"/admin/announcements_feed\";s:8:\"numParts\";i:2;}}',	2),
('big_pipe.nojs',	'/big_pipe/no-js',	'/big_pipe/no-js',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:15:\"/big_pipe/no-js\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\big_pipe\\Controller\\BigPipeController:setNoJsCookie\";s:6:\"_title\";s:19:\"BigPipe no-JS check\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:23:\"{^/big_pipe/no\\-js$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/big_pipe/no-js\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:15:\"/big_pipe/no-js\";s:8:\"numParts\";i:2;}}',	2),
('block.admin_add',	'/admin/structure/block/add/{plugin_id}/{theme}',	'/admin/structure/block/add/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/block/add/{plugin_id}/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:66:\"\\Drupal\\block\\Controller\\BlockAddController::blockAddConfigureForm\";s:5:\"theme\";N;s:6:\"_title\";s:15:\"Configure block\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"plugin_id\";i:1;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/structure/block/add/(?P<plugin_id>[^/]++)(?:/(?P<theme>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"plugin_id\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/block/add\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"plugin_id\";i:1;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/structure/block/add/%\";s:8:\"numParts\";i:6;}}',	6),
('block.admin_demo',	'/admin/structure/block/demo/{theme}',	'/admin/structure/block/demo/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/block/demo/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:46:\"\\Drupal\\block\\Controller\\BlockController::demo\";s:15:\"_title_callback\";s:21:\"theme_handler:getName\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/block/demo/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/block/demo\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/block/demo/%\";s:8:\"numParts\";i:5;}}',	5),
('block.admin_display',	'/admin/structure/block',	'/admin/structure/block',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:53:\"\\Drupal\\block\\Controller\\BlockListController::listing\";s:6:\"_title\";s:12:\"Block layout\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/block\";s:8:\"numParts\";i:3;}}',	3),
('block.admin_display_theme',	'/admin/structure/block/list/{theme}',	'/admin/structure/block/list/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/block/list/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:53:\"\\Drupal\\block\\Controller\\BlockListController::listing\";s:6:\"_title\";s:12:\"Block layout\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/block/list/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/block/list\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/block/list/%\";s:8:\"numParts\";i:5;}}',	5),
('block.admin_library',	'/admin/structure/block/library/{theme}',	'/admin/structure/block/library/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/structure/block/library/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\block\\Controller\\BlockLibraryController::listBlocks\";s:6:\"_title\";s:11:\"Place block\";}s:12:\"requirements\";a:2:{s:13:\"_access_theme\";s:4:\"TRUE\";s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:18:\"access_check.theme\";i:1;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/structure/block/library/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/block/library\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:32:\"/admin/structure/block/library/%\";s:8:\"numParts\";i:5;}}',	5),
('block.category_autocomplete',	'/block-category/autocomplete',	'/block-category/autocomplete',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/block-category/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:69:\"\\Drupal\\block\\Controller\\CategoryAutocompleteController::autocomplete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/block\\-category/autocomplete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/block-category/autocomplete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:28:\"/block-category/autocomplete\";s:8:\"numParts\";i:2;}}',	2),
('block_content.add_form',	'/block/add/{block_content_type}',	'/block/add/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/block/add/{block_content_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\block_content\\Controller\\BlockContentController::addForm\";s:15:\"_title_callback\";s:72:\"\\Drupal\\block_content\\Controller\\BlockContentController::getAddFormTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:34:\"block_content:{block_content_type}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/block/add/(?P<block_content_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/block/add\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:12:\"/block/add/%\";s:8:\"numParts\";i:3;}}',	3),
('block_content.add_page',	'/block/add',	'/block/add',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/block/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\block_content\\Controller\\BlockContentController::add\";s:6:\"_title\";s:17:\"Add content block\";}s:12:\"requirements\";a:1:{s:25:\"_entity_create_any_access\";s:13:\"block_content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.entity_create_any\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/block/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/block/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:10:\"/block/add\";s:8:\"numParts\";i:2;}}',	2),
('block_content.type_add',	'/admin/structure/block-content/add',	'/admin/structure/block-content/add',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/structure/block-content/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"block_content_type.add\";s:6:\"_title\";s:3:\"Add\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:18:\"block_content_type\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/structure/block\\-content/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/structure/block-content/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/structure/block-content/add\";s:8:\"numParts\";i:4;}}',	4),
('block_content.type_add.bc',	'/admin/structure/block/block-content/types/add',	'/admin/structure/block/block-content/types/add',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/block/block-content/types/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:3:\"Add\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:18:\"block_content_type\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/structure/block/block\\-content/types/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/structure/block/block-content/types/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:46:\"/admin/structure/block/block-content/types/add\";s:8:\"numParts\";i:6;}}',	6),
('ckeditor5.media_entity_metadata',	'/ckeditor5/{editor}/media-entity-metadata',	'/ckeditor5/%/media-entity-metadata',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/ckeditor5/{editor}/media-entity-metadata\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:74:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5MediaController::mediaEntityMetadata\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:10:\"editor.use\";s:14:\"_custom_access\";s:61:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5MediaController::access\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"editor\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:3:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";i:2;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"editor\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/ckeditor5/(?P<editor>[^/]++)/media\\-entity\\-metadata$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/media-entity-metadata\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"editor\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/ckeditor5\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"editor\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:34:\"/ckeditor5/%/media-entity-metadata\";s:8:\"numParts\";i:3;}}',	3),
('ckeditor5.upload_image',	'/ckeditor5/upload-image/{editor}',	'/ckeditor5/upload-image/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/ckeditor5/upload-image/{editor}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:61:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5ImageController::upload\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:10:\"editor.use\";s:14:\"_custom_access\";s:79:\"\\Drupal\\ckeditor5\\Controller\\CKEditor5ImageController::imageUploadEnabledAccess\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"editor\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:3:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";i:2;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"editor\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/ckeditor5/upload\\-image/(?P<editor>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"editor\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/ckeditor5/upload-image\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"editor\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:25:\"/ckeditor5/upload-image/%\";s:8:\"numParts\";i:3;}}',	3),
('config.diff',	'/admin/config/development/configuration/sync/diff/{source_name}/{target_name}',	'/admin/config/development/configuration/sync/diff/%',	126,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/config/development/configuration/sync/diff/{source_name}/{target_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\config\\Controller\\ConfigController::diff\";s:11:\"target_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"source_name\";i:1;s:11:\"target_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/config/development/configuration/sync/diff/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:49:\"/admin/config/development/configuration/sync/diff\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"source_name\";i:1;s:11:\"target_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:126;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/sync/diff/%\";s:8:\"numParts\";i:8;}}',	8),
('config.diff_collection',	'/admin/config/development/configuration/sync/diff_collection/{collection}/{source_name}/{target_name}',	'/admin/config/development/configuration/sync/diff_collection/%/%',	252,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:101:\"/admin/config/development/configuration/sync/diff_collection/{collection}/{source_name}/{target_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\config\\Controller\\ConfigController::diff\";s:11:\"target_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"collection\";i:1;s:11:\"source_name\";i:2;s:11:\"target_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:143:\"{^/admin/config/development/configuration/sync/diff_collection/(?P<collection>[^/]++)/(?P<source_name>[^/]++)(?:/(?P<target_name>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"source_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"collection\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:60:\"/admin/config/development/configuration/sync/diff_collection\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"collection\";i:1;s:11:\"source_name\";i:2;s:11:\"target_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:252;s:14:\"patternOutline\";s:64:\"/admin/config/development/configuration/sync/diff_collection/%/%\";s:8:\"numParts\";i:9;}}',	9),
('config.export_download',	'/admin/config/development/configuration/full/export-download',	'/admin/config/development/configuration/full/export-download',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/development/configuration/full/export-download\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\config\\Controller\\ConfigController::downloadExport\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/development/configuration/full/export\\-download$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:60:\"/admin/config/development/configuration/full/export-download\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:60:\"/admin/config/development/configuration/full/export-download\";s:8:\"numParts\";i:6;}}',	6),
('config.export_full',	'/admin/config/development/configuration/full/export',	'/admin/config/development/configuration/full/export',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/development/configuration/full/export\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\config\\Form\\ConfigExportForm\";s:6:\"_title\";s:6:\"Export\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/config/development/configuration/full/export$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/development/configuration/full/export\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/full/export\";s:8:\"numParts\";i:6;}}',	6),
('config.export_single',	'/admin/config/development/configuration/single/export/{config_type}/{config_name}',	'/admin/config/development/configuration/single/export',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/config/development/configuration/single/export/{config_type}/{config_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:13:\"Single export\";s:5:\"_form\";s:42:\"\\Drupal\\config\\Form\\ConfigSingleExportForm\";s:11:\"config_type\";N;s:11:\"config_name\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"config_type\";i:1;s:11:\"config_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:118:\"{^/admin/config/development/configuration/single/export(?:/(?P<config_type>[^/]++)(?:/(?P<config_name>[^/]++))?)?$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"config_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"config_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:53:\"/admin/config/development/configuration/single/export\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"config_type\";i:1;s:11:\"config_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:53:\"/admin/config/development/configuration/single/export\";s:8:\"numParts\";i:8;}}',	8),
('config.import_full',	'/admin/config/development/configuration/full/import',	'/admin/config/development/configuration/full/import',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/development/configuration/full/import\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\config\\Form\\ConfigImportForm\";s:6:\"_title\";s:6:\"Import\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"import configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/config/development/configuration/full/import$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/development/configuration/full/import\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:51:\"/admin/config/development/configuration/full/import\";s:8:\"numParts\";i:6;}}',	6),
('config.import_single',	'/admin/config/development/configuration/single/import',	'/admin/config/development/configuration/single/import',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/development/configuration/single/import\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:13:\"Single import\";s:5:\"_form\";s:42:\"\\Drupal\\config\\Form\\ConfigSingleImportForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"import configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/admin/config/development/configuration/single/import$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:53:\"/admin/config/development/configuration/single/import\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:53:\"/admin/config/development/configuration/single/import\";s:8:\"numParts\";i:6;}}',	6),
('config.sync',	'/admin/config/development/configuration',	'/admin/config/development/configuration',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/config/development/configuration\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:30:\"\\Drupal\\config\\Form\\ConfigSync\";s:6:\"_title\";s:11:\"Synchronize\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:25:\"synchronize configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/config/development/configuration$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/development/configuration\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/config/development/configuration\";s:8:\"numParts\";i:4;}}',	4),
('config_ignore.settings',	'/admin/config/development/configuration/ignore',	'/admin/config/development/configuration/ignore',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/config/development/configuration/ignore\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:45:\"\\Drupal\\config_ignore\\Form\\IgnoreSettingsForm\";s:6:\"_title\";s:6:\"Ignore\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"import configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/admin/config/development/configuration/ignore$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/config/development/configuration/ignore\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:46:\"/admin/config/development/configuration/ignore\";s:8:\"numParts\";i:5;}}',	5),
('contact.form_add',	'/admin/structure/contact/add',	'/admin/structure/contact/add',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/structure/contact/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"contact_form.add\";s:6:\"_title\";s:16:\"Add contact form\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer contact forms\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/structure/contact/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/contact/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/structure/contact/add\";s:8:\"numParts\";i:4;}}',	4),
('contact.site_page',	'/contact',	'/contact',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:8:\"/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:61:\"\\Drupal\\contact\\Controller\\ContactController::contactSitePage\";s:12:\"contact_form\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"access site-wide contact form\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:15:\"{^/contact$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:8:\"/contact\";s:8:\"numParts\";i:1;}}',	1),
('contextual.render',	'/contextual/render',	'/contextual/render',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/contextual/render\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\contextual\\ContextualController::render\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"access contextual links\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/contextual/render$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/contextual/render\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:18:\"/contextual/render\";s:8:\"numParts\";i:2;}}',	2),
('dblog.access_denied',	'/admin/reports/access-denied',	'/admin/reports/access-denied',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/access-denied\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:26:\"Top \'access denied\' errors\";s:11:\"_controller\";s:56:\"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages\";s:4:\"type\";s:13:\"access denied\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/access\\-denied$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/access-denied\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/reports/access-denied\";s:8:\"numParts\";i:3;}}',	3),
('dblog.confirm',	'/admin/reports/dblog/confirm',	'/admin/reports/dblog/confirm',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/dblog/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\dblog\\Form\\DblogClearLogConfirmForm\";s:6:\"_title\";s:34:\"Confirm delete recent log messages\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/reports/dblog/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/dblog/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/reports/dblog/confirm\";s:8:\"numParts\";i:4;}}',	4),
('dblog.event',	'/admin/reports/dblog/event/{event_id}',	'/admin/reports/dblog/event/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/reports/dblog/event/{event_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\dblog\\Controller\\DbLogController::eventDetails\";s:6:\"_title\";s:7:\"Details\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"event_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/reports/dblog/event/(?P<event_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"event_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/reports/dblog/event\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"event_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/reports/dblog/event/%\";s:8:\"numParts\";i:5;}}',	5),
('dblog.overview',	'/admin/reports/dblog',	'/admin/reports/dblog',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/reports/dblog\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"watchdog\";s:10:\"display_id\";s:4:\"page\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/reports/dblog$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/reports/dblog\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/reports/dblog\";s:8:\"numParts\";i:3;}}',	3),
('dblog.page_not_found',	'/admin/reports/page-not-found',	'/admin/reports/page-not-found',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/page-not-found\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:27:\"Top \'page not found\' errors\";s:11:\"_controller\";s:56:\"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages\";s:4:\"type\";s:14:\"page not found\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/page\\-not\\-found$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/page-not-found\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:29:\"/admin/reports/page-not-found\";s:8:\"numParts\";i:3;}}',	3),
('dblog.search',	'/admin/reports/search',	'/admin/reports/search',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/reports/search\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:56:\"\\Drupal\\dblog\\Controller\\DbLogController::topLogMessages\";s:6:\"_title\";s:18:\"Top search phrases\";s:4:\"type\";s:6:\"search\";}s:12:\"requirements\";a:2:{s:20:\"_module_dependencies\";s:6:\"search\";s:11:\"_permission\";s:19:\"access site reports\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/reports/search$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/reports/search\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/reports/search\";s:8:\"numParts\";i:3;}}',	3),
('ebt_core.settings',	'/admin/config/content/ebt-core',	'/admin/config/content/ebt-core',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/config/content/ebt-core\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:41:\"\\Drupal\\ebt_core\\Form\\EbtCoreSettingsForm\";s:6:\"_title\";s:32:\"Extra Block Types (EBT) settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/config/content/ebt\\-core$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/content/ebt-core\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/config/content/ebt-core\";s:8:\"numParts\";i:4;}}',	4),
('editor.filter_xss',	'/editor/filter_xss/{filter_format}',	'/editor/filter_xss/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/editor/filter_xss/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:42:\"\\Drupal\\editor\\EditorController::filterXss\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"filter_format.use\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/editor/filter_xss/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/editor/filter_xss\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:20:\"/editor/filter_xss/%\";s:8:\"numParts\";i:3;}}',	3),
('editor.image_dialog',	'/editor/dialog/image/{editor}',	'/editor/dialog/image/%',	14,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/editor/dialog/image/{editor}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\editor\\Form\\EditorImageDialog\";s:6:\"_title\";s:12:\"Upload image\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:10:\"editor.use\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:6:\"editor\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"editor\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/editor/dialog/image/(?P<editor>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"editor\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/editor/dialog/image\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"editor\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:22:\"/editor/dialog/image/%\";s:8:\"numParts\";i:4;}}',	4),
('editor.link_dialog',	'/editor/dialog/link/{editor}',	'/editor/dialog/link/%',	14,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/editor/dialog/link/{editor}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\editor\\Form\\EditorLinkDialog\";s:6:\"_title\";s:8:\"Add link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:10:\"editor.use\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:6:\"editor\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"editor\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/editor/dialog/link/(?P<editor>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"editor\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/editor/dialog/link\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"editor\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:21:\"/editor/dialog/link/%\";s:8:\"numParts\";i:4;}}',	4),
('editor.media_dialog',	'/editor/dialog/media/{editor}',	'/editor/dialog/media/%',	14,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/editor/dialog/media/{editor}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\media\\Form\\EditorMediaDialog\";s:6:\"_title\";s:10:\"Edit media\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:10:\"editor.use\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:6:\"editor\";a:2:{s:4:\"type\";s:13:\"entity:editor\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"editor\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/editor/dialog/media/(?P<editor>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"editor\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/editor/dialog/media\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"editor\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:22:\"/editor/dialog/media/%\";s:8:\"numParts\";i:4;}}',	4),
('entity.block.delete_form',	'/admin/structure/block/manage/{block}/delete',	'/admin/structure/block/manage/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/block/manage/{block}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"block.delete\";s:6:\"_title\";s:12:\"Remove block\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer blocks\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/block/manage/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.block.disable',	'/admin/structure/block/manage/{block}/disable',	'/admin/structure/block/manage/%/disable',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/block/manage/{block}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\block\\Controller\\BlockController::performOperation\";s:2:\"op\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:13:\"block.disable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/block/manage/%/disable\";s:8:\"numParts\";i:6;}}',	6),
('entity.block.edit_form',	'/admin/structure/block/manage/{block}',	'/admin/structure/block/manage/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/structure/block/manage/{block}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"block.default\";s:6:\"_title\";s:15:\"Configure block\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"block.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/structure/block/manage/(?P<block>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:31:\"/admin/structure/block/manage/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.block.enable',	'/admin/structure/block/manage/{block}/enable',	'/admin/structure/block/manage/%/enable',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/block/manage/{block}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\block\\Controller\\BlockController::performOperation\";s:2:\"op\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"block.enable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:5:\"block\";a:2:{s:4:\"type\";s:12:\"entity:block\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"block\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/block/manage/(?P<block>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"block\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/block/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"block\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/block/manage/%/enable\";s:8:\"numParts\";i:6;}}',	6),
('entity.block_content.canonical',	'/admin/content/block/{block_content}',	'/admin/content/block/%',	14,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/content/block/{block_content}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"block_content.edit\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/content/block/(?P<block_content>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:22:\"/admin/content/block/%\";s:8:\"numParts\";i:4;}}',	4),
('entity.block_content.collection',	'/admin/content/block',	'/admin/content/block',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"block_content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"access block library\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/block\";s:8:\"numParts\";i:3;}}',	3),
('entity.block_content.collection.bc',	'/admin/structure/block/block-content',	'/admin/structure/block/block-content',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/structure/block/block-content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:77:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockLibraryRedirect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:45:\"access block library+administer block content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/structure/block/block\\-content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/structure/block/block-content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:36:\"/admin/structure/block/block-content\";s:8:\"numParts\";i:4;}}',	4),
('entity.block_content.delete_form',	'/admin/content/block/{block_content}/delete',	'/admin/content/block/%/delete',	29,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/content/block/{block_content}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"block_content.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.delete\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/admin/content/block/(?P<block_content>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:29:\"/admin/content/block/%/delete\";s:8:\"numParts\";i:5;}}',	5),
('entity.block_content.delete_form.bc',	'/block/{block_content}/delete',	'/block/%/delete',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/block/{block_content}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:69:\"\\Drupal\\block_content\\Controller\\BlockContentController::editRedirect\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.delete\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/block/(?P<block_content>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/block/%/delete\";s:8:\"numParts\";i:3;}}',	3),
('entity.block_content.edit_form',	'/admin/content/block/{block_content}',	'/admin/content/block/%',	14,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/content/block/{block_content}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:18:\"block_content.edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/content/block/(?P<block_content>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:22:\"/admin/content/block/%\";s:8:\"numParts\";i:4;}}',	4),
('entity.block_content.edit_form.bc',	'/block/{block_content}',	'/block/%',	2,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/block/{block_content}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:69:\"\\Drupal\\block_content\\Controller\\BlockContentController::editRedirect\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/block/(?P<block_content>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:8:\"/block/%\";s:8:\"numParts\";i:2;}}',	2),
('entity.block_content.field_ui_fields',	'/admin/structure/block-content/manage/{block_content_type}/fields',	'/admin/structure/block-content/manage/%/fields',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/block-content/manage/%/fields\";s:8:\"numParts\";i:6;}}',	6),
('entity.block_content.field_ui_fields.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/fields',	'/admin/structure/block/block-content/manage/%/fields',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/block/block-content/manage/{block_content_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:52:\"/admin/structure/block/block-content/manage/%/fields\";s:8:\"numParts\";i:7;}}',	7),
('entity.block_content.revision_delete_form',	'/admin/content/block/{block_content}/revision/{block_content_revision}/delete',	'/admin/content/block/%/revision/%/delete',	117,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"block_content.revision-delete\";s:6:\"_title\";s:15:\"Delete revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:38:\"block_content_revision.delete revision\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"block_content_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:block_content\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/content/block/(?P<block_content>[^/]++)/revision/(?P<block_content_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"block_content_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:40:\"/admin/content/block/%/revision/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.block_content.revision_revert_form',	'/admin/content/block/{block_content}/revision/{block_content_revision}/revert',	'/admin/content/block/%/revision/%/revert',	117,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/content/block/{block_content}/revision/{block_content_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"block_content.revision-revert\";s:6:\"_title\";s:15:\"Revert revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:29:\"block_content_revision.revert\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"block_content_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:block_content\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/content/block/(?P<block_content>[^/]++)/revision/(?P<block_content_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"block_content_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"block_content\";i:1;s:22:\"block_content_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:40:\"/admin/content/block/%/revision/%/revert\";s:8:\"numParts\";i:7;}}',	7),
('entity.block_content.version_history',	'/admin/content/block/{block_content}/revisions',	'/admin/content/block/%/revisions',	29,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/content/block/{block_content}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"Drupal\\Core\\Entity\\Controller\\VersionHistoryController\";s:6:\"_title\";s:9:\"Revisions\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:32:\"block_content.view all revisions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"entity_type_id\";s:13:\"block_content\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/content/block/(?P<block_content>[^/]++)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:32:\"/admin/content/block/%/revisions\";s:8:\"numParts\";i:5;}}',	5),
('entity.block_content_type.collection',	'/admin/structure/block-content',	'/admin/structure/block-content',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/structure/block-content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:18:\"block_content_type\";s:6:\"_title\";s:11:\"Block types\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer block types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/block\\-content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/block-content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/admin/structure/block-content\";s:8:\"numParts\";i:3;}}',	3),
('entity.block_content_type.collection.bc',	'/admin/structure/block/block-content/types',	'/admin/structure/block/block-content/types',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/block/block-content/types\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer block types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/structure/block/block\\-content/types$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/block/block-content/types\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:42:\"/admin/structure/block/block-content/types\";s:8:\"numParts\";i:5;}}',	5),
('entity.block_content_type.delete_form',	'/admin/structure/block-content/manage/{block_content_type}/delete',	'/admin/structure/block-content/manage/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/block-content/manage/{block_content_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"block_content_type.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"block_content_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/block-content/manage/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.block_content_type.delete_form.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/delete',	'/admin/structure/block/block-content/manage/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/block/block-content/manage/{block_content_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"block_content_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:52:\"/admin/structure/block/block-content/manage/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.block_content_type.edit_form',	'/admin/structure/block-content/manage/{block_content_type}',	'/admin/structure/block-content/manage/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/block-content/manage/{block_content_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"block_content_type.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"block_content_type.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:39:\"/admin/structure/block-content/manage/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.block_content_type.edit_form.bc',	'/admin/structure/block/block-content/manage/{block_content_type}',	'/admin/structure/block/block-content/manage/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/block/block-content/manage/{block_content_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer block types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:45:\"/admin/structure/block/block-content/manage/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.block_content_type.entity_permissions_form',	'/admin/structure/block-content/manage/{block_content_type}/permissions',	'/admin/structure/block-content/manage/%/permissions',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/block-content/manage/{block_content_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:13:\"block_content\";s:18:\"bundle_entity_type\";s:18:\"block_content_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:3:{s:4:\"type\";s:25:\"entity:block_content_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:51:\"/admin/structure/block-content/manage/%/permissions\";s:8:\"numParts\";i:6;}}',	6),
('entity.block_content_type.entity_permissions_form.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/permissions',	'/admin/structure/block/block-content/manage/%/permissions',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/block/block-content/manage/{block_content_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:14:\"entity_type_id\";s:13:\"block_content\";s:18:\"bundle_entity_type\";s:18:\"block_content_type\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:3:{s:4:\"type\";s:25:\"entity:block_content_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:57:\"/admin/structure/block/block-content/manage/%/permissions\";s:8:\"numParts\";i:7;}}',	7),
('entity.ckeditor5_template.add_form',	'/admin/config/ckeditor5-templates/content-templates/add',	'/admin/config/ckeditor5-templates/content-templates/add',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"ckeditor5_template.add\";s:6:\"_title\";s:24:\"Add a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:55:\"/admin/config/ckeditor5-templates/content-templates/add\";s:8:\"numParts\";i:5;}}',	5),
('entity.ckeditor5_template.collection',	'/admin/config/ckeditor5-templates/content-templates',	'/admin/config/ckeditor5-templates/content-templates',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:18:\"ckeditor5_template\";s:6:\"_title\";s:41:\"CKEditor5 Content Templates Configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:60:\"{^/admin/config/ckeditor5\\-templates/content\\-templates$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:51:\"/admin/config/ckeditor5-templates/content-templates\";s:8:\"numParts\";i:4;}}',	4),
('entity.ckeditor5_template.delete_form',	'/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/delete',	'/admin/config/ckeditor5-templates/content-templates/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"ckeditor5_template.delete\";s:6:\"_title\";s:27:\"Delete a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:60:\"/admin/config/ckeditor5-templates/content-templates/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.ckeditor5_template.edit_form',	'/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}',	'/admin/config/ckeditor5-templates/content-templates/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/config/ckeditor5-templates/content-templates/{ckeditor5_template}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"ckeditor5_template.edit\";s:6:\"_title\";s:25:\"Edit a CKEditor5 Template\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer ckeditor5 templates\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"ckeditor5_template\";a:2:{s:4:\"type\";s:25:\"entity:ckeditor5_template\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:91:\"{^/admin/config/ckeditor5\\-templates/content\\-templates/(?P<ckeditor5_template>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"ckeditor5_template\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:51:\"/admin/config/ckeditor5-templates/content-templates\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"ckeditor5_template\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:53:\"/admin/config/ckeditor5-templates/content-templates/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.contact_form.canonical',	'/contact/{contact_form}',	'/contact/%',	2,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/contact/{contact_form}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:61:\"\\Drupal\\contact\\Controller\\ContactController::contactSitePage\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"contact_form.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/contact/(?P<contact_form>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:10:\"/contact/%\";s:8:\"numParts\";i:2;}}',	2),
('entity.contact_form.collection',	'/admin/structure/contact',	'/admin/structure/contact',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/structure/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"contact_form\";s:6:\"_title\";s:13:\"Contact forms\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer contact forms\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/structure/contact$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/structure/contact\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/structure/contact\";s:8:\"numParts\";i:3;}}',	3),
('entity.contact_form.delete_form',	'/admin/structure/contact/manage/{contact_form}/delete',	'/admin/structure/contact/manage/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/contact/manage/{contact_form}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"contact_form.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"contact_form.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/contact/manage/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.contact_form.edit_form',	'/admin/structure/contact/manage/{contact_form}',	'/admin/structure/contact/manage/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/contact/manage/{contact_form}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"contact_form.edit\";s:6:\"_title\";s:17:\"Edit contact form\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"contact_form.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/structure/contact/manage/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.contact_form.entity_permissions_form',	'/admin/structure/contact/manage/{contact_form}/permissions',	'/admin/structure/contact/manage/%/permissions',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/contact/manage/{contact_form}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:18:\"bundle_entity_type\";s:12:\"contact_form\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:22:\"administer permissions\";s:14:\"_custom_access\";s:47:\"\\Drupal\\user\\Form\\EntityPermissionsForm::access\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:3:{s:4:\"type\";s:19:\"entity:contact_form\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:45:\"/admin/structure/contact/manage/%/permissions\";s:8:\"numParts\";i:6;}}',	6),
('entity.contact_message.field_ui_fields',	'/admin/structure/contact/manage/{contact_form}/fields',	'/admin/structure/contact/manage/%/fields',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/contact/manage/{contact_form}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/contact/manage/%/fields\";s:8:\"numParts\";i:6;}}',	6),
('entity.date_format.collection',	'/admin/config/regional/date-time',	'/admin/config/regional/date-time',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/regional/date-time\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"date_format\";s:6:\"_title\";s:21:\"Date and time formats\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/regional/date\\-time$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/regional/date-time\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/regional/date-time\";s:8:\"numParts\";i:4;}}',	4),
('entity.date_format.delete_form',	'/admin/config/regional/date-time/formats/manage/{date_format}/delete',	'/admin/config/regional/date-time/formats/manage/%/delete',	253,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/regional/date-time/formats/manage/{date_format}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"date_format.delete\";s:6:\"_title\";s:18:\"Delete date format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"date_format.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"date_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"date_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:253;s:14:\"patternOutline\";s:56:\"/admin/config/regional/date-time/formats/manage/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('entity.date_format.edit_form',	'/admin/config/regional/date-time/formats/manage/{date_format}',	'/admin/config/regional/date-time/formats/manage/%',	126,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/config/regional/date-time/formats/manage/{date_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"date_format.edit\";s:6:\"_title\";s:16:\"Edit date format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"date_format.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"date_format\";a:2:{s:4:\"type\";s:18:\"entity:date_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"date_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/config/regional/date\\-time/formats/manage/(?P<date_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"date_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/regional/date-time/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"date_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:126;s:14:\"patternOutline\";s:49:\"/admin/config/regional/date-time/formats/manage/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_form_display.block_content.default',	'/admin/structure/block-content/manage/{block_content_type}/form-display',	'/admin/structure/block-content/manage/%/form-display',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/block-content/manage/{block_content_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:52:\"/admin/structure/block-content/manage/%/form-display\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_form_display.block_content.default.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/form-display',	'/admin/structure/block/block-content/manage/%/form-display',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/structure/block/block-content/manage/{block_content_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:96:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:58:\"/admin/structure/block/block-content/manage/%/form-display\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_form_display.block_content.form_mode',	'/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}',	'/admin/structure/block-content/manage/%/form-display/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:54:\"/admin/structure/block-content/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_form_display.block_content.form_mode.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/form-display/{form_mode_name}',	'/admin/structure/block/block-content/manage/%/form-display/%',	250,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:94:\"/admin/structure/block/block-content/manage/{block_content_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:123:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:60:\"/admin/structure/block/block-content/manage/%/form-display/%\";s:8:\"numParts\";i:8;}}',	8),
('entity.entity_form_display.contact_message.default',	'/admin/structure/contact/manage/{contact_form}/form-display',	'/admin/structure/contact/manage/%/form-display',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/contact/manage/{contact_form}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:46:\"/admin/structure/contact/manage/%/form-display\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_form_display.contact_message.form_mode',	'/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}',	'/admin/structure/contact/manage/%/form-display/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:48:\"/admin/structure/contact/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_form_display.media.default',	'/admin/structure/media/manage/{media_type}/form-display',	'/admin/structure/media/manage/%/form-display',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/media/manage/{media_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/media/manage/%/form-display\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_form_display.media.form_mode',	'/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}',	'/admin/structure/media/manage/%/form-display/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:46:\"/admin/structure/media/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_form_display.node.default',	'/admin/structure/types/manage/{node_type}/form-display',	'/admin/structure/types/manage/%/form-display',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/types/manage/{node_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/types/manage/%/form-display\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_form_display.node.form_mode',	'/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}',	'/admin/structure/types/manage/%/form-display/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:46:\"/admin/structure/types/manage/%/form-display/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_form_display.paragraph.default',	'/admin/structure/paragraphs_type/{paragraphs_type}/form-display',	'/admin/structure/paragraphs_type/%/form-display',	29,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:47:\"/admin/structure/paragraphs_type/%/form-display\";s:8:\"numParts\";i:5;}}',	5),
('entity.entity_form_display.paragraph.form_mode',	'/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}',	'/admin/structure/paragraphs_type/%/form-display/%',	58,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:58;s:14:\"patternOutline\";s:49:\"/admin/structure/paragraphs_type/%/form-display/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_form_display.taxonomy_term.default',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display',	'/admin/structure/taxonomy/manage/%/overview/form-display',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/taxonomy/manage/%/overview/form-display\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_form_display.taxonomy_term.form_mode',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}',	'/admin/structure/taxonomy/manage/%/overview/form-display/%',	246,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:58:\"/admin/structure/taxonomy/manage/%/overview/form-display/%\";s:8:\"numParts\";i:8;}}',	8),
('entity.entity_form_display.user.default',	'/admin/config/people/accounts/form-display',	'/admin/config/people/accounts/form-display',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/config/people/accounts/form-display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"form_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer user form display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/config/people/accounts/form\\-display$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:42:\"/admin/config/people/accounts/form-display\";s:8:\"numParts\";i:5;}}',	5),
('entity.entity_form_display.user.form_mode',	'/admin/config/people/accounts/form-display/{form_mode_name}',	'/admin/config/people/accounts/form-display/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/people/accounts/form-display/{form_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:24:\"entity_form_display.edit\";s:6:\"_title\";s:19:\"Manage form display\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_form_mode_access\";s:28:\"administer user form display\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.form_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/people/accounts/form-display/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_form_mode.add_form',	'/admin/structure/display-modes/form/add/{entity_type_id}',	'/admin/structure/display-modes/form/add/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/display-modes/form/add/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"entity_form_mode.add\";s:6:\"_title\";s:13:\"Add form mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/display\\-modes/form/add/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/form/add\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/structure/display-modes/form/add/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_form_mode.collection',	'/admin/structure/display-modes/form',	'/admin/structure/display-modes/form',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/display-modes/form\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"entity_form_mode\";s:6:\"_title\";s:10:\"Form modes\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/structure/display\\-modes/form$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/structure/display-modes/form\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/admin/structure/display-modes/form\";s:8:\"numParts\";i:4;}}',	4),
('entity.entity_form_mode.delete_form',	'/admin/structure/display-modes/form/manage/{entity_form_mode}/delete',	'/admin/structure/display-modes/form/manage/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/display-modes/form/manage/{entity_form_mode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"entity_form_mode.delete\";s:6:\"_title\";s:16:\"Delete form mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_form_mode.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/structure/display-modes/form/manage/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_form_mode.edit_form',	'/admin/structure/display-modes/form/manage/{entity_form_mode}',	'/admin/structure/display-modes/form/manage/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/display-modes/form/manage/{entity_form_mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"entity_form_mode.edit\";s:6:\"_title\";s:14:\"Edit form mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_form_mode.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_form_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_form_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/display\\-modes/form/manage/(?P<entity_form_mode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_form_mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/form/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_form_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/structure/display-modes/form/manage/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_view_display.block_content.default',	'/admin/structure/block-content/manage/{block_content_type}/display',	'/admin/structure/block-content/manage/%/display',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/block-content/manage/{block_content_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:8:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:18:\"block_content_type\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:47:\"/admin/structure/block-content/manage/%/display\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_view_display.block_content.default.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/display',	'/admin/structure/block/block-content/manage/%/display',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/block/block-content/manage/{block_content_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:8:{s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:18:\"block_content_type\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:53:\"/admin/structure/block/block-content/manage/%/display\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_view_display.block_content.view_mode',	'/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}',	'/admin/structure/block-content/manage/%/display/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:18:\"block_content_type\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:49:\"/admin/structure/block-content/manage/%/display/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_view_display.block_content.view_mode.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/display/{view_mode_name}',	'/admin/structure/block/block-content/manage/%/display/%',	250,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/admin/structure/block/block-content/manage/{block_content_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:18:\"block_content_type\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:55:\"/admin/structure/block/block-content/manage/%/display/%\";s:8:\"numParts\";i:8;}}',	8),
('entity.entity_view_display.contact_message.default',	'/admin/structure/contact/manage/{contact_form}/display',	'/admin/structure/contact/manage/%/display',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/contact/manage/{contact_form}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:8:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:12:\"contact_form\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:3:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/contact/manage/%/display\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_view_display.contact_message.view_mode',	'/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}',	'/admin/structure/contact/manage/%/display/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:12:\"contact_form\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:3:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:43:\"/admin/structure/contact/manage/%/display/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_view_display.media.default',	'/admin/structure/media/manage/{media_type}/display',	'/admin/structure/media/manage/%/display',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/media/manage/{media_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:8:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:10:\"media_type\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:4:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/media/manage/%/display\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_view_display.media.view_mode',	'/admin/structure/media/manage/{media_type}/display/{view_mode_name}',	'/admin/structure/media/manage/%/display/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:10:\"media_type\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:4:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:41:\"/admin/structure/media/manage/%/display/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_view_display.node.default',	'/admin/structure/types/manage/{node_type}/display',	'/admin/structure/types/manage/%/display',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/types/manage/{node_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:8:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:9:\"node_type\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:5:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/types/manage/%/display\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_view_display.node.view_mode',	'/admin/structure/types/manage/{node_type}/display/{view_mode_name}',	'/admin/structure/types/manage/%/display/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:9:\"node_type\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:5:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:41:\"/admin/structure/types/manage/%/display/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_view_display.paragraph.default',	'/admin/structure/paragraphs_type/{paragraphs_type}/display',	'/admin/structure/paragraphs_type/%/display',	29,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/paragraphs_type/{paragraphs_type}/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:8:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:15:\"paragraphs_type\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:7:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:42:\"/admin/structure/paragraphs_type/%/display\";s:8:\"numParts\";i:5;}}',	5),
('entity.entity_view_display.paragraph.view_mode',	'/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}',	'/admin/structure/paragraphs_type/%/display/%',	58,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:15:\"paragraphs_type\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:7:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:58;s:14:\"patternOutline\";s:44:\"/admin/structure/paragraphs_type/%/display/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_view_display.taxonomy_term.default',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display',	'/admin/structure/taxonomy/manage/%/overview/display',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:8:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:19:\"taxonomy_vocabulary\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:6:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:51:\"/admin/structure/taxonomy/manage/%/overview/display\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_view_display.taxonomy_term.view_mode',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}',	'/admin/structure/taxonomy/manage/%/overview/display/%',	246,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:10:\"bundle_key\";s:19:\"taxonomy_vocabulary\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:6:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:53:\"/admin/structure/taxonomy/manage/%/overview/display/%\";s:8:\"numParts\";i:8;}}',	8),
('entity.entity_view_display.user.default',	'/admin/config/people/accounts/display',	'/admin/config/people/accounts/display',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/people/accounts/display\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"view_mode_name\";s:7:\"default\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:6:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/people/accounts/display$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:37:\"/admin/config/people/accounts/display\";s:8:\"numParts\";i:5;}}',	5),
('entity.entity_view_display.user.view_mode',	'/admin/config/people/accounts/display/{view_mode_name}',	'/admin/config/people/accounts/display/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/people/accounts/display/{view_mode_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:6:{s:12:\"_entity_form\";s:24:\"entity_view_display.edit\";s:6:\"_title\";s:14:\"Manage display\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";}s:12:\"requirements\";a:1:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:6:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:31:\"access_check.field_ui.view_mode\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:39:\"/admin/config/people/accounts/display/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_view_mode.add_form',	'/admin/structure/display-modes/view/add/{entity_type_id}',	'/admin/structure/display-modes/view/add/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/display-modes/view/add/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"entity_view_mode.add\";s:6:\"_title\";s:13:\"Add view mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/display\\-modes/view/add/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/view/add\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/structure/display-modes/view/add/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.entity_view_mode.collection',	'/admin/structure/display-modes/view',	'/admin/structure/display-modes/view',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/display-modes/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"entity_view_mode\";s:6:\"_title\";s:10:\"View modes\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/structure/display\\-modes/view$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/structure/display-modes/view\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/admin/structure/display-modes/view\";s:8:\"numParts\";i:4;}}',	4),
('entity.entity_view_mode.delete_form',	'/admin/structure/display-modes/view/manage/{entity_view_mode}/delete',	'/admin/structure/display-modes/view/manage/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/display-modes/view/manage/{entity_view_mode}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"entity_view_mode.delete\";s:6:\"_title\";s:16:\"Delete view mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_view_mode.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/structure/display-modes/view/manage/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.entity_view_mode.edit_form',	'/admin/structure/display-modes/view/manage/{entity_view_mode}',	'/admin/structure/display-modes/view/manage/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/display-modes/view/manage/{entity_view_mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"entity_view_mode.edit\";s:6:\"_title\";s:14:\"Edit view mode\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"entity_view_mode.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"entity_view_mode\";a:2:{s:4:\"type\";s:23:\"entity:entity_view_mode\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/display\\-modes/view/manage/(?P<entity_view_mode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"entity_view_mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/display-modes/view/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"entity_view_mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/structure/display-modes/view/manage/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.field_config.block_content_field_delete_form',	'/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/delete',	'/admin/structure/block-content/manage/%/fields/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/block-content/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('entity.field_config.block_content_field_delete_form.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/fields/{field_config}/delete',	'/admin/structure/block/block-content/manage/%/fields/%/delete',	501,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/block/block-content/manage/{block_content_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:61:\"/admin/structure/block/block-content/manage/%/fields/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('entity.field_config.block_content_field_edit_form',	'/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}',	'/admin/structure/block-content/manage/%/fields/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/block-content/manage/{block_content_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:48:\"/admin/structure/block-content/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.field_config.block_content_field_edit_form.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/fields/{field_config}',	'/admin/structure/block/block-content/manage/%/fields/%',	250,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/block/block-content/manage/{block_content_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:54:\"/admin/structure/block/block-content/manage/%/fields/%\";s:8:\"numParts\";i:8;}}',	8),
('entity.field_config.contact_message_field_delete_form',	'/admin/structure/contact/manage/{contact_form}/fields/{field_config}/delete',	'/admin/structure/contact/manage/%/fields/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/contact/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('entity.field_config.contact_message_field_edit_form',	'/admin/structure/contact/manage/{contact_form}/fields/{field_config}',	'/admin/structure/contact/manage/%/fields/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/contact/manage/{contact_form}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:42:\"/admin/structure/contact/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.field_config.media_field_delete_form',	'/admin/structure/media/manage/{media_type}/fields/{field_config}/delete',	'/admin/structure/media/manage/%/fields/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/media/manage/{media_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/structure/media/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('entity.field_config.media_field_edit_form',	'/admin/structure/media/manage/{media_type}/fields/{field_config}',	'/admin/structure/media/manage/%/fields/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/media/manage/{media_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:91:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:40:\"/admin/structure/media/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.field_config.node_field_delete_form',	'/admin/structure/types/manage/{node_type}/fields/{field_config}/delete',	'/admin/structure/types/manage/%/fields/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/types/manage/{node_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:97:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:47:\"/admin/structure/types/manage/%/fields/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('entity.field_config.node_field_edit_form',	'/admin/structure/types/manage/{node_type}/fields/{field_config}',	'/admin/structure/types/manage/%/fields/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/types/manage/{node_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:40:\"/admin/structure/types/manage/%/fields/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.field_config.paragraph_field_delete_form',	'/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}/delete',	'/admin/structure/paragraphs_type/%/fields/%/delete',	117,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:50:\"/admin/structure/paragraphs_type/%/fields/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.field_config.paragraph_field_edit_form',	'/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}',	'/admin/structure/paragraphs_type/%/fields/%',	58,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:58;s:14:\"patternOutline\";s:43:\"/admin/structure/paragraphs_type/%/fields/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.field_config.taxonomy_term_field_delete_form',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/delete',	'/admin/structure/taxonomy/manage/%/overview/fields/%/delete',	493,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:119:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:59:\"/admin/structure/taxonomy/manage/%/overview/fields/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('entity.field_config.taxonomy_term_field_edit_form',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}',	'/admin/structure/taxonomy/manage/%/overview/fields/%',	246,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:52:\"/admin/structure/taxonomy/manage/%/overview/fields/%\";s:8:\"numParts\";i:8;}}',	8),
('entity.field_config.user_field_delete_form',	'/admin/config/people/accounts/fields/{field_config}/delete',	'/admin/config/people/accounts/fields/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/config/people/accounts/fields/{field_config}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:19:\"field_config.delete\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:45:\"/admin/config/people/accounts/fields/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.field_config.user_field_edit_form',	'/admin/config/people/accounts/fields/{field_config}',	'/admin/config/people/accounts/fields/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/config/people/accounts/fields/{field_config}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:17:\"field_config.edit\";s:15:\"_title_callback\";s:51:\"\\Drupal\\field_ui\\Form\\FieldConfigEditForm::getTitle\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"field_config.update\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:12:\"field_config\";a:2:{s:4:\"type\";s:19:\"entity:field_config\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"field_config\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/people/accounts/fields/(?P<field_config>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"field_config\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"field_config\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:38:\"/admin/config/people/accounts/fields/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.field_storage_config.collection',	'/admin/reports/fields',	'/admin/reports/fields',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/reports/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:20:\"field_storage_config\";s:6:\"_title\";s:10:\"Field list\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/reports/fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/reports/fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/reports/fields\";s:8:\"numParts\";i:3;}}',	3),
('entity.file.delete_form',	'/file/{file}/delete',	'/file/%/delete',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/file/{file}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"file.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:4:\"file\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"file.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"file\";a:2:{s:4:\"type\";s:11:\"entity:file\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"file\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/file/(?P<file>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"file\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/file\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"file\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/file/%/delete\";s:8:\"numParts\";i:3;}}',	3),
('entity.filter_format.disable',	'/admin/config/content/formats/manage/{filter_format}/disable',	'/admin/config/content/formats/manage/%/disable',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/content/formats/manage/{filter_format}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"filter_format.disable\";s:6:\"_title\";s:19:\"Disable text format\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:21:\"filter_format.disable\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/content/formats/manage/%/disable\";s:8:\"numParts\";i:7;}}',	7),
('entity.filter_format.edit_form',	'/admin/config/content/formats/manage/{filter_format}',	'/admin/config/content/formats/manage/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/content/formats/manage/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"filter_format.edit\";s:15:\"_title_callback\";s:52:\"\\Drupal\\filter\\Controller\\FilterController::getLabel\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:20:\"filter_format.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/config/content/formats/manage/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/content/formats/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:38:\"/admin/config/content/formats/manage/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.image_style.collection',	'/admin/config/media/image-styles',	'/admin/config/media/image-styles',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/media/image-styles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"image_style\";s:6:\"_title\";s:12:\"Image styles\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/media/image\\-styles$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/media/image-styles\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/media/image-styles\";s:8:\"numParts\";i:4;}}',	4),
('entity.image_style.delete_form',	'/admin/config/media/image-styles/manage/{image_style}/delete',	'/admin/config/media/image-styles/manage/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/media/image-styles/manage/{image_style}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"image_style.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"image_style.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:48:\"/admin/config/media/image-styles/manage/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.image_style.edit_form',	'/admin/config/media/image-styles/manage/{image_style}',	'/admin/config/media/image-styles/manage/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/media/image-styles/manage/{image_style}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"image_style.edit\";s:6:\"_title\";s:10:\"Edit style\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:41:\"/admin/config/media/image-styles/manage/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.image_style.flush_form',	'/admin/config/media/image-styles/manage/{image_style}/flush',	'/admin/config/media/image-styles/manage/%/flush',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/media/image-styles/manage/{image_style}/flush\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"image_style.flush\";s:6:\"_title\";s:5:\"Flush\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"image_style\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/flush$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/flush\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"image_style\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:47:\"/admin/config/media/image-styles/manage/%/flush\";s:8:\"numParts\";i:7;}}',	7),
('entity.linkit_profile.add_form',	'/admin/config/content/linkit/add',	'/admin/config/content/linkit/add',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/content/linkit/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"linkit_profile.add\";s:6:\"_title\";s:11:\"Add profile\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/content/linkit/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/content/linkit/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:32:\"/admin/config/content/linkit/add\";s:8:\"numParts\";i:5;}}',	5),
('entity.linkit_profile.collection',	'/admin/config/content/linkit',	'/admin/config/content/linkit',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/config/content/linkit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:14:\"linkit_profile\";s:6:\"_title\";s:15:\"Linkit profiles\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/config/content/linkit$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/content/linkit\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/config/content/linkit\";s:8:\"numParts\";i:4;}}',	4),
('entity.linkit_profile.delete_form',	'/admin/config/content/linkit/manage/{linkit_profile}/delete',	'/admin/config/content/linkit/manage/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/content/linkit/manage/{linkit_profile}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:21:\"linkit_profile.delete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:44:\"/admin/config/content/linkit/manage/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.linkit_profile.edit_form',	'/admin/config/content/linkit/manage/{linkit_profile}',	'/admin/config/content/linkit/manage/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/content/linkit/manage/{linkit_profile}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"linkit_profile.edit\";s:15:\"_title_callback\";s:55:\"Drupal\\linkit\\Controller\\LinkitController::profileTitle\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:37:\"/admin/config/content/linkit/manage/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.media.add_form',	'/media/add/{media_type}',	'/media/add/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/media/add/{media_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_form\";s:9:\"media.add\";s:14:\"entity_type_id\";s:5:\"media\";s:15:\"_title_callback\";s:62:\"Drupal\\Core\\Entity\\Controller\\EntityController::addBundleTitle\";s:16:\"bundle_parameter\";s:10:\"media_type\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:18:\"media:{media_type}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:3:{s:4:\"type\";s:17:\"entity:media_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/media/add/(?P<media_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/media/add\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:12:\"/media/add/%\";s:8:\"numParts\";i:3;}}',	3),
('entity.media.add_page',	'/media/add',	'/media/add',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/media/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:55:\"Drupal\\Core\\Entity\\Controller\\EntityController::addPage\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";s:14:\"entity_type_id\";s:5:\"media\";}s:12:\"requirements\";a:1:{s:25:\"_entity_create_any_access\";s:5:\"media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.entity_create_any\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/media/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/media/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:10:\"/media/add\";s:8:\"numParts\";i:2;}}',	2),
('entity.media.canonical',	'/media/{media}/edit',	'/media/%/edit',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/media/{media}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:10:\"media.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"media.update\";s:5:\"media\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/media/(?P<media>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:13:\"/media/%/edit\";s:8:\"numParts\";i:3;}}',	3),
('entity.media.collection',	'/admin/content/media',	'/admin/content/media',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"media\";s:10:\"display_id\";s:15:\"media_page_list\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access media overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/media\";s:8:\"numParts\";i:3;}}',	3),
('entity.media.delete_form',	'/media/{media}/delete',	'/media/%/delete',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/media/{media}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"media.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"media.delete\";s:5:\"media\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/media/(?P<media>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/media/%/delete\";s:8:\"numParts\";i:3;}}',	3),
('entity.media.delete_multiple_form',	'/media/delete',	'/media/delete',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/media/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"Drupal\\Core\\Entity\\Form\\DeleteMultipleForm\";s:14:\"entity_type_id\";s:5:\"media\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:5:\"media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/media/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/media/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/media/delete\";s:8:\"numParts\";i:2;}}',	2),
('entity.media.edit_form',	'/media/{media}/edit',	'/media/%/edit',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/media/{media}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:10:\"media.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"media.update\";s:5:\"media\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/media/(?P<media>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:13:\"/media/%/edit\";s:8:\"numParts\";i:3;}}',	3),
('entity.media.field_ui_fields',	'/admin/structure/media/manage/{media_type}/fields',	'/admin/structure/media/manage/%/fields',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/media/manage/{media_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/media/manage/%/fields\";s:8:\"numParts\";i:6;}}',	6),
('entity.media.revision',	'/media/{media}/revisions/{media_revision}/view',	'/media/%/revisions/%/view',	21,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/media/{media}/revisions/{media_revision}/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController\";s:15:\"_title_callback\";s:65:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:28:\"media_revision.view revision\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:14:\"media_revision\";a:2:{s:4:\"type\";s:21:\"entity_revision:media\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/media/(?P<media>[^/]++)/revisions/(?P<media_revision>[^/]++)/view$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"media_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:25:\"/media/%/revisions/%/view\";s:8:\"numParts\";i:5;}}',	5),
('entity.media.revision_delete_form',	'/media/{media}/revision/{media_revision}/delete',	'/media/%/revision/%/delete',	21,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/media/{media}/revision/{media_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"media.revision-delete\";s:6:\"_title\";s:15:\"Delete revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:30:\"media_revision.delete revision\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:14:\"media_revision\";a:2:{s:4:\"type\";s:21:\"entity_revision:media\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/media/(?P<media>[^/]++)/revision/(?P<media_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"media_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/media/%/revision/%/delete\";s:8:\"numParts\";i:5;}}',	5),
('entity.media.revision_revert_form',	'/media/{media}/revision/{media_revision}/revert',	'/media/%/revision/%/revert',	21,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/media/{media}/revision/{media_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"media.revision-revert\";s:6:\"_title\";s:15:\"Revert revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:21:\"media_revision.revert\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:14:\"media_revision\";a:2:{s:4:\"type\";s:21:\"entity_revision:media\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/media/(?P<media>[^/]++)/revision/(?P<media_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"media_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:2:{i:0;s:5:\"media\";i:1;s:14:\"media_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/media/%/revision/%/revert\";s:8:\"numParts\";i:5;}}',	5),
('entity.media.version_history',	'/media/{media}/revisions',	'/media/%/revisions',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/media/{media}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"Drupal\\Core\\Entity\\Controller\\VersionHistoryController\";s:6:\"_title\";s:9:\"Revisions\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"media.view all revisions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"entity_type_id\";s:5:\"media\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/media/(?P<media>[^/]++)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:18:\"/media/%/revisions\";s:8:\"numParts\";i:3;}}',	3),
('entity.media_type.add_form',	'/admin/structure/media/add',	'/admin/structure/media/add',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/structure/media/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:14:\"media_type.add\";s:14:\"entity_type_id\";s:10:\"media_type\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:10:\"media_type\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/structure/media/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/media/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/structure/media/add\";s:8:\"numParts\";i:4;}}',	4),
('entity.media_type.collection',	'/admin/structure/media',	'/admin/structure/media',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:10:\"media_type\";s:6:\"_title\";s:11:\"Media types\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer media types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/media\";s:8:\"numParts\";i:3;}}',	3),
('entity.media_type.delete_form',	'/admin/structure/media/manage/{media_type}/delete',	'/admin/structure/media/manage/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/structure/media/manage/{media_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"media_type.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"media_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/media/manage/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.media_type.edit_form',	'/admin/structure/media/manage/{media_type}',	'/admin/structure/media/manage/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/media/manage/{media_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"media_type.edit\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"media_type.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:31:\"/admin/structure/media/manage/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.media_type.entity_permissions_form',	'/admin/structure/media/manage/{media_type}/permissions',	'/admin/structure/media/manage/%/permissions',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/media/manage/{media_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:5:\"media\";s:18:\"bundle_entity_type\";s:10:\"media_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:10:\"media_type\";a:3:{s:4:\"type\";s:17:\"entity:media_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/media/manage/%/permissions\";s:8:\"numParts\";i:6;}}',	6),
('entity.menu.add_form',	'/admin/structure/menu/add',	'/admin/structure/menu/add',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/structure/menu/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:8:\"menu.add\";s:6:\"_title\";s:8:\"Add menu\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/structure/menu/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/structure/menu/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/structure/menu/add\";s:8:\"numParts\";i:4;}}',	4),
('entity.menu.add_link_form',	'/admin/structure/menu/manage/{menu}/add',	'/admin/structure/menu/manage/%/add',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/menu/manage/{menu}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\menu_link_content\\Controller\\MenuController::addLink\";s:6:\"_title\";s:13:\"Add menu link\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:17:\"menu_link_content\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:56:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/menu/manage/%/add\";s:8:\"numParts\";i:6;}}',	6),
('entity.menu.collection',	'/admin/structure/menu',	'/admin/structure/menu',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/structure/menu\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:4:\"menu\";s:6:\"_title\";s:5:\"Menus\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/structure/menu$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/structure/menu\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/structure/menu\";s:8:\"numParts\";i:3;}}',	3),
('entity.menu.delete_form',	'/admin/structure/menu/manage/{menu}/delete',	'/admin/structure/menu/manage/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/menu/manage/{menu}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"menu.delete\";s:6:\"_title\";s:11:\"Delete menu\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"menu.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/menu/manage/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.menu.edit_form',	'/admin/structure/menu/manage/{menu}',	'/admin/structure/menu/manage/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/structure/menu/manage/{menu}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:9:\"menu.edit\";s:15:\"_title_callback\";s:52:\"\\Drupal\\menu_ui\\Controller\\MenuController::menuTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"menu.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"menu\";a:2:{s:4:\"type\";s:11:\"entity:menu\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"menu\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/menu/manage/(?P<menu>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"menu\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/menu/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"menu\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:30:\"/admin/structure/menu/manage/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.menu_link_content.canonical',	'/admin/structure/menu/item/{menu_link_content}/edit',	'/admin/structure/menu/item/%/edit',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"menu_link_content.default\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/item/%/edit\";s:8:\"numParts\";i:6;}}',	6),
('entity.menu_link_content.delete_form',	'/admin/structure/menu/item/{menu_link_content}/delete',	'/admin/structure/menu/item/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/menu/item/{menu_link_content}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"menu_link_content.delete\";s:6:\"_title\";s:16:\"Delete menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:35:\"/admin/structure/menu/item/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.menu_link_content.edit_form',	'/admin/structure/menu/item/{menu_link_content}/edit',	'/admin/structure/menu/item/%/edit',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/item/{menu_link_content}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"menu_link_content.default\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"menu_link_content.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/item/%/edit\";s:8:\"numParts\";i:6;}}',	6),
('entity.metatag_defaults.add_form',	'/admin/config/search/metatag/add',	'/admin/config/search/metatag/add',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/search/metatag/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"metatag_defaults.add\";s:6:\"_title\";s:21:\"Add default meta tags\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/search/metatag/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/search/metatag/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:32:\"/admin/config/search/metatag/add\";s:8:\"numParts\";i:5;}}',	5),
('entity.metatag_defaults.collection',	'/admin/config/search/metatag',	'/admin/config/search/metatag',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/config/search/metatag\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"metatag_defaults\";s:6:\"_title\";s:7:\"Metatag\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/config/search/metatag$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/config/search/metatag\";s:8:\"numParts\";i:4;}}',	4),
('entity.metatag_defaults.delete_form',	'/admin/config/search/metatag/{metatag_defaults}/delete',	'/admin/config/search/metatag/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/search/metatag/{metatag_defaults}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"metatag_defaults.delete\";s:6:\"_title\";s:24:\"Delete default meta tags\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"metatag_defaults\";a:2:{s:4:\"type\";s:23:\"entity:metatag_defaults\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/search/metatag/(?P<metatag_defaults>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"metatag_defaults\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/config/search/metatag/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.metatag_defaults.edit_form',	'/admin/config/search/metatag/{metatag_defaults}',	'/admin/config/search/metatag/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/search/metatag/{metatag_defaults}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"metatag_defaults.edit\";s:15:\"_title_callback\";s:50:\"\\Drupal\\metatag\\Form\\MetatagDefaultsForm::getTitle\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"metatag_defaults\";a:2:{s:4:\"type\";s:23:\"entity:metatag_defaults\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/config/search/metatag/(?P<metatag_defaults>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"metatag_defaults\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:30:\"/admin/config/search/metatag/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.metatag_defaults.revert_form',	'/admin/config/search/metatag/{metatag_defaults}/revert',	'/admin/config/search/metatag/%/revert',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/search/metatag/{metatag_defaults}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"metatag_defaults.revert\";s:6:\"_title\";s:24:\"Revert default meta tags\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"metatag_defaults\";a:2:{s:4:\"type\";s:23:\"entity:metatag_defaults\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/search/metatag/(?P<metatag_defaults>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"metatag_defaults\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/search/metatag\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"metatag_defaults\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/config/search/metatag/%/revert\";s:8:\"numParts\";i:6;}}',	6),
('entity.node.canonical',	'/node/{node}',	'/node/%',	2,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/node/{node}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\node\\Controller\\NodeViewController::view\";s:15:\"_title_callback\";s:49:\"\\Drupal\\node\\Controller\\NodeViewController::title\";}s:12:\"requirements\";a:2:{s:4:\"node\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"node.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/node/(?P<node>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/node/%\";s:8:\"numParts\";i:2;}}',	2),
('entity.node.delete_form',	'/node/{node}/delete',	'/node/%/delete',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/node/{node}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"node.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:4:\"node\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"node.delete\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/node/(?P<node>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/node/%/delete\";s:8:\"numParts\";i:3;}}',	3),
('entity.node.delete_multiple_form',	'/admin/content/node/delete',	'/admin/content/node/delete',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/content/node/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\node\\Form\\DeleteMultiple\";s:14:\"entity_type_id\";s:4:\"node\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:4:\"node\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/content/node/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/node/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/content/node/delete\";s:8:\"numParts\";i:4;}}',	4),
('entity.node.edit_form',	'/node/{node}/edit',	'/node/%/edit',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/node/{node}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:9:\"node.edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"node.update\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/node/(?P<node>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:12:\"/node/%/edit\";s:8:\"numParts\";i:3;}}',	3),
('entity.node.field_ui_fields',	'/admin/structure/types/manage/{node_type}/fields',	'/admin/structure/types/manage/%/fields',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/types/manage/{node_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/types/manage/%/fields\";s:8:\"numParts\";i:6;}}',	6),
('entity.node.preview',	'/node/preview/{node_preview}/{view_mode_id}',	'/node/preview/%/%',	12,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/node/preview/{node_preview}/{view_mode_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:51:\"\\Drupal\\node\\Controller\\NodePreviewController::view\";s:15:\"_title_callback\";s:52:\"\\Drupal\\node\\Controller\\NodePreviewController::title\";}s:12:\"requirements\";a:1:{s:20:\"_node_preview_access\";s:14:\"{node_preview}\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:12:\"node_preview\";a:2:{s:4:\"type\";s:12:\"node_preview\";s:9:\"converter\";s:42:\"drupal.proxy_original_service.node_preview\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:25:\"access_check.node.preview\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"node_preview\";i:1;s:12:\"view_mode_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/node/preview/(?P<node_preview>[^/]++)/(?P<view_mode_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"view_mode_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"node_preview\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/node/preview\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"node_preview\";i:1;s:12:\"view_mode_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:12;s:14:\"patternOutline\";s:17:\"/node/preview/%/%\";s:8:\"numParts\";i:4;}}',	4),
('entity.node.revision',	'/node/{node}/revisions/{node_revision}/view',	'/node/%/revisions/%/view',	21,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/node/{node}/revisions/{node_revision}/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\node\\Controller\\NodeController::revisionShow\";s:15:\"_title_callback\";s:57:\"\\Drupal\\node\\Controller\\NodeController::revisionPageTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"node_revision.view revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/view$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:24:\"/node/%/revisions/%/view\";s:8:\"numParts\";i:5;}}',	5),
('entity.node.version_history',	'/node/{node}/revisions',	'/node/%/revisions',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/node/{node}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:9:\"Revisions\";s:11:\"_controller\";s:56:\"\\Drupal\\node\\Controller\\NodeController::revisionOverview\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:23:\"node.view all revisions\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/node/(?P<node>\\d+)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/node/%/revisions\";s:8:\"numParts\";i:3;}}',	3),
('entity.node_type.collection',	'/admin/structure/types',	'/admin/structure/types',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/types\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:9:\"node_type\";s:6:\"_title\";s:13:\"Content types\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/types$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/types\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/types\";s:8:\"numParts\";i:3;}}',	3),
('entity.node_type.delete_form',	'/admin/structure/types/manage/{node_type}/delete',	'/admin/structure/types/manage/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/types/manage/{node_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"node_type.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"node_type.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/types/manage/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.node_type.edit_form',	'/admin/structure/types/manage/{node_type}',	'/admin/structure/types/manage/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/types/manage/{node_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"node_type.edit\";s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:31:\"/admin/structure/types/manage/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.node_type.entity_permissions_form',	'/admin/structure/types/manage/{node_type}/permissions',	'/admin/structure/types/manage/%/permissions',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/structure/types/manage/{node_type}/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:4:\"node\";s:18:\"bundle_entity_type\";s:9:\"node_type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:3:{s:4:\"type\";s:16:\"entity:node_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/types/manage/%/permissions\";s:8:\"numParts\";i:6;}}',	6),
('entity.paragraph.field_ui_fields',	'/admin/structure/paragraphs_type/{paragraphs_type}/fields',	'/admin/structure/paragraphs_type/%/fields',	29,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:41:\"/admin/structure/paragraphs_type/%/fields\";s:8:\"numParts\";i:5;}}',	5),
('entity.paragraphs_type.collection',	'/admin/structure/paragraphs_type',	'/admin/structure/paragraphs_type',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/structure/paragraphs_type\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:15:\"paragraphs_type\";s:6:\"_title\";s:16:\"Paragraphs types\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/structure/paragraphs_type$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:32:\"/admin/structure/paragraphs_type\";s:8:\"numParts\";i:3;}}',	3),
('entity.paragraphs_type.delete_form',	'/admin/structure/paragraphs_type/{paragraphs_type}/delete',	'/admin/structure/paragraphs_type/%/delete',	29,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/paragraphs_type/{paragraphs_type}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"paragraphs_type.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:41:\"/admin/structure/paragraphs_type/%/delete\";s:8:\"numParts\";i:5;}}',	5),
('entity.paragraphs_type.edit_form',	'/admin/structure/paragraphs_type/{paragraphs_type}',	'/admin/structure/paragraphs_type/%',	14,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/paragraphs_type/{paragraphs_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:20:\"paragraphs_type.edit\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:34:\"/admin/structure/paragraphs_type/%\";s:8:\"numParts\";i:4;}}',	4),
('entity.pathauto_pattern.add_form',	'/admin/config/search/path/patterns/add',	'/admin/config/search/path/patterns/add',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/config/search/path/patterns/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:24:\"pathauto_pattern.default\";s:6:\"_title\";s:20:\"Add Pathauto pattern\";s:12:\"tempstore_id\";s:16:\"pathauto.pattern\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"administer pathauto\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/search/path/patterns/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/config/search/path/patterns/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:38:\"/admin/config/search/path/patterns/add\";s:8:\"numParts\";i:6;}}',	6),
('entity.pathauto_pattern.collection',	'/admin/config/search/path/patterns',	'/admin/config/search/path/patterns',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/search/path/patterns\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:16:\"pathauto_pattern\";s:6:\"_title\";s:8:\"Patterns\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"administer pathauto\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/search/path/patterns$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/config/search/path/patterns\";s:8:\"numParts\";i:5;}}',	5),
('entity.pathauto_pattern.delete_form',	'/admin/config/search/path/patterns/{pathauto_pattern}/delete',	'/admin/config/search/path/patterns/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/search/path/patterns/{pathauto_pattern}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"pathauto_pattern.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"pathauto_pattern.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:43:\"/admin/config/search/path/patterns/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.pathauto_pattern.disable',	'/admin/config/search/path/patterns/{pathauto_pattern}/disable',	'/admin/config/search/path/patterns/%/disable',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/config/search/path/patterns/{pathauto_pattern}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:24:\"pathauto_pattern.disable\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"pathauto_pattern.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:44:\"/admin/config/search/path/patterns/%/disable\";s:8:\"numParts\";i:7;}}',	7),
('entity.pathauto_pattern.duplicate_form',	'/admin/config/search/path/patterns/{pathauto_pattern}/duplicate',	'/admin/config/search/path/patterns/%/duplicate',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/config/search/path/patterns/{pathauto_pattern}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:26:\"pathauto_pattern.duplicate\";s:6:\"_title\";s:26:\"Duplicate Pathauto pattern\";s:12:\"tempstore_id\";s:16:\"pathauto.pattern\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"administer pathauto\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/search/path/patterns/%/duplicate\";s:8:\"numParts\";i:7;}}',	7),
('entity.pathauto_pattern.edit_form',	'/admin/config/search/path/patterns/{pathauto_pattern}',	'/admin/config/search/path/patterns/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/search/path/patterns/{pathauto_pattern}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"pathauto_pattern.default\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"pathauto_pattern.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:36:\"/admin/config/search/path/patterns/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.pathauto_pattern.enable',	'/admin/config/search/path/patterns/{pathauto_pattern}/enable',	'/admin/config/search/path/patterns/%/enable',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/search/path/patterns/{pathauto_pattern}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:12:\"_entity_form\";s:23:\"pathauto_pattern.enable\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"pathauto_pattern.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:16:\"pathauto_pattern\";a:2:{s:4:\"type\";s:23:\"entity:pathauto_pattern\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/search/path/patterns/(?P<pathauto_pattern>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"pathauto_pattern\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/patterns\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"pathauto_pattern\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:43:\"/admin/config/search/path/patterns/%/enable\";s:8:\"numParts\";i:7;}}',	7),
('entity.path_alias.add_form',	'/admin/config/search/path/add',	'/admin/config/search/path/add',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/search/path/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:18:\"path_alias.default\";s:14:\"entity_type_id\";s:10:\"path_alias\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:10:\"path_alias\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/search/path/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/search/path/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:29:\"/admin/config/search/path/add\";s:8:\"numParts\";i:5;}}',	5),
('entity.path_alias.collection',	'/admin/config/search/path',	'/admin/config/search/path',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/search/path\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:10:\"path_alias\";s:6:\"_title\";s:11:\"URL aliases\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer url aliases\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/search/path$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/search/path\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/config/search/path\";s:8:\"numParts\";i:4;}}',	4),
('entity.path_alias.delete_form',	'/admin/config/search/path/delete/{path_alias}',	'/admin/config/search/path/delete/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/search/path/delete/{path_alias}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"path_alias.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:17:\"path_alias.delete\";s:10:\"path_alias\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"path_alias\";a:2:{s:4:\"type\";s:17:\"entity:path_alias\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"path_alias\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/config/search/path/delete/(?P<path_alias>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:10:\"path_alias\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/search/path/delete\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"path_alias\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:34:\"/admin/config/search/path/delete/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.path_alias.edit_form',	'/admin/config/search/path/edit/{path_alias}',	'/admin/config/search/path/edit/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/config/search/path/edit/{path_alias}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"path_alias.default\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:17:\"path_alias.update\";s:10:\"path_alias\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"path_alias\";a:2:{s:4:\"type\";s:17:\"entity:path_alias\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"path_alias\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/admin/config/search/path/edit/(?P<path_alias>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:10:\"path_alias\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/search/path/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"path_alias\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:32:\"/admin/config/search/path/edit/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.redirect.canonical',	'/admin/config/search/redirect/edit/{redirect}',	'/admin/config/search/redirect/edit/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/search/redirect/edit/{redirect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"redirect.edit\";s:6:\"_title\";s:17:\"Edit URL redirect\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:15:\"redirect.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"redirect\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"redirect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/config/search/redirect/edit/(?P<redirect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"redirect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/redirect/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"redirect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:36:\"/admin/config/search/redirect/edit/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.redirect.delete_form',	'/admin/config/search/redirect/delete/{redirect}',	'/admin/config/search/redirect/delete/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/search/redirect/delete/{redirect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"redirect.delete\";s:6:\"_title\";s:19:\"Delete URL redirect\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:15:\"redirect.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"redirect\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"redirect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/config/search/redirect/delete/(?P<redirect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"redirect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/search/redirect/delete\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"redirect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:38:\"/admin/config/search/redirect/delete/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.redirect.edit_form',	'/admin/config/search/redirect/edit/{redirect}',	'/admin/config/search/redirect/edit/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/search/redirect/edit/{redirect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"redirect.edit\";s:6:\"_title\";s:17:\"Edit URL redirect\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:15:\"redirect.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"redirect\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"redirect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/config/search/redirect/edit/(?P<redirect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"redirect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/redirect/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"redirect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:36:\"/admin/config/search/redirect/edit/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.redirect.multiple_delete_confirm',	'/admin/config/search/redirect/delete',	'/admin/config/search/redirect/delete',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/config/search/redirect/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:48:\"\\Drupal\\redirect\\Form\\RedirectDeleteMultipleForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer redirects\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/config/search/redirect/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/search/redirect/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:36:\"/admin/config/search/redirect/delete\";s:8:\"numParts\";i:5;}}',	5),
('entity.search_page.collection',	'/admin/config/search/pages',	'/admin/config/search/pages',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/config/search/pages\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:11:\"search_page\";s:6:\"_title\";s:12:\"Search pages\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer search\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/config/search/pages$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/config/search/pages\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/config/search/pages\";s:8:\"numParts\";i:4;}}',	4),
('entity.search_page.delete_form',	'/admin/config/search/pages/manage/{search_page}/delete',	'/admin/config/search/pages/manage/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/search/pages/manage/{search_page}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:18:\"search_page.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"search_page.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"search_page\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"search_page\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"search_page\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/pages/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"search_page\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:42:\"/admin/config/search/pages/manage/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.search_page.disable',	'/admin/config/search/pages/manage/{search_page}/disable',	'/admin/config/search/pages/manage/%/disable',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/config/search/pages/manage/{search_page}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\search\\Controller\\SearchController::performOperation\";s:2:\"op\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:19:\"search_page.disable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"search_page\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"search_page\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"search_page\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/pages/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"search_page\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:43:\"/admin/config/search/pages/manage/%/disable\";s:8:\"numParts\";i:7;}}',	7),
('entity.search_page.edit_form',	'/admin/config/search/pages/manage/{search_page}',	'/admin/config/search/pages/manage/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/search/pages/manage/{search_page}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"search_page.edit\";s:15:\"_title_callback\";s:53:\"\\Drupal\\search\\Controller\\SearchController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:18:\"search_page.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"search_page\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"search_page\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"search_page\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/pages/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"search_page\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:35:\"/admin/config/search/pages/manage/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.search_page.enable',	'/admin/config/search/pages/manage/{search_page}/enable',	'/admin/config/search/pages/manage/%/enable',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/config/search/pages/manage/{search_page}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\search\\Controller\\SearchController::performOperation\";s:2:\"op\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:18:\"search_page.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"search_page\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"search_page\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"search_page\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/pages/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"search_page\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:42:\"/admin/config/search/pages/manage/%/enable\";s:8:\"numParts\";i:7;}}',	7),
('entity.search_page.set_default',	'/admin/config/search/pages/manage/{search_page}/set-default',	'/admin/config/search/pages/manage/%/set-default',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/search/pages/manage/{search_page}/set-default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:56:\"\\Drupal\\search\\Controller\\SearchController::setAsDefault\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:18:\"search_page.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"search_page\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:11:\"search_page\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/search/pages/manage/(?P<search_page>[^/]++)/set\\-default$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/set-default\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"search_page\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/pages/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:11:\"search_page\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:47:\"/admin/config/search/pages/manage/%/set-default\";s:8:\"numParts\";i:7;}}',	7),
('entity.shortcut.canonical',	'/admin/config/user-interface/shortcut/link/{shortcut}',	'/admin/config/user-interface/shortcut/link/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut.default\";s:6:\"_title\";s:4:\"Edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.update\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/user-interface/shortcut/link/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.shortcut.delete_form',	'/admin/config/user-interface/shortcut/link/{shortcut}/delete',	'/admin/config/user-interface/shortcut/link/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"shortcut.delete\";s:6:\"_title\";s:6:\"Delete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.delete\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/config/user-interface/shortcut/link/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.shortcut.edit_form',	'/admin/config/user-interface/shortcut/link/{shortcut}',	'/admin/config/user-interface/shortcut/link/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/admin/config/user-interface/shortcut/link/{shortcut}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut.default\";s:6:\"_title\";s:4:\"Edit\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"shortcut.update\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:44:\"/admin/config/user-interface/shortcut/link/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.shortcut.link_delete_inline',	'/admin/config/user-interface/shortcut/link/{shortcut}/delete-inline',	'/admin/config/user-interface/shortcut/link/%/delete-inline',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/config/user-interface/shortcut/link/{shortcut}/delete-inline\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:72:\"\\Drupal\\shortcut\\Controller\\ShortcutController::deleteShortcutLinkInline\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:15:\"shortcut.delete\";s:11:\"_csrf_token\";s:4:\"TRUE\";s:8:\"shortcut\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/delete\\-inline$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/delete-inline\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:58:\"/admin/config/user-interface/shortcut/link/%/delete-inline\";s:8:\"numParts\";i:7;}}',	7),
('entity.shortcut_set.collection',	'/admin/config/user-interface/shortcut',	'/admin/config/user-interface/shortcut',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/user-interface/shortcut\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:12:\"shortcut_set\";s:6:\"_title\";s:9:\"Shortcuts\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer shortcuts\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/user\\-interface/shortcut$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/user-interface/shortcut\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/user-interface/shortcut\";s:8:\"numParts\";i:4;}}',	4),
('entity.shortcut_set.customize_form',	'/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize',	'/admin/config/user-interface/shortcut/manage/%/customize',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/customize\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"shortcut_set.customize\";s:6:\"_title\";s:10:\"List links\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/customize$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/customize\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:56:\"/admin/config/user-interface/shortcut/manage/%/customize\";s:8:\"numParts\";i:7;}}',	7),
('entity.shortcut_set.delete_form',	'/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete',	'/admin/config/user-interface/shortcut/manage/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"shortcut_set.delete\";s:6:\"_title\";s:19:\"Delete shortcut set\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:53:\"/admin/config/user-interface/shortcut/manage/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('entity.shortcut_set.edit_form',	'/admin/config/user-interface/shortcut/manage/{shortcut_set}',	'/admin/config/user-interface/shortcut/manage/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"shortcut_set.edit\";s:6:\"_title\";s:17:\"Edit shortcut set\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:46:\"/admin/config/user-interface/shortcut/manage/%\";s:8:\"numParts\";i:6;}}',	6),
('entity.taxonomy_term.add_form',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/add',	'/admin/structure/taxonomy/manage/%/add',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\taxonomy\\Controller\\TaxonomyController::addForm\";s:6:\"_title\";s:8:\"Add term\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:35:\"taxonomy_term:{taxonomy_vocabulary}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:38:\"/admin/structure/taxonomy/manage/%/add\";s:8:\"numParts\";i:6;}}',	6),
('entity.taxonomy_term.canonical',	'/taxonomy/term/{taxonomy_term}',	'/taxonomy/term/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/taxonomy/term/{taxonomy_term}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:57:\"\\Drupal\\taxonomy\\Controller\\TaxonomyController::termTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:13:\"taxonomy_term\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/taxonomy/term/%\";s:8:\"numParts\";i:3;}}',	3),
('entity.taxonomy_term.delete_form',	'/taxonomy/term/{taxonomy_term}/delete',	'/taxonomy/term/%/delete',	13,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/taxonomy/term/{taxonomy_term}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"taxonomy_term.delete\";s:6:\"_title\";s:11:\"Delete term\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"taxonomy_term.delete\";s:13:\"taxonomy_term\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:23:\"/taxonomy/term/%/delete\";s:8:\"numParts\";i:4;}}',	4),
('entity.taxonomy_term.edit_form',	'/taxonomy/term/{taxonomy_term}/edit',	'/taxonomy/term/%/edit',	13,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/taxonomy/term/{taxonomy_term}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"taxonomy_term.default\";s:6:\"_title\";s:9:\"Edit term\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:20:\"taxonomy_term.update\";s:13:\"taxonomy_term\";s:3:\"\\d+\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:21:\"/taxonomy/term/%/edit\";s:8:\"numParts\";i:4;}}',	4),
('entity.taxonomy_term.field_ui_fields',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields',	'/admin/structure/taxonomy/manage/%/overview/fields',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:70:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/overview/fields\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/taxonomy/manage/%/overview/fields\";s:8:\"numParts\";i:7;}}',	7),
('entity.taxonomy_term.revision',	'/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view',	'/taxonomy/term/%/revision/%/view',	53,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController\";s:15:\"_title_callback\";s:65:\"Drupal\\Core\\Entity\\Controller\\EntityRevisionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:36:\"taxonomy_term_revision.view revision\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:96:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/view$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:32:\"/taxonomy/term/%/revision/%/view\";s:8:\"numParts\";i:6;}}',	6),
('entity.taxonomy_term.revision_delete_form',	'/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete',	'/taxonomy/term/%/revision/%/delete',	53,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"taxonomy_term.revision-delete\";s:6:\"_title\";s:15:\"Delete revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:38:\"taxonomy_term_revision.delete revision\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:34:\"/taxonomy/term/%/revision/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.taxonomy_term.revision_revert_form',	'/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert',	'/taxonomy/term/%/revision/%/revert',	53,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/taxonomy/term/{taxonomy_term}/revision/{taxonomy_term_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"taxonomy_term.revision-revert\";s:6:\"_title\";s:15:\"Revert revision\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:29:\"taxonomy_term_revision.revert\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:22:\"taxonomy_term_revision\";a:2:{s:4:\"type\";s:29:\"entity_revision:taxonomy_term\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revision/(?P<taxonomy_term_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"taxonomy_term_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/revision\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:2:{i:0;s:13:\"taxonomy_term\";i:1;s:22:\"taxonomy_term_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:53;s:14:\"patternOutline\";s:34:\"/taxonomy/term/%/revision/%/revert\";s:8:\"numParts\";i:6;}}',	6),
('entity.taxonomy_term.version_history',	'/taxonomy/term/{taxonomy_term}/revisions',	'/taxonomy/term/%/revisions',	13,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/taxonomy/term/{taxonomy_term}/revisions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"Drupal\\Core\\Entity\\Controller\\VersionHistoryController\";s:6:\"_title\";s:9:\"Revisions\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:32:\"taxonomy_term.view all revisions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/taxonomy/term/(?P<taxonomy_term>[^/]++)/revisions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:26:\"/taxonomy/term/%/revisions\";s:8:\"numParts\";i:4;}}',	4),
('entity.taxonomy_vocabulary.add_form',	'/admin/structure/taxonomy/add',	'/admin/structure/taxonomy/add',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/structure/taxonomy/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:27:\"taxonomy_vocabulary.default\";s:14:\"entity_type_id\";s:19:\"taxonomy_vocabulary\";s:15:\"_title_callback\";s:56:\"Drupal\\Core\\Entity\\Controller\\EntityController::addTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:19:\"taxonomy_vocabulary\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/taxonomy/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/taxonomy/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/structure/taxonomy/add\";s:8:\"numParts\";i:4;}}',	4),
('entity.taxonomy_vocabulary.collection',	'/admin/structure/taxonomy',	'/admin/structure/taxonomy',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/structure/taxonomy\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:12:\"_entity_list\";s:19:\"taxonomy_vocabulary\";s:6:\"_title\";s:8:\"Taxonomy\";s:16:\"_title_arguments\";a:0:{}s:14:\"_title_context\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:44:\"administer taxonomy+access taxonomy overview\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/structure/taxonomy$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/structure/taxonomy\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/structure/taxonomy\";s:8:\"numParts\";i:3;}}',	3),
('entity.taxonomy_vocabulary.delete_form',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete',	'/admin/structure/taxonomy/manage/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:26:\"taxonomy_vocabulary.delete\";s:15:\"_title_callback\";s:60:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::deleteTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:26:\"taxonomy_vocabulary.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/taxonomy/manage/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.taxonomy_vocabulary.edit_form',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}',	'/admin/structure/taxonomy/manage/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:27:\"taxonomy_vocabulary.default\";s:15:\"_title_callback\";s:58:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::editTitle\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:26:\"taxonomy_vocabulary.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:34:\"/admin/structure/taxonomy/manage/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.taxonomy_vocabulary.entity_permissions_form',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions',	'/admin/structure/taxonomy/manage/%/overview/permissions',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:18:\"Manage permissions\";s:5:\"_form\";s:38:\"Drupal\\user\\Form\\EntityPermissionsForm\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:18:\"bundle_entity_type\";s:19:\"taxonomy_vocabulary\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/permissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/overview/permissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:55:\"/admin/structure/taxonomy/manage/%/overview/permissions\";s:8:\"numParts\";i:7;}}',	7),
('entity.taxonomy_vocabulary.overview_form',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview',	'/admin/structure/taxonomy/manage/%/overview',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:15:\"_title_callback\";s:54:\"\\Drupal\\Core\\Entity\\Controller\\EntityController::title\";s:5:\"_form\";s:34:\"Drupal\\taxonomy\\Form\\OverviewTerms\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:44:\"taxonomy_vocabulary.access taxonomy overview\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:21:\"with_config_overrides\";b:1;s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/overview\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/taxonomy/manage/%/overview\";s:8:\"numParts\";i:6;}}',	6),
('entity.taxonomy_vocabulary.reset_form',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset',	'/admin/structure/taxonomy/manage/%/reset',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/reset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"taxonomy_vocabulary.reset\";s:6:\"_title\";s:5:\"Reset\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:37:\"taxonomy_vocabulary.reset all weights\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:3:{s:21:\"with_config_overrides\";b:1;s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/reset$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/reset\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/taxonomy/manage/%/reset\";s:8:\"numParts\";i:6;}}',	6),
('entity.user.admin_form',	'/admin/config/people/accounts',	'/admin/config/people/accounts',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/people/accounts\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\user\\AccountSettingsForm\";s:6:\"_title\";s:16:\"Account settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer account settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/people/accounts$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/people/accounts\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/people/accounts\";s:8:\"numParts\";i:4;}}',	4),
('entity.user.cancel_form',	'/user/{user}/cancel',	'/user/%/cancel',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/user/{user}/cancel\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:14:\"Cancel account\";s:12:\"_entity_form\";s:11:\"user.cancel\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"user.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/user/(?P<user>\\d+)/cancel$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/cancel\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/user/%/cancel\";s:8:\"numParts\";i:3;}}',	3),
('entity.user.canonical',	'/user/{user}',	'/user/%',	2,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/{user}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_view\";s:9:\"user.full\";s:15:\"_title_callback\";s:48:\"Drupal\\user\\Controller\\UserController::userTitle\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"user.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/user/(?P<user>\\d+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/user/%\";s:8:\"numParts\";i:2;}}',	2),
('entity.user.collection',	'/admin/people',	'/admin/people',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:17:\"user_admin_people\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:16:\"administer users\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/people\";s:8:\"numParts\";i:2;}}',	2),
('entity.user.contact_form',	'/user/{user}/contact',	'/user/%/contact',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/user/{user}/contact\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:7:\"Contact\";s:11:\"_controller\";s:65:\"\\Drupal\\contact\\Controller\\ContactController::contactPersonalPage\";}s:12:\"requirements\";a:2:{s:28:\"_access_contact_personal_tab\";s:4:\"TRUE\";s:4:\"user\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:29:\"access_check.contact_personal\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/user/(?P<user>\\d+)/contact$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/contact\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/user/%/contact\";s:8:\"numParts\";i:3;}}',	3),
('entity.user.edit_form',	'/user/{user}/edit',	'/user/%/edit',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/user/{user}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"user.default\";s:15:\"_title_callback\";s:48:\"Drupal\\user\\Controller\\UserController::userTitle\";}s:12:\"requirements\";a:2:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:11:\"user.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/user/(?P<user>\\d+)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:12:\"/user/%/edit\";s:8:\"numParts\";i:3;}}',	3),
('entity.user.field_ui_fields',	'/admin/config/people/accounts/fields',	'/admin/config/people/accounts/fields',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/config/people/accounts/fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:62:\"\\Drupal\\field_ui\\Controller\\FieldConfigListController::listing\";s:6:\"_title\";s:13:\"Manage fields\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/config/people/accounts/fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/people/accounts/fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:36:\"/admin/config/people/accounts/fields\";s:8:\"numParts\";i:5;}}',	5),
('entity.user_role.collection',	'/admin/people/roles',	'/admin/people/roles',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/people/roles\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:9:\"user_role\";s:6:\"_title\";s:5:\"Roles\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/people/roles$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/people/roles\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/people/roles\";s:8:\"numParts\";i:3;}}',	3),
('entity.user_role.delete_form',	'/admin/people/roles/manage/{user_role}/delete',	'/admin/people/roles/manage/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/people/roles/manage/{user_role}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"user_role.delete\";s:6:\"_title\";s:11:\"Delete role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:62:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:35:\"/admin/people/roles/manage/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.user_role.edit_form',	'/admin/people/roles/manage/{user_role}',	'/admin/people/roles/manage/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/people/roles/manage/{user_role}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"user_role.default\";s:6:\"_title\";s:9:\"Edit role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/people/roles/manage/(?P<user_role>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/people/roles/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/people/roles/manage/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.user_role.edit_permissions_form',	'/admin/people/permissions/{user_role}',	'/admin/people/permissions/%',	14,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/people/permissions/{user_role}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:49:\"\\Drupal\\user\\Form\\UserPermissionsRoleSpecificForm\";s:6:\"_title\";s:9:\"Edit role\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:16:\"user_role.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"user_role\";a:2:{s:4:\"type\";s:16:\"entity:user_role\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"user_role\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/people/permissions/(?P<user_role>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"user_role\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/people/permissions\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"user_role\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:27:\"/admin/people/permissions/%\";s:8:\"numParts\";i:4;}}',	4),
('entity.view.break_lock_form',	'/admin/structure/views/view/{view}/break-lock',	'/admin/structure/views/view/%/break-lock',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/views/view/{view}/break-lock\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"view.break_lock\";s:6:\"_title\";s:10:\"Break lock\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:15:\"view.break-lock\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:63:\"{^/admin/structure/views/view/(?P<view>[^/]++)/break\\-lock$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/break-lock\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/views/view/%/break-lock\";s:8:\"numParts\";i:6;}}',	6),
('entity.view.collection',	'/admin/structure/views',	'/admin/structure/views',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/structure/views\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:4:\"view\";s:6:\"_title\";s:5:\"Views\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/structure/views$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/structure/views\";s:8:\"numParts\";i:3;}}',	3),
('entity.view.delete_form',	'/admin/structure/views/view/{view}/delete',	'/admin/structure/views/view/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/views/view/{view}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"view.delete\";s:6:\"_title\";s:11:\"Delete view\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/views/view/(?P<view>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:36:\"/admin/structure/views/view/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.view.disable',	'/admin/structure/views/view/{view}/disable',	'/admin/structure/views/view/%/disable',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/views/view/{view}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::ajaxOperation\";s:2:\"op\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:12:\"view.disable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:59:\"{^/admin/structure/views/view/(?P<view>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/views/view/%/disable\";s:8:\"numParts\";i:6;}}',	6),
('entity.view.duplicate_form',	'/admin/structure/views/view/{view}/duplicate',	'/admin/structure/views/view/%/duplicate',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/structure/views/view/{view}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"view.duplicate\";s:6:\"_title\";s:14:\"Duplicate view\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"view.duplicate\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/structure/views/view/(?P<view>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:39:\"/admin/structure/views/view/%/duplicate\";s:8:\"numParts\";i:6;}}',	6),
('entity.view.edit_display_form',	'/admin/structure/views/view/{view}/edit/{display_id}',	'/admin/structure/views/view/%/edit',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/structure/views/view/{view}/edit/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::edit\";s:10:\"display_id\";N;}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/views/view/(?P<view>[^/]++)/edit(?:/(?P<display_id>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/views/view/%/edit\";s:8:\"numParts\";i:7;}}',	7),
('entity.view.edit_form',	'/admin/structure/views/view/{view}',	'/admin/structure/views/view/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/structure/views/view/{view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::edit\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:11:\"view.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/structure/views/view/(?P<view>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:29:\"/admin/structure/views/view/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.view.enable',	'/admin/structure/views/view/{view}/enable',	'/admin/structure/views/view/%/enable',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/views/view/{view}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::ajaxOperation\";s:2:\"op\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.enable\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"view\";a:2:{s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/views/view/(?P<view>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:36:\"/admin/structure/views/view/%/enable\";s:8:\"numParts\";i:6;}}',	6),
('entity.view.preview_form',	'/admin/structure/views/view/{view}/preview/{display_id}',	'/admin/structure/views/view/%/preview',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/views/view/{view}/preview/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"view.preview\";s:10:\"display_id\";N;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/structure/views/view/(?P<view>[^/]++)/preview(?:/(?P<display_id>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/preview\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/structure/views/view\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"view\";i:1;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:37:\"/admin/structure/views/view/%/preview\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.access_denied',	'/webform/{webform}/access-denied',	'/webform/%/access-denied',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/webform/{webform}/access-denied\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::accessDenied\";s:15:\"_title_callback\";s:69:\"\\Drupal\\webform\\Controller\\WebformEntityController::accessDeniedTitle\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/webform/(?P<webform>[^/]++)/access\\-denied$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/access-denied\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:24:\"/webform/%/access-denied\";s:8:\"numParts\";i:3;}}',	3),
('entity.webform.add_form',	'/admin/structure/webform/add',	'/admin/structure/webform/add',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/structure/webform/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:11:\"webform.add\";s:6:\"_title\";s:11:\"Add webform\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:7:\"webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/structure/webform/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/structure/webform/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/structure/webform/add\";s:8:\"numParts\";i:4;}}',	4),
('entity.webform.assets.css',	'/webform/css/{webform}/custom.css',	'/webform/css/%/custom.css',	13,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/webform/css/{webform}/custom.css\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:55:\"\\Drupal\\webform\\Controller\\WebformEntityController::css\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/webform/css/(?P<webform>[^/]++)/custom\\.css$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/custom.css\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/webform/css\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:25:\"/webform/css/%/custom.css\";s:8:\"numParts\";i:4;}}',	4),
('entity.webform.assets.javascript',	'/webform/javascript/{webform}/custom.js',	'/webform/javascript/%/custom.js',	13,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/webform/javascript/{webform}/custom.js\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\webform\\Controller\\WebformEntityController::javascript\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/webform/javascript/(?P<webform>[^/]++)/custom\\.js$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/custom.js\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/webform/javascript\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:31:\"/webform/javascript/%/custom.js\";s:8:\"numParts\";i:4;}}',	4),
('entity.webform.autocomplete',	'/admin/structure/webform/autocomplete',	'/admin/structure/webform/autocomplete',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/structure/webform/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::autocomplete\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkOverviewAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/structure/webform/autocomplete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/webform/autocomplete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/structure/webform/autocomplete\";s:8:\"numParts\";i:4;}}',	4),
('entity.webform.autocomplete.archived',	'/admin/structure/webform/autocomplete/archived',	'/admin/structure/webform/autocomplete/archived',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/structure/webform/autocomplete/archived\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::autocomplete\";s:8:\"archived\";b:1;}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkOverviewAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/admin/structure/webform/autocomplete/archived$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/structure/webform/autocomplete/archived\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/autocomplete/archived\";s:8:\"numParts\";i:5;}}',	5),
('entity.webform.canonical',	'/webform/{webform}',	'/webform/%',	2,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/webform/{webform}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\webform\\Controller\\WebformEntityController::addForm\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform.submission_page\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/webform/(?P<webform>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:10:\"/webform/%\";s:8:\"numParts\";i:2;}}',	2),
('entity.webform.collection',	'/admin/structure/webform',	'/admin/structure/webform',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/structure/webform\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:7:\"webform\";s:6:\"_title\";s:8:\"Webforms\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkOverviewAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/structure/webform$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/structure/webform\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/structure/webform\";s:8:\"numParts\";i:3;}}',	3),
('entity.webform.confirmation',	'/webform/{webform}/confirmation',	'/webform/%/confirmation',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/webform/{webform}/confirmation\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformEntityController::confirmation\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/webform/(?P<webform>[^/]++)/confirmation$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/confirmation\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:23:\"/webform/%/confirmation\";s:8:\"numParts\";i:3;}}',	3),
('entity.webform.delete_form',	'/admin/structure/webform/manage/{webform}/delete',	'/admin/structure/webform/manage/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/manage/{webform}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"webform.delete\";s:6:\"_title\";s:14:\"Delete webform\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/manage/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.webform.duplicate_form',	'/admin/structure/webform/manage/{webform}/duplicate',	'/admin/structure/webform/manage/%/duplicate',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/webform/manage/{webform}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"webform.duplicate\";s:6:\"_title\";s:17:\"Duplicate webform\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"webform.duplicate\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/manage/%/duplicate\";s:8:\"numParts\";i:6;}}',	6),
('entity.webform.edit_form',	'/admin/structure/webform/manage/{webform}',	'/admin/structure/webform/manage/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/webform/manage/{webform}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"webform.edit\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/structure/webform/manage/%\";s:8:\"numParts\";i:5;}}',	5),
('entity.webform.export_form',	'/admin/structure/webform/manage/{webform}/export',	'/admin/structure/webform/manage/%/export',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/manage/{webform}/export\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:14:\"webform.export\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"export configuration\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/export$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/export\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/manage/%/export\";s:8:\"numParts\";i:6;}}',	6),
('entity.webform.handler',	'/admin/structure/webform/manage/{webform}/handlers/add',	'/admin/structure/webform/manage/%/handlers/add',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/webform/manage/{webform}/handlers/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:71:\"\\Drupal\\webform\\Controller\\WebformPluginHandlerController::listHandlers\";s:6:\"_title\";s:16:\"Select a handler\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:63:\"\\Drupal\\webform\\Access\\WebformHandlerAccess::checkHandlerAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/handlers/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/manage/%/handlers/add\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.handler.add_email',	'/admin/structure/webform/manage/{webform}/handlers/add/email',	'/admin/structure/webform/manage/%/handlers/add/email',	247,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/webform/manage/{webform}/handlers/add/email\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:42:\"\\Drupal\\webform\\Form\\WebformHandlerAddForm\";s:6:\"_title\";s:9:\"Add email\";s:15:\"webform_handler\";s:5:\"email\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:63:\"\\Drupal\\webform\\Access\\WebformHandlerAccess::checkHandlerAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/add/email$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/handlers/add/email\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/handlers/add/email\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.handler.add_form',	'/admin/structure/webform/manage/{webform}/handlers/add/{webform_handler}',	'/admin/structure/webform/manage/%/handlers/add/%',	246,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/webform/manage/{webform}/handlers/add/{webform_handler}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\webform\\Form\\WebformHandlerAddForm\";s:6:\"_title\";s:19:\"Add webform handler\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:63:\"\\Drupal\\webform\\Access\\WebformHandlerAccess::checkHandlerAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/add/(?P<webform_handler>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/handlers/add\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/handlers/add/%\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.handler.delete_form',	'/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/delete',	'/admin/structure/webform/manage/%/handlers/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:45:\"\\Drupal\\webform\\Form\\WebformHandlerDeleteForm\";s:6:\"_title\";s:22:\"Delete webform handler\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/handlers/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.handler.disable',	'/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/disable',	'/admin/structure/webform/manage/%/handlers/%/disable',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityHandlersForm::ajaxOperation\";s:9:\"operation\";s:7:\"disable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:103:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/handlers/%/disable\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.handler.duplicate_form',	'/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/duplicate',	'/admin/structure/webform/manage/%/handlers/%/duplicate',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:48:\"\\Drupal\\webform\\Form\\WebformHandlerDuplicateForm\";s:6:\"_title\";s:25:\"Duplicate webform handler\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:54:\"/admin/structure/webform/manage/%/handlers/%/duplicate\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.handler.edit_form',	'/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/edit',	'/admin/structure/webform/manage/%/handlers/%/edit',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformHandlerEditForm\";s:6:\"_title\";s:20:\"Edit webform handler\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/webform/manage/%/handlers/%/edit\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.handler.enable',	'/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/enable',	'/admin/structure/webform/manage/%/handlers/%/enable',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/handlers/{webform_handler}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityHandlersForm::ajaxOperation\";s:9:\"operation\";s:6:\"enable\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers/(?P<webform_handler>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_handler\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_handler\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/handlers/%/enable\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.handlers',	'/admin/structure/webform/manage/{webform}/handlers',	'/admin/structure/webform/manage/%/handlers',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/webform/manage/{webform}/handlers\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"webform.handlers\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/handlers$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/handlers\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/manage/%/handlers\";s:8:\"numParts\";i:6;}}',	6),
('entity.webform.multiple_delete_confirm',	'/admin/structure/webform/delete',	'/admin/structure/webform/delete',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/webform/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:52:\"\\Drupal\\webform\\Form\\WebformEntityDeleteMultipleForm\";s:14:\"entity_type_id\";s:7:\"webform\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:7:\"webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/webform/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/webform/delete\";s:8:\"numParts\";i:4;}}',	4),
('entity.webform.results.source_entity.autocomplete',	'/admin/structure/webform/manage/{webform}/results/source-entity/autocomplete',	'/admin/structure/webform/manage/%/results/source-entity/autocomplete',	247,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/webform/manage/{webform}/results/source-entity/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:81:\"\\Drupal\\webform\\Controller\\WebformSubmissionsController::sourceEntityAutocomplete\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/source\\-entity/autocomplete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/results/source-entity/autocomplete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:68:\"/admin/structure/webform/manage/%/results/source-entity/autocomplete\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.results_clear',	'/admin/structure/webform/manage/{webform}/results/clear',	'/admin/structure/webform/manage/%/results/clear',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/results/clear\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"Drupal\\webform\\Form\\WebformResultsClearForm\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:28:\"webform.submission_purge_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/clear$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/results/clear\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/results/clear\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.results_export',	'/admin/structure/webform/manage/{webform}/results/download',	'/admin/structure/webform/manage/%/results/download',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/webform/manage/{webform}/results/download\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformResultsExportController::index\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/download$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/results/download\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/webform/manage/%/results/download\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.results_export_file',	'/admin/structure/webform/manage/{webform}/results/download/file/{filename}',	'/admin/structure/webform/manage/%/results/download/file/%',	494,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/structure/webform/manage/{webform}/results/download/file/{filename}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:63:\"\\Drupal\\webform\\Controller\\WebformResultsExportController::file\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"filename\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/download/file/(?P<filename>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"filename\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/results/download/file\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:8:\"filename\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:494;s:14:\"patternOutline\";s:57:\"/admin/structure/webform/manage/%/results/download/file/%\";s:8:\"numParts\";i:9;}}',	9),
('entity.webform.results_submissions',	'/admin/structure/webform/manage/{webform}/results/submissions/{submission_view}',	'/admin/structure/webform/manage/%/results/submissions',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/webform/manage/{webform}/results/submissions/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/submissions(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/results/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/results/submissions\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.results_submissions.custom',	'/admin/structure/webform/manage/{webform}/results/submissions/custom',	'/admin/structure/webform/manage/%/results/submissions/custom',	247,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/webform/manage/{webform}/results/submissions/custom\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"Drupal\\webform\\Form\\WebformResultsCustomForm\";s:6:\"_title\";s:15:\"Customize table\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/submissions/custom$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/results/submissions/custom\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:60:\"/admin/structure/webform/manage/%/results/submissions/custom\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.results_submissions.custom.user',	'/admin/structure/webform/manage/{webform}/results/submissions/custom/user',	'/admin/structure/webform/manage/%/results/submissions/custom/user',	495,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/results/submissions/custom/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:44:\"Drupal\\webform\\Form\\WebformResultsCustomForm\";s:6:\"_title\";s:18:\"Customize my table\";s:4:\"type\";s:4:\"user\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:27:\"webform.submission_view_any\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess:checkResultsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/results/submissions/custom/user$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/results/submissions/custom/user\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:495;s:14:\"patternOutline\";s:65:\"/admin/structure/webform/manage/%/results/submissions/custom/user\";s:8:\"numParts\";i:9;}}',	9),
('entity.webform.settings',	'/admin/structure/webform/manage/{webform}/settings',	'/admin/structure/webform/manage/%/settings',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/webform/manage/{webform}/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"webform.settings\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/settings\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/manage/%/settings\";s:8:\"numParts\";i:6;}}',	6),
('entity.webform.settings_access',	'/admin/structure/webform/manage/{webform}/access',	'/admin/structure/webform/manage/%/access',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/structure/webform/manage/{webform}/access\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform.settings_access\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/access$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/access\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/manage/%/access\";s:8:\"numParts\";i:6;}}',	6),
('entity.webform.settings_assets',	'/admin/structure/webform/manage/{webform}/settings/assets',	'/admin/structure/webform/manage/%/settings/assets',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/webform/manage/{webform}/settings/assets\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform.settings_assets\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"edit webform assets\";s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/assets$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/settings/assets\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:49:\"/admin/structure/webform/manage/%/settings/assets\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.settings_confirmation',	'/admin/structure/webform/manage/{webform}/settings/confirmation',	'/admin/structure/webform/manage/%/settings/confirmation',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/webform/manage/{webform}/settings/confirmation\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:29:\"webform.settings_confirmation\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/confirmation$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/settings/confirmation\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:55:\"/admin/structure/webform/manage/%/settings/confirmation\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.settings_form',	'/admin/structure/webform/manage/{webform}/settings/form',	'/admin/structure/webform/manage/%/settings/form',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/settings/form\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:21:\"webform.settings_form\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/form$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/settings/form\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/settings/form\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.settings_submissions',	'/admin/structure/webform/manage/{webform}/settings/submissions',	'/admin/structure/webform/manage/%/settings/submissions',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/webform/manage/{webform}/settings/submissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:28:\"webform.settings_submissions\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:14:\"webform.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/settings/submissions$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/settings/submissions\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:54:\"/admin/structure/webform/manage/%/settings/submissions\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.test_form',	'/webform/{webform}/test',	'/webform/%/test',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/webform/{webform}/test\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\webform\\Controller\\WebformTestController::testForm\";s:15:\"_title_callback\";s:55:\"\\Drupal\\webform\\Controller\\WebformTestController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:12:\"webform.test\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/webform/(?P<webform>[^/]++)/test$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/test\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/webform/%/test\";s:8:\"numParts\";i:3;}}',	3),
('entity.webform.user.drafts',	'/webform/{webform}/drafts/{submission_view}',	'/webform/%/drafts',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/webform/{webform}/drafts/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:6:\"Drafts\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform.submission_create\";s:14:\"_custom_access\";s:61:\"\\Drupal\\webform\\Access\\WebformEntityAccess::checkDraftsAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/webform/(?P<webform>[^/]++)/drafts(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/drafts\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/webform/%/drafts\";s:8:\"numParts\";i:4;}}',	4),
('entity.webform.user.submission',	'/webform/{webform}/submissions/{webform_submission}',	'/webform/%/submissions/%',	10,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/webform/{webform}/submissions/{webform_submission}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"html\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:24:\"/webform/%/submissions/%\";s:8:\"numParts\";i:4;}}',	4),
('entity.webform.user.submission.delete',	'/webform/{webform}/submissions/{webform_submission}/delete',	'/webform/%/submissions/%/delete',	21,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/webform/{webform}/submissions/{webform_submission}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"webform_submission.delete\";s:6:\"_title\";s:25:\"Delete webform submission\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.delete\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:31:\"/webform/%/submissions/%/delete\";s:8:\"numParts\";i:5;}}',	5),
('entity.webform.user.submission.duplicate',	'/webform/{webform}/submissions/{webform_submission}/duplicate',	'/webform/%/submissions/%/duplicate',	21,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/webform/{webform}/submissions/{webform_submission}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:12:\"_entity_form\";s:28:\"webform_submission.duplicate\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"duplicate\";b:1;s:7:\"setting\";s:25:\"submission_user_duplicate\";s:5:\"value\";b:1;}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:28:\"webform_submission.duplicate\";s:14:\"_custom_access\";s:68:\"\\Drupal\\webform\\Access\\WebformEntityAccess::checkWebformSettingValue\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:34:\"/webform/%/submissions/%/duplicate\";s:8:\"numParts\";i:5;}}',	5),
('entity.webform.user.submission.edit',	'/webform/{webform}/submissions/{webform_submission}/edit',	'/webform/%/submissions/%/edit',	21,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/webform/{webform}/submissions/{webform_submission}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform_submission.edit\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/webform/(?P<webform>[^/]++)/submissions/(?P<webform_submission>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:29:\"/webform/%/submissions/%/edit\";s:8:\"numParts\";i:5;}}',	5),
('entity.webform.user.submissions',	'/webform/{webform}/submissions/{submission_view}',	'/webform/%/submissions',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/webform/{webform}/submissions/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:11:\"Submissions\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:27:\"webform.submission_view_own\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/webform/(?P<webform>[^/]++)/submissions(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:22:\"/webform/%/submissions\";s:8:\"numParts\";i:4;}}',	4),
('entity.webform.variant',	'/admin/structure/webform/manage/{webform}/variants/add',	'/admin/structure/webform/manage/%/variants/add',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/webform/manage/{webform}/variants/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:71:\"\\Drupal\\webform\\Controller\\WebformPluginVariantController::listVariants\";s:6:\"_title\";s:16:\"Select a variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/variants/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/manage/%/variants/add\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.variant.add_form',	'/admin/structure/webform/manage/{webform}/variants/add/{webform_variant}',	'/admin/structure/webform/manage/%/variants/add/%',	246,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/structure/webform/manage/{webform}/variants/add/{webform_variant}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\webform\\Form\\WebformVariantAddForm\";s:6:\"_title\";s:19:\"Add webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:69:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantCreateAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/add/(?P<webform_variant>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/variants/add\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:246;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/variants/add/%\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.variant.apply_form',	'/admin/structure/webform/manage/{webform}/variants/apply',	'/admin/structure/webform/manage/%/variants/apply',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/admin/structure/webform/manage/{webform}/variants/apply\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"\\Drupal\\webform\\Form\\WebformVariantApplyForm\";s:6:\"_title\";s:21:\"Apply webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/apply$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/variants/apply\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/webform/manage/%/variants/apply\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.variant.delete_form',	'/admin/structure/webform/manage/{webform}/variants/{webform_variant}/delete',	'/admin/structure/webform/manage/%/variants/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:45:\"\\Drupal\\webform\\Form\\WebformVariantDeleteForm\";s:6:\"_title\";s:22:\"Delete webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/variants/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.variant.disable',	'/admin/structure/webform/manage/{webform}/variants/{webform_variant}/disable',	'/admin/structure/webform/manage/%/variants/%/disable',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityVariantsForm::ajaxOperation\";s:9:\"operation\";s:7:\"disable\";}s:12:\"requirements\";a:4:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:4:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";i:3;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:103:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/variants/%/disable\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.variant.duplicate_form',	'/admin/structure/webform/manage/{webform}/variants/{webform_variant}/duplicate',	'/admin/structure/webform/manage/%/variants/%/duplicate',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:48:\"\\Drupal\\webform\\Form\\WebformVariantDuplicateForm\";s:6:\"_title\";s:25:\"Duplicate webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:54:\"/admin/structure/webform/manage/%/variants/%/duplicate\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.variant.edit_form',	'/admin/structure/webform/manage/{webform}/variants/{webform_variant}/edit',	'/admin/structure/webform/manage/%/variants/%/edit',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformVariantEditForm\";s:6:\"_title\";s:20:\"Edit webform variant\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:49:\"/admin/structure/webform/manage/%/variants/%/edit\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.variant.enable',	'/admin/structure/webform/manage/{webform}/variants/{webform_variant}/enable',	'/admin/structure/webform/manage/%/variants/%/enable',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/webform/manage/{webform}/variants/{webform_variant}/enable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\webform\\WebformEntityVariantsForm::ajaxOperation\";s:9:\"operation\";s:6:\"enable\";}s:12:\"requirements\";a:4:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:4:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";i:3;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/(?P<webform_variant>[^/]++)/enable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/enable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_variant\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:15:\"webform_variant\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/variants/%/enable\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform.variant.test_form',	'/admin/structure/webform/manage/{webform}/variants/test',	'/admin/structure/webform/manage/%/variants/test',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/variants/test\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformVariantViewForm\";s:6:\"_title\";s:21:\"Test webform variants\";s:9:\"operation\";s:4:\"test\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/test$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/variants/test\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/variants/test\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.variant.view_form',	'/admin/structure/webform/manage/{webform}/variants/view',	'/admin/structure/webform/manage/%/variants/view',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/webform/manage/{webform}/variants/view\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:5:\"_form\";s:43:\"\\Drupal\\webform\\Form\\WebformVariantViewForm\";s:6:\"_title\";s:21:\"View webform variants\";s:9:\"operation\";s:4:\"view\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants/view$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/variants/view\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:47:\"/admin/structure/webform/manage/%/variants/view\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform.variants',	'/admin/structure/webform/manage/{webform}/variants',	'/admin/structure/webform/manage/%/variants',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/webform/manage/{webform}/variants\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"webform.variants\";s:15:\"_title_callback\";s:57:\"\\Drupal\\webform\\Controller\\WebformEntityController::title\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:21:\"edit webform variants\";s:14:\"_entity_access\";s:14:\"webform.update\";s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformVariantAccess::checkVariantSettingsAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:3:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";i:2;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"webform\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/variants$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/variants\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"webform\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/manage/%/variants\";s:8:\"numParts\";i:6;}}',	6),
('entity.webform_options.add_form',	'/admin/structure/webform/options/manage/add',	'/admin/structure/webform/options/manage/add',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/structure/webform/options/manage/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"webform_options.add\";s:6:\"_title\";s:19:\"Add webform options\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:15:\"webform_options\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/structure/webform/options/manage/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/options/manage/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/options/manage/add\";s:8:\"numParts\";i:6;}}',	6),
('entity.webform_options.autocomplete',	'/admin/structure/webform/options/autocomplete',	'/admin/structure/webform/options/autocomplete',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/structure/webform/options/autocomplete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:65:\"\\Drupal\\webform\\Controller\\WebformOptionsController::autocomplete\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/structure/webform/options/autocomplete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/structure/webform/options/autocomplete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:45:\"/admin/structure/webform/options/autocomplete\";s:8:\"numParts\";i:5;}}',	5),
('entity.webform_options.collection',	'/admin/structure/webform/options/manage',	'/admin/structure/webform/options/manage',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/webform/options/manage\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:15:\"webform_options\";s:6:\"_title\";s:17:\"Webforms: Options\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/structure/webform/options/manage$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/options/manage\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/webform/options/manage\";s:8:\"numParts\";i:5;}}',	5),
('entity.webform_options.delete_form',	'/admin/structure/webform/options/{webform_options}/delete',	'/admin/structure/webform/options/%/delete',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:57:\"/admin/structure/webform/options/{webform_options}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:22:\"webform_options.delete\";s:6:\"_title\";s:22:\"Delete webform options\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:22:\"webform_options.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/structure/webform/options/(?P<webform_options>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/webform/options\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:41:\"/admin/structure/webform/options/%/delete\";s:8:\"numParts\";i:6;}}',	6),
('entity.webform_options.duplicate_form',	'/admin/structure/webform/options/{webform_options}/duplicate',	'/admin/structure/webform/options/%/duplicate',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/webform/options/{webform_options}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"webform_options.duplicate\";s:6:\"_title\";s:25:\"Duplicate webform options\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_options.duplicate\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/webform/options/(?P<webform_options>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/webform/options\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:44:\"/admin/structure/webform/options/%/duplicate\";s:8:\"numParts\";i:6;}}',	6),
('entity.webform_options.edit_form',	'/admin/structure/webform/options/manage/{webform_options}/edit',	'/admin/structure/webform/options/manage/%/edit',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/webform/options/manage/{webform_options}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:20:\"webform_options.edit\";s:6:\"_title\";s:20:\"Edit webform options\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:22:\"webform_options.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"webform_options\";a:2:{s:4:\"type\";s:22:\"entity:webform_options\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"webform_options\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/admin/structure/webform/options/manage/(?P<webform_options>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"webform_options\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/options/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"webform_options\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/options/manage/%/edit\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform_submission.access_denied',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/access-denied',	'/admin/structure/webform/manage/%/submission/%/access-denied',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/access-denied\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::accessDenied\";s:15:\"_title_callback\";s:73:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::accessDeniedTitle\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/access\\-denied$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/access-denied\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:60:\"/admin/structure/webform/manage/%/submission/%/access-denied\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform_submission.canonical',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}',	'/admin/structure/webform/manage/%/submission/%',	122,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"html\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:122;s:14:\"patternOutline\";s:46:\"/admin/structure/webform/manage/%/submission/%\";s:8:\"numParts\";i:7;}}',	7),
('entity.webform_submission.collection',	'/admin/structure/webform/submissions/manage/{submission_view}',	'/admin/structure/webform/submissions/manage',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/structure/webform/submissions/manage/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:21:\"Webforms: Submissions\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:65:\"\\Drupal\\webform\\Access\\WebformAccountAccess:checkSubmissionAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/webform/submissions/manage(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/submissions/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/submissions/manage\";s:8:\"numParts\";i:6;}}',	6),
('entity.webform_submission.collection_purge',	'/admin/structure/webform/submissions/purge',	'/admin/structure/webform/submissions/purge',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/structure/webform/submissions/purge\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"Drupal\\webform\\Form\\WebformSubmissionsPurgeForm\";s:6:\"_title\";s:27:\"Webforms: Submissions purge\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/admin/structure/webform/submissions/purge$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/structure/webform/submissions/purge\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:42:\"/admin/structure/webform/submissions/purge\";s:8:\"numParts\";i:5;}}',	5),
('entity.webform_submission.delete_form',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/delete',	'/admin/structure/webform/manage/%/submission/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:25:\"webform_submission.delete\";s:6:\"_title\";s:25:\"Delete webform submission\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.delete\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform_submission.duplicate_form',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/duplicate',	'/admin/structure/webform/manage/%/submission/%/duplicate',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/duplicate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_form\";s:28:\"webform_submission.duplicate\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"duplicate\";b:1;}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:29:\"webform_submission.update_any\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:110:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/duplicate$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/duplicate\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/webform/manage/%/submission/%/duplicate\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform_submission.edit_form',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit',	'/admin/structure/webform/manage/%/submission/%/edit',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:23:\"webform_submission.edit\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/submission/%/edit\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform_submission.edit_form.all',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit/all',	'/admin/structure/webform/manage/%/submission/%/edit/all',	491,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/edit/all\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:27:\"webform_submission.edit_all\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";s:14:\"_custom_access\";s:70:\"\\Drupal\\webform\\Access\\WebformSubmissionAccess::checkWizardPagesAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/edit/all$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/edit/all\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:55:\"/admin/structure/webform/manage/%/submission/%/edit/all\";s:8:\"numParts\";i:9;}}',	9),
('entity.webform_submission.locked_toggle',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/locked',	'/admin/structure/webform/manage/%/submission/%/locked',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/locked\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::locked\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/locked$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/locked\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/locked\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform_submission.notes_form',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/notes',	'/admin/structure/webform/manage/%/submission/%/notes',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/notes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:24:\"webform_submission.notes\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:24:\"webform_submission.notes\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/notes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/notes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/submission/%/notes\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform_submission.resend_form',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/resend',	'/admin/structure/webform/manage/%/submission/%/resend',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/resend\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"Drupal\\webform\\Form\\WebformSubmissionResendForm\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.resend\";s:14:\"_custom_access\";s:65:\"\\Drupal\\webform\\Access\\WebformSubmissionAccess::checkResendAccess\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/resend$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/resend\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/resend\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform_submission.sticky_toggle',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/sticky',	'/admin/structure/webform/manage/%/submission/%/sticky',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/sticky\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\webform\\Controller\\WebformSubmissionController::sticky\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:25:\"webform_submission.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/sticky$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/sticky\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/sticky\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform_submission.table',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/table',	'/admin/structure/webform/manage/%/submission/%/table',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/table\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:5:\"table\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:106:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/table$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/table\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:52:\"/admin/structure/webform/manage/%/submission/%/table\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform_submission.text',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/text',	'/admin/structure/webform/manage/%/submission/%/text',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/text\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"text\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:27:\"webform_submission.view_any\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/text$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/text\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/submission/%/text\";s:8:\"numParts\";i:8;}}',	8),
('entity.webform_submission.user',	'/user/{user}/submissions/{submission_view}',	'/user/%/submissions',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/user/{user}/submissions/{submission_view}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:12:\"_entity_list\";s:18:\"webform_submission\";s:6:\"_title\";s:11:\"Submissions\";s:15:\"submission_view\";s:0:\"\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:71:\"\\Drupal\\webform\\Access\\WebformAccountAccess::checkUserSubmissionsAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"user\";i:1;s:15:\"submission_view\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/user/(?P<user>[^/]++)/submissions(?:/(?P<submission_view>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"submission_view\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/submissions\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"user\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"user\";i:1;s:15:\"submission_view\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:19:\"/user/%/submissions\";s:8:\"numParts\";i:4;}}',	4),
('entity.webform_submission.yaml',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/yaml',	'/admin/structure/webform/manage/%/submission/%/yaml',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/yaml\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::view\";s:15:\"_title_callback\";s:65:\"\\Drupal\\webform\\Controller\\WebformSubmissionViewController::title\";s:9:\"view_mode\";s:4:\"yaml\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"edit webform source\";s:14:\"_entity_access\";s:27:\"webform_submission.view_any\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/yaml$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/yaml\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/webform/manage/%/submission/%/yaml\";s:8:\"numParts\";i:8;}}',	8),
('entity_reference_revisions.delete_orphans',	'/admin/config/system/delete-orphans',	'/admin/config/system/delete-orphans',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/config/system/delete-orphans\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:74:\"Drupal\\entity_reference_revisions\\Form\\OrphanedCompositeEntitiesDeleteForm\";s:6:\"_title\";s:34:\"Delete orphaned composite entities\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"delete orphan revisions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/config/system/delete\\-orphans$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/system/delete-orphans\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:35:\"/admin/config/system/delete-orphans\";s:8:\"numParts\";i:4;}}',	4),
('field_ui.display_mode',	'/admin/structure/display-modes',	'/admin/structure/display-modes',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/structure/display-modes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:13:\"Display modes\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:24:\"administer display modes\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/display\\-modes$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/structure/display-modes\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/admin/structure/display-modes\";s:8:\"numParts\";i:3;}}',	3),
('field_ui.entity_form_mode_add',	'/admin/structure/display-modes/form/add',	'/admin/structure/display-modes/form/add',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/display-modes/form/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:78:\"\\Drupal\\field_ui\\Controller\\EntityDisplayModeController::formModeTypeSelection\";s:6:\"_title\";s:28:\"Choose form mode entity type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/display\\-modes/form/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/form/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/display-modes/form/add\";s:8:\"numParts\";i:5;}}',	5),
('field_ui.entity_view_mode_add',	'/admin/structure/display-modes/view/add',	'/admin/structure/display-modes/view/add',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/display-modes/view/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:78:\"\\Drupal\\field_ui\\Controller\\EntityDisplayModeController::viewModeTypeSelection\";s:6:\"_title\";s:28:\"Choose view mode entity type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer display modes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/display\\-modes/view/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/display-modes/view/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/display-modes/view/add\";s:8:\"numParts\";i:5;}}',	5),
('field_ui.field_add_block_content',	'/admin/structure/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}',	'/admin/structure/block-content/manage/%/add-field/%/%',	244,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:95:\"/admin/structure/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:53:\"/admin/structure/block-content/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_add_block_content.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}',	'/admin/structure/block/block-content/manage/%/add-field/%/%',	500,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:101:\"/admin/structure/block/block-content/manage/{block_content_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:140:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:500;s:14:\"patternOutline\";s:59:\"/admin/structure/block/block-content/manage/%/add-field/%/%\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_add_contact_message',	'/admin/structure/contact/manage/{contact_form}/add-field/{entity_type}/{field_name}',	'/admin/structure/contact/manage/%/add-field/%/%',	244,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/structure/contact/manage/{contact_form}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:121:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:47:\"/admin/structure/contact/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_add_media',	'/admin/structure/media/manage/{media_type}/add-field/{entity_type}/{field_name}',	'/admin/structure/media/manage/%/add-field/%/%',	244,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/admin/structure/media/manage/{media_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:45:\"/admin/structure/media/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_add_node',	'/admin/structure/types/manage/{node_type}/add-field/{entity_type}/{field_name}',	'/admin/structure/types/manage/%/add-field/%/%',	244,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/types/manage/{node_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:116:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:244;s:14:\"patternOutline\";s:45:\"/admin/structure/types/manage/%/add-field/%/%\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_add_paragraph',	'/admin/structure/paragraphs_type/{paragraphs_type}/add-field/{entity_type}/{field_name}',	'/admin/structure/paragraphs_type/%/add-field/%/%',	116,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/paragraphs_type/{paragraphs_type}/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:125:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:48:\"/admin/structure/paragraphs_type/%/add-field/%/%\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_add_taxonomy_term',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/add-field/{entity_type}/{field_name}',	'/admin/structure/taxonomy/manage/%/overview/add-field/%/%',	492,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:100:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:138:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/overview/add-field\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:11:\"entity_type\";i:2;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:492;s:14:\"patternOutline\";s:57:\"/admin/structure/taxonomy/manage/%/overview/add-field/%/%\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_add_user',	'/admin/config/people/accounts/add-field/{entity_type}/{field_name}',	'/admin/config/people/accounts/add-field/%/%',	124,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/config/people/accounts/add-field/{entity_type}/{field_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:80:\"Drupal\\field_ui\\Controller\\FieldConfigAddController::fieldConfigAddConfigureForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"entity_type\";i:1;s:10:\"field_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/config/people/accounts/add\\-field/(?P<entity_type>[^/]++)/(?P<field_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"field_name\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"entity_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/people/accounts/add-field\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"entity_type\";i:1;s:10:\"field_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:124;s:14:\"patternOutline\";s:43:\"/admin/config/people/accounts/add-field/%/%\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_block_content.display',	'/admin/structure/block-content/manage/{block_content_type}/display/add-group',	'/admin/structure/block-content/manage/%/display/add-group',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/block-content/manage/{block_content_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:57:\"/admin/structure/block-content/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_block_content.display.view_mode',	'/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/add-group',	'/admin/structure/block-content/manage/%/display/%/add-group',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:122:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:59:\"/admin/structure/block-content/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_add_block_content.form_display',	'/admin/structure/block-content/manage/{block_content_type}/form-display/add-group',	'/admin/structure/block-content/manage/%/form-display/add-group',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/block-content/manage/{block_content_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:62:\"/admin/structure/block-content/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_block_content.form_display.form_mode',	'/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/add-group',	'/admin/structure/block-content/manage/%/form-display/%/add-group',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:128:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:64:\"/admin/structure/block-content/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_add_contact_message.display',	'/admin/structure/contact/manage/{contact_form}/display/add-group',	'/admin/structure/contact/manage/%/display/add-group',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/contact/manage/{contact_form}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:51:\"/admin/structure/contact/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_contact_message.display.view_mode',	'/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/add-group',	'/admin/structure/contact/manage/%/display/%/add-group',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/contact/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_add_contact_message.form_display',	'/admin/structure/contact/manage/{contact_form}/form-display/add-group',	'/admin/structure/contact/manage/%/form-display/add-group',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/structure/contact/manage/{contact_form}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/contact/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_contact_message.form_display.form_mode',	'/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/add-group',	'/admin/structure/contact/manage/%/form-display/%/add-group',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:115:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:58:\"/admin/structure/contact/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_add_media.display',	'/admin/structure/media/manage/{media_type}/display/add-group',	'/admin/structure/media/manage/%/display/add-group',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/media/manage/{media_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:49:\"/admin/structure/media/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_media.display.view_mode',	'/admin/structure/media/manage/{media_type}/display/{view_mode_name}/add-group',	'/admin/structure/media/manage/%/display/%/add-group',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/media/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_add_media.form_display',	'/admin/structure/media/manage/{media_type}/form-display/add-group',	'/admin/structure/media/manage/%/form-display/add-group',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/media/manage/{media_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:84:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:54:\"/admin/structure/media/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_media.form_display.form_mode',	'/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/add-group',	'/admin/structure/media/manage/%/form-display/%/add-group',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/media/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_add_node.display',	'/admin/structure/types/manage/{node_type}/display/add-group',	'/admin/structure/types/manage/%/display/add-group',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/types/manage/{node_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:49:\"/admin/structure/types/manage/%/display/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_node.display.view_mode',	'/admin/structure/types/manage/{node_type}/display/{view_mode_name}/add-group',	'/admin/structure/types/manage/%/display/%/add-group',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:51:\"/admin/structure/types/manage/%/display/%/add-group\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_add_node.form_display',	'/admin/structure/types/manage/{node_type}/form-display/add-group',	'/admin/structure/types/manage/%/form-display/add-group',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/types/manage/{node_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:83:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:54:\"/admin/structure/types/manage/%/form-display/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_node.form_display.form_mode',	'/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/add-group',	'/admin/structure/types/manage/%/form-display/%/add-group',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:110:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/types/manage/%/form-display/%/add-group\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_add_paragraph.display',	'/admin/structure/paragraphs_type/{paragraphs_type}/display/add-group',	'/admin/structure/paragraphs_type/%/display/add-group',	59,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:52:\"/admin/structure/paragraphs_type/%/display/add-group\";s:8:\"numParts\";i:6;}}',	6),
('field_ui.field_group_add_paragraph.display.view_mode',	'/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/add-group',	'/admin/structure/paragraphs_type/%/display/%/add-group',	117,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:54:\"/admin/structure/paragraphs_type/%/display/%/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_paragraph.form_display',	'/admin/structure/paragraphs_type/{paragraphs_type}/form-display/add-group',	'/admin/structure/paragraphs_type/%/form-display/add-group',	59,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:57:\"/admin/structure/paragraphs_type/%/form-display/add-group\";s:8:\"numParts\";i:6;}}',	6),
('field_ui.field_group_add_paragraph.form_display.form_mode',	'/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/add-group',	'/admin/structure/paragraphs_type/%/form-display/%/add-group',	117,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:90:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:119:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:59:\"/admin/structure/paragraphs_type/%/form-display/%/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_taxonomy_term.display',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/add-group',	'/admin/structure/taxonomy/manage/%/overview/display/add-group',	247,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:99:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/overview/display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:61:\"/admin/structure/taxonomy/manage/%/overview/display/add-group\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_add_taxonomy_term.display.view_mode',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/add-group',	'/admin/structure/taxonomy/manage/%/overview/display/%/add-group',	493,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:63:\"/admin/structure/taxonomy/manage/%/overview/display/%/add-group\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_add_taxonomy_term.form_display',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/add-group',	'/admin/structure/taxonomy/manage/%/overview/form-display/add-group',	247,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/overview/form-display/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:66:\"/admin/structure/taxonomy/manage/%/overview/form-display/add-group\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_add_taxonomy_term.form_display.form_mode',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/add-group',	'/admin/structure/taxonomy/manage/%/overview/form-display/%/add-group',	493,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:103:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:132:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:68:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/add-group\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_add_user.display',	'/admin/config/people/accounts/display/add-group',	'/admin/config/people/accounts/display/add-group',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:47:\"/admin/config/people/accounts/display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:55:\"{^/admin/config/people/accounts/display/add\\-group$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:47:\"/admin/config/people/accounts/display/add-group\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:47:\"/admin/config/people/accounts/display/add-group\";s:8:\"numParts\";i:6;}}',	6),
('field_ui.field_group_add_user.display.view_mode',	'/admin/config/people/accounts/display/{view_mode_name}/add-group',	'/admin/config/people/accounts/display/%/add-group',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/config/people/accounts/display/{view_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:49:\"/admin/config/people/accounts/display/%/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_add_user.form_display',	'/admin/config/people/accounts/form-display/add-group',	'/admin/config/people/accounts/form-display/add-group',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/people/accounts/form-display/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:61:\"{^/admin/config/people/accounts/form\\-display/add\\-group$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:52:\"/admin/config/people/accounts/form-display/add-group\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:52:\"/admin/config/people/accounts/form-display/add-group\";s:8:\"numParts\";i:6;}}',	6),
('field_ui.field_group_add_user.form_display.form_mode',	'/admin/config/people/accounts/form-display/{form_mode_name}/add-group',	'/admin/config/people/accounts/form-display/%/add-group',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/config/people/accounts/form-display/{form_mode_name}/add-group\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:42:\"\\Drupal\\field_group\\Form\\FieldGroupAddForm\";s:6:\"_title\";s:15:\"Add field group\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:88:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)/add\\-group$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/add-group\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"form_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:54:\"/admin/config/people/accounts/form-display/%/add-group\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_delete_block_content.display',	'/admin/structure/block-content/manage/{block_content_type}/display/{field_group_name}/delete',	'/admin/structure/block-content/manage/%/display/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/block-content/manage/{block_content_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:120:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/block-content/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_delete_block_content.display.view_mode',	'/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/{field_group_name}/delete',	'/admin/structure/block-content/manage/%/display/%/%/delete',	489,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:109:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer block_content display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:147:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:58:\"/admin/structure/block-content/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_delete_block_content.form_display',	'/admin/structure/block-content/manage/{block_content_type}/form-display/{field_group_name}/delete',	'/admin/structure/block-content/manage/%/form-display/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:61:\"/admin/structure/block-content/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_delete_block_content.form_display.form_mode',	'/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/{field_group_name}/delete',	'/admin/structure/block-content/manage/%/form-display/%/%/delete',	489,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:114:\"/admin/structure/block-content/manage/{block_content_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"block_content\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer block_content form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:18:\"block_content_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:153:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:18:\"block_content_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:63:\"/admin/structure/block-content/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_delete_contact_message.display',	'/admin/structure/contact/manage/{contact_form}/display/{field_group_name}/delete',	'/admin/structure/contact/manage/%/display/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/contact/manage/{contact_form}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/contact/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_delete_contact_message.display.view_mode',	'/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/{field_group_name}/delete',	'/admin/structure/contact/manage/%/display/%/%/delete',	489,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:34:\"administer contact_message display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:52:\"/admin/structure/contact/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_delete_contact_message.form_display',	'/admin/structure/contact/manage/{contact_form}/form-display/{field_group_name}/delete',	'/admin/structure/contact/manage/%/form-display/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/structure/contact/manage/{contact_form}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:55:\"/admin/structure/contact/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_delete_contact_message.form_display.form_mode',	'/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/{field_group_name}/delete',	'/admin/structure/contact/manage/%/form-display/%/%/delete',	489,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/structure/contact/manage/{contact_form}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:39:\"administer contact_message form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:12:\"contact_form\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:140:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"contact_form\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:57:\"/admin/structure/contact/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_delete_media.display',	'/admin/structure/media/manage/{media_type}/display/{field_group_name}/delete',	'/admin/structure/media/manage/%/display/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/media/manage/{media_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:103:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/media/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_delete_media.display.view_mode',	'/admin/structure/media/manage/{media_type}/display/{view_mode_name}/{field_group_name}/delete',	'/admin/structure/media/manage/%/display/%/%/delete',	489,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer media display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:130:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:50:\"/admin/structure/media/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_delete_media.form_display',	'/admin/structure/media/manage/{media_type}/form-display/{field_group_name}/delete',	'/admin/structure/media/manage/%/form-display/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/media/manage/{media_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/media/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_delete_media.form_display.form_mode',	'/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/{field_group_name}/delete',	'/admin/structure/media/manage/%/form-display/%/%/delete',	489,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/media/manage/{media_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:5:\"media\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer media form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:10:\"media_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:136:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:10:\"media_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:55:\"/admin/structure/media/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_delete_node.display',	'/admin/structure/types/manage/{node_type}/display/{field_group_name}/delete',	'/admin/structure/types/manage/%/display/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/types/manage/{node_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:102:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/types/manage/%/display/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_delete_node.display.view_mode',	'/admin/structure/types/manage/{node_type}/display/{view_mode_name}/{field_group_name}/delete',	'/admin/structure/types/manage/%/display/%/%/delete',	489,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:92:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer node display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:129:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:50:\"/admin/structure/types/manage/%/display/%/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_delete_node.form_display',	'/admin/structure/types/manage/{node_type}/form-display/{field_group_name}/delete',	'/admin/structure/types/manage/%/form-display/%/delete',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/types/manage/{node_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/types/manage/%/form-display/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_delete_node.form_display.form_mode',	'/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/{field_group_name}/delete',	'/admin/structure/types/manage/%/form-display/%/%/delete',	489,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/types/manage/{node_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"node\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer node form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:9:\"node_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:135:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:9:\"node_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:489;s:14:\"patternOutline\";s:55:\"/admin/structure/types/manage/%/form-display/%/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_delete_paragraph.display',	'/admin/structure/paragraphs_type/{paragraphs_type}/display/{field_group_name}/delete',	'/admin/structure/paragraphs_type/%/display/%/delete',	117,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:84:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:51:\"/admin/structure/paragraphs_type/%/display/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_delete_paragraph.display.view_mode',	'/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/{field_group_name}/delete',	'/admin/structure/paragraphs_type/%/display/%/%/delete',	233,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:101:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer paragraph display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:138:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:233;s:14:\"patternOutline\";s:53:\"/admin/structure/paragraphs_type/%/display/%/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_delete_paragraph.form_display',	'/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{field_group_name}/delete',	'/admin/structure/paragraphs_type/%/form-display/%/delete',	117,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:56:\"/admin/structure/paragraphs_type/%/form-display/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_delete_paragraph.form_display.form_mode',	'/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/{field_group_name}/delete',	'/admin/structure/paragraphs_type/%/form-display/%/%/delete',	233,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:106:\"/admin/structure/paragraphs_type/{paragraphs_type}/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer paragraph form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:2:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:15:\"paragraphs_type\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:144:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:3:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:233;s:14:\"patternOutline\";s:58:\"/admin/structure/paragraphs_type/%/form-display/%/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_delete_taxonomy_term.display',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{field_group_name}/delete',	'/admin/structure/taxonomy/manage/%/overview/display/%/delete',	493,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:97:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:124:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:60:\"/admin/structure/taxonomy/manage/%/overview/display/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_delete_taxonomy_term.display.view_mode',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/{field_group_name}/delete',	'/admin/structure/taxonomy/manage/%/overview/display/%/%/delete',	985,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:114:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:32:\"administer taxonomy_term display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:151:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:985;s:14:\"patternOutline\";s:62:\"/admin/structure/taxonomy/manage/%/overview/display/%/%/delete\";s:8:\"numParts\";i:10;}}',	10),
('field_ui.field_group_delete_taxonomy_term.form_display',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{field_group_name}/delete',	'/admin/structure/taxonomy/manage/%/overview/form-display/%/delete',	493,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:102:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:130:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:65:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('field_ui.field_group_delete_taxonomy_term.form_display.form_mode',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/{field_group_name}/delete',	'/admin/structure/taxonomy/manage/%/overview/form-display/%/%/delete',	985,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:119:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:37:\"administer taxonomy_term form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:2:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";s:19:\"taxonomy_vocabulary\";s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:157:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/form-display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:3:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"form_mode_name\";i:2;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:985;s:14:\"patternOutline\";s:67:\"/admin/structure/taxonomy/manage/%/overview/form-display/%/%/delete\";s:8:\"numParts\";i:10;}}',	10),
('field_ui.field_group_delete_user.display',	'/admin/config/people/accounts/display/{field_group_name}/delete',	'/admin/config/people/accounts/display/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/config/people/accounts/display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/config/people/accounts/display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/people/accounts/display/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_delete_user.display.view_mode',	'/admin/config/people/accounts/display/{view_mode_name}/{field_group_name}/delete',	'/admin/config/people/accounts/display/%/%/delete',	249,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/config/people/accounts/display/{view_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"view\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer user display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"view_mode_name\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"view_mode_name\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:249;s:14:\"patternOutline\";s:48:\"/admin/config/people/accounts/display/%/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_group_delete_user.form_display',	'/admin/config/people/accounts/form-display/{field_group_name}/delete',	'/admin/config/people/accounts/form-display/%/delete',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/people/accounts/form-display/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/config/people/accounts/form\\-display/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/config/people/accounts/form-display/%/delete\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_group_delete_user.form_display.form_mode',	'/admin/config/people/accounts/form-display/{form_mode_name}/{field_group_name}/delete',	'/admin/config/people/accounts/form-display/%/%/delete',	249,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:85:\"/admin/config/people/accounts/form-display/{form_mode_name}/{field_group_name}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:7:\"context\";s:4:\"form\";s:14:\"entity_type_id\";s:4:\"user\";s:5:\"_form\";s:45:\"\\Drupal\\field_group\\Form\\FieldGroupDeleteForm\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer user form display\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:10:\"parameters\";a:1:{s:11:\"field_group\";a:3:{s:4:\"type\";s:11:\"field_group\";s:11:\"entity_type\";N;s:9:\"converter\";s:27:\"field_group.param_converter\";}}s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"form_mode_name\";i:1;s:16:\"field_group_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/config/people/accounts/form\\-display/(?P<form_mode_name>[^/]++)/(?P<field_group_name>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"field_group_name\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"form_mode_name\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/form-display\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"form_mode_name\";i:1;s:16:\"field_group_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:249;s:14:\"patternOutline\";s:53:\"/admin/config/people/accounts/form-display/%/%/delete\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_storage_config_add_block_content',	'/admin/structure/block-content/manage/{block_content_type}/fields/add-field',	'/admin/structure/block-content/manage/%/fields/add-field',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/structure/block-content/manage/{block_content_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:94:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:56:\"/admin/structure/block-content/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_storage_config_add_block_content.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/fields/add-field',	'/admin/structure/block/block-content/manage/%/fields/add-field',	251,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/block/block-content/manage/{block_content_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:62:\"/admin/structure/block/block-content/manage/%/fields/add-field\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_storage_config_add_contact_message',	'/admin/structure/contact/manage/{contact_form}/fields/add-field',	'/admin/structure/contact/manage/%/fields/add-field',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/contact/manage/{contact_form}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:81:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:50:\"/admin/structure/contact/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_storage_config_add_media',	'/admin/structure/media/manage/{media_type}/fields/add-field',	'/admin/structure/media/manage/%/fields/add-field',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/media/manage/{media_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/media/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_storage_config_add_node',	'/admin/structure/types/manage/{node_type}/fields/add-field',	'/admin/structure/types/manage/%/fields/add-field',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/types/manage/{node_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:48:\"/admin/structure/types/manage/%/fields/add-field\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_storage_config_add_paragraph',	'/admin/structure/paragraphs_type/{paragraphs_type}/fields/add-field',	'/admin/structure/paragraphs_type/%/fields/add-field',	59,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:85:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:51:\"/admin/structure/paragraphs_type/%/fields/add-field\";s:8:\"numParts\";i:6;}}',	6),
('field_ui.field_storage_config_add_taxonomy_term',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/add-field',	'/admin/structure/taxonomy/manage/%/overview/fields/add-field',	247,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:98:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/overview/fields/add-field\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:60:\"/admin/structure/taxonomy/manage/%/overview/fields/add-field\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_storage_config_add_user',	'/admin/config/people/accounts/fields/add-field',	'/admin/config/people/accounts/fields/add-field',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:46:\"/admin/config/people/accounts/fields/add-field\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:41:\"\\Drupal\\field_ui\\Form\\FieldStorageAddForm\";s:6:\"_title\";s:9:\"Add field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/config/people/accounts/fields/add\\-field$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:46:\"/admin/config/people/accounts/fields/add-field\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:46:\"/admin/config/people/accounts/fields/add-field\";s:8:\"numParts\";i:6;}}',	6),
('field_ui.field_storage_config_reuse_block_content',	'/admin/structure/block-content/manage/{block_content_type}/fields/reuse',	'/admin/structure/block-content/manage/%/fields/reuse',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:71:\"/admin/structure/block-content/manage/{block_content_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:89:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:52:\"/admin/structure/block-content/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_storage_config_reuse_block_content.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/fields/reuse',	'/admin/structure/block/block-content/manage/%/fields/reuse',	251,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/structure/block/block-content/manage/{block_content_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:13:\"block_content\";s:6:\"bundle\";s:0:\"\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:31:\"administer block_content fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:18:\"block_content_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:18:\"block_content_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:58:\"/admin/structure/block/block-content/manage/%/fields/reuse\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_storage_config_reuse_contact_message',	'/admin/structure/contact/manage/{contact_form}/fields/reuse',	'/admin/structure/contact/manage/%/fields/reuse',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/structure/contact/manage/{contact_form}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:15:\"contact_message\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:33:\"administer contact_message fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"contact_form\";a:2:{s:4:\"type\";s:19:\"entity:contact_form\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"contact_form\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"contact_form\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:46:\"/admin/structure/contact/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_storage_config_reuse_media',	'/admin/structure/media/manage/{media_type}/fields/reuse',	'/admin/structure/media/manage/%/fields/reuse',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/media/manage/{media_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:5:\"media\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:23:\"administer media fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:10:\"media_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:72:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:10:\"media_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:44:\"/admin/structure/media/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_storage_config_reuse_node',	'/admin/structure/types/manage/{node_type}/fields/reuse',	'/admin/structure/types/manage/%/fields/reuse',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:54:\"/admin/structure/types/manage/{node_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:4:\"node\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:22:\"administer node fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:2:{s:4:\"type\";s:16:\"entity:node_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:71:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:44:\"/admin/structure/types/manage/%/fields/reuse\";s:8:\"numParts\";i:7;}}',	7),
('field_ui.field_storage_config_reuse_paragraph',	'/admin/structure/paragraphs_type/{paragraphs_type}/fields/reuse',	'/admin/structure/paragraphs_type/%/fields/reuse',	59,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:63:\"/admin/structure/paragraphs_type/{paragraphs_type}/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:9:\"paragraph\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:27:\"administer paragraph fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:15:\"paragraphs_type\";a:2:{s:4:\"type\";s:22:\"entity:paragraphs_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:80:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:1:{i:0;s:15:\"paragraphs_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:47:\"/admin/structure/paragraphs_type/%/fields/reuse\";s:8:\"numParts\";i:6;}}',	6),
('field_ui.field_storage_config_reuse_taxonomy_term',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/reuse',	'/admin/structure/taxonomy/manage/%/overview/fields/reuse',	247,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:31:\"administer taxonomy_term fields\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:19:\"taxonomy_vocabulary\";a:2:{s:4:\"type\";s:26:\"entity:taxonomy_vocabulary\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:93:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/fields/reuse$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/overview/fields/reuse\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:19:\"taxonomy_vocabulary\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:56:\"/admin/structure/taxonomy/manage/%/overview/fields/reuse\";s:8:\"numParts\";i:8;}}',	8),
('field_ui.field_storage_config_reuse_user',	'/admin/config/people/accounts/fields/reuse',	'/admin/config/people/accounts/fields/reuse',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/config/people/accounts/fields/reuse\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:5:\"_form\";s:43:\"\\Drupal\\field_ui\\Form\\FieldStorageReuseForm\";s:6:\"_title\";s:24:\"Re-use an existing field\";s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";}s:12:\"requirements\";a:1:{s:28:\"_field_ui_field_reuse_access\";s:22:\"administer user fields\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:9:\"_field_ui\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:33:\"access_check.field_ui.field_reuse\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:49:\"{^/admin/config/people/accounts/fields/reuse$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/people/accounts/fields/reuse\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:42:\"/admin/config/people/accounts/fields/reuse\";s:8:\"numParts\";i:6;}}',	6),
('file.ajax_progress',	'/file/progress/{key}',	'/file/progress/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/file/progress/{key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\file\\Controller\\FileWidgetAjaxController::progress\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/file/progress/(?P<key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/file/progress\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/file/progress/%\";s:8:\"numParts\";i:3;}}',	3),
('filter.admin_overview',	'/admin/config/content/formats',	'/admin/config/content/formats',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/content/formats\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_list\";s:13:\"filter_format\";s:6:\"_title\";s:24:\"Text formats and editors\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer filters\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/content/formats$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/content/formats\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/content/formats\";s:8:\"numParts\";i:4;}}',	4),
('filter.format_add',	'/admin/config/content/formats/add',	'/admin/config/content/formats/add',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/content/formats/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"filter_format.add\";s:6:\"_title\";s:15:\"Add text format\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:13:\"filter_format\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/content/formats/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/content/formats/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:33:\"/admin/config/content/formats/add\";s:8:\"numParts\";i:5;}}',	5),
('filter.tips',	'/filter/tips/{filter_format}',	'/filter/tips/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/filter/tips/{filter_format}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\filter\\Controller\\FilterController::filterTips\";s:6:\"_title\";s:12:\"Compose tips\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:17:\"filter_format.use\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/filter/tips/(?P<filter_format>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/filter/tips\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:14:\"/filter/tips/%\";s:8:\"numParts\";i:3;}}',	3),
('filter.tips_all',	'/filter/tips',	'/filter/tips',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/filter/tips\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\filter\\Controller\\FilterController::filterTips\";s:6:\"_title\";s:12:\"Compose tips\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/filter/tips$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/filter/tips\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/filter/tips\";s:8:\"numParts\";i:2;}}',	2),
('glightbox.admin_settings',	'/admin/config/media/glightbox',	'/admin/config/media/glightbox',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/media/glightbox\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"\\Drupal\\glightbox\\Form\\GLightboxSettingsForm\";s:6:\"_title\";s:18:\"GLightbox settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/media/glightbox$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/media/glightbox\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/media/glightbox\";s:8:\"numParts\";i:4;}}',	4),
('google_analytics.admin_settings_form',	'/admin/config/services/google-analytics',	'/admin/config/services/google-analytics',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/config/services/google-analytics\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:62:\"\\Drupal\\google_analytics\\Form\\GoogleAnalyticsAdminSettingsForm\";s:6:\"_title\";s:16:\"Google Analytics\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer google analytics\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/config/services/google\\-analytics$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/services/google-analytics\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/config/services/google-analytics\";s:8:\"numParts\";i:4;}}',	4),
('help.help_topic',	'/admin/help/topic/{id}',	'/admin/help/topic/%',	14,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/help/topic/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:64:\"\\Drupal\\help\\Controller\\HelpTopicPluginController::viewHelpTopic\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/help/topic/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/help/topic\";}}s:9:\"path_vars\";a:1:{i:0;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:19:\"/admin/help/topic/%\";s:8:\"numParts\";i:4;}}',	4),
('help.main',	'/admin/help',	'/admin/help',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/admin/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\help\\Controller\\HelpController::helpMain\";s:6:\"_title\";s:4:\"Help\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/admin/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/admin/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/admin/help\";s:8:\"numParts\";i:2;}}',	2),
('help.page',	'/admin/help/{name}',	'/admin/help/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/admin/help/{name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\help\\Controller\\HelpController::helpPage\";s:6:\"_title\";s:4:\"Help\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"access help pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/help/(?P<name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/admin/help\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:13:\"/admin/help/%\";s:8:\"numParts\";i:3;}}',	3),
('history.get_last_node_view',	'/history/get_node_read_timestamps',	'/history/get_node_read_timestamps',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/history/get_node_read_timestamps\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:67:\"\\Drupal\\history\\Controller\\HistoryController::getNodeReadTimestamps\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/history/get_node_read_timestamps$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/history/get_node_read_timestamps\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:33:\"/history/get_node_read_timestamps\";s:8:\"numParts\";i:2;}}',	2),
('history.read_node',	'/history/{node}/read',	'/history/%/read',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/history/{node}/read\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:54:\"\\Drupal\\history\\Controller\\HistoryController::readNode\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:9:\"node.view\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/history/(?P<node>\\d+)/read$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/read\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/history\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:15:\"/history/%/read\";s:8:\"numParts\";i:3;}}',	3),
('image.effect_add_form',	'/admin/config/media/image-styles/manage/{image_style}/add/{image_effect}',	'/admin/config/media/image-styles/manage/%/add/%',	250,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:72:\"/admin/config/media/image-styles/manage/{image_style}/add/{image_effect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\image\\Form\\ImageEffectAddForm\";s:6:\"_title\";s:16:\"Add image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/add/(?P<image_effect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:4:\"/add\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:47:\"/admin/config/media/image-styles/manage/%/add/%\";s:8:\"numParts\";i:8;}}',	8),
('image.effect_delete',	'/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}/delete',	'/admin/config/media/image-styles/manage/%/effects/%/delete',	501,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:83:\"/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\image\\Form\\ImageEffectDeleteForm\";s:6:\"_title\";s:19:\"Delete image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:111:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/effects/(?P<image_effect>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/effects\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:58:\"/admin/config/media/image-styles/manage/%/effects/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('image.effect_edit_form',	'/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}',	'/admin/config/media/image-styles/manage/%/effects/%',	250,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/config/media/image-styles/manage/{image_style}/effects/{image_effect}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:38:\"\\Drupal\\image\\Form\\ImageEffectEditForm\";s:6:\"_title\";s:17:\"Edit image effect\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:104:\"{^/admin/config/media/image\\-styles/manage/(?P<image_style>[^/]++)/effects/(?P<image_effect>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"image_effect\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/effects\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/config/media/image-styles/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:12:\"image_effect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:51:\"/admin/config/media/image-styles/manage/%/effects/%\";s:8:\"numParts\";i:8;}}',	8),
('image.style_add',	'/admin/config/media/image-styles/add',	'/admin/config/media/image-styles/add',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/config/media/image-styles/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"image_style.add\";s:6:\"_title\";s:15:\"Add image style\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:23:\"administer image styles\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/media/image\\-styles/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/config/media/image-styles/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:36:\"/admin/config/media/image-styles/add\";s:8:\"numParts\";i:5;}}',	5),
('image.style_private',	'/system/files/styles/{image_style}/{scheme}',	'/system/files/styles/%/%',	28,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/system/files/styles/{image_style}/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:62:\"\\Drupal\\image\\Controller\\ImageStyleDownloadController::deliver\";s:26:\"required_derivative_scheme\";s:7:\"private\";s:25:\"_disable_route_normalizer\";b:1;}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:70:\"{^/system/files/styles/(?P<image_style>[^/]++)/(?P<scheme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/system/files/styles\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:28;s:14:\"patternOutline\";s:24:\"/system/files/styles/%/%\";s:8:\"numParts\";i:5;}}',	5),
('image.style_public',	'/sites/default/files/styles/{image_style}/{scheme}',	'/sites/default/files/styles/%/%',	60,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/sites/default/files/styles/{image_style}/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:61:\"Drupal\\image\\Controller\\ImageStyleDownloadController::deliver\";s:26:\"required_derivative_scheme\";s:6:\"public\";s:25:\"_disable_route_normalizer\";b:1;}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:11:\"image_style\";a:2:{s:4:\"type\";s:18:\"entity:image_style\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:77:\"{^/sites/default/files/styles/(?P<image_style>[^/]++)/(?P<scheme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"image_style\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/sites/default/files/styles\";}}s:9:\"path_vars\";a:2:{i:0;s:11:\"image_style\";i:1;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:60;s:14:\"patternOutline\";s:31:\"/sites/default/files/styles/%/%\";s:8:\"numParts\";i:6;}}',	6),
('layout_builder.add_block',	'/layout_builder/add/block/{section_storage_type}/{section_storage}/{delta}/{region}/{plugin_id}',	'/layout_builder/add/block/%/%/%/%/%',	224,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:95:\"/layout_builder/add/block/{section_storage_type}/{section_storage}/{delta}/{region}/{plugin_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\layout_builder\\Form\\AddBlockForm\";s:6:\"_title\";s:15:\"Configure block\";}s:12:\"requirements\";a:1:{s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";i:4;s:9:\"plugin_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:152:\"{^/layout_builder/add/block/(?P<section_storage_type>[^/]++)/(?P<section_storage>[^/]++)/(?P<delta>[^/]++)/(?P<region>[^/]++)/(?P<plugin_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"plugin_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"region\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"delta\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"section_storage\";i:4;b:1;}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"section_storage_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/layout_builder/add/block\";}}s:9:\"path_vars\";a:5:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";i:4;s:9:\"plugin_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:224;s:14:\"patternOutline\";s:35:\"/layout_builder/add/block/%/%/%/%/%\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.add_section',	'/layout_builder/add/section/{section_storage_type}/{section_storage}/{delta}/{plugin_id}',	'/layout_builder/add/section/%/%/%/%',	112,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:88:\"/layout_builder/add/section/{section_storage_type}/{section_storage}/{delta}/{plugin_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:61:\"\\Drupal\\layout_builder\\Controller\\AddSectionController::build\";}s:12:\"requirements\";a:1:{s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:9:\"plugin_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:135:\"{^/layout_builder/add/section/(?P<section_storage_type>[^/]++)/(?P<section_storage>[^/]++)/(?P<delta>[^/]++)/(?P<plugin_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"plugin_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"delta\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"section_storage\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"section_storage_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/layout_builder/add/section\";}}s:9:\"path_vars\";a:4:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:9:\"plugin_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:112;s:14:\"patternOutline\";s:35:\"/layout_builder/add/section/%/%/%/%\";s:8:\"numParts\";i:7;}}',	7),
('layout_builder.choose_block',	'/layout_builder/choose/block/{section_storage_type}/{section_storage}/{delta}/{region}',	'/layout_builder/choose/block/%/%/%/%',	112,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/layout_builder/choose/block/{section_storage_type}/{section_storage}/{delta}/{region}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:62:\"\\Drupal\\layout_builder\\Controller\\ChooseBlockController::build\";s:6:\"_title\";s:14:\"Choose a block\";}s:12:\"requirements\";a:1:{s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:133:\"{^/layout_builder/choose/block/(?P<section_storage_type>[^/]++)/(?P<section_storage>[^/]++)/(?P<delta>[^/]++)/(?P<region>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"region\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"delta\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"section_storage\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"section_storage_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/layout_builder/choose/block\";}}s:9:\"path_vars\";a:4:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:112;s:14:\"patternOutline\";s:36:\"/layout_builder/choose/block/%/%/%/%\";s:8:\"numParts\";i:7;}}',	7),
('layout_builder.choose_inline_block',	'/layout_builder/choose/inline-block/{section_storage_type}/{section_storage}/{delta}/{region}',	'/layout_builder/choose/inline-block/%/%/%/%',	112,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/layout_builder/choose/inline-block/{section_storage_type}/{section_storage}/{delta}/{region}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:72:\"\\Drupal\\layout_builder\\Controller\\ChooseBlockController::inlineBlockList\";s:6:\"_title\";s:23:\"Add a new content block\";}s:12:\"requirements\";a:1:{s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:141:\"{^/layout_builder/choose/inline\\-block/(?P<section_storage_type>[^/]++)/(?P<section_storage>[^/]++)/(?P<delta>[^/]++)/(?P<region>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"region\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"delta\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"section_storage\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"section_storage_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/layout_builder/choose/inline-block\";}}s:9:\"path_vars\";a:4:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:112;s:14:\"patternOutline\";s:43:\"/layout_builder/choose/inline-block/%/%/%/%\";s:8:\"numParts\";i:7;}}',	7),
('layout_builder.choose_section',	'/layout_builder/choose/section/{section_storage_type}/{section_storage}/{delta}',	'/layout_builder/choose/section/%/%/%',	56,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/layout_builder/choose/section/{section_storage_type}/{section_storage}/{delta}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\layout_builder\\Controller\\ChooseSectionController::build\";s:6:\"_title\";s:32:\"Choose a layout for this section\";}s:12:\"requirements\";a:1:{s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:116:\"{^/layout_builder/choose/section/(?P<section_storage_type>[^/]++)/(?P<section_storage>[^/]++)/(?P<delta>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"delta\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"section_storage\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"section_storage_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/layout_builder/choose/section\";}}s:9:\"path_vars\";a:3:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:56;s:14:\"patternOutline\";s:36:\"/layout_builder/choose/section/%/%/%\";s:8:\"numParts\";i:6;}}',	6),
('layout_builder.configure_section',	'/layout_builder/configure/section/{section_storage_type}/{section_storage}/{delta}/{plugin_id}',	'/layout_builder/configure/section/%/%/%',	56,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:94:\"/layout_builder/configure/section/{section_storage_type}/{section_storage}/{delta}/{plugin_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:17:\"Configure section\";s:5:\"_form\";s:48:\"\\Drupal\\layout_builder\\Form\\ConfigureSectionForm\";s:9:\"plugin_id\";N;}s:12:\"requirements\";a:1:{s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:9:\"plugin_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:146:\"{^/layout_builder/configure/section/(?P<section_storage_type>[^/]++)/(?P<section_storage>[^/]++)/(?P<delta>[^/]++)(?:/(?P<plugin_id>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"plugin_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"delta\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"section_storage\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"section_storage_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/layout_builder/configure/section\";}}s:9:\"path_vars\";a:4:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:9:\"plugin_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:56;s:14:\"patternOutline\";s:39:\"/layout_builder/configure/section/%/%/%\";s:8:\"numParts\";i:7;}}',	7),
('layout_builder.defaults.block_content.disable',	'/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/layout/disable',	'/admin/structure/block-content/manage/%/display/%/layout/disable',	491,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/layout/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:13:\"block_content\";s:10:\"bundle_key\";s:18:\"block_content_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\LayoutBuilderDisableForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/layout/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:64:\"/admin/structure/block-content/manage/%/display/%/layout/disable\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.defaults.block_content.disable.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/display/{view_mode_name}/layout/disable',	'/admin/structure/block/block-content/manage/%/display/%/layout/disable',	1003,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:104:\"/admin/structure/block/block-content/manage/{block_content_type}/display/{view_mode_name}/layout/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:13:\"block_content\";s:10:\"bundle_key\";s:18:\"block_content_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:132:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/layout/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1003;s:14:\"patternOutline\";s:70:\"/admin/structure/block/block-content/manage/%/display/%/layout/disable\";s:8:\"numParts\";i:10;}}',	10),
('layout_builder.defaults.block_content.discard_changes',	'/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/layout/discard-changes',	'/admin/structure/block-content/manage/%/display/%/layout/discard-changes',	491,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:106:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:13:\"block_content\";s:10:\"bundle_key\";s:18:\"block_content_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:135:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:72:\"/admin/structure/block-content/manage/%/display/%/layout/discard-changes\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.defaults.block_content.discard_changes.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/display/{view_mode_name}/layout/discard-changes',	'/admin/structure/block/block-content/manage/%/display/%/layout/discard-changes',	1003,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:112:\"/admin/structure/block/block-content/manage/{block_content_type}/display/{view_mode_name}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:13:\"block_content\";s:10:\"bundle_key\";s:18:\"block_content_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:141:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1003;s:14:\"patternOutline\";s:78:\"/admin/structure/block/block-content/manage/%/display/%/layout/discard-changes\";s:8:\"numParts\";i:10;}}',	10),
('layout_builder.defaults.block_content.view',	'/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/layout',	'/admin/structure/block-content/manage/%/display/%/layout',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:90:\"/admin/structure/block-content/manage/{block_content_type}/display/{view_mode_name}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:14:\"entity_type_id\";s:13:\"block_content\";s:10:\"bundle_key\";s:18:\"block_content_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:34:\"entity_view_display.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:7:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:118:\"{^/admin/structure/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/structure/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:56:\"/admin/structure/block-content/manage/%/display/%/layout\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.defaults.block_content.view.bc',	'/admin/structure/block/block-content/manage/{block_content_type}/display/{view_mode_name}/layout',	'/admin/structure/block/block-content/manage/%/display/%/layout',	501,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:96:\"/admin/structure/block/block-content/manage/{block_content_type}/display/{view_mode_name}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:14:\"entity_type_id\";s:13:\"block_content\";s:10:\"bundle_key\";s:18:\"block_content_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";s:6:\"bundle\";s:0:\"\";s:11:\"_controller\";s:81:\"\\Drupal\\block_content\\Controller\\BlockContentController::blockContentTypeRedirect\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer block_content display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:7:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"block_content_type\";a:2:{s:4:\"type\";s:25:\"entity:block_content_type\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:124:\"{^/admin/structure/block/block\\-content/manage/(?P<block_content_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"block_content_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/block/block-content/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:18:\"block_content_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:62:\"/admin/structure/block/block-content/manage/%/display/%/layout\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.defaults.contact_message.disable',	'/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/layout/disable',	'/admin/structure/contact/manage/%/display/%/layout/disable',	491,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:86:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/layout/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:15:\"contact_message\";s:10:\"bundle_key\";s:12:\"contact_form\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\LayoutBuilderDisableForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:34:\"administer contact_message display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:113:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/layout/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:58:\"/admin/structure/contact/manage/%/display/%/layout/disable\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.defaults.contact_message.discard_changes',	'/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/layout/discard-changes',	'/admin/structure/contact/manage/%/display/%/layout/discard-changes',	491,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:94:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:15:\"contact_message\";s:10:\"bundle_key\";s:12:\"contact_form\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:34:\"administer contact_message display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:122:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:66:\"/admin/structure/contact/manage/%/display/%/layout/discard-changes\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.defaults.contact_message.view',	'/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/layout',	'/admin/structure/contact/manage/%/display/%/layout',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:78:\"/admin/structure/contact/manage/{contact_form}/display/{view_mode_name}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:14:\"entity_type_id\";s:15:\"contact_message\";s:10:\"bundle_key\";s:12:\"contact_form\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:34:\"entity_view_display.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:34:\"administer contact_message display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:7:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/contact/manage/(?P<contact_form>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"contact_form\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/contact/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:12:\"contact_form\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:50:\"/admin/structure/contact/manage/%/display/%/layout\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.defaults.media.disable',	'/admin/structure/media/manage/{media_type}/display/{view_mode_name}/layout/disable',	'/admin/structure/media/manage/%/display/%/layout/disable',	491,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}/layout/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:5:\"media\";s:10:\"bundle_key\";s:10:\"media_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\LayoutBuilderDisableForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:24:\"administer media display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/layout/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:56:\"/admin/structure/media/manage/%/display/%/layout/disable\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.defaults.media.discard_changes',	'/admin/structure/media/manage/{media_type}/display/{view_mode_name}/layout/discard-changes',	'/admin/structure/media/manage/%/display/%/layout/discard-changes',	491,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:90:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:5:\"media\";s:10:\"bundle_key\";s:10:\"media_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:24:\"administer media display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:118:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:64:\"/admin/structure/media/manage/%/display/%/layout/discard-changes\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.defaults.media.view',	'/admin/structure/media/manage/{media_type}/display/{view_mode_name}/layout',	'/admin/structure/media/manage/%/display/%/layout',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/structure/media/manage/{media_type}/display/{view_mode_name}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:14:\"entity_type_id\";s:5:\"media\";s:10:\"bundle_key\";s:10:\"media_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:34:\"entity_view_display.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:24:\"administer media display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:7:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:10:\"media_type\";a:2:{s:4:\"type\";s:17:\"entity:media_type\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/media/manage/(?P<media_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"media_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/media/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:10:\"media_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/media/manage/%/display/%/layout\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.defaults.node.disable',	'/admin/structure/types/manage/{node_type}/display/{view_mode_name}/layout/disable',	'/admin/structure/types/manage/%/display/%/layout/disable',	491,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:81:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}/layout/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:4:\"node\";s:10:\"bundle_key\";s:9:\"node_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\LayoutBuilderDisableForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer node display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:108:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/layout/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:56:\"/admin/structure/types/manage/%/display/%/layout/disable\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.defaults.node.discard_changes',	'/admin/structure/types/manage/{node_type}/display/{view_mode_name}/layout/discard-changes',	'/admin/structure/types/manage/%/display/%/layout/discard-changes',	491,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:4:\"node\";s:10:\"bundle_key\";s:9:\"node_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer node display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:64:\"/admin/structure/types/manage/%/display/%/layout/discard-changes\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.defaults.node.view',	'/admin/structure/types/manage/{node_type}/display/{view_mode_name}/layout',	'/admin/structure/types/manage/%/display/%/layout',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/types/manage/{node_type}/display/{view_mode_name}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:14:\"entity_type_id\";s:4:\"node\";s:10:\"bundle_key\";s:9:\"node_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:34:\"entity_view_display.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer node display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:7:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:100:\"{^/admin/structure/types/manage/(?P<node_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/types/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:9:\"node_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:48:\"/admin/structure/types/manage/%/display/%/layout\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.defaults.paragraph.disable',	'/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/layout/disable',	'/admin/structure/paragraphs_type/%/display/%/layout/disable',	235,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:90:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/layout/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:9:\"paragraph\";s:10:\"bundle_key\";s:15:\"paragraphs_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\LayoutBuilderDisableForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:28:\"administer paragraph display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/layout/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:235;s:14:\"patternOutline\";s:59:\"/admin/structure/paragraphs_type/%/display/%/layout/disable\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.defaults.paragraph.discard_changes',	'/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/layout/discard-changes',	'/admin/structure/paragraphs_type/%/display/%/layout/discard-changes',	235,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:98:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:9:\"paragraph\";s:10:\"bundle_key\";s:15:\"paragraphs_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:28:\"administer paragraph display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:235;s:14:\"patternOutline\";s:67:\"/admin/structure/paragraphs_type/%/display/%/layout/discard-changes\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.defaults.paragraph.view',	'/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/layout',	'/admin/structure/paragraphs_type/%/display/%/layout',	117,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/structure/paragraphs_type/{paragraphs_type}/display/{view_mode_name}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:14:\"entity_type_id\";s:9:\"paragraph\";s:10:\"bundle_key\";s:15:\"paragraphs_type\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:34:\"entity_view_display.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:28:\"administer paragraph display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:7:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/structure/paragraphs_type/(?P<paragraphs_type>[^/]++)/display/(?P<view_mode_name>[^/]++)/layout$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"paragraphs_type\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/paragraphs_type\";}}s:9:\"path_vars\";a:2:{i:0;s:15:\"paragraphs_type\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:117;s:14:\"patternOutline\";s:51:\"/admin/structure/paragraphs_type/%/display/%/layout\";s:8:\"numParts\";i:7;}}',	7),
('layout_builder.defaults.taxonomy_term.disable',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/layout/disable',	'/admin/structure/taxonomy/manage/%/overview/display/%/layout/disable',	987,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:103:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/layout/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:10:\"bundle_key\";s:19:\"taxonomy_vocabulary\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\LayoutBuilderDisableForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer taxonomy_term display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:19:\"taxonomy_vocabulary\";a:1:{s:21:\"with_config_overrides\";b:1;}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:130:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)/layout/disable$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/layout/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:987;s:14:\"patternOutline\";s:68:\"/admin/structure/taxonomy/manage/%/overview/display/%/layout/disable\";s:8:\"numParts\";i:10;}}',	10),
('layout_builder.defaults.taxonomy_term.discard_changes',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/layout/discard-changes',	'/admin/structure/taxonomy/manage/%/overview/display/%/layout/discard-changes',	987,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:111:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:10:\"bundle_key\";s:19:\"taxonomy_vocabulary\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer taxonomy_term display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:19:\"taxonomy_vocabulary\";a:1:{s:21:\"with_config_overrides\";b:1;}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:139:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:987;s:14:\"patternOutline\";s:76:\"/admin/structure/taxonomy/manage/%/overview/display/%/layout/discard-changes\";s:8:\"numParts\";i:10;}}',	10),
('layout_builder.defaults.taxonomy_term.view',	'/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/layout',	'/admin/structure/taxonomy/manage/%/overview/display/%/layout',	493,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:95:\"/admin/structure/taxonomy/manage/{taxonomy_vocabulary}/overview/display/{view_mode_name}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:10:\"bundle_key\";s:19:\"taxonomy_vocabulary\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:34:\"entity_view_display.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";s:6:\"bundle\";s:0:\"\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:32:\"administer taxonomy_term display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:7:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:19:\"taxonomy_vocabulary\";a:1:{s:21:\"with_config_overrides\";b:1;}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:9:\"_field_ui\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:122:\"{^/admin/structure/taxonomy/manage/(?P<taxonomy_vocabulary>[^/]++)/overview/display/(?P<view_mode_name>[^/]++)/layout$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/overview/display\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:19:\"taxonomy_vocabulary\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/structure/taxonomy/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:19:\"taxonomy_vocabulary\";i:1;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:493;s:14:\"patternOutline\";s:60:\"/admin/structure/taxonomy/manage/%/overview/display/%/layout\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.defaults.user.disable',	'/admin/config/people/accounts/display/{view_mode_name}/layout/disable',	'/admin/config/people/accounts/display/%/layout/disable',	251,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:69:\"/admin/config/people/accounts/display/{view_mode_name}/layout/disable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\LayoutBuilderDisableForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer user display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)/layout/disable$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/layout/disable\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:54:\"/admin/config/people/accounts/display/%/layout/disable\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.defaults.user.discard_changes',	'/admin/config/people/accounts/display/{view_mode_name}/layout/discard-changes',	'/admin/config/people/accounts/display/%/layout/discard-changes',	251,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:77:\"/admin/config/people/accounts/display/{view_mode_name}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer user display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:62:\"/admin/config/people/accounts/display/%/layout/discard-changes\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.defaults.user.view',	'/admin/config/people/accounts/display/{view_mode_name}/layout',	'/admin/config/people/accounts/display/%/layout',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/config/people/accounts/display/{view_mode_name}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:6:{s:14:\"entity_type_id\";s:4:\"user\";s:6:\"bundle\";s:4:\"user\";s:20:\"section_storage_type\";s:8:\"defaults\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:34:\"entity_view_display.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";}s:12:\"requirements\";a:2:{s:26:\"_field_ui_view_mode_access\";s:23:\"administer user display\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:31:\"access_check.field_ui.view_mode\";i:1;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/config/people/accounts/display/(?P<view_mode_name>[^/]++)/layout$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"view_mode_name\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/people/accounts/display\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"view_mode_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/people/accounts/display/%/layout\";s:8:\"numParts\";i:7;}}',	7),
('layout_builder.move_block',	'/layout_builder/move/block/{section_storage_type}/{section_storage}/{delta_from}/{delta_to}/{region_to}/{block_uuid}/{preceding_block_uuid}',	'/layout_builder/move/block/%/%',	28,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:139:\"/layout_builder/move/block/{section_storage_type}/{section_storage}/{delta_from}/{delta_to}/{region_to}/{block_uuid}/{preceding_block_uuid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:7:{s:11:\"_controller\";s:60:\"\\Drupal\\layout_builder\\Controller\\MoveBlockController::build\";s:10:\"delta_from\";N;s:8:\"delta_to\";N;s:11:\"region_from\";N;s:9:\"region_to\";N;s:10:\"block_uuid\";N;s:20:\"preceding_block_uuid\";N;}s:12:\"requirements\";a:1:{s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:7:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:10:\"delta_from\";i:3;s:8:\"delta_to\";i:4;s:9:\"region_to\";i:5;s:10:\"block_uuid\";i:6;s:20:\"preceding_block_uuid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:241:\"{^/layout_builder/move/block/(?P<section_storage_type>[^/]++)/(?P<section_storage>[^/]++)(?:/(?P<delta_from>[^/]++)(?:/(?P<delta_to>[^/]++)(?:/(?P<region_to>[^/]++)(?:/(?P<block_uuid>[^/]++)(?:/(?P<preceding_block_uuid>[^/]++))?)?)?)?)?$}sDu\";s:11:\"path_tokens\";a:8:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"preceding_block_uuid\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"block_uuid\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"region_to\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"delta_to\";i:4;b:1;}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"delta_from\";i:4;b:1;}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"section_storage\";i:4;b:1;}i:6;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"section_storage_type\";i:4;b:1;}i:7;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout_builder/move/block\";}}s:9:\"path_vars\";a:7:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:10:\"delta_from\";i:3;s:8:\"delta_to\";i:4;s:9:\"region_to\";i:5;s:10:\"block_uuid\";i:6;s:20:\"preceding_block_uuid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:28;s:14:\"patternOutline\";s:30:\"/layout_builder/move/block/%/%\";s:8:\"numParts\";i:10;}}',	10),
('layout_builder.move_block_form',	'/layout_builder/move/block/{section_storage_type}/{section_storage}/{delta}/{region}/{uuid}',	'/layout_builder/move/block/%/%/%/%/%',	224,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:91:\"/layout_builder/move/block/{section_storage_type}/{section_storage}/{delta}/{region}/{uuid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:15:\"_title_callback\";s:48:\"\\Drupal\\layout_builder\\Form\\MoveBlockForm::title\";s:5:\"_form\";s:41:\"\\Drupal\\layout_builder\\Form\\MoveBlockForm\";}s:12:\"requirements\";a:1:{s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";i:4;s:4:\"uuid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:148:\"{^/layout_builder/move/block/(?P<section_storage_type>[^/]++)/(?P<section_storage>[^/]++)/(?P<delta>[^/]++)/(?P<region>[^/]++)/(?P<uuid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"uuid\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"region\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"delta\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"section_storage\";i:4;b:1;}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"section_storage_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/layout_builder/move/block\";}}s:9:\"path_vars\";a:5:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";i:4;s:4:\"uuid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:224;s:14:\"patternOutline\";s:36:\"/layout_builder/move/block/%/%/%/%/%\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.overrides.block_content.discard_changes',	'/admin/content/block/{block_content}/layout/discard-changes',	'/admin/content/block/%/layout/discard-changes',	59,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/content/block/{block_content}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:13:\"block_content\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:74:\"{^/admin/content/block/(?P<block_content>\\d+)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:45:\"/admin/content/block/%/layout/discard-changes\";s:8:\"numParts\";i:6;}}',	6),
('layout_builder.overrides.block_content.revert',	'/admin/content/block/{block_content}/layout/revert',	'/admin/content/block/%/layout/revert',	59,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/content/block/{block_content}/layout/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:13:\"block_content\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:47:\"\\Drupal\\layout_builder\\Form\\RevertOverridesForm\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/admin/content/block/(?P<block_content>\\d+)/layout/revert$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/layout/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:59;s:14:\"patternOutline\";s:36:\"/admin/content/block/%/layout/revert\";s:8:\"numParts\";i:6;}}',	6),
('layout_builder.overrides.block_content.view',	'/admin/content/block/{block_content}/layout',	'/admin/content/block/%/layout',	29,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/content/block/{block_content}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:13:\"block_content\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:28:\"block_content.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:20:\"block_content.update\";s:13:\"block_content\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:13:\"block_content\";a:2:{s:4:\"type\";s:20:\"entity:block_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"block_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/admin/content/block/(?P<block_content>\\d+)/layout$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"block_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"block_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:29;s:14:\"patternOutline\";s:29:\"/admin/content/block/%/layout\";s:8:\"numParts\";i:5;}}',	5),
('layout_builder.overrides.media.discard_changes',	'/media/{media}/edit/layout/discard-changes',	'/media/%/edit/layout/discard-changes',	23,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/media/{media}/edit/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:5:\"media\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:12:\"media.update\";s:5:\"media\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/media/(?P<media>\\d+)/edit/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/edit/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:23;s:14:\"patternOutline\";s:36:\"/media/%/edit/layout/discard-changes\";s:8:\"numParts\";i:5;}}',	5),
('layout_builder.overrides.media.revert',	'/media/{media}/edit/layout/revert',	'/media/%/edit/layout/revert',	23,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/media/{media}/edit/layout/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:5:\"media\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:47:\"\\Drupal\\layout_builder\\Form\\RevertOverridesForm\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:12:\"media.update\";s:5:\"media\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/media/(?P<media>\\d+)/edit/layout/revert$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/edit/layout/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:23;s:14:\"patternOutline\";s:27:\"/media/%/edit/layout/revert\";s:8:\"numParts\";i:5;}}',	5),
('layout_builder.overrides.media.view',	'/media/{media}/edit/layout',	'/media/%/edit/layout',	11,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/media/{media}/edit/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:5:\"media\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:20:\"media.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:12:\"media.update\";s:5:\"media\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:5:\"media\";a:2:{s:4:\"type\";s:12:\"entity:media\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"media\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/media/(?P<media>\\d+)/edit/layout$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/edit/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:5:\"media\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"media\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:20:\"/media/%/edit/layout\";s:8:\"numParts\";i:4;}}',	4),
('layout_builder.overrides.menu_link_content.discard_changes',	'/admin/structure/menu/item/{menu_link_content}/edit/layout/discard-changes',	'/admin/structure/menu/item/%/edit/layout/discard-changes',	247,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:74:\"/admin/structure/menu/item/{menu_link_content}/edit/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:24:\"menu_link_content.update\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/edit/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:56:\"/admin/structure/menu/item/%/edit/layout/discard-changes\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.overrides.menu_link_content.revert',	'/admin/structure/menu/item/{menu_link_content}/edit/layout/revert',	'/admin/structure/menu/item/%/edit/layout/revert',	247,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/structure/menu/item/{menu_link_content}/edit/layout/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:47:\"\\Drupal\\layout_builder\\Form\\RevertOverridesForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:24:\"menu_link_content.update\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit/layout/revert$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/edit/layout/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:247;s:14:\"patternOutline\";s:47:\"/admin/structure/menu/item/%/edit/layout/revert\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.overrides.menu_link_content.view',	'/admin/structure/menu/item/{menu_link_content}/edit/layout',	'/admin/structure/menu/item/%/edit/layout',	123,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:58:\"/admin/structure/menu/item/{menu_link_content}/edit/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:17:\"menu_link_content\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:32:\"menu_link_content.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:24:\"menu_link_content.update\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:17:\"menu_link_content\";a:2:{s:4:\"type\";s:24:\"entity:menu_link_content\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/structure/menu/item/(?P<menu_link_content>[^/]++)/edit/layout$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/edit/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"menu_link_content\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/item\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"menu_link_content\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:123;s:14:\"patternOutline\";s:40:\"/admin/structure/menu/item/%/edit/layout\";s:8:\"numParts\";i:7;}}',	7),
('layout_builder.overrides.node.discard_changes',	'/node/{node}/layout/discard-changes',	'/node/%/layout/discard-changes',	11,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/node/{node}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:4:\"node\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:3:{s:4:\"node\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"node.view\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/node/(?P<node>\\d+)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:30:\"/node/%/layout/discard-changes\";s:8:\"numParts\";i:4;}}',	4),
('layout_builder.overrides.node.revert',	'/node/{node}/layout/revert',	'/node/%/layout/revert',	11,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/node/{node}/layout/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:4:\"node\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:47:\"\\Drupal\\layout_builder\\Form\\RevertOverridesForm\";}s:12:\"requirements\";a:3:{s:4:\"node\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"node.view\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/node/(?P<node>\\d+)/layout/revert$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/layout/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:21:\"/node/%/layout/revert\";s:8:\"numParts\";i:4;}}',	4),
('layout_builder.overrides.node.view',	'/node/{node}/layout',	'/node/%/layout',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/node/{node}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:4:\"node\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:19:\"node.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";}s:12:\"requirements\";a:3:{s:4:\"node\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"node.view\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"node\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/node/(?P<node>\\d+)/layout$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"node\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/node/%/layout\";s:8:\"numParts\";i:3;}}',	3),
('layout_builder.overrides.redirect.discard_changes',	'/admin/config/search/redirect/edit/{redirect}/layout/discard-changes',	'/admin/config/search/redirect/edit/%/layout/discard-changes',	251,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/search/redirect/edit/{redirect}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:8:\"redirect\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"redirect.update\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:8:\"redirect\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"redirect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:86:\"{^/admin/config/search/redirect/edit/(?P<redirect>[^/]++)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"redirect\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/redirect/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"redirect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:59:\"/admin/config/search/redirect/edit/%/layout/discard-changes\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.overrides.redirect.revert',	'/admin/config/search/redirect/edit/{redirect}/layout/revert',	'/admin/config/search/redirect/edit/%/layout/revert',	251,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:59:\"/admin/config/search/redirect/edit/{redirect}/layout/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:8:\"redirect\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:47:\"\\Drupal\\layout_builder\\Form\\RevertOverridesForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"redirect.update\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:8:\"redirect\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"redirect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:76:\"{^/admin/config/search/redirect/edit/(?P<redirect>[^/]++)/layout/revert$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/layout/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"redirect\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/redirect/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"redirect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:50:\"/admin/config/search/redirect/edit/%/layout/revert\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.overrides.redirect.view',	'/admin/config/search/redirect/edit/{redirect}/layout',	'/admin/config/search/redirect/edit/%/layout',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:52:\"/admin/config/search/redirect/edit/{redirect}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:8:\"redirect\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:23:\"redirect.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:15:\"redirect.update\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:8:\"redirect\";a:2:{s:4:\"type\";s:15:\"entity:redirect\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"redirect\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/config/search/redirect/edit/(?P<redirect>[^/]++)/layout$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"redirect\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/redirect/edit\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"redirect\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:43:\"/admin/config/search/redirect/edit/%/layout\";s:8:\"numParts\";i:7;}}',	7),
('layout_builder.overrides.shortcut.discard_changes',	'/admin/config/user-interface/shortcut/link/{shortcut}/layout/discard-changes',	'/admin/config/user-interface/shortcut/link/%/layout/discard-changes',	251,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:76:\"/admin/config/user-interface/shortcut/link/{shortcut}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:8:\"shortcut\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:15:\"shortcut.update\";s:8:\"shortcut\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:92:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:67:\"/admin/config/user-interface/shortcut/link/%/layout/discard-changes\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.overrides.shortcut.revert',	'/admin/config/user-interface/shortcut/link/{shortcut}/layout/revert',	'/admin/config/user-interface/shortcut/link/%/layout/revert',	251,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/config/user-interface/shortcut/link/{shortcut}/layout/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:8:\"shortcut\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:47:\"\\Drupal\\layout_builder\\Form\\RevertOverridesForm\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:15:\"shortcut.update\";s:8:\"shortcut\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/layout/revert$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/layout/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:58:\"/admin/config/user-interface/shortcut/link/%/layout/revert\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.overrides.shortcut.view',	'/admin/config/user-interface/shortcut/link/{shortcut}/layout',	'/admin/config/user-interface/shortcut/link/%/layout',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/config/user-interface/shortcut/link/{shortcut}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:8:\"shortcut\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:23:\"shortcut.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:15:\"shortcut.update\";s:8:\"shortcut\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:8:\"shortcut\";a:2:{s:4:\"type\";s:15:\"entity:shortcut\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"shortcut\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:75:\"{^/admin/config/user\\-interface/shortcut/link/(?P<shortcut>\\d+)/layout$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:8:\"shortcut\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:42:\"/admin/config/user-interface/shortcut/link\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"shortcut\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:51:\"/admin/config/user-interface/shortcut/link/%/layout\";s:8:\"numParts\";i:7;}}',	7),
('layout_builder.overrides.taxonomy_term.discard_changes',	'/taxonomy/term/{taxonomy_term}/layout/discard-changes',	'/taxonomy/term/%/layout/discard-changes',	27,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/taxonomy/term/{taxonomy_term}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:18:\"taxonomy_term.view\";s:13:\"taxonomy_term\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:27;s:14:\"patternOutline\";s:39:\"/taxonomy/term/%/layout/discard-changes\";s:8:\"numParts\";i:5;}}',	5),
('layout_builder.overrides.taxonomy_term.revert',	'/taxonomy/term/{taxonomy_term}/layout/revert',	'/taxonomy/term/%/layout/revert',	27,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/taxonomy/term/{taxonomy_term}/layout/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:47:\"\\Drupal\\layout_builder\\Form\\RevertOverridesForm\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:18:\"taxonomy_term.view\";s:13:\"taxonomy_term\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/layout/revert$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/layout/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:27;s:14:\"patternOutline\";s:30:\"/taxonomy/term/%/layout/revert\";s:8:\"numParts\";i:5;}}',	5),
('layout_builder.overrides.taxonomy_term.view',	'/taxonomy/term/{taxonomy_term}/layout',	'/taxonomy/term/%/layout',	13,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/taxonomy/term/{taxonomy_term}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:13:\"taxonomy_term\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:28:\"taxonomy_term.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";}s:12:\"requirements\";a:3:{s:14:\"_entity_access\";s:18:\"taxonomy_term.view\";s:13:\"taxonomy_term\";s:3:\"\\d+\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:13:\"taxonomy_term\";a:2:{s:4:\"type\";s:20:\"entity:taxonomy_term\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/taxonomy/term/(?P<taxonomy_term>\\d+)/layout$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:13:\"taxonomy_term\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"taxonomy_term\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:23:\"/taxonomy/term/%/layout\";s:8:\"numParts\";i:4;}}',	4),
('layout_builder.overrides.user.discard_changes',	'/user/{user}/layout/discard-changes',	'/user/%/layout/discard-changes',	11,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/user/{user}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:4:\"user\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:3:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"user.view\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/user/(?P<user>\\d+)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:30:\"/user/%/layout/discard-changes\";s:8:\"numParts\";i:4;}}',	4),
('layout_builder.overrides.user.revert',	'/user/{user}/layout/revert',	'/user/%/layout/revert',	11,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/user/{user}/layout/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:4:\"user\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:47:\"\\Drupal\\layout_builder\\Form\\RevertOverridesForm\";}s:12:\"requirements\";a:3:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"user.view\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/user/(?P<user>\\d+)/layout/revert$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/layout/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:21:\"/user/%/layout/revert\";s:8:\"numParts\";i:4;}}',	4),
('layout_builder.overrides.user.view',	'/user/{user}/layout',	'/user/%/layout',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/user/{user}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:4:\"user\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:19:\"user.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";}s:12:\"requirements\";a:3:{s:4:\"user\";s:3:\"\\d+\";s:14:\"_entity_access\";s:9:\"user.view\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/user/(?P<user>\\d+)/layout$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:14:\"/user/%/layout\";s:8:\"numParts\";i:3;}}',	3),
('layout_builder.overrides.webform_submission.discard_changes',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/layout/discard-changes',	'/admin/structure/webform/manage/%/submission/%/layout/discard-changes',	491,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:96:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/layout/discard-changes\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:18:\"webform_submission\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:52:\"\\Drupal\\layout_builder\\Form\\DiscardLayoutChangesForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:124:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/layout/discard\\-changes$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/layout/discard-changes\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:69:\"/admin/structure/webform/manage/%/submission/%/layout/discard-changes\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.overrides.webform_submission.revert',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/layout/revert',	'/admin/structure/webform/manage/%/submission/%/layout/revert',	491,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:87:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/layout/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:14:\"entity_type_id\";s:18:\"webform_submission\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:5:\"_form\";s:47:\"\\Drupal\\layout_builder\\Form\\RevertOverridesForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/layout/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/layout/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:491;s:14:\"patternOutline\";s:60:\"/admin/structure/webform/manage/%/submission/%/layout/revert\";s:8:\"numParts\";i:9;}}',	9),
('layout_builder.overrides.webform_submission.view',	'/admin/structure/webform/manage/{webform}/submission/{webform_submission}/layout',	'/admin/structure/webform/manage/%/submission/%/layout',	245,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:80:\"/admin/structure/webform/manage/{webform}/submission/{webform_submission}/layout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:14:\"entity_type_id\";s:18:\"webform_submission\";s:20:\"section_storage_type\";s:9:\"overrides\";s:15:\"section_storage\";s:0:\"\";s:12:\"_entity_form\";s:33:\"webform_submission.layout_builder\";s:15:\"_title_callback\";s:64:\"\\Drupal\\layout_builder\\Controller\\LayoutBuilderController::title\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:23:\"webform_submission.view\";s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:2:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}s:18:\"webform_submission\";a:2:{s:4:\"type\";s:25:\"entity:webform_submission\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:12:\"_admin_route\";b:0;s:15:\"_layout_builder\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:41:\"access_check.entity.layout_builder_access\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:107:\"{^/admin/structure/webform/manage/(?P<webform>[^/]++)/submission/(?P<webform_submission>[^/]++)/layout$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/layout\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"webform_submission\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/submission\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:18:\"webform_submission\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:245;s:14:\"patternOutline\";s:53:\"/admin/structure/webform/manage/%/submission/%/layout\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.remove_block',	'/layout_builder/remove/block/{section_storage_type}/{section_storage}/{delta}/{region}/{uuid}',	'/layout_builder/remove/block/%/%/%/%/%',	224,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/layout_builder/remove/block/{section_storage_type}/{section_storage}/{delta}/{region}/{uuid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:43:\"\\Drupal\\layout_builder\\Form\\RemoveBlockForm\";}s:12:\"requirements\";a:1:{s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";i:4;s:4:\"uuid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:150:\"{^/layout_builder/remove/block/(?P<section_storage_type>[^/]++)/(?P<section_storage>[^/]++)/(?P<delta>[^/]++)/(?P<region>[^/]++)/(?P<uuid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"uuid\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"region\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"delta\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"section_storage\";i:4;b:1;}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"section_storage_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/layout_builder/remove/block\";}}s:9:\"path_vars\";a:5:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";i:4;s:4:\"uuid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:224;s:14:\"patternOutline\";s:38:\"/layout_builder/remove/block/%/%/%/%/%\";s:8:\"numParts\";i:8;}}',	8),
('layout_builder.remove_section',	'/layout_builder/remove/section/{section_storage_type}/{section_storage}/{delta}',	'/layout_builder/remove/section/%/%/%',	56,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:79:\"/layout_builder/remove/section/{section_storage_type}/{section_storage}/{delta}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:45:\"\\Drupal\\layout_builder\\Form\\RemoveSectionForm\";}s:12:\"requirements\";a:1:{s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:116:\"{^/layout_builder/remove/section/(?P<section_storage_type>[^/]++)/(?P<section_storage>[^/]++)/(?P<delta>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"delta\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"section_storage\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"section_storage_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/layout_builder/remove/section\";}}s:9:\"path_vars\";a:3:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:56;s:14:\"patternOutline\";s:36:\"/layout_builder/remove/section/%/%/%\";s:8:\"numParts\";i:6;}}',	6),
('layout_builder.update_block',	'/layout_builder/update/block/{section_storage_type}/{section_storage}/{delta}/{region}/{uuid}',	'/layout_builder/update/block/%/%/%/%/%',	224,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:93:\"/layout_builder/update/block/{section_storage_type}/{section_storage}/{delta}/{region}/{uuid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\layout_builder\\Form\\UpdateBlockForm\";s:6:\"_title\";s:15:\"Configure block\";}s:12:\"requirements\";a:1:{s:22:\"_layout_builder_access\";s:4:\"view\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:10:\"parameters\";a:1:{s:15:\"section_storage\";a:2:{s:24:\"layout_builder_tempstore\";b:1;s:9:\"converter\";s:30:\"layout_builder.param_converter\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:41:\"access_check.entity.layout_builder_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";i:4;s:4:\"uuid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:150:\"{^/layout_builder/update/block/(?P<section_storage_type>[^/]++)/(?P<section_storage>[^/]++)/(?P<delta>[^/]++)/(?P<region>[^/]++)/(?P<uuid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"uuid\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"region\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"delta\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:15:\"section_storage\";i:4;b:1;}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:20:\"section_storage_type\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/layout_builder/update/block\";}}s:9:\"path_vars\";a:5:{i:0;s:20:\"section_storage_type\";i:1;s:15:\"section_storage\";i:2;s:5:\"delta\";i:3;s:6:\"region\";i:4;s:4:\"uuid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:224;s:14:\"patternOutline\";s:38:\"/layout_builder/update/block/%/%/%/%/%\";s:8:\"numParts\";i:8;}}',	8),
('linkit.autocomplete',	'/linkit/autocomplete/{linkit_profile_id}',	'/linkit/autocomplete/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/linkit/autocomplete/{linkit_profile_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\linkit\\Controller\\AutocompleteController::autocomplete\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:6:\"_theme\";s:14:\"ajax_base_page\";s:10:\"parameters\";a:1:{s:17:\"linkit_profile_id\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:17:\"linkit_profile_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:57:\"{^/linkit/autocomplete/(?P<linkit_profile_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"linkit_profile_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/linkit/autocomplete\";}}s:9:\"path_vars\";a:1:{i:0;s:17:\"linkit_profile_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:22:\"/linkit/autocomplete/%\";s:8:\"numParts\";i:3;}}',	3),
('linkit.matcher.add',	'/admin/config/content/linkit/manage/{linkit_profile}/matchers/add',	'/admin/config/content/linkit/manage/%/matchers/add',	251,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:65:\"/admin/config/content/linkit/manage/{linkit_profile}/matchers/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:35:\"\\Drupal\\linkit\\Form\\Matcher\\AddForm\";s:6:\"_title\";s:11:\"Add matcher\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:82:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/matchers/add$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/matchers/add\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:251;s:14:\"patternOutline\";s:50:\"/admin/config/content/linkit/manage/%/matchers/add\";s:8:\"numParts\";i:8;}}',	8),
('linkit.matcher.delete',	'/admin/config/content/linkit/manage/{linkit_profile}/matchers/{plugin_instance_id}/delete',	'/admin/config/content/linkit/manage/%/matchers/%/delete',	501,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/admin/config/content/linkit/manage/{linkit_profile}/matchers/{plugin_instance_id}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:38:\"\\Drupal\\linkit\\Form\\Matcher\\DeleteForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:18:\"plugin_instance_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:116:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/matchers/(?P<plugin_instance_id>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"plugin_instance_id\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/matchers\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:18:\"plugin_instance_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:501;s:14:\"patternOutline\";s:55:\"/admin/config/content/linkit/manage/%/matchers/%/delete\";s:8:\"numParts\";i:9;}}',	9),
('linkit.matcher.edit',	'/admin/config/content/linkit/manage/{linkit_profile}/matchers/{plugin_instance_id}',	'/admin/config/content/linkit/manage/%/matchers/%',	250,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:82:\"/admin/config/content/linkit/manage/{linkit_profile}/matchers/{plugin_instance_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\linkit\\Form\\Matcher\\EditForm\";s:15:\"_title_callback\";s:55:\"Drupal\\linkit\\Controller\\LinkitController::matcherTitle\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:18:\"plugin_instance_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:109:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/matchers/(?P<plugin_instance_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:18:\"plugin_instance_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/matchers\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:2:{i:0;s:14:\"linkit_profile\";i:1;s:18:\"plugin_instance_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:250;s:14:\"patternOutline\";s:48:\"/admin/config/content/linkit/manage/%/matchers/%\";s:8:\"numParts\";i:8;}}',	8),
('linkit.matchers',	'/admin/config/content/linkit/manage/{linkit_profile}/matchers',	'/admin/config/content/linkit/manage/%/matchers',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:61:\"/admin/config/content/linkit/manage/{linkit_profile}/matchers\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\linkit\\Form\\Matcher\\OverviewForm\";s:6:\"_title\";s:15:\"Manage matchers\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:26:\"administer linkit profiles\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:14:\"linkit_profile\";a:2:{s:4:\"type\";s:21:\"entity:linkit_profile\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:78:\"{^/admin/config/content/linkit/manage/(?P<linkit_profile>[^/]++)/matchers$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/matchers\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"linkit_profile\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:35:\"/admin/config/content/linkit/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"linkit_profile\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:46:\"/admin/config/content/linkit/manage/%/matchers\";s:8:\"numParts\";i:7;}}',	7),
('media.filter.preview',	'/media/{filter_format}/preview',	'/media/%/preview',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/media/{filter_format}/preview\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:55:\"\\Drupal\\media\\Controller\\MediaFilterController::preview\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:17:\"filter_format.use\";s:14:\"_custom_access\";s:74:\"\\Drupal\\media\\Controller\\MediaFilterController::formatUsesMediaEmbedFilter\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:13:\"filter_format\";a:2:{s:4:\"type\";s:20:\"entity:filter_format\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:13:\"filter_format\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/media/(?P<filter_format>[^/]++)/preview$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/preview\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"filter_format\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/media\";}}s:9:\"path_vars\";a:1:{i:0;s:13:\"filter_format\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:16:\"/media/%/preview\";s:8:\"numParts\";i:3;}}',	3),
('media.oembed_iframe',	'/media/oembed',	'/media/oembed',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/media/oembed\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:55:\"\\Drupal\\media\\Controller\\OEmbedIframeController::render\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:10:\"view media\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/media/oembed$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/media/oembed\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/media/oembed\";s:8:\"numParts\";i:2;}}',	2),
('media.settings',	'/admin/config/media/media-settings',	'/admin/config/media/media-settings',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/media/media-settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\media\\Form\\MediaSettingsForm\";s:6:\"_title\";s:14:\"Media settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/config/media/media\\-settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/media/media-settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/config/media/media-settings\";s:8:\"numParts\";i:4;}}',	4),
('media_library.settings',	'/admin/config/media/media-library',	'/admin/config/media/media-library',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/media/media-library\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\media_library\\Form\\SettingsForm\";s:6:\"_title\";s:22:\"Media Library settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer media\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/media/media\\-library$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/media/media-library\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/media/media-library\";s:8:\"numParts\";i:4;}}',	4),
('media_library.ui',	'/media-library',	'/media-library',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/media-library\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:32:\"media_library.ui_builder:buildUi\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:36:\"media_library.ui_builder:checkAccess\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:22:\"{^/media\\-library$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/media-library\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:14:\"/media-library\";s:8:\"numParts\";i:1;}}',	1),
('menu_ui.link_edit',	'/admin/structure/menu/link/{menu_link_plugin}/edit',	'/admin/structure/menu/link/%/edit',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:50:\"/admin/structure/menu/link/{menu_link_plugin}/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\menu_ui\\Form\\MenuLinkEditForm\";s:6:\"_title\";s:14:\"Edit menu link\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"menu_link_plugin\";a:2:{s:4:\"type\";s:16:\"menu_link_plugin\";s:9:\"converter\";s:54:\"drupal.proxy_original_service.paramconverter.menu_link\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:67:\"{^/admin/structure/menu/link/(?P<menu_link_plugin>[^/]++)/edit$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/edit\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"menu_link_plugin\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/link\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:33:\"/admin/structure/menu/link/%/edit\";s:8:\"numParts\";i:6;}}',	6),
('menu_ui.link_reset',	'/admin/structure/menu/link/{menu_link_plugin}/reset',	'/admin/structure/menu/link/%/reset',	61,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:51:\"/admin/structure/menu/link/{menu_link_plugin}/reset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:38:\"\\Drupal\\menu_ui\\Form\\MenuLinkResetForm\";s:6:\"_title\";s:15:\"Reset menu link\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:15:\"administer menu\";s:14:\"_custom_access\";s:56:\"\\Drupal\\menu_ui\\Form\\MenuLinkResetForm::linkIsResettable\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:16:\"menu_link_plugin\";a:2:{s:4:\"type\";s:16:\"menu_link_plugin\";s:9:\"converter\";s:54:\"drupal.proxy_original_service.paramconverter.menu_link\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:68:\"{^/admin/structure/menu/link/(?P<menu_link_plugin>[^/]++)/reset$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/reset\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"menu_link_plugin\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/menu/link\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"menu_link_plugin\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:61;s:14:\"patternOutline\";s:34:\"/admin/structure/menu/link/%/reset\";s:8:\"numParts\";i:6;}}',	6),
('menu_ui.parent_options_js',	'/admin/structure/menu/parents',	'/admin/structure/menu/parents',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/structure/menu/parents\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:59:\"\\Drupal\\menu_ui\\Controller\\MenuController::getParentOptions\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:15:\"administer menu\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/menu/parents$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/menu/parents\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/structure/menu/parents\";s:8:\"numParts\";i:4;}}',	4),
('metatag.reports_plugins',	'/admin/reports/metatag-plugins',	'/admin/reports/metatag-plugins',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/reports/metatag-plugins\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\metatag\\Controller\\MetatagController::reportPlugins\";s:6:\"_title\";s:15:\"Metatag plugins\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/metatag\\-plugins$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/reports/metatag-plugins\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:30:\"/admin/reports/metatag-plugins\";s:8:\"numParts\";i:3;}}',	3),
('metatag.settings',	'/admin/config/search/metatag/settings',	'/admin/config/search/metatag/settings',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/search/metatag/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\metatag\\Form\\MetatagSettingsForm\";s:6:\"_title\";s:28:\"Configure the Metatag module\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:20:\"administer meta tags\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/search/metatag/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/search/metatag/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:37:\"/admin/config/search/metatag/settings\";s:8:\"numParts\";i:5;}}',	5),
('node.add',	'/node/add/{node_type}',	'/node/add/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/node/add/{node_type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:12:\"node.default\";s:15:\"_title_callback\";s:52:\"\\Drupal\\node\\Controller\\NodeController::addPageTitle\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:16:\"node:{node_type}\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:1:{s:9:\"node_type\";a:3:{s:4:\"type\";s:16:\"entity:node_type\";s:21:\"with_config_overrides\";b:1;s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"node_type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/node/add/(?P<node_type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"node_type\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/node/add\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"node_type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:11:\"/node/add/%\";s:8:\"numParts\";i:3;}}',	3),
('node.add_page',	'/node/add',	'/node/add',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:9:\"/node/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:11:\"Add content\";s:11:\"_controller\";s:47:\"\\Drupal\\node\\Controller\\NodeController::addPage\";}s:12:\"requirements\";a:1:{s:25:\"_entity_create_any_access\";s:4:\"node\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.entity_create_any\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:16:\"{^/node/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/node/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:9:\"/node/add\";s:8:\"numParts\";i:2;}}',	2),
('node.configure_rebuild_confirm',	'/admin/reports/status/rebuild',	'/admin/reports/status/rebuild',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/status/rebuild\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\RebuildPermissionsForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer nodes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/status/rebuild$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/status/rebuild\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/reports/status/rebuild\";s:8:\"numParts\";i:4;}}',	4),
('node.multiple_delete_confirm',	'/admin/content/node/delete',	'/admin/content/node/delete',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/content/node/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\node\\Form\\DeleteMultiple\";s:14:\"entity_type_id\";s:4:\"node\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:4:\"node\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/content/node/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/node/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/content/node/delete\";s:8:\"numParts\";i:4;}}',	4),
('node.revision_delete_confirm',	'/node/{node}/revisions/{node_revision}/delete',	'/node/%/revisions/%/delete',	21,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/node/{node}/revisions/{node_revision}/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\NodeRevisionDeleteForm\";s:6:\"_title\";s:23:\"Delete earlier revision\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.delete revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/delete$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/delete\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/node/%/revisions/%/delete\";s:8:\"numParts\";i:5;}}',	5),
('node.revision_revert_confirm',	'/node/{node}/revisions/{node_revision}/revert',	'/node/%/revisions/%/revert',	21,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/node/{node}/revisions/{node_revision}/revert\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\node\\Form\\NodeRevisionRevertForm\";s:6:\"_title\";s:26:\"Revert to earlier revision\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.revert revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/revert$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:2:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:21;s:14:\"patternOutline\";s:26:\"/node/%/revisions/%/revert\";s:8:\"numParts\";i:5;}}',	5),
('node.revision_revert_translation_confirm',	'/node/{node}/revisions/{node_revision}/revert/{langcode}',	'/node/%/revisions/%/revert/%',	42,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:56:\"/node/{node}/revisions/{node_revision}/revert/{langcode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\node\\Form\\NodeRevisionRevertTranslationForm\";s:6:\"_title\";s:43:\"Revert to earlier revision of a translation\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:29:\"node_revision.revert revision\";s:4:\"node\";s:3:\"\\d+\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:21:\"_node_operation_route\";b:1;s:10:\"parameters\";a:2:{s:4:\"node\";a:2:{s:4:\"type\";s:11:\"entity:node\";s:9:\"converter\";s:21:\"paramconverter.entity\";}s:13:\"node_revision\";a:2:{s:4:\"type\";s:20:\"entity_revision:node\";s:9:\"converter\";s:30:\"paramconverter.entity_revision\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";i:2;s:8:\"langcode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:90:\"{^/node/(?P<node>\\d+)/revisions/(?P<node_revision>[^/]++)/revert/(?P<langcode>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:8:\"langcode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/revert\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:13:\"node_revision\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/revisions\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"node\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"node\";i:1;s:13:\"node_revision\";i:2;s:8:\"langcode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:42;s:14:\"patternOutline\";s:28:\"/node/%/revisions/%/revert/%\";s:8:\"numParts\";i:6;}}',	6),
('node.type_add',	'/admin/structure/types/add',	'/admin/structure/types/add',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/structure/types/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"node_type.add\";s:6:\"_title\";s:16:\"Add content type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:24:\"administer content types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/structure/types/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/types/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/structure/types/add\";s:8:\"numParts\";i:4;}}',	4),
('paragraphs.settings',	'/admin/config/content/paragraphs',	'/admin/config/content/paragraphs',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/config/content/paragraphs\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:46:\"\\Drupal\\paragraphs\\Form\\ParagraphsSettingsForm\";s:6:\"_title\";s:19:\"Paragraphs settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:30:\"administer paragraphs settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/content/paragraphs$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/config/content/paragraphs\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/config/content/paragraphs\";s:8:\"numParts\";i:4;}}',	4),
('paragraphs.type_add',	'/admin/structure/paragraphs_type/add',	'/admin/structure/paragraphs_type/add',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/admin/structure/paragraphs_type/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:19:\"paragraphs_type.add\";s:6:\"_title\";s:19:\"Add Paragraphs type\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"administer paragraphs types\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/structure/paragraphs_type/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:36:\"/admin/structure/paragraphs_type/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:36:\"/admin/structure/paragraphs_type/add\";s:8:\"numParts\";i:4;}}',	4),
('pathauto.admin.delete',	'/admin/config/search/path/delete_bulk',	'/admin/config/search/path/delete_bulk',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/search/path/delete_bulk\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:41:\"\\Drupal\\pathauto\\Form\\PathautoAdminDelete\";s:6:\"_title\";s:14:\"Delete aliases\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer url aliases\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/search/path/delete_bulk$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/search/path/delete_bulk\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:37:\"/admin/config/search/path/delete_bulk\";s:8:\"numParts\";i:5;}}',	5),
('pathauto.bulk.update.form',	'/admin/config/search/path/update_bulk',	'/admin/config/search/path/update_bulk',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/search/path/update_bulk\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:44:\"\\Drupal\\pathauto\\Form\\PathautoBulkUpdateForm\";s:6:\"_title\";s:13:\"Bulk generate\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer url aliases\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/search/path/update_bulk$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/search/path/update_bulk\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:37:\"/admin/config/search/path/update_bulk\";s:8:\"numParts\";i:5;}}',	5),
('pathauto.settings.form',	'/admin/config/search/path/settings',	'/admin/config/search/path/settings',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/search/path/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\pathauto\\Form\\PathautoSettingsForm\";s:6:\"_title\";s:8:\"Settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"administer pathauto\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/search/path/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/path/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/config/search/path/settings\";s:8:\"numParts\";i:5;}}',	5),
('redirect.add',	'/admin/config/search/redirect/add',	'/admin/config/search/redirect/add',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/search/redirect/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"redirect.default\";s:6:\"_title\";s:16:\"Add URL redirect\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:8:\"redirect\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/search/redirect/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/search/redirect/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:33:\"/admin/config/search/redirect/add\";s:8:\"numParts\";i:5;}}',	5),
('redirect.list',	'/admin/config/search/redirect',	'/admin/config/search/redirect',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/search/redirect\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"redirect\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"administer redirects\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/search/redirect$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/search/redirect\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/search/redirect\";s:8:\"numParts\";i:4;}}',	4),
('redirect.settings',	'/admin/config/search/redirect/settings',	'/admin/config/search/redirect/settings',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/config/search/redirect/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\redirect\\Form\\RedirectSettingsForm\";s:6:\"_title\";s:8:\"Settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:28:\"administer redirect settings\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/search/redirect/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/config/search/redirect/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:38:\"/admin/config/search/redirect/settings\";s:8:\"numParts\";i:5;}}',	5),
('search.add_type',	'/admin/config/search/pages/add/{search_plugin_id}',	'/admin/config/search/pages/add/%',	62,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:49:\"/admin/config/search/pages/add/{search_plugin_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"search_page.add\";s:6:\"_title\";s:19:\"Add new search page\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:11:\"search_page\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:16:\"search_plugin_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:66:\"{^/admin/config/search/pages/add/(?P<search_plugin_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:16:\"search_plugin_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/search/pages/add\";}}s:9:\"path_vars\";a:1:{i:0;s:16:\"search_plugin_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:62;s:14:\"patternOutline\";s:32:\"/admin/config/search/pages/add/%\";s:8:\"numParts\";i:6;}}',	6),
('search.help_help_search',	'/search/help/help',	'/search/help/help',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/search/help/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:53:\"Drupal\\search\\Controller\\SearchController::searchHelp\";s:6:\"_title\";s:15:\"About searching\";s:6:\"entity\";s:11:\"help_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/search/help/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/search/help/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/search/help/help\";s:8:\"numParts\";i:3;}}',	3),
('search.help_node_search',	'/search/node/help',	'/search/node/help',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/search/node/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:53:\"Drupal\\search\\Controller\\SearchController::searchHelp\";s:6:\"_title\";s:15:\"About searching\";s:6:\"entity\";s:11:\"node_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/search/node/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/search/node/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/search/node/help\";s:8:\"numParts\";i:3;}}',	3),
('search.help_user_search',	'/search/user/help',	'/search/user/help',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/search/user/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:53:\"Drupal\\search\\Controller\\SearchController::searchHelp\";s:6:\"_title\";s:15:\"About searching\";s:6:\"entity\";s:11:\"user_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/search/user/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/search/user/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:17:\"/search/user/help\";s:8:\"numParts\";i:3;}}',	3),
('search.reindex_confirm',	'/admin/config/search/pages/reindex',	'/admin/config/search/pages/reindex',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/search/pages/reindex\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\search\\Form\\ReindexConfirm\";s:6:\"_title\";s:11:\"Clear index\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer search\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/search/pages/reindex$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/search/pages/reindex\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/config/search/pages/reindex\";s:8:\"numParts\";i:5;}}',	5),
('search.view',	'/search',	'/search',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:7:\"/search\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:61:\"Drupal\\search\\Controller\\SearchController::redirectSearchPage\";s:6:\"_title\";s:6:\"Search\";s:6:\"entity\";s:11:\"node_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:14:\"{^/search$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:7:\"/search\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:7:\"/search\";s:8:\"numParts\";i:1;}}',	1),
('search.view_help_search',	'/search/help',	'/search/help',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/search/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:47:\"Drupal\\search\\Controller\\SearchController::view\";s:6:\"_title\";s:6:\"Search\";s:6:\"entity\";s:11:\"help_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/search/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/search/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/search/help\";s:8:\"numParts\";i:2;}}',	2),
('search.view_node_search',	'/search/node',	'/search/node',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/search/node\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:47:\"Drupal\\search\\Controller\\SearchController::view\";s:6:\"_title\";s:6:\"Search\";s:6:\"entity\";s:11:\"node_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/search/node$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/search/node\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/search/node\";s:8:\"numParts\";i:2;}}',	2),
('search.view_user_search',	'/search/user',	'/search/user',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/search/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:47:\"Drupal\\search\\Controller\\SearchController::view\";s:6:\"_title\";s:6:\"Search\";s:6:\"entity\";s:11:\"user_search\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"entity.view\";s:11:\"_permission\";s:14:\"search content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:6:\"entity\";a:2:{s:4:\"type\";s:18:\"entity:search_page\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:23:\"access_check.permission\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/search/user$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/search/user\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/search/user\";s:8:\"numParts\";i:2;}}',	2),
('shortcut.link_add',	'/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link',	'/admin/config/user-interface/shortcut/manage/%/add-link',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:68:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\shortcut\\Controller\\ShortcutController::addForm\";s:6:\"_title\";s:8:\"Add link\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:23:\"shortcut:{shortcut_set}\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:87:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/add\\-link$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:9:\"/add-link\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:55:\"/admin/config/user-interface/shortcut/manage/%/add-link\";s:8:\"numParts\";i:7;}}',	7),
('shortcut.link_add_inline',	'/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link-inline',	'/admin/config/user-interface/shortcut/manage/%/add-link-inline',	125,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:75:\"/admin/config/user-interface/shortcut/manage/{shortcut_set}/add-link-inline\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:72:\"\\Drupal\\shortcut\\Controller\\ShortcutSetController::addShortcutLinkInline\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:19:\"shortcut_set.update\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:12:\"shortcut_set\";a:2:{s:4:\"type\";s:19:\"entity:shortcut_set\";s:9:\"converter\";s:63:\"drupal.proxy_original_service.paramconverter.configentity_admin\";}}s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:19:\"access_check.entity\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/config/user\\-interface/shortcut/manage/(?P<shortcut_set>[^/]++)/add\\-link\\-inline$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/add-link-inline\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:12:\"shortcut_set\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/user-interface/shortcut/manage\";}}s:9:\"path_vars\";a:1:{i:0;s:12:\"shortcut_set\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:125;s:14:\"patternOutline\";s:62:\"/admin/config/user-interface/shortcut/manage/%/add-link-inline\";s:8:\"numParts\";i:7;}}',	7),
('shortcut.set_add',	'/admin/config/user-interface/shortcut/add-set',	'/admin/config/user-interface/shortcut/add-set',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:45:\"/admin/config/user-interface/shortcut/add-set\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:16:\"shortcut_set.add\";s:6:\"_title\";s:16:\"Add shortcut set\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:12:\"shortcut_set\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:54:\"{^/admin/config/user\\-interface/shortcut/add\\-set$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:45:\"/admin/config/user-interface/shortcut/add-set\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:45:\"/admin/config/user-interface/shortcut/add-set\";s:8:\"numParts\";i:5;}}',	5),
('shortcut.set_switch',	'/user/{user}/shortcuts',	'/user/%/shortcuts',	5,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/user/{user}/shortcuts\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\shortcut\\Form\\SwitchShortcutSet\";s:6:\"_title\";s:9:\"Shortcuts\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:52:\"\\Drupal\\shortcut\\Form\\SwitchShortcutSet::checkAccess\";}s:7:\"options\";a:6:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"user\";s:3:\"\\d+\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"user\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/user/(?P<user>[^/]++)/shortcuts$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/shortcuts\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"user\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"user\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:5;s:14:\"patternOutline\";s:17:\"/user/%/shortcuts\";s:8:\"numParts\";i:3;}}',	3),
('system.401',	'/system/401',	'/system/401',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/401\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on401\";s:6:\"_title\";s:12:\"Unauthorized\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/401$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/401\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/401\";s:8:\"numParts\";i:2;}}',	2),
('system.403',	'/system/403',	'/system/403',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/403\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on403\";s:6:\"_title\";s:13:\"Access denied\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/403$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/403\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/403\";s:8:\"numParts\";i:2;}}',	2),
('system.404',	'/system/404',	'/system/404',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/404\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on404\";s:6:\"_title\";s:14:\"Page not found\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/404$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/404\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/404\";s:8:\"numParts\";i:2;}}',	2),
('system.4xx',	'/system/4xx',	'/system/4xx',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/system/4xx\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\system\\Controller\\Http4xxController:on4xx\";s:6:\"_title\";s:12:\"Client error\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/system/4xx$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/system/4xx\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/system/4xx\";s:8:\"numParts\";i:2;}}',	2),
('system.admin',	'/admin',	'/admin',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/admin\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:14:\"Administration\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/admin$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/admin\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/admin\";s:8:\"numParts\";i:1;}}',	1),
('system.admin_compact_page',	'/admin/compact/{mode}',	'/admin/compact',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/compact/{mode}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\system\\Controller\\SystemController::compactPage\";s:4:\"mode\";s:3:\"off\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"access administration pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"mode\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:43:\"{^/admin/compact(?:/(?P<mode>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"mode\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/compact\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"mode\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/compact\";s:8:\"numParts\";i:3;}}',	3),
('system.admin_config',	'/admin/config',	'/admin/config',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/config\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\SystemController::overview\";s:7:\"link_id\";s:19:\"system.admin_config\";s:6:\"_title\";s:13:\"Configuration\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:27:\"_access_admin_overview_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:32:\"access_check.admin_overview_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/config$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/config\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/config\";s:8:\"numParts\";i:2;}}',	2),
('system.admin_config_content',	'/admin/config/content',	'/admin/config/content',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/config/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:17:\"Content authoring\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/config/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/config/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/config/content\";s:8:\"numParts\";i:3;}}',	3),
('system.admin_config_development',	'/admin/config/development',	'/admin/config/development',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/development\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:11:\"Development\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/development$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/development\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/config/development\";s:8:\"numParts\";i:3;}}',	3),
('system.admin_config_media',	'/admin/config/media',	'/admin/config/media',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/config/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:5:\"Media\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/config/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/config/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/config/media\";s:8:\"numParts\";i:3;}}',	3),
('system.admin_config_regional',	'/admin/config/regional',	'/admin/config/regional',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/regional\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:19:\"Region and language\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/regional$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/regional\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/regional\";s:8:\"numParts\";i:3;}}',	3),
('system.admin_config_search',	'/admin/config/search',	'/admin/config/search',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/search\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:19:\"Search and metadata\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/search$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/search\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/search\";s:8:\"numParts\";i:3;}}',	3),
('system.admin_config_services',	'/admin/config/services',	'/admin/config/services',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/services\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:12:\"Web services\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/services$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/services\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/services\";s:8:\"numParts\";i:3;}}',	3),
('system.admin_config_system',	'/admin/config/system',	'/admin/config/system',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/system\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:6:\"System\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/system$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/system\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/system\";s:8:\"numParts\";i:3;}}',	3),
('system.admin_config_ui',	'/admin/config/user-interface',	'/admin/config/user-interface',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/config/user-interface\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:14:\"User interface\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/user\\-interface$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/config/user-interface\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/config/user-interface\";s:8:\"numParts\";i:3;}}',	3),
('system.admin_config_workflow',	'/admin/config/workflow',	'/admin/config/workflow',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/config/workflow\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:8:\"Workflow\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/config/workflow$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/config/workflow\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/config/workflow\";s:8:\"numParts\";i:3;}}',	3),
('system.admin_content',	'/admin/content',	'/admin/content',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:23:\"access content overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:0:{}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/content\";s:8:\"numParts\";i:2;}}',	2),
('system.admin_index',	'/admin/index',	'/admin/index',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/admin/index\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\system\\Controller\\AdminController::index\";s:6:\"_title\";s:14:\"Administration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:27:\"access administration pages\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/admin/index$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/admin/index\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/admin/index\";s:8:\"numParts\";i:2;}}',	2),
('system.admin_reports',	'/admin/reports',	'/admin/reports',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/reports\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:7:\"Reports\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/reports$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/reports\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/reports\";s:8:\"numParts\";i:2;}}',	2),
('system.admin_structure',	'/admin/structure',	'/admin/structure',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:16:\"/admin/structure\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:9:\"Structure\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:23:\"{^/admin/structure$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/admin/structure\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:16:\"/admin/structure\";s:8:\"numParts\";i:2;}}',	2),
('system.batch_page.html',	'/batch',	'/batch',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/batch\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\BatchController::batchPage\";s:15:\"_title_callback\";s:57:\"\\Drupal\\system\\Controller\\BatchController::batchPageTitle\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:12:\"_no_big_pipe\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/batch$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/batch\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/batch\";s:8:\"numParts\";i:1;}}',	1),
('system.batch_page.json',	'/batch',	'/batch',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:6:\"/batch\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\BatchController::batchPage\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:13:\"{^/batch$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/batch\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:6:\"/batch\";s:8:\"numParts\";i:1;}}',	1),
('system.cron',	'/cron/{key}',	'/cron/%',	2,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/cron/{key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:34:\"\\Drupal\\system\\CronController::run\";}s:12:\"requirements\";a:1:{s:19:\"_access_system_cron\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:17:\"access_check.cron\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/cron/(?P<key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/cron\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:2;s:14:\"patternOutline\";s:7:\"/cron/%\";s:8:\"numParts\";i:2;}}',	2),
('system.cron_settings',	'/admin/config/system/cron',	'/admin/config/system/cron',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/config/system/cron\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:28:\"\\Drupal\\system\\Form\\CronForm\";s:6:\"_title\";s:4:\"Cron\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/config/system/cron$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/config/system/cron\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/config/system/cron\";s:8:\"numParts\";i:4;}}',	4),
('system.csrftoken',	'/session/token',	'/session/token',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/session/token\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:56:\"\\Drupal\\system\\Controller\\CsrfTokenController::csrfToken\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/session/token$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/session/token\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/session/token\";s:8:\"numParts\";i:2;}}',	2),
('system.css_asset',	'/sites/default/files/css/{file_name}',	'/sites/default/files/css/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/sites/default/files/css/{file_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"Drupal\\system\\Controller\\CssAssetController::deliver\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"file_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:53:\"{^/sites/default/files/css/(?P<file_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"file_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/sites/default/files/css\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"file_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:26:\"/sites/default/files/css/%\";s:8:\"numParts\";i:5;}}',	5),
('system.date_format_add',	'/admin/config/regional/date-time/formats/add',	'/admin/config/regional/date-time/formats/add',	63,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:44:\"/admin/config/regional/date-time/formats/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:15:\"date_format.add\";s:6:\"_title\";s:15:\"Add date format\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/admin/config/regional/date\\-time/formats/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:44:\"/admin/config/regional/date-time/formats/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:63;s:14:\"patternOutline\";s:44:\"/admin/config/regional/date-time/formats/add\";s:8:\"numParts\";i:6;}}',	6),
('system.db_update',	'/update.php/{op}',	'/update.php',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:16:\"/update.php/{op}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:2:\"op\";s:4:\"info\";}s:12:\"requirements\";a:1:{s:21:\"_access_system_update\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"default_url_options\";a:1:{s:15:\"path_processing\";b:0;}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:22:\"access_check.db_update\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:2:\"op\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/update\\.php(?:/(?P<op>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"op\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/update.php\";}}s:9:\"path_vars\";a:1:{i:0;s:2:\"op\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:11:\"/update.php\";s:8:\"numParts\";i:2;}}',	2),
('system.development_settings',	'/admin/config/development/settings',	'/admin/config/development/settings',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/config/development/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\system\\Form\\DevelopmentSettingsForm\";s:6:\"_title\";s:20:\"Development settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/development/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/config/development/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/config/development/settings\";s:8:\"numParts\";i:4;}}',	4),
('system.entity_autocomplete',	'/entity_reference_autocomplete/{target_type}/{selection_handler}/{selection_settings_key}',	'/entity_reference_autocomplete/%/%/%',	8,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:89:\"/entity_reference_autocomplete/{target_type}/{selection_handler}/{selection_settings_key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:74:\"\\Drupal\\system\\Controller\\EntityAutocompleteController::handleAutocomplete\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:11:\"target_type\";i:1;s:17:\"selection_handler\";i:2;s:22:\"selection_settings_key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:126:\"{^/entity_reference_autocomplete/(?P<target_type>[^/]++)/(?P<selection_handler>[^/]++)/(?P<selection_settings_key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:22:\"selection_settings_key\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:17:\"selection_handler\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"target_type\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/entity_reference_autocomplete\";}}s:9:\"path_vars\";a:3:{i:0;s:11:\"target_type\";i:1;s:17:\"selection_handler\";i:2;s:22:\"selection_settings_key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:8;s:14:\"patternOutline\";s:36:\"/entity_reference_autocomplete/%/%/%\";s:8:\"numParts\";i:4;}}',	4),
('system.files',	'/system/files/{scheme}',	'/system/files',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/system/files/{scheme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";s:6:\"scheme\";s:7:\"private\";s:25:\"_disable_route_normalizer\";b:1;}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:6:\"scheme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/system/files(?:/(?P<scheme>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:6:\"scheme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/system/files\";}}s:9:\"path_vars\";a:1:{i:0;s:6:\"scheme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/system/files\";s:8:\"numParts\";i:3;}}',	3),
('system.file_system_settings',	'/admin/config/media/file-system',	'/admin/config/media/file-system',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/config/media/file-system\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\system\\Form\\FileSystemForm\";s:6:\"_title\";s:11:\"File system\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/config/media/file\\-system$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/config/media/file-system\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/config/media/file-system\";s:8:\"numParts\";i:4;}}',	4),
('system.image_toolkit_settings',	'/admin/config/media/image-toolkit',	'/admin/config/media/image-toolkit',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/media/image-toolkit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:36:\"\\Drupal\\system\\Form\\ImageToolkitForm\";s:6:\"_title\";s:13:\"Image toolkit\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/config/media/image\\-toolkit$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/media/image-toolkit\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/media/image-toolkit\";s:8:\"numParts\";i:4;}}',	4),
('system.js_asset',	'/sites/default/files/js/{file_name}',	'/sites/default/files/js/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/sites/default/files/js/{file_name}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"Drupal\\system\\Controller\\JsAssetController::deliver\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}s:4:\"utf8\";b:1;}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:9:\"file_name\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:52:\"{^/sites/default/files/js/(?P<file_name>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"file_name\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/sites/default/files/js\";}}s:9:\"path_vars\";a:1:{i:0;s:9:\"file_name\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:25:\"/sites/default/files/js/%\";s:8:\"numParts\";i:5;}}',	5),
('system.linkset_settings',	'/admin/config/services/linkset',	'/admin/config/services/linkset',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/config/services/linkset\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:21:\"Menu Linkset Settings\";s:5:\"_form\";s:42:\"Drupal\\system\\Form\\MenuLinksetSettingsForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/admin/config/services/linkset$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/config/services/linkset\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/config/services/linkset\";s:8:\"numParts\";i:4;}}',	4),
('system.logging_settings',	'/admin/config/development/logging',	'/admin/config/development/logging',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:33:\"/admin/config/development/logging\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\system\\Form\\LoggingForm\";s:6:\"_title\";s:18:\"Logging and errors\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:40:\"{^/admin/config/development/logging$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/config/development/logging\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:33:\"/admin/config/development/logging\";s:8:\"numParts\";i:4;}}',	4),
('system.machine_name_transliterate',	'/machine_name/transliterate',	'/machine_name/transliterate',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/machine_name/transliterate\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\system\\MachineNameController::transliterate\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/machine_name/transliterate$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/machine_name/transliterate\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:27:\"/machine_name/transliterate\";s:8:\"numParts\";i:2;}}',	2),
('system.modules_list',	'/admin/modules',	'/admin/modules',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/modules\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:3:{s:6:\"_title\";s:6:\"Extend\";s:14:\"_title_context\";s:15:\"With components\";s:5:\"_form\";s:35:\"\\Drupal\\system\\Form\\ModulesListForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_no_big_pipe\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/modules$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/modules\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/modules\";s:8:\"numParts\";i:2;}}',	2);
INSERT INTO `router` (`name`, `path`, `pattern_outline`, `fit`, `route`, `number_parts`) VALUES
('system.modules_list_confirm',	'/admin/modules/list/confirm',	'/admin/modules/list/confirm',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/modules/list/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\system\\Form\\ModulesListConfirmForm\";s:6:\"_title\";s:39:\"Some required modules must be installed\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/modules/list/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/modules/list/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:27:\"/admin/modules/list/confirm\";s:8:\"numParts\";i:4;}}',	4),
('system.modules_list_non_stable_confirm',	'/admin/modules/list/confirm-non-stable',	'/admin/modules/list/confirm-non-stable',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/modules/list/confirm-non-stable\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\system\\Form\\ModulesListNonStableConfirmForm\";s:6:\"_title\";s:18:\"Non-stable modules\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/modules/list/confirm\\-non\\-stable$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/modules/list/confirm-non-stable\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:38:\"/admin/modules/list/confirm-non-stable\";s:8:\"numParts\";i:4;}}',	4),
('system.modules_uninstall',	'/admin/modules/uninstall',	'/admin/modules/uninstall',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/modules/uninstall\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\system\\Form\\ModulesUninstallForm\";s:6:\"_title\";s:9:\"Uninstall\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/modules/uninstall$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/modules/uninstall\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/modules/uninstall\";s:8:\"numParts\";i:3;}}',	3),
('system.modules_uninstall_confirm',	'/admin/modules/uninstall/confirm',	'/admin/modules/uninstall/confirm',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:32:\"/admin/modules/uninstall/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:47:\"\\Drupal\\system\\Form\\ModulesUninstallConfirmForm\";s:6:\"_title\";s:17:\"Confirm uninstall\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer modules\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/admin/modules/uninstall/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/modules/uninstall/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:32:\"/admin/modules/uninstall/confirm\";s:8:\"numParts\";i:4;}}',	4),
('system.performance_settings',	'/admin/config/development/performance',	'/admin/config/development/performance',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/development/performance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\PerformanceController::build\";s:6:\"_title\";s:11:\"Performance\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/development/performance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/development/performance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/development/performance\";s:8:\"numParts\";i:4;}}',	4),
('system.php',	'/admin/reports/status/php',	'/admin/reports/status/php',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/reports/status/php\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\system\\Controller\\SystemInfoController::php\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:12:\"_admin_route\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/reports/status/php$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/reports/status/php\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:25:\"/admin/reports/status/php\";s:8:\"numParts\";i:4;}}',	4),
('system.prepare_modules_entity_uninstall',	'/admin/modules/uninstall/entity/{entity_type_id}',	'/admin/modules/uninstall/entity/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:48:\"/admin/modules/uninstall/entity/{entity_type_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:53:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm\";s:15:\"_title_callback\";s:64:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm::formTitle\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:18:\"administer modules\";s:14:\"_custom_access\";s:66:\"\\Drupal\\system\\Form\\PrepareModulesEntityUninstallForm::checkAccess\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/modules/uninstall/entity/(?P<entity_type_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:14:\"entity_type_id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/modules/uninstall/entity\";}}s:9:\"path_vars\";a:1:{i:0;s:14:\"entity_type_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:33:\"/admin/modules/uninstall/entity/%\";s:8:\"numParts\";i:5;}}',	5),
('system.private_file_download',	'/system/files/{filepath}',	'/system/files/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/system/files/{filepath}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";}s:12:\"requirements\";a:2:{s:8:\"filepath\";s:2:\".+\";s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:8:\"filepath\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/system/files/(?P<filepath>.+)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:2:\".+\";i:3;s:8:\"filepath\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/system/files\";}}s:9:\"path_vars\";a:1:{i:0;s:8:\"filepath\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:15:\"/system/files/%\";s:8:\"numParts\";i:3;}}',	3),
('system.regional_settings',	'/admin/config/regional/settings',	'/admin/config/regional/settings',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/config/regional/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\system\\Form\\RegionalForm\";s:6:\"_title\";s:17:\"Regional settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/config/regional/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/config/regional/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/config/regional/settings\";s:8:\"numParts\";i:4;}}',	4),
('system.rss_feeds_settings',	'/admin/config/services/rss-publishing',	'/admin/config/services/rss-publishing',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/services/rss-publishing\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:32:\"\\Drupal\\system\\Form\\RssFeedsForm\";s:6:\"_title\";s:14:\"RSS publishing\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/services/rss\\-publishing$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/services/rss-publishing\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/services/rss-publishing\";s:8:\"numParts\";i:4;}}',	4),
('system.run_cron',	'/admin/reports/status/run-cron',	'/admin/reports/status/run-cron',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/reports/status/run-cron\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:42:\"\\Drupal\\system\\CronController::runManually\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/status/run\\-cron$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/reports/status/run-cron\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/reports/status/run-cron\";s:8:\"numParts\";i:4;}}',	4),
('system.site_information_settings',	'/admin/config/system/site-information',	'/admin/config/system/site-information',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/system/site-information\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\system\\Form\\SiteInformationForm\";s:6:\"_title\";s:19:\"Basic site settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/config/system/site\\-information$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/system/site-information\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/system/site-information\";s:8:\"numParts\";i:4;}}',	4),
('system.site_maintenance_mode',	'/admin/config/development/maintenance',	'/admin/config/development/maintenance',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/admin/config/development/maintenance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\system\\Form\\SiteMaintenanceModeForm\";s:6:\"_title\";s:16:\"Maintenance mode\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:57:\"administer site configuration+administer software updates\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/admin/config/development/maintenance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:37:\"/admin/config/development/maintenance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:37:\"/admin/config/development/maintenance\";s:8:\"numParts\";i:4;}}',	4),
('system.status',	'/admin/reports/status',	'/admin/reports/status',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/reports/status\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\SystemInfoController::status\";s:6:\"_title\";s:13:\"Status report\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/reports/status$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/reports/status\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/reports/status\";s:8:\"numParts\";i:3;}}',	3),
('system.temporary',	'/system/temporary',	'/system/temporary',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/system/temporary\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:47:\"\\Drupal\\system\\FileDownloadController::download\";s:6:\"scheme\";s:9:\"temporary\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/system/temporary$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/system/temporary\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:17:\"/system/temporary\";s:8:\"numParts\";i:2;}}',	2),
('system.themes_page',	'/admin/appearance',	'/admin/appearance',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/admin/appearance\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:10:\"Appearance\";s:11:\"_controller\";s:54:\"\\Drupal\\system\\Controller\\SystemController::themesPage\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:24:\"{^/admin/appearance$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/admin/appearance\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:17:\"/admin/appearance\";s:8:\"numParts\";i:2;}}',	2),
('system.theme_install',	'/admin/appearance/install',	'/admin/appearance/install',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/appearance/install\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:50:\"\\Drupal\\system\\Controller\\ThemeController::install\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/appearance/install$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/appearance/install\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/appearance/install\";s:8:\"numParts\";i:3;}}',	3),
('system.theme_settings',	'/admin/appearance/settings',	'/admin/appearance/settings',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/appearance/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\system\\Form\\ThemeSettingsForm\";s:6:\"_title\";s:19:\"Appearance settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/appearance/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/appearance/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:26:\"/admin/appearance/settings\";s:8:\"numParts\";i:3;}}',	3),
('system.theme_settings_theme',	'/admin/appearance/settings/{theme}',	'/admin/appearance/settings/%',	14,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/appearance/settings/{theme}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\system\\Form\\ThemeSettingsForm\";s:15:\"_title_callback\";s:21:\"theme_handler:getName\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:17:\"administer themes\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"theme\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/appearance/settings/(?P<theme>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"theme\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/appearance/settings\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"theme\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:14;s:14:\"patternOutline\";s:28:\"/admin/appearance/settings/%\";s:8:\"numParts\";i:4;}}',	4),
('system.theme_set_default',	'/admin/appearance/default',	'/admin/appearance/default',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/appearance/default\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:20:\"Set as default theme\";s:11:\"_controller\";s:58:\"\\Drupal\\system\\Controller\\ThemeController::setDefaultTheme\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/appearance/default$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/appearance/default\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/appearance/default\";s:8:\"numParts\";i:3;}}',	3),
('system.theme_uninstall',	'/admin/appearance/uninstall',	'/admin/appearance/uninstall',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/appearance/uninstall\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\system\\Controller\\ThemeController::uninstall\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:17:\"administer themes\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/admin/appearance/uninstall$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/appearance/uninstall\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/appearance/uninstall\";s:8:\"numParts\";i:3;}}',	3),
('system.timezone',	'/system/timezone/{abbreviation}/{offset}/{is_daylight_saving_time}',	'/system/timezone',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/system/timezone/{abbreviation}/{offset}/{is_daylight_saving_time}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:11:\"_controller\";s:57:\"\\Drupal\\system\\Controller\\TimezoneController::getTimezone\";s:12:\"abbreviation\";s:0:\"\";s:6:\"offset\";i:-1;s:23:\"is_daylight_saving_time\";N;}s:12:\"requirements\";a:4:{s:7:\"_access\";s:4:\"TRUE\";s:12:\"abbreviation\";s:14:\"0|([A-Z]{3,5})\";s:6:\"offset\";s:6:\"\\-?\\d+\";s:23:\"is_daylight_saving_time\";s:7:\"\\-1|0|1\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:12:\"abbreviation\";i:1;s:6:\"offset\";i:2;s:23:\"is_daylight_saving_time\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:129:\"{^/system/timezone(?:/(?P<abbreviation>0|(?:[A-Z]{3,5}))(?:/(?P<offset>\\-?\\d+)(?:/(?P<is_daylight_saving_time>\\-1|0|1))?)?)?$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:7:\"\\-1|0|1\";i:3;s:23:\"is_daylight_saving_time\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"\\-?\\d+\";i:3;s:6:\"offset\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:16:\"0|(?:[A-Z]{3,5})\";i:3;s:12:\"abbreviation\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:16:\"/system/timezone\";}}s:9:\"path_vars\";a:3:{i:0;s:12:\"abbreviation\";i:1;s:6:\"offset\";i:2;s:23:\"is_daylight_saving_time\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:16:\"/system/timezone\";s:8:\"numParts\";i:5;}}',	5),
('token.tree',	'/token/tree',	'/token/tree',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/token/tree\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:56:\"\\Drupal\\token\\Controller\\TokenTreeController::outputTree\";}s:12:\"requirements\";a:1:{s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/token/tree$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/token/tree\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/token/tree\";s:8:\"numParts\";i:2;}}',	2),
('toolbar.subtrees',	'/toolbar/subtrees/{hash}',	'/toolbar/subtrees/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/toolbar/subtrees/{hash}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:58:\"\\Drupal\\toolbar\\Controller\\ToolbarController::subtreesAjax\";}s:12:\"requirements\";a:1:{s:14:\"_custom_access\";s:64:\"\\Drupal\\toolbar\\Controller\\ToolbarController::checkSubTreeAccess\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/toolbar/subtrees/(?P<hash>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/toolbar/subtrees\";}}s:9:\"path_vars\";a:1:{i:0;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:19:\"/toolbar/subtrees/%\";s:8:\"numParts\";i:3;}}',	3),
('update.confirmation_page',	'/admin/update/ready',	'/admin/update/ready',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/update/ready\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\update\\Form\\UpdateReady\";s:6:\"_title\";s:15:\"Ready to update\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"administer software updates\";s:22:\"_access_update_manager\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.update.manager_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/update/ready$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/update/ready\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/update/ready\";s:8:\"numParts\";i:3;}}',	3),
('update.manual_status',	'/admin/reports/updates/check',	'/admin/reports/updates/check',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/updates/check\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:19:\"Manual update check\";s:11:\"_controller\";s:64:\"\\Drupal\\update\\Controller\\UpdateController::updateStatusManually\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:29:\"administer site configuration\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/reports/updates/check$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/updates/check\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:28:\"/admin/reports/updates/check\";s:8:\"numParts\";i:4;}}',	4),
('update.module_install',	'/admin/modules/install',	'/admin/modules/install',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/modules/install\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\update\\Form\\UpdateManagerInstall\";s:6:\"_title\";s:14:\"Add new module\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"administer software updates\";s:22:\"_access_update_manager\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.update.manager_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/modules/install$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/modules/install\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/modules/install\";s:8:\"numParts\";i:3;}}',	3),
('update.module_update',	'/admin/modules/update',	'/admin/modules/update',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:21:\"/admin/modules/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"administer software updates\";s:22:\"_access_update_manager\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.update.manager_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:28:\"{^/admin/modules/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:21:\"/admin/modules/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:21:\"/admin/modules/update\";s:8:\"numParts\";i:3;}}',	3),
('update.report_install',	'/admin/reports/updates/install',	'/admin/reports/updates/install',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/reports/updates/install\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\update\\Form\\UpdateManagerInstall\";s:6:\"_title\";s:23:\"Add new module or theme\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"administer software updates\";s:22:\"_access_update_manager\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.update.manager_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:37:\"{^/admin/reports/updates/install$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:30:\"/admin/reports/updates/install\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:30:\"/admin/reports/updates/install\";s:8:\"numParts\";i:4;}}',	4),
('update.report_update',	'/admin/reports/updates/update',	'/admin/reports/updates/update',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/reports/updates/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"administer software updates\";s:22:\"_access_update_manager\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.update.manager_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/updates/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/reports/updates/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/reports/updates/update\";s:8:\"numParts\";i:4;}}',	4),
('update.settings',	'/admin/reports/updates/settings',	'/admin/reports/updates/settings',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/reports/updates/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:33:\"\\Drupal\\update\\UpdateSettingsForm\";s:6:\"_title\";s:23:\"Update Manager settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/reports/updates/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/reports/updates/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/reports/updates/settings\";s:8:\"numParts\";i:4;}}',	4),
('update.status',	'/admin/reports/updates',	'/admin/reports/updates',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/admin/reports/updates\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\update\\Controller\\UpdateController::updateStatus\";s:6:\"_title\";s:17:\"Available updates\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:29:\"administer site configuration\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:29:\"{^/admin/reports/updates$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/reports/updates\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:22:\"/admin/reports/updates\";s:8:\"numParts\";i:3;}}',	3),
('update.theme_install',	'/admin/theme/install',	'/admin/theme/install',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/theme/install\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:40:\"\\Drupal\\update\\Form\\UpdateManagerInstall\";s:6:\"_title\";s:13:\"Add new theme\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"administer software updates\";s:22:\"_access_update_manager\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.update.manager_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/theme/install$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/theme/install\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/theme/install\";s:8:\"numParts\";i:3;}}',	3),
('update.theme_update',	'/admin/appearance/update',	'/admin/appearance/update',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:24:\"/admin/appearance/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\update\\Form\\UpdateManagerUpdate\";s:6:\"_title\";s:6:\"Update\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"administer software updates\";s:22:\"_access_update_manager\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.update.manager_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:31:\"{^/admin/appearance/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:24:\"/admin/appearance/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:24:\"/admin/appearance/update\";s:8:\"numParts\";i:3;}}',	3),
('update.theme_update.bc',	'/admin/theme/update',	'/admin/theme/update',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:19:\"/admin/theme/update\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:6:\"_title\";s:6:\"Update\";s:11:\"_controller\";s:58:\"\\Drupal\\update\\Controller\\UpdateController::updateRedirect\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"administer software updates\";s:22:\"_access_update_manager\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.update.manager_access\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:26:\"{^/admin/theme/update$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:19:\"/admin/theme/update\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:19:\"/admin/theme/update\";s:8:\"numParts\";i:3;}}',	3),
('user.admin_create',	'/admin/people/create',	'/admin/people/create',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/people/create\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"user.register\";s:6:\"_title\";s:8:\"Add user\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"user\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/people/create$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/people/create\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/people/create\";s:8:\"numParts\";i:3;}}',	3),
('user.admin_index',	'/admin/config/people',	'/admin/config/people',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/config/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:68:\"\\Drupal\\system\\Controller\\SystemController::systemAdminMenuBlockPage\";s:6:\"_title\";s:6:\"People\";}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:27:\"access administration pages\";s:29:\"_access_admin_menu_block_page\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:34:\"access_check.admin_menu_block_page\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/config/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/config/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/config/people\";s:8:\"numParts\";i:3;}}',	3),
('user.admin_permissions',	'/admin/people/permissions',	'/admin/people/permissions',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/people/permissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:37:\"\\Drupal\\user\\Form\\UserPermissionsForm\";s:6:\"_title\";s:11:\"Permissions\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:32:\"{^/admin/people/permissions$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/people/permissions\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/people/permissions\";s:8:\"numParts\";i:3;}}',	3),
('user.admin_permissions.module',	'/admin/people/permissions/module/{modules}',	'/admin/people/permissions/module/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/admin/people/permissions/module/{modules}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:51:\"\\Drupal\\user\\Form\\UserPermissionsModuleSpecificForm\";s:6:\"_title\";s:18:\"Module Permissions\";}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:22:\"administer permissions\";s:7:\"modules\";s:16:\"[a-z][a-z0-9_,]*\";s:14:\"_custom_access\";s:59:\"\\Drupal\\user\\Form\\UserPermissionsModuleSpecificForm::access\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:7:\"modules\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:69:\"{^/admin/people/permissions/module/(?P<modules>[a-z][a-z0-9_,]*)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:16:\"[a-z][a-z0-9_,]*\";i:3;s:7:\"modules\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:32:\"/admin/people/permissions/module\";}}s:9:\"path_vars\";a:1:{i:0;s:7:\"modules\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:34:\"/admin/people/permissions/module/%\";s:8:\"numParts\";i:5;}}',	5),
('user.cancel_confirm',	'/user/{user}/cancel/confirm/{timestamp}/{hashed_pass}',	'/user/%/cancel/confirm',	11,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:53:\"/user/{user}/cancel/confirm/{timestamp}/{hashed_pass}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:4:{s:6:\"_title\";s:28:\"Confirm account cancellation\";s:11:\"_controller\";s:53:\"\\Drupal\\user\\Controller\\UserController::confirmCancel\";s:9:\"timestamp\";i:0;s:11:\"hashed_pass\";s:0:\"\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"user.delete\";s:4:\"user\";s:3:\"\\d+\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:10:\"parameters\";a:1:{s:4:\"user\";a:2:{s:4:\"type\";s:11:\"entity:user\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:4:\"user\";i:1;s:9:\"timestamp\";i:2;s:11:\"hashed_pass\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:97:\"{^/user/(?P<user>\\d+)/cancel/confirm(?:/(?P<timestamp>[^/]++)(?:/(?P<hashed_pass>[^/]++))?)?$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:11:\"hashed_pass\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:15:\"/cancel/confirm\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:3:\"\\d+\";i:3;s:4:\"user\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:3:{i:0;s:4:\"user\";i:1;s:9:\"timestamp\";i:2;s:11:\"hashed_pass\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:11;s:14:\"patternOutline\";s:22:\"/user/%/cancel/confirm\";s:8:\"numParts\";i:6;}}',	6),
('user.edit',	'/user/edit',	'/user/edit',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:10:\"/user/edit\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:52:\"\\Drupal\\user\\Controller\\UserController::userEditPage\";s:6:\"_title\";s:12:\"Edit account\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:17:\"{^/user/edit$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/user/edit\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:10:\"/user/edit\";s:8:\"numParts\";i:2;}}',	2),
('user.login',	'/user/login',	'/user/login',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/user/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:31:\"\\Drupal\\user\\Form\\UserLoginForm\";s:6:\"_title\";s:6:\"Log in\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/user/login$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/login\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/user/login\";s:8:\"numParts\";i:2;}}',	2),
('user.login.http',	'/user/login',	'/user/login',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/user/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:59:\"\\Drupal\\user\\Controller\\UserAuthenticationController::login\";}s:12:\"requirements\";a:2:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/user/login$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/login\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/user/login\";s:8:\"numParts\";i:2;}}',	2),
('user.login_status.http',	'/user/login_status',	'/user/login_status',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:18:\"/user/login_status\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:65:\"\\Drupal\\user\\Controller\\UserAuthenticationController::loginStatus\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:3:\"GET\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:25:\"{^/user/login_status$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:18:\"/user/login_status\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:18:\"/user/login_status\";s:8:\"numParts\";i:2;}}',	2),
('user.logout',	'/user/logout',	'/user/logout',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/logout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:46:\"\\Drupal\\user\\Controller\\UserController::logout\";}s:12:\"requirements\";a:2:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:24:\"_csrf_confirm_form_route\";s:19:\"user.logout.confirm\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:30:\"access_check.user.login_status\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/user/logout$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/user/logout\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/user/logout\";s:8:\"numParts\";i:2;}}',	2),
('user.logout.confirm',	'/user/logout/confirm',	'/user/logout/confirm',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/user/logout/confirm\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:35:\"\\Drupal\\user\\Form\\UserLogoutConfirm\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/user/logout/confirm$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/user/logout/confirm\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/user/logout/confirm\";s:8:\"numParts\";i:3;}}',	3),
('user.logout.http',	'/user/logout',	'/user/logout',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:12:\"/user/logout\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:60:\"\\Drupal\\user\\Controller\\UserAuthenticationController::logout\";}s:12:\"requirements\";a:3:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:30:\"access_check.user.login_status\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:19:\"{^/user/logout$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/user/logout\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:12:\"/user/logout\";s:8:\"numParts\";i:2;}}',	2),
('user.multiple_cancel_confirm',	'/admin/people/cancel',	'/admin/people/cancel',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/people/cancel\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:43:\"\\Drupal\\user\\Form\\UserMultipleCancelConfirm\";s:6:\"_title\";s:11:\"Cancel user\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer users\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/people/cancel$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/people/cancel\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/people/cancel\";s:8:\"numParts\";i:3;}}',	3),
('user.page',	'/user',	'/user',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:5:\"/user\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:48:\"\\Drupal\\user\\Controller\\UserController::userPage\";s:6:\"_title\";s:10:\"My account\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:12:\"{^/user$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/user\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:5:\"/user\";s:8:\"numParts\";i:1;}}',	1),
('user.pass',	'/user/password',	'/user/password',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\user\\Form\\UserPasswordForm\";s:6:\"_title\";s:19:\"Reset your password\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/password\";s:8:\"numParts\";i:2;}}',	2),
('user.pass.http',	'/user/password',	'/user/password',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:67:\"\\Drupal\\user\\Controller\\UserAuthenticationController::resetPassword\";}s:12:\"requirements\";a:2:{s:7:\"_access\";s:4:\"TRUE\";s:7:\"_format\";s:4:\"json\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:1:{i:0;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/password\";s:8:\"numParts\";i:2;}}',	2),
('user.register',	'/user/register',	'/user/register',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/user/register\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:13:\"user.register\";s:6:\"_title\";s:18:\"Create new account\";}s:12:\"requirements\";a:1:{s:21:\"_access_user_register\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.user.register\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/user/register$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/user/register\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/user/register\";s:8:\"numParts\";i:2;}}',	2),
('user.reset',	'/user/reset/{uid}/{timestamp}/{hash}',	'/user/reset/%/%/%',	24,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:36:\"/user/reset/{uid}/{timestamp}/{hash}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:49:\"\\Drupal\\user\\Controller\\UserController::resetPass\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:73:\"{^/user/reset/(?P<uid>[^/]++)/(?P<timestamp>[^/]++)/(?P<hash>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:24;s:14:\"patternOutline\";s:17:\"/user/reset/%/%/%\";s:8:\"numParts\";i:5;}}',	5),
('user.reset.form',	'/user/reset/{uid}',	'/user/reset/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:17:\"/user/reset/{uid}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:56:\"\\Drupal\\user\\Controller\\UserController::getResetPassForm\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:3:\"uid\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:34:\"{^/user/reset/(?P<uid>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:1:{i:0;s:3:\"uid\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:13:\"/user/reset/%\";s:8:\"numParts\";i:3;}}',	3),
('user.reset.login',	'/user/reset/{uid}/{timestamp}/{hash}/login',	'/user/reset/%/%/%/login',	49,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:42:\"/user/reset/{uid}/{timestamp}/{hash}/login\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\user\\Controller\\UserController::resetPassLogin\";s:6:\"_title\";s:14:\"Reset password\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:5:\"FALSE\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:19:\"_maintenance_access\";b:1;s:8:\"no_cache\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:79:\"{^/user/reset/(?P<uid>[^/]++)/(?P<timestamp>[^/]++)/(?P<hash>[^/]++)/login$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:6:\"/login\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"hash\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:9:\"timestamp\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"uid\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/user/reset\";}}s:9:\"path_vars\";a:3:{i:0;s:3:\"uid\";i:1;s:9:\"timestamp\";i:2;s:4:\"hash\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:49;s:14:\"patternOutline\";s:23:\"/user/reset/%/%/%/login\";s:8:\"numParts\";i:6;}}',	6),
('user.role.settings',	'/admin/people/role-settings',	'/admin/people/role-settings',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/admin/people/role-settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:34:\"\\Drupal\\user\\Form\\RoleSettingsForm\";s:6:\"_title\";s:13:\"Role settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:35:\"{^/admin/people/role\\-settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/people/role-settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/people/role-settings\";s:8:\"numParts\";i:3;}}',	3),
('user.role_add',	'/admin/people/roles/add',	'/admin/people/roles/add',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:23:\"/admin/people/roles/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:17:\"user_role.default\";s:6:\"_title\";s:8:\"Add role\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:22:\"administer permissions\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:30:\"{^/admin/people/roles/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:23:\"/admin/people/roles/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:23:\"/admin/people/roles/add\";s:8:\"numParts\";i:4;}}',	4),
('user.well-known.change_password',	'/.well-known/change-password',	'/.well-known/change-password',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/.well-known/change-password\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:52:\"\\Drupal\\user\\Controller\\UserController::userEditPage\";}s:12:\"requirements\";a:1:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:30:\"access_check.user.login_status\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/\\.well\\-known/change\\-password$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/.well-known/change-password\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:28:\"/.well-known/change-password\";s:8:\"numParts\";i:2;}}',	2),
('view.block_content.page_1',	'/admin/content/block',	'/admin/content/block',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/block\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"block_content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"access block library\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/block$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/block\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/block\";s:8:\"numParts\";i:3;}}',	3),
('view.content.page_1',	'/admin/content',	'/admin/content',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:14:\"/admin/content\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:7:\"content\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:23:\"access content overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:21:\"{^/admin/content$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/admin/content\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:14:\"/admin/content\";s:8:\"numParts\";i:2;}}',	2),
('view.files.page_1',	'/admin/content/files',	'/admin/content/files',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/files\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"files\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access files overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/files$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/files\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/files\";s:8:\"numParts\";i:3;}}',	3),
('view.files.page_2',	'/admin/content/files/usage/{arg_0}',	'/admin/content/files/usage/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/content/files/usage/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"files\";s:10:\"display_id\";s:6:\"page_2\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access files overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:51:\"{^/admin/content/files/usage/(?P<arg_0>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/content/files/usage\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:28:\"/admin/content/files/usage/%\";s:8:\"numParts\";i:5;}}',	5),
('view.frontpage.feed_1',	'/rss.xml',	'/rss.xml',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:8:\"/rss.xml\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:9:\"frontpage\";s:10:\"display_id\";s:6:\"feed_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"feed\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Feed\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:16:\"{^/rss\\.xml$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/rss.xml\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:8:\"/rss.xml\";s:8:\"numParts\";i:1;}}',	1),
('view.frontpage.page_1',	'/node',	'/node',	1,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:5:\"/node\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:9:\"frontpage\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:12:\"{^/node$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/node\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:1;s:14:\"patternOutline\";s:5:\"/node\";s:8:\"numParts\";i:1;}}',	1),
('view.media.media_page_list',	'/admin/content/media',	'/admin/content/media',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/content/media\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:5:\"media\";s:10:\"display_id\";s:15:\"media_page_list\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access media overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/content/media$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/content/media\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/content/media\";s:8:\"numParts\";i:3;}}',	3),
('view.media_library.page',	'/admin/content/media-grid',	'/admin/content/media-grid',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:25:\"/admin/content/media-grid\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"media_library\";s:10:\"display_id\";s:4:\"page\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:21:\"access media overview\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/content/media\\-grid$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/content/media-grid\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:25:\"/admin/content/media-grid\";s:8:\"numParts\";i:3;}}',	3),
('view.media_library.widget',	'/admin/content/media-widget/{arg_0}',	'/admin/content/media-widget',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:35:\"/admin/content/media-widget/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:6:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"media_library\";s:10:\"display_id\";s:6:\"widget\";s:30:\"_view_display_show_admin_links\";b:1;s:5:\"arg_0\";N;}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:10:\"view media\";s:7:\"_format\";s:4:\"html\";s:14:\"_custom_access\";s:36:\"media_library.ui_builder:checkAccess\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:58:\"{^/admin/content/media\\-widget(?:/(?P<arg_0>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:27:\"/admin/content/media-widget\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:27:\"/admin/content/media-widget\";s:8:\"numParts\";i:4;}}',	4),
('view.media_library.widget_table',	'/admin/content/media-widget-table/{arg_0}',	'/admin/content/media-widget-table',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/content/media-widget-table/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:6:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"media_library\";s:10:\"display_id\";s:12:\"widget_table\";s:30:\"_view_display_show_admin_links\";b:1;s:5:\"arg_0\";N;}s:12:\"requirements\";a:3:{s:11:\"_permission\";s:10:\"view media\";s:7:\"_format\";s:4:\"html\";s:14:\"_custom_access\";s:36:\"media_library.ui_builder:checkAccess\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:23:\"access_check.permission\";i:1;s:19:\"access_check.custom\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:65:\"{^/admin/content/media\\-widget\\-table(?:/(?P<arg_0>[^/]++))?$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:33:\"/admin/content/media-widget-table\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:33:\"/admin/content/media-widget-table\";s:8:\"numParts\";i:4;}}',	4),
('view.redirect.page_1',	'/admin/config/search/redirect',	'/admin/config/search/redirect',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/config/search/redirect\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"redirect\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:20:\"administer redirects\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/config/search/redirect$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/config/search/redirect\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/config/search/redirect\";s:8:\"numParts\";i:4;}}',	4),
('view.taxonomy_term.feed_1',	'/taxonomy/term/{arg_0}/feed',	'/taxonomy/term/%/feed',	13,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:27:\"/taxonomy/term/{arg_0}/feed\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"feed_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"feed\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Feed\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:1;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:44:\"{^/taxonomy/term/(?P<arg_0>[^/]++)/feed$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:5:\"/feed\";}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:13;s:14:\"patternOutline\";s:21:\"/taxonomy/term/%/feed\";s:8:\"numParts\";i:4;}}',	4),
('view.taxonomy_term.page_1',	'/taxonomy/term/{arg_0}',	'/taxonomy/term/%',	6,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:22:\"/taxonomy/term/{arg_0}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:13:\"taxonomy_term\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:14:\"access content\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:8:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:1:{s:5:\"arg_0\";s:5:\"arg_0\";}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:5:\"arg_0\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:39:\"{^/taxonomy/term/(?P<arg_0>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:5:\"arg_0\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/taxonomy/term\";}}s:9:\"path_vars\";a:1:{i:0;s:5:\"arg_0\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:6;s:14:\"patternOutline\";s:16:\"/taxonomy/term/%\";s:8:\"numParts\";i:3;}}',	3),
('view.user_admin_people.page_1',	'/admin/people',	'/admin/people',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:13:\"/admin/people\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:17:\"user_admin_people\";s:10:\"display_id\";s:6:\"page_1\";s:30:\"_view_display_show_admin_links\";b:0;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:16:\"administer users\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:0;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:20:\"{^/admin/people$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/admin/people\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:13:\"/admin/people\";s:8:\"numParts\";i:2;}}',	2),
('view.watchdog.page',	'/admin/reports/dblog',	'/admin/reports/dblog',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:20:\"/admin/reports/dblog\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:5:{s:11:\"_controller\";s:47:\"Drupal\\views\\Routing\\ViewPageController::handle\";s:15:\"_title_callback\";s:49:\"Drupal\\views\\Routing\\ViewPageController::getTitle\";s:7:\"view_id\";s:8:\"watchdog\";s:10:\"display_id\";s:4:\"page\";s:30:\"_view_display_show_admin_links\";b:1;}s:12:\"requirements\";a:2:{s:11:\"_permission\";s:19:\"access site reports\";s:7:\"_format\";s:4:\"html\";}s:7:\"options\";a:9:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:18:\"_view_argument_map\";a:0:{}s:23:\"_view_display_plugin_id\";s:4:\"page\";s:26:\"_view_display_plugin_class\";s:38:\"Drupal\\views\\Plugin\\views\\display\\Page\";s:30:\"_view_display_show_admin_links\";b:1;s:16:\"returns_response\";b:0;s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:27:\"{^/admin/reports/dblog$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:20:\"/admin/reports/dblog\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:20:\"/admin/reports/dblog\";s:8:\"numParts\";i:3;}}',	3),
('views.ajax',	'/views/ajax',	'/views/ajax',	3,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:11:\"/views/ajax\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:53:\"\\Drupal\\views\\Controller\\ViewAjaxController::ajaxView\";}s:12:\"requirements\";a:1:{s:7:\"_access\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:20:\"access_check.default\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:18:\"{^/views/ajax$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:11:\"/views/ajax\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:3;s:14:\"patternOutline\";s:11:\"/views/ajax\";s:8:\"numParts\";i:2;}}',	2),
('views_ui.add',	'/admin/structure/views/add',	'/admin/structure/views/add',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:26:\"/admin/structure/views/add\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:12:\"_entity_form\";s:8:\"view.add\";s:6:\"_title\";s:8:\"Add view\";}s:12:\"requirements\";a:1:{s:21:\"_entity_create_access\";s:4:\"view\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:26:\"access_check.entity_create\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:33:\"{^/admin/structure/views/add$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:26:\"/admin/structure/views/add\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:26:\"/admin/structure/views/add\";s:8:\"numParts\";i:4;}}',	4),
('views_ui.autocomplete',	'/admin/views/ajax/autocomplete/tag',	'/admin/views/ajax/autocomplete/tag',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/views/ajax/autocomplete/tag\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:62:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::autocompleteTag\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:41:\"{^/admin/views/ajax/autocomplete/tag$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/views/ajax/autocomplete/tag\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:34:\"/admin/views/ajax/autocomplete/tag\";s:8:\"numParts\";i:5;}}',	5),
('views_ui.form_add_handler',	'/admin/structure/views/{js}/add-handler/{view}/{display_id}/{type}',	'/admin/structure/views/%/add-handler/%/%/%',	232,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:66:\"/admin/structure/views/{js}/add-handler/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:46:\"\\Drupal\\views_ui\\Form\\Ajax\\AddHandler::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:117:\"{^/admin/structure/views/(?P<js>nojs|ajax)/add\\-handler/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:12:\"/add-handler\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:42:\"/admin/structure/views/%/add-handler/%/%/%\";s:8:\"numParts\";i:8;}}',	8),
('views_ui.form_analyze',	'/admin/structure/views/{js}/analyze/{view}/{display_id}',	'/admin/structure/views/%/analyze/%/%',	116,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:55:\"/admin/structure/views/{js}/analyze/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:43:\"\\Drupal\\views_ui\\Form\\Ajax\\Analyze::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:95:\"{^/admin/structure/views/(?P<js>nojs|ajax)/analyze/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/analyze\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:36:\"/admin/structure/views/%/analyze/%/%\";s:8:\"numParts\";i:7;}}',	7),
('views_ui.form_display',	'/admin/structure/views/{js}/display/{view}/{display_id}/{type}',	'/admin/structure/views/%/display/%/%/%',	232,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:62:\"/admin/structure/views/{js}/display/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:43:\"\\Drupal\\views_ui\\Form\\Ajax\\Display::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:112:\"{^/admin/structure/views/(?P<js>nojs|ajax)/display/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/display\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:38:\"/admin/structure/views/%/display/%/%/%\";s:8:\"numParts\";i:8;}}',	8),
('views_ui.form_edit_details',	'/admin/structure/views/{js}/edit-details/{view}/{display_id}',	'/admin/structure/views/%/edit-details/%/%',	116,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:60:\"/admin/structure/views/{js}/edit-details/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:47:\"\\Drupal\\views_ui\\Form\\Ajax\\EditDetails::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:101:\"{^/admin/structure/views/(?P<js>nojs|ajax)/edit\\-details/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/edit-details\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:41:\"/admin/structure/views/%/edit-details/%/%\";s:8:\"numParts\";i:7;}}',	7),
('views_ui.form_handler',	'/admin/structure/views/{js}/handler/{view}/{display_id}/{type}/{id}',	'/admin/structure/views/%/handler/%/%/%/%',	464,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:67:\"/admin/structure/views/{js}/handler/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:49:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandler::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:127:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/handler\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:40:\"/admin/structure/views/%/handler/%/%/%/%\";s:8:\"numParts\";i:9;}}',	9),
('views_ui.form_handler_extra',	'/admin/structure/views/{js}/handler-extra/{view}/{display_id}/{type}/{id}',	'/admin/structure/views/%/handler-extra/%/%/%/%',	464,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/views/{js}/handler-extra/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:54:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandlerExtra::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler\\-extra/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/handler-extra\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:46:\"/admin/structure/views/%/handler-extra/%/%/%/%\";s:8:\"numParts\";i:9;}}',	9),
('views_ui.form_handler_group',	'/admin/structure/views/{js}/handler-group/{view}/{display_id}/{type}/{id}',	'/admin/structure/views/%/handler-group/%/%/%/%',	464,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:73:\"/admin/structure/views/{js}/handler-group/{view}/{display_id}/{type}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:54:\"\\Drupal\\views_ui\\Form\\Ajax\\ConfigHandlerGroup::getForm\";s:10:\"form_state\";N;}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:134:\"{^/admin/structure/views/(?P<js>nojs|ajax)/handler\\-group/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:7:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:14:\"/handler-group\";}i:5;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:6;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:5:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";i:4;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:464;s:14:\"patternOutline\";s:46:\"/admin/structure/views/%/handler-group/%/%/%/%\";s:8:\"numParts\";i:9;}}',	9),
('views_ui.form_rearrange',	'/admin/structure/views/{js}/rearrange/{view}/{display_id}/{type}',	'/admin/structure/views/%/rearrange/%/%/%',	232,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/rearrange/{view}/{display_id}/{type}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:45:\"\\Drupal\\views_ui\\Form\\Ajax\\Rearrange::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:114:\"{^/admin/structure/views/(?P<js>nojs|ajax)/rearrange/(?P<view>[^/]++)/(?P<display_id>[^/]++)/(?P<type>[^/]++)$}sDu\";s:11:\"path_tokens\";a:6:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"type\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:10:\"/rearrange\";}i:4;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:5;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:4:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";i:3;s:4:\"type\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:232;s:14:\"patternOutline\";s:40:\"/admin/structure/views/%/rearrange/%/%/%\";s:8:\"numParts\";i:8;}}',	8),
('views_ui.form_rearrange_filter',	'/admin/structure/views/{js}/rearrange-filter/{view}/{display_id}',	'/admin/structure/views/%/rearrange-filter/%/%',	116,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/rearrange-filter/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Form\\Ajax\\RearrangeFilter::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/views/(?P<js>nojs|ajax)/rearrange\\-filter/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/rearrange-filter\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:45:\"/admin/structure/views/%/rearrange-filter/%/%\";s:8:\"numParts\";i:7;}}',	7),
('views_ui.form_reorder_displays',	'/admin/structure/views/{js}/reorder-displays/{view}/{display_id}',	'/admin/structure/views/%/reorder-displays/%/%',	116,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:64:\"/admin/structure/views/{js}/reorder-displays/{view}/{display_id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:51:\"\\Drupal\\views_ui\\Form\\Ajax\\ReorderDisplays::getForm\";}s:12:\"requirements\";a:2:{s:14:\"_entity_access\";s:11:\"view.update\";s:2:\"js\";s:9:\"nojs|ajax\";}s:7:\"options\";a:5:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:4:\"view\";a:3:{s:9:\"tempstore\";b:1;s:4:\"type\";s:11:\"entity:view\";s:9:\"converter\";s:53:\"drupal.proxy_original_service.paramconverter.views_ui\";}}s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:105:\"{^/admin/structure/views/(?P<js>nojs|ajax)/reorder\\-displays/(?P<view>[^/]++)/(?P<display_id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:5:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:10:\"display_id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:4:\"view\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:17:\"/reorder-displays\";}i:3;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:9:\"nojs|ajax\";i:3;s:2:\"js\";i:4;b:1;}i:4;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/admin/structure/views\";}}s:9:\"path_vars\";a:3:{i:0;s:2:\"js\";i:1;s:4:\"view\";i:2;s:10:\"display_id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:116;s:14:\"patternOutline\";s:45:\"/admin/structure/views/%/reorder-displays/%/%\";s:8:\"numParts\";i:7;}}',	7),
('views_ui.reports_fields',	'/admin/reports/fields/views-fields',	'/admin/reports/fields/views-fields',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:34:\"/admin/reports/fields/views-fields\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:59:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::reportFields\";s:6:\"_title\";s:13:\"Used in views\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:42:\"{^/admin/reports/fields/views\\-fields$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:34:\"/admin/reports/fields/views-fields\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:34:\"/admin/reports/fields/views-fields\";s:8:\"numParts\";i:4;}}',	4),
('views_ui.reports_plugins',	'/admin/reports/views-plugins',	'/admin/reports/views-plugins',	7,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:28:\"/admin/reports/views-plugins\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:60:\"\\Drupal\\views_ui\\Controller\\ViewsUIController::reportPlugins\";s:6:\"_title\";s:13:\"Views plugins\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/reports/views\\-plugins$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:28:\"/admin/reports/views-plugins\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:7;s:14:\"patternOutline\";s:28:\"/admin/reports/views-plugins\";s:8:\"numParts\";i:3;}}',	3),
('views_ui.settings_advanced',	'/admin/structure/views/settings/advanced',	'/admin/structure/views/settings/advanced',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/views/settings/advanced\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:42:\"\\Drupal\\views_ui\\Form\\AdvancedSettingsForm\";s:6:\"_title\";s:23:\"Advanced Views settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/views/settings/advanced$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/views/settings/advanced\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/views/settings/advanced\";s:8:\"numParts\";i:5;}}',	5),
('views_ui.settings_basic',	'/admin/structure/views/settings',	'/admin/structure/views/settings',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/views/settings\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:39:\"\\Drupal\\views_ui\\Form\\BasicSettingsForm\";s:6:\"_title\";s:14:\"Views settings\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:16:\"administer views\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/views/settings$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/views/settings\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/views/settings\";s:8:\"numParts\";i:4;}}',	4),
('webform.addons',	'/admin/structure/webform/addons',	'/admin/structure/webform/addons',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/webform/addons\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:57:\"\\Drupal\\webform\\Controller\\WebformAddonsController::index\";s:6:\"_title\";s:17:\"Webforms: Add-ons\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/webform/addons$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/addons\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/webform/addons\";s:8:\"numParts\";i:4;}}',	4),
('webform.config',	'/admin/structure/webform/config',	'/admin/structure/webform/config',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:31:\"/admin/structure/webform/config\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:60:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigFormsForm\";s:6:\"_title\";s:29:\"Webforms: Forms configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:38:\"{^/admin/structure/webform/config$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:31:\"/admin/structure/webform/config\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:31:\"/admin/structure/webform/config\";s:8:\"numParts\";i:4;}}',	4),
('webform.config.advanced',	'/admin/structure/webform/config/advanced',	'/admin/structure/webform/config/advanced',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/advanced\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigAdvancedForm\";s:6:\"_title\";s:32:\"Webforms: Advanced configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/advanced$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/advanced\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/advanced\";s:8:\"numParts\";i:5;}}',	5),
('webform.config.elements',	'/admin/structure/webform/config/elements',	'/admin/structure/webform/config/elements',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/elements\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigElementsForm\";s:6:\"_title\";s:32:\"Webforms: Elements configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/elements$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/elements\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/elements\";s:8:\"numParts\";i:5;}}',	5),
('webform.config.exporters',	'/admin/structure/webform/config/exporters',	'/admin/structure/webform/config/exporters',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/webform/config/exporters\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:64:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigExportersForm\";s:6:\"_title\";s:33:\"Webforms: Exporters configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/structure/webform/config/exporters$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/structure/webform/config/exporters\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:41:\"/admin/structure/webform/config/exporters\";s:8:\"numParts\";i:5;}}',	5),
('webform.config.handlers',	'/admin/structure/webform/config/handlers',	'/admin/structure/webform/config/handlers',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/handlers\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigHandlersForm\";s:6:\"_title\";s:32:\"Webforms: Handlers configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/handlers$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/handlers\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/handlers\";s:8:\"numParts\";i:5;}}',	5),
('webform.config.libraries',	'/admin/structure/webform/config/libraries',	'/admin/structure/webform/config/libraries',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:41:\"/admin/structure/webform/config/libraries\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:64:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigLibrariesForm\";s:6:\"_title\";s:33:\"Webforms: Libraries configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/structure/webform/config/libraries$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:41:\"/admin/structure/webform/config/libraries\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:41:\"/admin/structure/webform/config/libraries\";s:8:\"numParts\";i:5;}}',	5),
('webform.config.repair',	'/admin/structure/webform/config/repair',	'/admin/structure/webform/config/repair',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:38:\"/admin/structure/webform/config/repair\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:61:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigRepairForm\";s:6:\"_title\";s:38:\"Webforms: Repair webform configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:45:\"{^/admin/structure/webform/config/repair$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:38:\"/admin/structure/webform/config/repair\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:38:\"/admin/structure/webform/config/repair\";s:8:\"numParts\";i:5;}}',	5),
('webform.config.submissions',	'/admin/structure/webform/config/submissions',	'/admin/structure/webform/config/submissions',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:43:\"/admin/structure/webform/config/submissions\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:66:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigSubmissionsForm\";s:6:\"_title\";s:35:\"Webforms: Submissions configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:50:\"{^/admin/structure/webform/config/submissions$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:43:\"/admin/structure/webform/config/submissions\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:43:\"/admin/structure/webform/config/submissions\";s:8:\"numParts\";i:5;}}',	5),
('webform.config.variants',	'/admin/structure/webform/config/variants',	'/admin/structure/webform/config/variants',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/structure/webform/config/variants\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:63:\"\\Drupal\\webform\\Form\\AdminConfig\\WebformAdminConfigVariantsForm\";s:6:\"_title\";s:32:\"Webforms: Variants configuration\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/structure/webform/config/variants$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/structure/webform/config/variants\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:40:\"/admin/structure/webform/config/variants\";s:8:\"numParts\";i:5;}}',	5),
('webform.element.autocomplete',	'/webform/{webform}/autocomplete/{key}',	'/webform/%/autocomplete/%',	10,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/webform/{webform}/autocomplete/{key}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:11:\"_controller\";s:65:\"\\Drupal\\webform\\Controller\\WebformElementController::autocomplete\";}s:12:\"requirements\";a:1:{s:14:\"_entity_access\";s:25:\"webform.submission_create\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:10:\"parameters\";a:1:{s:7:\"webform\";a:2:{s:4:\"type\";s:14:\"entity:webform\";s:9:\"converter\";s:21:\"paramconverter.entity\";}}s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:19:\"access_check.entity\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/webform/(?P<webform>[^/]++)/autocomplete/(?P<key>[^/]++)$}sDu\";s:11:\"path_tokens\";a:4:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:3:\"key\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:13:\"/autocomplete\";}i:2;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"webform\";i:4;b:1;}i:3;a:2:{i:0;s:4:\"text\";i:1;s:8:\"/webform\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"webform\";i:1;s:3:\"key\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:10;s:14:\"patternOutline\";s:25:\"/webform/%/autocomplete/%\";s:8:\"numParts\";i:4;}}',	4),
('webform.element.message.close',	'/webform/message/close/{storage}/{id}',	'/webform/message/close/%/%',	28,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:37:\"/webform/message/close/{storage}/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:58:\"\\Drupal\\webform\\Controller\\WebformElementController::close\";s:8:\"_storage\";s:4:\"user\";}s:12:\"requirements\";a:2:{s:18:\"_user_is_logged_in\";s:4:\"TRUE\";s:11:\"_csrf_token\";s:4:\"TRUE\";}s:7:\"options\";a:3:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:14:\"_access_checks\";a:2:{i:0;s:30:\"access_check.user.login_status\";i:1;s:17:\"access_check.csrf\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:2:{i:0;s:7:\"storage\";i:1;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:64:\"{^/webform/message/close/(?P<storage>[^/]++)/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:3:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:7:\"storage\";i:4;b:1;}i:2;a:2:{i:0;s:4:\"text\";i:1;s:22:\"/webform/message/close\";}}s:9:\"path_vars\";a:2:{i:0;s:7:\"storage\";i:1;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:28;s:14:\"patternOutline\";s:26:\"/webform/message/close/%/%\";s:8:\"numParts\";i:5;}}',	5),
('webform.help',	'/admin/structure/webform/help',	'/admin/structure/webform/help',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:29:\"/admin/structure/webform/help\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:55:\"\\Drupal\\webform\\Controller\\WebformHelpController::index\";s:6:\"_title\";s:14:\"Webforms: Help\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:19:\"access webform help\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:36:\"{^/admin/structure/webform/help$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:29:\"/admin/structure/webform/help\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:29:\"/admin/structure/webform/help\";s:8:\"numParts\";i:4;}}',	4),
('webform.help.video',	'/admin/help/webform/video/{id}',	'/admin/help/webform/video/%',	30,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:30:\"/admin/help/webform/video/{id}\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:1:{s:5:\"_form\";s:41:\"\\Drupal\\webform\\Form\\WebformHelpVideoForm\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:14:\"access content\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:1:{i:0;s:2:\"id\";}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/help/webform/video/(?P<id>[^/]++)$}sDu\";s:11:\"path_tokens\";a:2:{i:0;a:5:{i:0;s:8:\"variable\";i:1;s:1:\"/\";i:2;s:6:\"[^/]++\";i:3;s:2:\"id\";i:4;b:1;}i:1;a:2:{i:0;s:4:\"text\";i:1;s:25:\"/admin/help/webform/video\";}}s:9:\"path_vars\";a:1:{i:0;s:2:\"id\";}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:30;s:14:\"patternOutline\";s:27:\"/admin/help/webform/video/%\";s:8:\"numParts\";i:5;}}',	5),
('webform.reports_plugins.elements',	'/admin/reports/webform-plugins/elements',	'/admin/reports/webform-plugins/elements',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/reports/webform-plugins/elements\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformPluginElementController::index\";s:6:\"_title\";s:25:\"Webform plugins: Elements\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/reports/webform\\-plugins/elements$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/reports/webform-plugins/elements\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/reports/webform-plugins/elements\";s:8:\"numParts\";i:4;}}',	4),
('webform.reports_plugins.exporters',	'/admin/reports/webform-plugins/exporters',	'/admin/reports/webform-plugins/exporters',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:40:\"/admin/reports/webform-plugins/exporters\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:65:\"\\Drupal\\webform\\Controller\\WebformPluginExporterController::index\";s:6:\"_title\";s:26:\"Webform plugins: Exporters\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:48:\"{^/admin/reports/webform\\-plugins/exporters$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:40:\"/admin/reports/webform-plugins/exporters\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:40:\"/admin/reports/webform-plugins/exporters\";s:8:\"numParts\";i:4;}}',	4),
('webform.reports_plugins.handlers',	'/admin/reports/webform-plugins/handlers',	'/admin/reports/webform-plugins/handlers',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/reports/webform-plugins/handlers\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformPluginHandlerController::index\";s:6:\"_title\";s:25:\"Webform plugins: Handlers\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/reports/webform\\-plugins/handlers$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/reports/webform-plugins/handlers\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/reports/webform-plugins/handlers\";s:8:\"numParts\";i:4;}}',	4),
('webform.reports_plugins.variants',	'/admin/reports/webform-plugins/variants',	'/admin/reports/webform-plugins/variants',	15,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/reports/webform-plugins/variants\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:11:\"_controller\";s:64:\"\\Drupal\\webform\\Controller\\WebformPluginVariantController::index\";s:6:\"_title\";s:25:\"Webform plugins: Variants\";}s:12:\"requirements\";a:1:{s:11:\"_permission\";s:18:\"administer webform\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:23:\"access_check.permission\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:47:\"{^/admin/reports/webform\\-plugins/variants$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/reports/webform-plugins/variants\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:15;s:14:\"patternOutline\";s:39:\"/admin/reports/webform-plugins/variants\";s:8:\"numParts\";i:4;}}',	4),
('webform_submission.multiple_delete_confirm',	'/admin/structure/webform/results/delete',	'/admin/structure/webform/results/delete',	31,	'O:31:\"Symfony\\Component\\Routing\\Route\":9:{s:4:\"path\";s:39:\"/admin/structure/webform/results/delete\";s:4:\"host\";s:0:\"\";s:8:\"defaults\";a:2:{s:5:\"_form\";s:56:\"\\Drupal\\webform\\Form\\WebformSubmissionDeleteMultipleForm\";s:14:\"entity_type_id\";s:18:\"webform_submission\";}s:12:\"requirements\";a:1:{s:30:\"_entity_delete_multiple_access\";s:18:\"webform_submission\";}s:7:\"options\";a:4:{s:14:\"compiler_class\";s:33:\"Drupal\\Core\\Routing\\RouteCompiler\";s:4:\"utf8\";b:1;s:12:\"_admin_route\";b:1;s:14:\"_access_checks\";a:1:{i:0;s:35:\"access_check.entity_delete_multiple\";}}s:7:\"schemes\";a:0:{}s:7:\"methods\";a:2:{i:0;s:3:\"GET\";i:1;s:4:\"POST\";}s:9:\"condition\";s:0:\"\";s:8:\"compiled\";O:33:\"Drupal\\Core\\Routing\\CompiledRoute\":11:{s:4:\"vars\";a:0:{}s:11:\"path_prefix\";s:0:\"\";s:10:\"path_regex\";s:46:\"{^/admin/structure/webform/results/delete$}sDu\";s:11:\"path_tokens\";a:1:{i:0;a:2:{i:0;s:4:\"text\";i:1;s:39:\"/admin/structure/webform/results/delete\";}}s:9:\"path_vars\";a:0:{}s:10:\"host_regex\";N;s:11:\"host_tokens\";a:0:{}s:9:\"host_vars\";a:0:{}s:3:\"fit\";i:31;s:14:\"patternOutline\";s:39:\"/admin/structure/webform/results/delete\";s:8:\"numParts\";i:5;}}',	5);

DROP TABLE IF EXISTS `search_dataset`;
CREATE TABLE `search_dataset` (
  `sid` int unsigned NOT NULL DEFAULT '0' COMMENT 'Search item ID, e.g. node ID for nodes.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "languages".langcode of the item variant.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'Type of item, e.g. node.',
  `data` longtext NOT NULL COMMENT 'List of space-separated words from the item.',
  `reindex` int unsigned NOT NULL DEFAULT '0' COMMENT 'Set to force node reindexing.',
  PRIMARY KEY (`sid`,`langcode`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores items that will be searched.';

INSERT INTO `search_dataset` (`sid`, `langcode`, `type`, `data`, `reindex`) VALUES
(1,	'en',	'help_search',	' exporting your complete site configuration goal create and download an archive containing all your site s configuration exported as yaml files see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   export  click export and save the archive file  ',	1723096663),
(1,	'en',	'node_search',	' langing page langing page admin mon 7292024 916 test test  ',	0),
(2,	'en',	'help_search',	' exporting a single configuration item goal export a single configuration item to a file see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   export   single item  select the configuration type that you want to export and then select the specific configuration name to export use your browser to copy the text in the box marked here is your configuration to the clipboard paste the copied text into a plaintext editor on your computer or other device and save it using the suggested file name below the text box  ',	1723096663),
(3,	'en',	'help_search',	' importing your complete site configuration goal import the complete configuration of your site from an archive file such as one that was previously exported see exporting your complete site configuration see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   import  browse to find the configuration archive that you want to import click upload  your configuration archive will be unpacked and placed in the configuration synchronization directory and you will be redirected to the synchronize page review the differences between your uploaded configuration and the active configuration if any and click import all to import the changes  ',	1723096663),
(4,	'en',	'help_search',	' importing a single configuration item goal import a single configuration item in yaml format such as one that was previously exported see exporting a single configuration item see managing and deploying configuration for more information about configuration steps in the manage administrative menu navigate to configuration   development   configuration synchronization   import   single item  select the configuration type that you want to import on your computer or other device copy the yamlformat configuration that you want to import to the clipboard paste the clipboard text into the box labeled paste your configuration here  click import   ',	1723096663),
(5,	'en',	'help_search',	' managing the fields of contact forms goal add remove or rearrange the fields on personal and sitewide contact forms what are the fields on contact forms  both personal and sitewide contact forms will always have subject and message fields you can add additional fields for users to fill out if desired note that if you want to display other content on a form page such as text or images you can use a content block steps in the manage administrative menu navigate to structure   contact forms  click manage fields for the form you want to change the fields of and add or remove one or more fields on the form click manage form display to change the order or configuration of the fields on the form  ',	1723096663),
(6,	'en',	'help_search',	' configuring personal contact forms goal configure personal contact forms for registered users on the website steps in the manage administrative menu navigate to configuration   people   account settings  in the contact settings section check uncheck the box to enable disable the contact form for new user accounts click save configuration  in the manage administrative menu navigate to people   permissions  verify that permissions are correct for your site s roles including the generic anonymous user and authenticated user  in order to use personal contact forms users need both view user information  in the user section which enables them to view user profiles and use users personal contact forms  in the contact section which enables them to use contact forms if they can view user profiles click save permissions  the contact form will always have subject and message fields if you want to add more fields follow the steps in managing the fields of contact forms  ',	1723096663),
(7,	'en',	'help_search',	' creating a new contact form goal create a new sitewide contact form steps in the manage administrative menu navigate to structure   contact forms  click add contact form  fill in the label  title for the form  recipients  and optionally the other settings click save  you should see your new contact form in the table along with a link to view it the contact form will always have subject and message fields if you want to add more fields follow the steps in managing the fields of contact forms  ',	1723096663),
(8,	'en',	'help_search',	' managing contact forms what are contact forms  there are two different types of contact forms provided by the core contact module personal contact forms which allow users to contact other users on the site and sitewide contact forms which allow users to contact site managers or administrators a site can have more than one sitewide contact form each has its own fields to fill out recipients and url you can also change the fields that are shown on personal contact forms using the personal contact form site visitors can email registered users on your site by using the personal contact form without knowing or learning the email address of the recipient when a user with the correct permissions is viewing another user s profile the viewer will see a contact tab or link which leads to the personal contact form if the user whose profile is being viewed has their personal contact form enabled this is a user account setting  contact form management tasks see the related topics below for specific tasks  ',	1723096663),
(9,	'en',	'help_search',	' setting a default contact form goal set a sitewide contact form to be the default contact form  the form displayed on the default contact page  for example   contact   steps in the manage administrative menu navigate to structure   contact forms  click edit for the sitewide form you want to be the default check make this the default form and click save   ',	1723096663),
(10,	'en',	'help_search',	' changing the appearance of your site what is a theme  a theme is a set of files that define the visual look and feel of your site the core software and modules that run on your site determine which content including html text and other data stored in the database uploaded images and any other asset files is displayed on the pages of your site the theme determines the html markup and css styling that wraps the content several basic themes are supplied with the core software additional contributed themes can be downloaded separately from the download extend page on drupalorg  or you can create your own theme what is a base theme  a base theme is a theme that is not meant to be used directly on a site but instead acts as a scaffolding for building other themes the core stable 9 theme is one example other base themes can be downloaded from the download extend page on drupalorg  what is a layout  a layout is a template that defines where blocks and other pieces of content should be displayed the core layout discovery module allows modules and themes to register layouts and the core layout builder module provides a visual interface for placing fields and blocks in layouts for entity subtypes and individual entity items see managing content structure for more on entities and fields  changing site appearance overview the main way to change the overall appearance of your site is to switch the default theme the core layout builder and layout discovery modules allow you to define layouts for your site s content and the core breakpoint module helps themes change appearance for differentsized devices see the related topics listed below for specific tasks additional resources extending and customizing your site drupal user guide  theming drupal ',	1723096663),
(11,	'en',	'help_search',	' managing and deploying configuration what is the configuration system  the configuration system provides the ability for administrators to customize the site and to move and synchronize configuration changes between development sites and the live site it does this in 2 ways providing storage for configuration providing a process in which configuration changes can be imported and exported between instances of the same site for example from dev to staging to live  what is configuration data  configuration data describes settings that define how your site behaves or is displayed for example when a site administrator updates settings using an administrative form these settings are stored as configuration data configuration data describes settings as simple as a site name and as complex as a view or image style what kinds of configuration are there  active configuration active configuration is the current working configuration of a site storage of active configuration is defined by the site and resides in the database by default simple configuration a simple configuration item is a group of settings such as the settings for a module or theme each simple configuration item has its own unique structure configuration entities configuration entities are userdefined configuration items grouped by type such as views image styles and content types each configuration entity within a type has a similar structure default configuration default configuration can be defined by a module theme or installation profile in its config install or config optional directories configuration is provided in yaml files file extension yml yaml is a humanreadable data serialization standard that is used by the core software for several purposes once the default configuration has been imported into the site s active configuration through installing the extension that configuration is owned by the site not the extension this means that future updates of the extension will not override the site s active configuration for that extension what is configuration synchronization  configuration synchronization is the process of exporting and importing configuration to keep configuration synchronized between different versions of a site for example between a development site and the live site each site has unique identifier also called a uuid  which identifies the site to the system in any instance of the site as long as the site instances have been reproduced as clones cloning is when the codebase and database are copied to create a new site instance when site instances are cloned a dev instance of the site has the same uuid as the live instance when site instances share the same uuid configuration can be exported from one instance to another the following list contains terms and concepts related to configuration synchronization exported configuration when configuration is exported the active configuration is exported as a set of files in yaml format when using the configuration synchronization administrative ui configuration can be exported as a fullexport or singleitem archive this archive can then be imported into the destination site instance imported configuration imported configuration is configuration that has been exported from another instance of the site the source and is now being imported into another site instance the destination thereby updating its active configuration to match the imported configuration data set configuration sync directory the configuration sync directory location is set in the site s settingsphp file when configuration is exported the active configuration is exported and described in yaml files which are stored in the configuration sync directory after the first export the system compares the site s active configuration with the configuration data in the sync directory and will only export active configuration items that are different than their counterparts in the sync directory managing configuration overview configuration management tasks such as exporting or importing configuration and synchronizing configuration can be done either through the administrative ui provided by the core configuration manager module or a commandline interface cli tool defining a configuration sync directory path other than the default value requires read write access to the site s settingsphp file most modules and themes also provide settings forms for updating the configuration they provide see the related topics listed below for specific tasks additional resources configuration management workflow using drush concept types of data drupal user guide  concept development sites drupal user guide  making a development site drupal user guide  ',	1723096663),
(12,	'en',	'help_search',	' managing content structure what types of data does a site have  there are four main types of data content is the information text images etc meant to be displayed to website visitors configuration is data that defines how the content is displayed some configuration such as field labels may also be visible to site visitors state is temporary data about the state of your site such as the last time the system cron jobs ran session is a subset of state information related to users interactions with the site such as site cookies and whether or not they are logged in what is a content entity  a content entity  or more commonly  entity  is an item of content data which can consist of text html markup images attached files and other data content entities are grouped into entity types  which have different purposes and are displayed in very different ways on the site most entity types are also divided into entity subtypes  which are divisions within an entity type to allow for smaller variations in how the entities are used and displayed for example the content item entity type that stores pagelevel content is divided into content type subtypes the content block entity type has block types  but the user entity type for user profile information does not have subtypes what is a field  within entity items the data is stored in individual fields  each of which holds one type of data such as formatted or plain text images or other files or dates fields can be added by an administrator on entity subtypes so that all entity items of a given entity subtype have the same collection of fields available and they can be singlevalued or multiplevalued when you create or edit entity items you are specifying the values for the fields on the entity item what is a reference field  a reference field is a field that stores a relationship between an entity and one or more other entities which may belong to the same or different entity type for example a content reference field on a content type stores a relationship between one content item and one or more other content items what field types are available  the following field types are provided by the core system and core modules many more are provided by contributed modules boolean number provided by the core system stores true false values and numbers comment provided by the core comment module allows users to add comments to an entity date timestamp datetime module stores dates and times date range datetime range module stores time date periods with a start and an end email core system stores email addresses link link module stores urls and link text list options module stores values chosen from predefined lists where the values can be numbers or text see section below for more on list fields reference core system stores entity references see section above telephone telephone module stores telephone numbers text text module stores formatted and unformatted text see section below for more on text fields what settings are available for list field types  list fields associate predefined keys  or value codes with labels that the user sees for example you might define a list field that shows the user the names of several locations while behind the scenes a location code is stored in the database each list field type corresponds to one type of stored key for example a list integer  field stores integers while the list text  field stores text strings once you have chosen the field type the main setting for a list field is the allowed values list which associates the keys with the labels what types of text fields are available  there are several types of text fields with different characteristics text fields can be either plain or formatted  plain text fields do not contain html while formatted fields can contain html and are processed through text filters  these are provided by the core filter module if you have that module enabled see the related topic below on filters for more information text fields can also be regularlength with a limit of 255 characters or long  with a very large character limit and long formatted text fields can include a summary attribute all possible combinations of these characteristics exist as text field types for example  text plain  and text formatted long with summary  are two examples of text field types what is a formatter  a formatter is a way to display a field most field types offer several types of formatters and most formatters have settings that further define how the field is displayed it is also possible to completely hide a field from display and you have the option of showing or hiding the field s label when it is displayed what is a widget  a widget is a way to edit a field some field types such as plain text singleline fields have only one widget available in this case a singleline text input field other field types offer choices for the widget for example singlevalued list fields can use a select or radio button widget for editing many widget types have settings that further define how the field can be edited managing content structure overview besides the field modules listed in the previous section there are additional core modules that you can use to manage your content structure the core node comment content block custom menu links user file image media taxonomy and contact modules all provide content entity types the core field ui module provides a user interface for managing fields and their display on entities the core layout builder module provides a more flexible user interface for configuring the display of entities the core filter responsive image and path modules provide settings and display options for entities and fields depending on the core and contributed modules that you currently have installed on your site the related topics below and other topics listed on the main help page see help will help you with tasks related to content structure additional resources concept types of data drupal user guide  planning your site drupal user guide  concept reference fields drupal user guide  ',	1723096663),
(13,	'en',	'help_search',	' running and configuring cron goal configure your system so that cron will run automatically what are cron tasks  to ensure that your site and its modules continue to function well a group of administrative operations should be run periodically these operations are called cron tasks and running the tasks is known as running cron  depending on how often content is updated on your site you might need to run cron on a schedule ranging from hourly to weekly to keep your site running well what options are available for running cron  if the core automated cron module is installed your site will run cron periodically on a schedule you can configure you can set up a task on your web server to visit the cron url  which is unique to your site on a schedule you can also run cron manually but this is not the recommended way to make sure it is run periodically steps in the manage administration menu navigate to configuration   system   cron  note the last run time on the page if you want to run cron right now click run cron and wait for cron to finish if you have a way to configure tasks on your web server copy the link where it says to run cron from outside the site go to  set up a task to visit that url on your desired cron schedule such as once an hour or once a week on linuxlike servers you can use the wget command to visit a url if you configure an outside task you should uninstall the automated cron module if you are not configuring an outside task and you have the core automated cron module installed select a schedule for automated cron runs in cron settings   run cron every  click save configuration  additional resources concept cron drupal user guide  configuring cron maintenance tasks drupal user guide  ',	1723096663),
(14,	'en',	'help_search',	' extending and modifying your site functionality what is a module  a module is a set of php javascript and or css files that extends site features and adds functionality a set of core modules is distributed as part of the core software download additional contributed modules can be downloaded separately from the download extend page on drupalorg  what is an experimental module  an experimental module is a module that is still in development and is not yet stable using experimental modules on production sites is not recommended what are installing and uninstalling  installing a core or downloaded contributed module means turning it on so that you can use its features and functionality uninstalling means turning it off and removing all of its configuration a module cannot be uninstalled if another installed module depends on it or if you have created content on your site using the module you would need to delete the content and uninstall dependent modules first extending overview see the related topics listed below for help performing tasks related to extending the functionality of your site additional resources concept modules drupal user guide  extending and customizing your site drupal user guide  ',	1723096663),
(15,	'en',	'help_search',	' maintaining and troubleshooting your site maintaining and troubleshooting overview here are some tasks and hints related to maintaining your site and troubleshooting problems that may come up on your site see the related topics below for more information when performing maintenance such as installing uninstalling or updating a module put your site in maintenance mode configure your site so that cron runs periodically if your site is not behaving as expected clear the cache before trying to diagnose the problem there are several site reports that can help you diagnose problems with your site there are also two core modules that can be used for error logging database logging and syslog additional resources preventing and fixing problems drupal user guide  security and maintenance drupal user guide  ',	1723096663),
(16,	'en',	'help_search',	' managing media what are media items  core media items include audio images documents and videos you can add other media types such as social media posts through the use of contributed modules media items may be files located in your site s file system or remote items referenced by a url media items are content entities and they are divided into media types which are entity subtypes media types can have fields see managing content structure for more information on content entities and fields what is the media library  the media library is a visual user interface for managing and reusing media items add media items to content using media reference fields and the media library field widget what is an image style  an image style is a set of processing steps known as effects  that can be applied to images examples of effects include scaling and cropping images to different sizes responsive image styles can associate image styles with your theme s size breakpoints this allows serving images sized for the browser width overview of managing media the following modules provide mediarelated functionality media items and media types are managed by the core media module the core media module provides a media reference field to add media to content entities the core file and image modules also provide reference fields it is recommended to use the media reference field because it is more versatile the core media library module provides the media library and the media library field widget with this module installed the media library field widget becomes the default widget for editing media reference fields the core image module provides a user interface for defining image styles the core responsive image module provides responsive image styles using the core breakpoint module and a breakpointenabled theme these responsive styles can serve images sized for the browser see the related topics listed below for specific tasks additional resources media module ',	1723096663),
(17,	'en',	'help_search',	' managing menus what is a menu  a menu is a collection of menu links used to navigate a web site menus and menu links can be provided by modules or site administrators managing menus overview the core menu ui module provides a user interface for managing menus including creating new menus reordering menu links and disabling links provided by modules it also provides the ability for links to content items to be added to menus while editing if configured on the content type the core custom menu links module provides the ability to add custom links to menus each menu can be displayed by placing a block in a theme region some themes also can display a menu outside of the block system see the related topics listed below for specific tasks additional resources concept menu drupal user guide  ',	1723096663),
(18,	'en',	'help_search',	' optimizing site performance what is site performance  site performance in this context refers to speed factors such as the page load time and the response time after a user action on a page what is caching  caching is saving alreadyrendered html output and other calculated data for later use the first time it is needed this saves time because the next time the same data is needed it can be quickly retrieved instead of recalculated automatic caching systems also include mechanisms to delete cached calculations or mark them as no longer valid when the underlying data changes to facilitate that cached data has a lifetime  which is the maximum time before the data will be deleted from the cache forcing recalculation  what is file aggregation  aggregation is when css and javascript files are merged together and compressed into a format that is much smaller than the original this allows for faster transmission and faster rendering on the other end what can i do to improve my site s performance  the following core software modules and mechanisms can improve your site s performance internal page cache module caches pages requested by users who are not logged in anonymous users do not use if your site needs to send different output to different anonymous users internal dynamic page cache module caches data for both authenticated and anonymous users with noncacheable data in the page converted to placeholders and calculated when the page is requested big pipe module changes the way pages are sent to users so that cacheable parts are sent out first with placeholders and the uncacheable or personalized parts of the page are streamed afterwards this allows the browser to render the bulk of the page quickly and fill in the details later performance page settings in the manage administrative menu if you navigate to configuration   development   performance  you will find a setting for the maximum cache lifetime as well as the ability to turn on css and javascript file aggregation additional resources online documentation for the internal page cache module online documentation for the internal dynamic page cache module online documentation for the bigpipe module ',	1723096663),
(19,	'en',	'help_search',	' making your site secure what are security updates  any software occasionally has bugs and sometimes these bugs have security implications when security bugs are fixed in the core software modules or themes that your site uses they are released in a security update  you will need to apply security updates in order to keep your site secure what are security advisories  a security advisory is a public announcement about a reported security problem in the core software contributed projects with a shield icon and stable releases for this project are covered by the security advisory policy on their project page are also covered by drupal s security advisory policy security advisories are managed by the drupal security team  security tasks keeping track of updates updating the core software and updating contributed modules and or themes are all part of keeping your site secure see the related topics listed below for specific tasks additional resources security and maintenance drupal user guide  security advisory process and permissions policy ',	1723096663),
(20,	'en',	'help_search',	' using inline quick settings editing goal edit settings in place what is quick editing  the core settings tray module provides the ability to quickly edit settings inline it requires the core contextual links module in order to expose the links that let you edit in place who can edit settings in place  in order to follow these steps to edit settings in place the core settings tray module must be installed also either the core toolbar module or a contributed replacement must be installed you will need to have use contextual links permission as well as permission to edit the particular content or settings steps find and visit a page on your site that has the settings that you would like to edit click the contextual links edit button on the toolbar in most themes it looks like a pencil contextual edit links with the same icon will appear all over your page find the contextual link for the part of the page you want to edit for example if you want to edit the settings for a block the link should be in the topright corner of the block or topleft for righttoleft languages click the link to open the contextual links menu and click quick edit  an editing form for the settings should appear on the page make your edits and submit the form  ',	1723096663),
(21,	'en',	'help_search',	' tracking the content of your website tracking overview the core history module tracks how recently users have viewed content items and provides a views field and filter that can be used to show users content that they haven t yet seen if you have one or more tracking modules installed on your site see the related topics listed below for specific tasks  ',	1723096663),
(22,	'en',	'help_search',	' working with languages and translations what text can be translated in your site  there are three types of text that can be translated content blocks content items etc can be written in english or another language and can be translated into additional languages see managing content structure to learn more about content many configuration items also include text that can be translated default configuration provided by your site s software is provided in english you can also download communityprovided translations see managing and deploying configuration to learn more about configuration user interface text that is provided by the core software your install profile themes and modules is provided in english but can be translated into other languages you can also download translations that communitymembers have provided working with languages overview the core language module lets you add new languages to your site provides the language switcher block and provides the ability to configure block visibility by language the block and block visibility settings are only available if you have multiple languages configured the core content translation configuration translation and interface translation modules let you translate content configuration and the builtin user interface respectively the core update manager module manages automatic downloads of communityprovided translations of default configuration and userinterface text see the related topics listed below for specific tasks  ',	1723096663),
(23,	'en',	'help_search',	' accessibility of the administrative interface overview of accessibility the core administrative interface has builtin compliance with many accessibility standards so that most pages are accessible to most users in their default state however certain pages become more accessible to some users through the use of a nondefault or improved interface these interfaces include disabling draganddrop functionality the default draganddrop user interface for ordering tables in the administrative interface presents a challenge for some users including keyboardonly users and users of screen readers and other assistive technology the draganddrop interface can be disabled in a table by clicking a link labeled show row weights above the table the replacement interface allows users to order the table by choosing numerical weights with increasing numbers instead of dragging table rows enabling inline form errors errors that occur when you submit a form such as not filling in a required field are sometimes difficult for users to understand and locate in order to make these errors easier to find the best practice is to put a summary of the errors at the top of the form page to make them easier to understand the best practice is to display error messages with the form fields they are related to both of these practices are implemented by the core inline form errors module  ',	1723096663),
(24,	'en',	'help_search',	' using the administrative interface what administrative interface components are available  the following administrative interface components are provided by the core software and its modules some contributed modules offer additional functionality accessibility features to enable all users to perform administrative tasks see accessibility of the administrative interface for more information a menu system which you can navigate to find pages for administrative tasks the core toolbar module displays this menu on the top or left side of the page right side in righttoleft languages there are also contributed module replacements for the core toolbar module with additional features such as the admin toolbar module  the core shortcuts module enhances the toolbar with a configurable list of links to commonlyused tasks if you install the core contextual links module nonadministrative pages will contain links leading to related administrative tasks inplace or quick editing inplace editing of configuration is provided by the core settings tray module see using inline quick settings editing for more information the core help module displays help topics and provides a help block that can be placed on administrative pages to provide an overview of their functionality what are the sections of the administrative menu  the administrative menu which you can navigate by visiting  admin on your site or by using an administrative toolbar has the following sections some may not be available depending on which modules are currently installed on your site and your permissions  content  find manage and create new pages manage comments and files structure  place and edit blocks set up content types and fields configure menus administer taxonomy and configure some contributed modules appearance  switch between themes install themes and update existing themes extend  update install and uninstall modules configuration  configure the settings for various site functionality including some contributed modules people  manage user accounts and permissions reports  display information about site security necessary updates and site activity help  get help on using the administrative interface administrative interface overview install the core modules mentioned above to use the corresponding aspect of the administrative interface see the related topics listed below for more details on some aspects of the administrative interface  ',	1723096663),
(25,	'en',	'help_search',	' enabling web services what is a web service  a web service allows your site to provide its content and data to other web sites and applications typically the data is transported via http in a serialized machinereadable format what is serialization  serialization is the process of converting complex data structures into text strings so that they can be exchanged and stored the reverse process is called deserialization  json and xml are the two mostcommonlyused data serialization formats for web services what is http basic authentication  http basic authentication is a method for authenticating requests by sending a user name and password along with the request what modules provide web services  the following core software modules provide web services json api module exposes entities to other applications using a fully compliant implementation of the json api specification  see managing content structure for more information on content entities and fields restful web services module exposes entities and other resources to other applications using a rest implementation data is exchanged using a serialization format such as json and transferred using an authentication method such as http basic authentication serialization module provides a framework for adding specific serialization formats for other modules to use http basic authentication module provides a way for web services to be authenticated using http basic authentication against site user accounts there are also contributed modules that provide web services additional resources online documentation for the restful web services module online documentation for the json api module comparison of the restful web services and json api modules ',	1723096663),
(26,	'en',	'help_search',	' configuring help search goal set up your site so that users can search for help steps in the manage administrative menu navigate to extend  verify that the search help and block modules are installed or install them if they are not already installed in the manage administrative menu navigate to configuration   search and metadata   search pages  verify that a help search page is listed in the search pages section if not add a new page of type help  check the indexing status of the help search page if it is not fully indexed see running and configuring cron about how to run cron until indexing is complete in the future you can click rebuild search index on this page or clearing the site cache in order to force help topic text to be reindexed for searching this should be done whenever a module theme language or string translation is updated in the manage administrative menu navigate to structure   block layout  click the link for your administrative theme such as the core claro theme near the top of the page and verify that there is already a search block for help located in the help region if not follow the steps in the related topic to place the search form block in the help region when configuring the block choose help as the search page and in the pages tab under visibility  enter  admin help to make the search form only visible on the main help page in the manage administrative menu navigate to help  verify that the search block is visible and try a search  ',	1723096663),
(27,	'en',	'help_search',	' working with help topics what is a help topic  a help topic describes a concept or steps to accomplish a task related to a feature provided by one or more modules or themes if the core search module is enabled these topics are also searchable where are help topics listed  the toplevel help topics are listed at help links to other topics including nontoplevel help topics can be found under the related heading when viewing a topic page how are help topics provided  modules and themes can provide help topics as twigfilebased plugins in a project subdirectory called helptopics  plugin metadata is provided in yaml front matter within each twig file pluginbased help topics provided by modules and themes will automatically be updated when a module or theme is updated use the plugins in core modules help helptopics as a guide when writing and formatting a help topic plugin for your theme or module how are help topics translated  the title and body text of help topics provided by contributed modules and themes are translatable using user interface translation provided by interface translation module topics provided by custom modules and themes are also translatable if they have been viewed at least once in a nonenglish language which triggers putting their translatable text into the translation database how can users search for help topics  to enable users to search help including help topics you will need to install the core search module configure a search page and add a search block to the help page or another administrative page a search page is provided automatically and if you use the core claro administrative theme a help search block is shown on the main help page then users with search permissions and permission to view help will be able to search help see the related topic configuring help search for stepbystep instructions additional resources help topics standards ',	1723096663),
(28,	'en',	'help_search',	' configuring search pages goal configure one or more search pages steps in the manage administrative menu navigate to configuration   search and metadata   search pages  scroll down to the search pages section you will see a list of the alreadyconfigured search pages on your site to configure an existing search page click edit  or to add a new search page select the search page type and click add search page  enter the desired label name and url path for the search page for content search pages select the desired level of influence in ranking search results of the available content ranking factors click save  you will be returned to the search pages page verify that the correct search page is listed as default in the status column if not click set as default in the operations list for the correct search page optionally disable or delete any search pages that you do not want to have available on the site disabling is temporary while deleting is permanent follow the steps in managing the search index to make sure that the search index is updated  ',	1723096663),
(29,	'en',	'help_search',	' managing the search index goal manage the search index and make sure that the site is fully indexed for searching what is the search index  the content and help search types provided by the core software preindex their content and store the results in several database tables that are collectively called the search index  the process of indexing renders the content and breaks it up into words which can then be matched more efficiently with keyword queries when users perform searches search indexing happens during cron runs see running and configuring cron for more information about cron steps in the manage administrative menu navigate to configuration   search and metadata   search pages  under indexing throttle  select the number of items to index per cron run  a smaller number will make cron faster and reduce the possibility of timeout a larger number will make sure more of your site is indexed in fewer cron runs under default indexing settings  enter the desired minimum word length to index  words smaller than this length will be dropped from both keywords when searching and content when indexing if your site uses chinese japanese or korean languages optionally check simple cjk handling under default indexing settings to provide some support for these languages click save configuration  and you should be returned to the search pages page click reindex site if you have changed the indexing configuration or later on if you believe that the search index has been corrupted follow the steps in running and configuring cron to make sure a cron task has been configured after waiting for cron to run several times verify that the content has been fully indexed for searching the overall status is listed under indexing progress  and the status for each search page is shown in the indexing progress column of the search pages section  ',	1723096663),
(30,	'en',	'help_search',	' configuring site search what are search pages  the core search module organizes site search into pages  each page allows users to search a particular type of content with a particular configuration the configuration includes specifying a url that starts with search  a name for the page and additional options for some search page types when users visit the main search page see search  they will see the configured search pages that they have access to each search page has a search form on it and the page will display search results after the user enters keywords into the form and clicks the search button what modules provide site search  the core search module provides the ability to configure search pages search page types are provided by both core and contributed modules the core modules that provide search page types are the node module for searching content pages the user module for searching user profiles the help module for searching help topics as an alternative to the core search module s system of search pages you can use contributed modules to provide site search for example the apache solr and sphinx contributed modules use thirdparty technology to provide site search what are the limitations of the core search module  there are two main limitations of the core search module first it is not appropriate for very large sites if you have a large site look into other search technologies like apache solr second the node search page type only supports exact keyword matching which is not the behavior that most users will expect you can improve this by installing a languagespecific stemming module for your language such as porter stemmer for american english which makes it so that for example a search for the word walk would match pages containing the words walk walking and walked what are the search permissions  users with use search permission can use the search form block and search page this permission is required for any search configured in the core search module in addition to use search   view user information permission is needed for searching users in addition to use search   view published content permission is needed for searching content users with use advanced search permission can use more complex search filtering when performing content searches configuring site search overview in order to configure site search using the core search module you will need to configure one or more search pages you will also need to verify or alter permissions so that the desired user roles can search the site see managing user accounts and site visitors for more information about roles and permissions for content search you will also need to make sure that the search index is configured and that the site is fully indexed finally you may wish to place the search form block on pages of your site or add the search page to a navigation menu to give users easy access to search see the related topics listed below for specific tasks additional resources online documentation for the search module ',	1723096663),
(31,	'en',	'help_search',	' clearing the site cache goal clear the data in the site cache what is the cache  some of the calculations that are done when your site loads a page take a long time to run to save time when these calculations would need to be done again their results can be cached in your site s database there are internal mechanisms to clear cached data when the conditions or assumptions that went into the calculation have changed but you can also clear cached data manually when your site is misbehaving a good first step is to clear the cache and see if the problem goes away steps in the manage administrative menu navigate to configuration   development   performance  click clear all caches  your site s cached data will be cleared additional resources concept cache drupal user guide  ',	1723096663),
(32,	'en',	'help_search',	' changing basic site settings goal configure the basic settings of your site including the site name slogan main email address default time zone default country and the date formats to use steps in the manage administrative menu navigate to configuration   system   basic site settings  enter the site name slogan and main email address for your site click save configuration  you should see a message indicating that the settings were saved in the manage administrative menu navigate to configuration   region and language   regional settings  select the default country and default time zone for your site click save configuration  you should see a message indicating that the settings were saved in the manage administrative menu navigate to configuration   region and language   date and time formats  look at the patterns for the default long medium and short date formats if any of them does not match the date format you want to use on your site click edit in that row to edit the format adjust the format string until the displayed format matches what you want date format strings are composed of php date format codes click save format  you should see a message indicating that the format was saved repeat the previous three steps for any other date formats that need to be changed additional resources php date format codes reference ',	1723096663),
(33,	'en',	'help_search',	' configuring error responses including 403404 pages goal set up your site to respond appropriately to site errors including 403 and 404 page responses what are 403 and 404 responses  when a user visits a web page the web server sends a response code in addition to the page content a normal nonerror response has code 200 if the page does not exist on the site the response code is 404 if the page exists but the user is not authorized to visit the page the response code is 403 the core software provides default responses for both 403 and 404 codes but if you prefer you can create your own pages for each what other errors can occur  under some situations your site can generate error messages these can be due to user errors such as entering invalid values in a form or incorrect configuration php runtime errors or software bugs some errors may result in a white screen of death  a totally blank web page response less drastic errors will generate error messages you can configure what happens when an error message is generated steps if desired create pages to use for 403 and 404 responses note the urls for these pages in the manage administrative menu navigate to configuration   system   basic site settings  in the error pages section enter the url for your 403404 pages starting after the site home page url for example if your site url is https examplecom and your 404 page is https examplecom notfound  you would enter  notfound  click save configuration  you should see a message indicating that the settings were saved in the manage administrative menu navigate to configuration   development   logging and errors  for a production site select none under error messages to display  for a site that is in development select one of the other options so that you are more aware of the errors the site is generating click save configuration  you should see a message indicating that the settings were saved  ',	1723096663),
(34,	'en',	'help_search',	' enabling and disabling maintenance mode goal put your site in maintenance mode to perform maintenance operations and then return to normal mode when finished what is maintenance mode  when your site is in maintenance mode most site visitors will see a simple maintenance mode message page rather than being able to use the full functionality of the site users with use the site in maintenance mode permission who are already logged in will be able to use the full site and the log in page at  user will also be accessible to anyone steps in the manage administrative menu navigate to configuration   development   maintenance mode  check put site into maintenance mode  optionally change the message to display when in maintenance mode  and click save configuration  your site will be in maintenance mode perform your maintenance operations in the manage administrative menu navigate to configuration   development   maintenance mode  uncheck put site into maintenance mode and click save configuration  your site will be back in normal operation mode clear the site cache see clearing the site cache for instructions  ',	1723096663),
(35,	'en',	'help_search',	' installing a module goal install a core module or a contributed module that has already been downloaded steps in the manage administrative menu navigate to extend  enter a word from the module name or description into the filter box to make the list of modules smaller locate the module you want to install check the box next to the name of the module you want to install you can also check more than one box to install multiple modules at the same time if the checkbox is disabled for the module you are trying to install expand the information to see why you may need to download an additional module that your module requires click install at the bottom of the page if you chose to install a module with dependencies that were not already installed or if you chose an experimental module confirm your choice on the next page wait for the module or modules to be installed you should be returned to the extend page with a message saying the module or modules were installed  ',	1723096663),
(36,	'en',	'help_search',	' uninstalling a module goal uninstall a module your site should be in maintenance mode when you uninstall modules see enabling and disabling maintenance mode for details steps in the manage administrative menu navigate to extend   uninstall  enter a word from the module name or description into the filter box to make the list of modules smaller locate the module you want to uninstall in the description column see if there are reasons that this module cannot be uninstalled for example you may have created content using this module which you would need to delete first or there may be another module installed that requires this module to be installed you would need to uninstall the other module first if there are no reasons listed the module can be uninstalled check the box in the uninstall column next to the module s name click uninstall at the bottom of the page verify the list of modules to be uninstalled and configuration to be deleted on the confirmation page and click uninstall  wait for the module to be uninstalled you should be returned to the uninstall page with a message saying the module was uninstalled  ',	1723096663),
(37,	'en',	'help_search',	' running reports on your site goal run reports to learn about the status and health of your site steps in the manage administrative menu navigate to reports   status report to see a report that summarizes the health and status of your site if there are any warnings or errors you will need to fix them take note of any upcoming highly critical security releases that may impact your site if you have the core database logging module installed in the manage administrative menu navigate to reports   recent log messages to see a report of the error and informational messages your site has generated you can filter the report by severity to see only the most critical messages if desired if you have the core update manager module installed in the manage administrative menu navigate to reports   available updates to see a report of the updates that are available for your site software if last checked is far in the past click check manually to update the report scan the report if the core software or any modules or themes have security updates available you should update them as soon as possible additional resources security and maintenance drupal user guide   which includes information on how to update your site s core software modules and themes  ',	1723096663),
(38,	'en',	'help_search',	' installing a theme and setting default themes goal install a core theme or a contributed theme that has already been downloaded choose the default themes to use for the site and for administrative pages steps in the manage administrative menu navigate to appearance  locate the themes that you want to use as the site default theme and for administrative pages for each of these themes if the theme is in the uninstalled themes section click the install link to install the theme wait for the theme to be installed translations might be downloaded you should be returned to the appearance page locate the theme that you want to be your default theme which should now be in the installed themes section if it is not already labeled as the default theme  click the set as default link at the bottom of the page select the administration theme that you want to use on administrative pages click save configuration if you selected a new theme if you changed the default theme for your site visit the site home page or another page on the nonadministration part of your site and verify that the site is using the new theme if you changed the administration theme verify that the new theme is used on administrative pages  ',	1723096663),
(39,	'en',	'help_search',	' uninstalling an unused theme goal uninstall a theme that was previously installed but is no longer being used on the site steps in the manage administrative menu navigate to appearance  locate the theme that you want to uninstall in the installed themes section click the uninstall link to uninstall the theme if there is not an uninstall link the theme cannot be uninstalled because it is either being used as the site default theme being used as the administration theme  or is the base theme for another installed theme  ',	1723096663),
(40,	'en',	'help_search',	' creating a user account goal create a new user account steps in the manage administrative menu navigate to people  click add user  enter the email address   username  and password  twice for the new user verify that the roles checked for the new user are correct if you want the new user to receive an email message notifying them of the new account check notify user of new account  optionally change other settings on the form click create new account  you will be left on the add user page repeat these steps if you have more user accounts to create  ',	1723096663),
(41,	'en',	'help_search',	' adding a new role goal create a new role steps in the manage administrative menu navigate to people   roles  click add role  enter the desired role name  if desired click edit to change the machine name for the role click save  you should be returned to the roles page and your new role should be in the role list  ',	1723096663),
(42,	'en',	'help_search',	' managing user accounts and site visitors what is a user  a user is anyone accessing or viewing your site anonymous users are users who are not logged in and authenticated users are users who are logged in what is a role  roles are used to group and classify users each user can be assigned one or more roles there are also special roles for all anonymous and all authenticated users what is a permission  granting a permission to a role allows users who have been assigned that role to perform an action on the site such as viewing content editing or creating a particular type of content administering settings for a particular module or using a particular function of the site such as search  overview of managing user accounts and visitors the core user module allows users to register log in and log out and administrators to manage user roles and permissions the core ban module allows administrators to ban certain ip addresses from accessing the site depending on which modules you have installed on your site the related topics below will help you with tasks related to managing user accounts and visitors  ',	1723096663),
(43,	'en',	'help_search',	' modifying the permissions for a role goal modify the permissions for an existing role steps in the manage administrative menu navigate to people   permissions  review the permissions for the role paying particular attention to the permissions marked with warning give to trusted roles only this permission has security implications uncheck permissions that this role should not have in the row of the permission and the column of the role check permissions that this role should have click save permissions   ',	1723096663),
(44,	'en',	'help_search',	' configuring how user accounts are created and deleted goal configure settings related to how user accounts are created and deleted what are the settings related to user account creation and deletion  you can make it possible for new users to register themselves for accounts with or without email verification or administrative approval or you can make it so only administrators with administer users permission can register new users you can configure what happens to content that a user created if their account is canceled  deleted you can edit the email messages that are sent to users when their accounts are pending approved created blocked or canceled or when they request a password reset what are variables in email message text  variables are short text strings enclosed in square brackets that you can insert into configured email message text when an individual message is generated data from your site is substituted for the variables some commonlyused variables are site name the name of your website site url the url of your website site loginurl the url where users can log in to your site user displayname the user s displayed name user accountname the user s account name user mail the user s email alias user onetimeloginurl an expiring url that a user can use to log in once if they need to reset their password steps in the manage administrative menu navigate to configuration   people   account settings  select the method you want to use for creating user accounts and check or uncheck the box that requires email verification to match the settings you want for your site select the desired option for what happens to content that a user created if their account is canceled optionally edit the text of email messages related to user accounts verify that the other settings are correct click save configuration  you should see a message indicating that the settings were saved  ',	1723096663),
(45,	'en',	'help_search',	' modifying or deleting a user account goal update or delete an existing user account steps in the manage administrative menu navigate to people  enter all or part of the user name or email address of the user account you want to update or delete and click filter  a short list of user accounts including the account of interest should be shown in the table if not modify the filter text until you can find the account of interest click edit in the operations area of the account of interest to delete the user account scroll to the bottom and click cancel account  select what you want to happen to the user s content on the next screen and click cancel account  to update the user account enter new values in the form and click save   ',	1723096663),
(46,	'en',	'help_search',	' viewing drupal announcements what are drupal announcements  a feed of announcements about the drupal project and drupal association programs the purpose of this feed is to provide a channel for outreach directly to drupal site owners this content must be highly relevant to site owners interests serve the strategic goals of the project and or promote the sustainability of the project and the drupal association the module sources its content from a json feed generated from here  the governance policy for the content is documented here  how can i see the announcements in my site  if you have the toolbar module enabled you will see a direct link to them in the toolbar if the toolbar module is not enabled the content can always be accessed in the announcements page who can see the announcements  users with the view official announcements related to drupal permission can view drupal announcements additional resources announcement module overview ',	1723096663),
(47,	'en',	'help_search',	' configuring a previouslyplaced block goal configure the settings of a block that was previously placed in a region of a theme steps in the manage administrative menu navigate to structure   block layout  click the name of the theme that contains the block optionally click demonstrate block regions to see the regions of the theme if you only want to change the region where a block is located or the ordering of blocks within a region drag blocks to their desired positions and click save blocks  if you want to change additional settings find the region where the block you want to update is currently located and click configure in the line of the block description edit the block s settings the available settings vary depending on the module that provides the block but for all blocks you can change  block title  the heading for the block on your site for some blocks you will need to check the override title checkbox in order to enter a title display title  check the box if you want the title displayed visibility  add conditions for when the block should be displayed region  change the theme region the block is displayed in click save block   ',	1723096663),
(48,	'en',	'help_search',	' managing blocks what are blocks  blocks are boxes of content rendered into an area or region of a web page of your site blocks are placed and configured specifically for each theme what are content blocks  content blocks are blocks whose content you can edit you can define one or more block types  and attach fields to each block type content blocks can be placed just like blocks provided by other modules what is the block description  the block description is an identification name for a block which is shown in the administrative interface it is not displayed on the site what is the block title  the block title is the heading that is optionally shown to site visitors when the block is placed in a region overview for managing blocks the block module allows you to place blocks in regions of your installed themes and configure block settings the block content module allows you to manage block types and content blocks see the related topics listed below for specific tasks additional resources blocks drupal user guide  ',	1723096663),
(49,	'en',	'help_search',	' placing a block goal place a block into a theme s region steps in the manage administrative menu navigate to structure  block layout click the name of the theme that you want to place the block in optionally click demonstrate block regions to see the regions of the theme find the region where you want the block and click place block in that region a modal dialog will pop up find the block you want to place and click place block  a configure block modal dialog will pop up configure the block and click save block  see configuring a previouslyplaced block for configuration details  ',	1723096663),
(50,	'en',	'help_search',	' managing text filters and text formats goal configure text formats on the site what are text filters and text formats  a text filter is a processing step that can be applied to text either to transform it in some way such as converting urls in the text into html links or to defend against potentiallydangerous input from site users a text format is an ordered sequence of text filters text filters are provided by modules text formats are managed by the core filter module text fields that have formatted in the field type name such as text formatted   use text formats users choose the text format when editing the field text when the field text is shown on the site it is processed by the chosen text format administrators can configure text formats and assign permissions for who can use each format if the core text editor module is enabled administrators can also associate visual editors with text formats what text filters are available  some of the more commonly used text filters are limit allowed html tags and correct faulty html limits which html tags can be used useful both for site security and enforcing site design convert line breaks into html line breaks in html source are displayed as horizontal spaces this filter converts line breaks into html paragraph and line break tags convert urls into links takes plain urls in text and turns them into html links restrict images to this site for text formats that allow html image tags restricts images to urls within this site steps in the manage administrative menu navigate to configuration   content authoring   text formats and editors  if you do not have the core text editor module installed the menu link and page title will instead be text formats  click configure to configure an existing text format or  add text format to create a new text format enter the desired name for the text format check the roles that can use this text format some html tags allow users to embed malicious links or scripts in text to ensure security anonymous and untrusted users should only have access to text formats that restrict them to either plain text or a safe set of html tags improper text format configuration is a security risk if the core text editor module is installed see the related topic to connect a text editor to this text format under enabled filters  check the text filters that you want to use under filter processing order  drag the filters to the correct order choose the order carefully for example if you have a filter that results in a particular html tag being added to the text that should run after a filter that restricts html tags to avoid deleting the new tags the first filter added under filter settings  verify and adjust the settings for each active filter that has configuration options click save configuration  which will return you to the text formats and editors page repeat these steps if you have additional text formats to configure  ',	1723096663),
(51,	'en',	'help_search',	' creating a content block goal create a content block which can later be placed on the site steps in the manage administrative menu navigate to content  open the content blocks tab click add content block  if you have more than one block type defined on your site click the name of the type you want to create enter a description of your block to be shown to administrators and the body text for your block click save   ',	1723096663),
(52,	'en',	'help_search',	' defining a block type goal define a block type and its fields steps in the manage administrative menu navigate to structure   block types  click add block type  enter a label for this block type shown in the administrative interface optionally edit the automaticallygenerated machine name or the description click save  you will be returned to the block types page click manage fields in the row of your new block type and add the desired fields to your block type optionally click manage form display or manage display to change the editing form or field display for your block type  ',	1723096663),
(53,	'en',	'help_search',	' creating a content item goal create and publish a content item see managing content for more about content types and content items who can create content  users with the access the content overview page permission can visit the content page as described in this topic each content type has its own create permissions for example to create content of type article a user would need the article create new content permission in addition users with the bypass content access control or administer content permission can create content items of all types some contributed modules change the permission structure for creating content steps in the manage administrative menu navigate to content  click add content  if there is more than one content type defined on your site that you have permission to create click the name of the type of content you want to create on the content edit form enter the title of your content which will show as the page title when the content item is displayed on a page and also as the label for the content item in administration screens fill in the other fields shown on the edit form for this specific content type leave the published field checked to publish the content immediately or uncheck it to make it unpublished unpublished content is generally not shown to nonadministrative site users optionally click preview to preview the content click save  you will see the content displayed on a page additional resources basic page management drupal user guide  creating a content item drupal user guide  ',	1723096663),
(54,	'en',	'help_search',	' creating a content type goal create a new content type see managing content for more about content types who can create a content type  users with the administer content types permission typically administrators can create new content types steps in the manage administrative menu navigate to structure   content types  click add content type in the name field enter a name for the content type which is how it will be listed in the administrative interface optionally enter a description for the content type you may also want to adjust some of the settings in the vertical tabs section of the edit page click save and manage fields  your content type will be created and assuming you have the core field ui module installed you will be taken to the manage fields page for the content type if you do not have the core field ui module installed the button will say save instead if you have the core field ui module installed follow the steps in the related topics to add fields to the new content type set up the editing form and configure the display additional resources adding a content type drupal user guide  setting up content structure drupal user guide  ',	1723096663),
(55,	'en',	'help_search',	' editing a content item goal find a content item and edit it or update a group of content items in bulk see managing content for more about content types and content items who can find and edit content  users with the access the content overview page permission can use the content page to find content each content type has its own edit permissions for example to edit content of type article a user would need the article edit own content permission to edit an article they created or the article edit any content permission to edit an article someone else created in addition users with the bypass content access control or administer content permission can edit content items of all types some contributed modules change the permission structure for editing content steps in the manage administrative menu navigate to content  optionally use filters to reduce the list of content items shown  title  key word s from the title content type published status language if you enter or select filter values click filter to apply the filters optionally sort the list by clicking a column header click again to reverse the order to edit the title or other field values for one content item click edit in the row of the content item update the values and click save  a few types of edits can be done in bulk to multiple content items for example to publish several unpublished content items check the boxes in the left column right column in righttoleft languages to select the desired content items for action  select the publish content action click apply to selected items to make the change the other actions under action work in a similar manner additional resources basic page management drupal user guide  editing a content item drupal user guide  ',	1723096663),
(56,	'en',	'help_search',	' managing content what is a content item  a content item is a type of content entity for pagelevel content which can have fields that store text html markup images attached files and other data see managing content structure for more about content entities and fields what is a content type  content items are divided into content types  which are the entity subtypes for the content item entity type each content type has its own fields and display settings for example you might set up content types for pages articles recipes events and blog entries on your web site overview of managing content the core node module allows you to define content types and add and edit content items the core field ui module allows you to attach fields to each content type and manage the edit form and display for each content type see the related topics listed below for specific tasks many other core and contributed modules and installation profiles provide predefined content types modify the permission structure for content items and provide other functionality  ',	1723096663),
(57,	'en',	'help_search',	' managing height width and resolution breakpoints what are breakpoints  breakpoints are the point at which your site s content will respond to provide the user with the best possible layout to consume the information a breakpoint separates the height or width of viewports screens printers and other media output types into steps for instance a width breakpoint of 40em creates two steps one for widths up to 40em and one for widths above 40em breakpoints can be used to define when layouts should shift from one form to another when images should be resized and other changes that need to respond to changes in viewport height or width what are media queries  media queries are a formal way to encode breakpoints for instance a width breakpoint at 40em would be written as the media query minwidth 40em breakpoints are really just media queries with some additional metadata such as a name and multiplier information what are resolution multipliers  resolution multipliers are a measure of the viewport s device resolution defined to be the ratio between the physical pixel size of the active device and the deviceindependent pixel size the breakpoint module defines multipliers of 1 15 and 2 when defining breakpoints modules and themes can define which multipliers apply to each breakpoint what is a breakpoint group  breakpoints can be organized into groups modules and themes should use groups to separate out breakpoints that are meant to be used for different purposes such as breakpoints for layouts or breakpoints for image sizing managing breakpoints and breakpoint groups overview the breakpoint module allows you to define breakpoints and breakpoint groups in yaml files modules and themes can use the api provided by the breakpoint module to define breakpoints and breakpoint groups and to assign resolution multipliers to breakpoints additional resources working with breakpoints in drupal w3c standards for media queries ',	1723096663),
(58,	'en',	'help_search',	' connecting text editors to text formats goal configure a text format so that when a user is editing text and selects this text format a text editor installed on your site is shown configure the text editor such as choosing which buttons and functions are available see managing text filters and text formats for more about text formats what is a text editor  a text editor is software typically a javascript library that provides buttons and other command mechanisms to make editing html text easier some editors are called visual or wysiwyg what you see is what you get  editors these editors hide the details of html from the user and instead show formatted output on the screen the core text editor module provides a framework for deploying text editors on your site the core ckeditor 5 module provides ckeditor 5 which is a widelyused javascript text editor that creates clean and valid html the module also enforces the html tag restrictions in the associated text format various contributed modules provide other editors to install a new editor besides installing the module you may need to download the editor library from a thirdparty site steps in the manage administrative menu navigate to configuration   content authoring   text formats and editors  the text editor column in the table shows the text editor that is currently connected to each text format if any follow the steps on managing text filters and text formats to add a new text format or configure an existing text format when you reach the step about text editors return to this topic select ckeditor 5 as the text editor  or another text editor that you have installed the rest of these steps assume you selected ckeditor 5  under toolbar configuration  drag buttons between available buttons and active toolbar  only buttons in active toolbar will be shown to the user focusing or hovering over a button will display a tooltip explaining what the button does drag buttons within active toolbar to the desired order and group buttons by dragging them between group identifiers drag a new group identifier to the toolbar to add additional groups if you add buttons that require configuration the ckeditor 5 plugin settings section will be visible and provide their respective configuration forms return to managing text filters and text formats to complete the text format configuration and be sure to save the text format  ',	1723096663),
(64,	'en',	'help_search',	' using contextual links goal use contextual links to access administrative tasks without navigating the administrative menu what are contextual links  contextual links give users with the use contextual links permission quick access to administrative tasks related to areas of nonadministrative pages for example if a page on your site displays a block the block would have a contextual link that would allow users with permission to configure the block if the block contains a menu or a view it would also have a contextual link for editing the menu links or the view clicking a contextual link takes you to the related administrative page directly without needing to navigate through the administrative menu system steps make sure that the core contextual links module is installed and that you have a role with the use contextual links permission optionally make sure that a toolbar module is installed either the core toolbar module or a contributed module replacement visit a nonadministrative page on your site such as the home page locate a block or another area on the page that you want to edit or configure make the contextual links button visible by hovering your mouse over that area in the page in most themes this button looks like a pencil and is placed in the upper right corner of the page area upper left for righttoleft languages and hovering will also temporarily outline the affected area alternatively click the contextual links toggle button on the right end of the toolbar left end for righttoleft languages which will make all contextual link buttons on the page visible until it is clicked again while the contextual links button for the area of interest is visible click the button to display the list of links for that area click a link in the list to visit the corresponding administrative page complete your administrative task and save your settings or cancel the action you should be returned to the page you started from  ',	1723096663),
(65,	'en',	'help_search',	' adding a field to an entity subtype goal add a field to an entity subtype see managing content structure for an overview of entity types and subtypes as well as an overview of field types steps navigate to the page for managing the entity subtype you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to add the field to and click manage fields  click add field  in add a new field  select the type of field you want to add see managing content structure for an overview of field types the label field should now be visible enter a label for the field which is used as the field label for both content editing and content display click save and continue  on the next screen enter a value for allowed number of values  you can limit the field to one value per entity item a set number of values or set it to have unlimited values click save field settings  on the next screen optionally edit the settings for the field which vary depending on what field type you are creating for all fields you can edit the label   help text  text to be displayed below the field on the content editing page and required field  to make it so a value must be entered in order to save the content when editing you can also configure a default value for the field click save settings  you should be returned to the manage fields page with your new field in the list  ',	1723096663),
(66,	'en',	'help_search',	' configuring field display for an entity subtype goal configure the formatters used to display the fields of an entity subtype their order in the display and the formatter settings see managing content structure for background information steps navigate to the page for managing the entity type you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to configure the display of and click manage display in the operations list use the drag arrows to order the fields in your preferred order drag any fields that you do not wish to see in the display to the disabled section in the label column select the position for each field label in the display or  hidden  to hide a label you can also choose  visually hidden if you want the label s text to appear in the html page so that screen readers and search engines can read it but it will not be visible in the format column select the formatter for displaying each field after selecting the desired formatters click the settings gear in each row to change the settings for the formatter when you are done making changes click save  test the display for your entity subtype by viewing an entity if needed return to these steps to further refine the display  ',	1723096663),
(67,	'en',	'help_search',	' configuring the edit form for an entity subtype goal configure the widgets used to edit the fields of an entity subtype their order on the form and the widget settings see managing content structure for background information steps navigate to the page for managing the entity type you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to configure the editing form for and click manage form display in the operations list use the drag arrows to order the fields in your preferred order drag any fields that you do not wish to see on the editing form to the disabled section in the widget column select the widget for editing each field after selecting the desired widgets click the settings gear in each row to change the settings for the widget when you are done making changes click save  test the editing form for your entity subtype by editing or creating an entity if needed return to these steps to further refine the form  ',	1723096663),
(68,	'en',	'help_search',	' adding a reference field to an entity subtype goal add an entity reference field to an entity subtype see managing content structure for more information on entities and reference fields steps navigate to the page for managing the entity subtype you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure   content types  find the particular subtype that you want to add the field to and click manage fields  click add field  in add a new field  select the type of reference field you want to add the reference section of the select list shows the most common types of reference field choose other  if the entity type you want to reference is not listed the label field should now be visible enter a label for the field which is used as the field label for both content editing and content display click save and continue  on the next screen verify that the type of entity you want to reference is shown in type of item to reference  or select it if not enter a value for allowed number of values  you can limit the field to one value per entity item a set number of values or set it to have unlimited values click save field settings  on the next screen optionally edit the settings for label   help text  text to be displayed below the field on the content editing page and required field  to make it so a value must be entered in order to save the content when editing in the reference type section you will usually want to limit the entity subtypes that can be referenced for example if you are creating a content reference you can check one or two content type choices the choices will be easier for content editors to scan if you also choose a sort value normally the entity title or label field click save settings  you should be returned to the manage fields page with your new field in the list  ',	1723096663),
(69,	'en',	'help_search',	' tracking which content a user has visited what content visits are tracked  the core history module tracks when each loggedin user has most recently visited each content item page on the site this allows content to be marked as new or updated for each user meaning that it was newly created or has been updated since the last time they visited its page these records are kept for one month meaning that content older than one month is never marked as new or updated what options are available for using this tracking information  you can display the new updated status of content by creating or editing a view there is a has new content field for content views which displays the new updated marker there is also a has new content filter which limits the view to new and updated content  ',	1723096663),
(70,	'en',	'help_search',	' configuring taxonomy goal create a taxonomy vocabulary and add a reference field for that vocabulary to a content entity see managing taxonomy for information about taxonomy and managing content structure for more on content entities who can configure a taxonomy vocabulary  users with the administer vocabularies and terms permission can configure a vocabulary to add a field in the administrative interface the core field ui module must be installed and you will also need the administer fields permission for the entity you are adding the field to steps in the manage administrative menu navigate to structure   taxonomy  click add vocabulary  in the name field enter a name for the vocabulary for example ingredients which is how it will be shown in the administrative interface optionally add a description click save  your vocabulary will be created and you will see the page that lists all the terms in this vocabulary optionally click add term to add a term to the new vocabulary in the name field enter the term name for example butter click save  you will receive a confirmation about the term you created you may optionally continue to add more terms if you have the field ui module installed follow the instructions on the related adding a reference field to an entity subtype topic to add a taxonomy reference field to the entity type of your choice the settings page will allow you to choose the vocabulary that you created as the vocabulary to reference you may also want to configure the display and form display of the new field see related topics  additional resources setting up a taxonomy drupal user guide  ',	1723096663),
(71,	'en',	'help_search',	' managing taxonomy what is taxonomy  taxonomy is used to classify website content one common example of taxonomy is the tags used to classify or categorize posts in a blog website a cooking website could use an ingredients taxonomy to classify recipes individual taxonomy items are known as terms  the blog tags or recipe ingredients in these examples and a set of terms is known as a vocabulary  the set of all blog post tags or the set of all recipe ingredients in these examples technically taxonomy terms are an entity type and the entity subtypes are the vocabularies see managing content structure for more on content entities like other entities taxonomy terms can have fields attached for instance you could set up an image field to contain an icon for each term an individual vocabulary can organize its terms in a hierarchy or it could be flat for example blog tags normally have a flat structure while a recipe ingredients vocabulary could be hierarchical for example tomatoes could be a subterm of vegetables and under tomatoes you could have green and red tomatoes taxonomy terms are normally attached as reference fields to other content entities which is how you can use them to classify content when you set up a taxonomy reference field you can let users enter terms in two ways free tagging new terms can be created right on the content editing form fixed list of terms the list of terms is curated and managed outside the content editing form and users can only select from the existing list when editing content taxonomy reference fields can be added to any entity such as user accounts content blocks or regular content items if you use them to classify regular content items your site will automatically be set up with taxonomy listing pages for each term each of these pages lists all of the content items that are classified with that term overview of managing taxonomy the core taxonomy module allows you to create and edit taxonomy vocabularies and taxonomy terms the core field ui module provides a user interface for adding fields to entities including the taxonomy reference field and configuring field editing and display see the related topics listed below for specific tasks additional resources concept taxonomy drupal user guide  ',	1723096663),
(72,	'en',	'help_search',	' adding an image style goal add a new image style which can be used to process and display images see managing media for an overview of image styles steps in the manage administrative menu navigate to configuration   media  image styles click add image style  enter a descriptive image style name  and click create new style  under effect  choose an effect to apply and click add  configure the effect on the next page most effects require some additional configuration after they are added for example for the crop effect enter the width and height to crop the image to and choose the anchor point click add effect  repeat the previous two steps until all of the effects have been added drag to change the order of the effects then click save to save the new order the image style can now be used to format a field containing an image in your layouts or traditional field displays it can also be used as part of a responsive image style see related topics below for more information  ',	1723096663),
(73,	'en',	'help_search',	' managing content listings views  what is a view  a view is a listing of items on your site for example a block showing the most recent comments a page listing news items or a list of registered users the listings can be formatted in a table grid list calendar rss feed and other formats some output formats may require you to install additional contributed modules  what are the components of a view  when you first create a view you will specify what type of base data is being displayed in the view which cannot be changed after choosing a base data type you can edit the following components which allow you to specify which data to output in what order and in what format  displays  whether the output goes to a page block feed etc a single view can have multiple displays each with different settings format  the output style for each display such as content item grid table or html list fields  if the format allows the particular fields to display filter criteria  criteria to limit the data to output such as whether the content is published the type of content etc filters can be exposed to let users choose how to filter the data sort criteria  how to order the data sorting can also be exposed to users page settings   block settings  etc settings specific to the display type such as the url for a page display most display types support an access setting where you can choose a permission or role that a user must have in order to see the view header and footer  content to display at the top or bottom of the view display no results behavior  what to do if the filter criteria result in having no data to display pager  how many items to display and how to paginate if there are additional items to display advanced   contextual filters  like regular filters except the criteria come from the context  such as the current date page the view is displayed on etc advanced   relationships  additional data to pull in and display related in some way to the base data of the view such as data about the user who created the content item  advanced   exposed form  if you have exposed filters or sorts how to display the form to the user what are bulk operations  views using a table display format can include a bulk operations form which allows users with sufficient permission to select one or more items from the view and apply an administrative action to them the bulk actions available are specific to the base data type of the view for example a view of content items could support bulk publishing and unpublishing actions if you have the core actions ui module installed see the related topic configuring actions for more about actions managing views overview the core views module handles the display of views and the core views ui module allows you to create edit and delete views in the administrative interface see the related topics listed below for specific tasks if the views ui module is installed  additional resources creating listings with views drupal user guide  ',	1723096663),
(74,	'en',	'help_search',	' configure menu settings for a content type goal for an existing content type configure the available menus that will be shown as options on content editing screens links to content items of this type can be added to these menus during editing steps in the manage administrative menu navigate to structure  content types locate the content type you want to configure and click edit in the operations list under menu settings  check the menus that you want to be available when editing a content item of this type optionally select the default parent item  to put links to content items under a default location in the menu structure click save   ',	1723096663),
(75,	'en',	'help_search',	' adding a link to a menu goal add a link to a menu note that you can also add a link to a menu from the content edit page if menu settings have been configured for the content type steps in the manage administration menu navigate to structure  menus locate the desired menu and click add link in the operations list enter the menu link title to be displayed enter the link  one of the following an internal path such as  node add a full external url start typing the title of a content item and select it when the full title comes up  nolink  to display the menu link title as plain text without a link  front  to link to the front page of your site make sure that enabled is checked if not the menu link will not be displayed optionally enter a description  which will be displayed when a user hovers over the link optionally check show as expanded to automatically show the children of this link if any when this link is shown optionally select the parent link  if this menu link should be a child of another menu link click save  you will be returned to the add link page to add another link in the manage administration menu navigate to structure  menus locate the menu you just added a link to and click edit in the operations list verify that the order of links is correct if it is not drag menu links until the order is correct and click save   ',	1723096663),
(76,	'en',	'help_search',	' creating a menu goal create a new menu steps in the manage administration menu navigate structure  menus click add menu  enter the title for the menu which is used as the default block title if the menu is displayed as a block if desired also edit the machine name of the menu which is by default derived from the title enter an administrative summary which is displayed on the menus page if your site has more than one language choose the language for the menu click save  you will be on the menu editing page ready to add links to the menu if the core custom menu links module is installed see related topics for further tasks  ',	1723096663),
(77,	'en',	'help_search',	' reordering and disabling menu links goal disable menu links or change the order and hierarchy of menu links steps in the manage administration menu navigate to structure  menus click edit menu for the menu that you want to edit drag menu links into a new order or check uncheck enabled to enable or disable menu links click save to save your changes  ',	1723096663),
(78,	'en',	'help_search',	' creating a url alias for a content item goal give a content item page a human or seofriendly url alias you can follow similar steps to create an alias for a taxonomy term page see configuring aliases for urls for more about aliases who can create url aliases  users with the create and edit url aliases permission can create aliases to follow the steps in this topic you will also need permission to edit the content item steps locate and open the content edit form for the content item or create a new content item see related topics on creating and editing content under url alias on the edit form enter the desired alias for example aboutus make sure the alias starts with a character click save  verify that the page can be visited with the new alias for example https examplecom aboutus  additional resources creating a content item drupal user guide  ',	1723096663),
(79,	'en',	'help_search',	' editing a url alias goal change an existing url alias to correct the path or the alias value see configuring aliases for urls for more about aliases who can manage url aliases  users with the administer url aliases permission can edit aliases steps in the manage administration menu navigate to configuration   search and metadata   url aliases  a list of all the site s aliases will appear click edit in the dropdown button for the alias that you would like to change make the required changes and click save  you will be returned to the url alias list page note that you can also add new aliases from this page for any path on your site  ',	1723096663),
(80,	'en',	'help_search',	' configuring aliases for urls what is a url  url is the abbreviation for uniform resource locator which is the page s address on the web it is the name by which a browser identifies a page to display in the example visit us at examplecom   https examplecom would be the url for the home page of your website users use urls to locate content on the web what is a path  a path is the unique last part of the url for a specific function or piece of content for example for a page whose full url is https examplecom node 7  the path is node 7  here are some examples of paths you might find in your site node 7 path to a particular content item taxonomy term 6 path to a taxonomy term page user 3 path to a user profile page what is an alias  the core software allows you to provide more understandable urls for pages on your site which are called aliases  for example if you have an about us page with the path node 7  you can set up an alias of about so that your visitors will see it as https wwwexamplecom about  overview of configuring paths aliases and urls the core path module provides the url aliasing functionality the contributed pathauto module allows you to configure automaticallygenerated url aliases for content items and other pages see the related topics listed below for specific tasks additional resources concept paths aliases and urls drupal user guide  ',	1723096663),
(81,	'en',	'help_search',	' creating and using shortcut administrative links goal create view and use a set of shortcuts to access administrative pages what are shortcuts  shortcuts are quick links to administrative pages they are managed by the core shortcut module a site can have one or more shortcut sets  which can be shared by one or more users by default there is only one set shared by all users each set contains a limited number of shortcuts users need use shortcuts permission to view shortcuts  edit current shortcut set permission to add delete or edit the shortcuts in the set assigned to them and select any shortcut set permission to select a different shortcut set when editing their user profile there is also an administer shortcuts permission which allows an administrator to do any of these actions as well as select shortcut sets for other users steps make sure that the core shortcut module is installed and that you have a role with edit current shortcut set or administer shortcuts permission also make sure that a toolbar module is installed either the core toolbar module or a contributed module replacement navigate to an administrative page that you want in your shortcut list click the shortcut link to add the page to your shortcut list in the core claro administrative theme the link looks like a star and is displayed next to the page title however if the page is already in your shortcut set clicking the shortcut link will remove it from your shortcut set repeat until all the desired links have been added to your shortcut set click shortcuts in the toolbar to display your shortcuts and verify that the list is complete optionally click edit shortcuts at the right end of the shortcut list left end in righttoleft languages to remove links or change their order click any link in the shortcut bar to go directly to the administrative page  ',	1723096663),
(82,	'en',	'help_search',	' adding a new display to an existing view goal add a new display to an existing view this will allow you to display similar data to an existing view using similar settings in a new block page feed etc steps if you are not already editing your view in the manage administrative menu navigate to structure   views  find the view you want to edit and click its edit link under displays  click add  in the popup list click the link for the type of display you want to add the most common types are page and block  the new display will be added to your view and you will be editing that display optionally click the link next to display name and enter a new name to be shown for this display in the administrative interface follow the steps in editing an existing view display to edit the other settings for the display  ',	1723096663),
(83,	'en',	'help_search',	' adding a bulk operations form to a view goal add one or more existing actions as bulk operations to an existing tablestyle view if you have the core actions ui module installed see the related topic configuring actions for more information about actions who can edit views  the core views ui module will need to be installed and you will need administer views permission in order to edit a view steps in the manage administrative menu navigate to structure   views  a list of all views is shown find the view that you would like to edit and click edit from the dropdown button note that bulk operations work best in a view with a page display and a table format if there is not already an operations bulk form in the fields list for the view click add in the fields section to add it the exact name of the bulk form field will vary and may contain keywords like bulk update form element or operations not to be confused with operations links  which are applied to each item in a row if the bulk operations field already exists click the field name to edit its settings check the action s you want to make available in the selected actions list and click apply all displays   verify that the access settings for the view are at least as restrictive as the permissions necessary to perform the bulk operations people with permission to see the view but who don t have permission to do the bulk operations will experience problems click save  the action s will be available as bulk operations in the view  ',	1723096663),
(84,	'en',	'help_search',	' creating a new view goal create a new view to list content or other items on your site steps in the manage administrative menu navigate to structure   views  click add view  in the view name field enter a name for the view which is how it will be listed in the administrative interface in view settings   show  select the base data type to display in your view this cannot be changed later optionally select or enter filtering sorting and page block display settings these can be added or changed later click save and edit  your view will be created edit it following the steps in the related topics below  ',	1723096663),
(85,	'en',	'help_search',	' editing an existing view display goal edit an existing view display to modify what data is displayed or how it is displayed steps if you are not already editing your view in the manage administrative menu navigate to structure   views  find the view you want to edit and click its edit link under displays  click the display you want to edit find the section whose settings you want to change such as format or filter criteria  see managing content listings views for more information for sections containing lists such as fields and filter criteria  to modify or delete an existing item click the name of the item to add a new item click add in the dropdown list to change the order of items click rearrange in the dropdown list for sections containing individual settings such as title and format  there are often two links for each setting the first link shows the current value click that link to change the value if there is a second link called settings  click that link to change the settings details for example if your format is currently shown as unformatted list  click unformatted list to switch to using a grid or table format click settings next to your format type to change the settings for your chosen format when you have finished changing all the settings verify that the display is correct by clicking update preview  return to editing settings if necessary when you have verified the display click save  alternatively if you have made mistakes and want to discard your changes click cancel  additional resources creating listings with views drupal user guide  ',	1723096663),
(86,	'en',	'help_search',	' changing the layout for an entity goal configure an entity subtype to have its fields displayed using a layout see managing content structure for more on entities and fields  what are the parts of a layout  a layout consists of one or more sections  each section can have from one to four columns  you can place blocks including special blocks for the fields on the entity subtype in each column of each section see managing blocks for more on blocks  steps navigate to the page for managing the entity type you want to add the field to for example to add a field to a content type in the manage administrative menu navigate to structure  content types find the particular subtype that you want to create a layout for and click manage display in the operations list under layout options  check use layout builder  you can also check the box below to allow each entity item to have its layout individually customized if it is left unchecked the site will use the same layout for all items of this entity subtype click save  you will be returned to the manage display page but you will no longer see the table of fields of the classic display manager click manage layout to enter layout management view a default layout will be set up for you with a single onecolumn section containing the fields on your entity subtype to remove the default section and start from an empty layout find and click the remove button for the default section which looks like an x confirm by clicking remove in the popup dialog add new sections each with one to four columns to your layout for instance you might want a onecolumn section at the top a twocolumn section in the middle and then a onecolumn section at the bottom to add a section click add section and click the desired number of columns for multicolumn sections set the column width percentages and click add section in the popup dialog in each section click add block to add a block you will see a list of the blocks available on your site plus a section called content fields with a block for each field on your content item each block can be configured if desired with a title  and for content field blocks you can also configure the field formatter continue to add blocks to your sections until all the desired blocks and fields are displayed verify your layout you can check show content preview to show a preview of what your layout will look like or uncheck it to see the names of the fields and blocks in each section if needed reorder the blocks by dragging them to new locations if you hover over a block a contextual menu will appear that will let you change the configuration of the block remove the block or move blocks within the section using a more compact interface when you are satisfied with your layout click save layout  additional resources creating layout defaults building layouts using the layout builder ui ',	1723096663),
(87,	'en',	'help_search',	' adding a new media type goal add a new media type that can be referenced in media reference fields media types are a content entity type see managing media for an overview of media items and media types and managing content structure for more information on content entities and fields steps in the manage administrative menu navigate to structure  media types if there is not already a media type for the type of media you want to use on your site click add media type  enter a name and description for your media type and select the media source  for most media sources there is additional information that will need to be stored with your media item in a field on your media type under media source configuration  select an existing field to reuse to store this information or select  create  to create a new field note the types of metadata in the field mapping section that can be mapped to fields on your media type click save  optionally add additional fields for the metadata noted above or for other information that you want to store to your media type by clicking on manage fields  see related topic below if you have added metadata fields click edit  under field mapping  select the fields you added for each piece of metadata information click save  you can now use this media type by adding a media reference field to any content entity subtype see related topic below  ',	1723096663);

DROP TABLE IF EXISTS `search_index`;
CREATE TABLE `search_index` (
  `word` varchar(50) NOT NULL DEFAULT '' COMMENT 'The "search_total".word that is associated with the search item.',
  `sid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "search_dataset".sid of the searchable item to which the word belongs.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "languages".langcode of the item variant.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The "search_dataset".type of the searchable item to which the word belongs.',
  `score` float DEFAULT NULL COMMENT 'The numeric score of the word, higher being more important.',
  PRIMARY KEY (`word`,`sid`,`langcode`,`type`),
  KEY `sid_type` (`sid`,`langcode`,`type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores the search index, associating words, items and…';

INSERT INTO `search_index` (`word`, `sid`, `langcode`, `type`, `score`) VALUES
('1',	57,	'en',	'help_search',	1),
('15',	57,	'en',	'help_search',	1),
('2',	11,	'en',	'help_search',	1),
('2',	57,	'en',	'help_search',	1),
('200',	33,	'en',	'help_search',	1),
('255',	12,	'en',	'help_search',	0.7017),
('3',	80,	'en',	'help_search',	1),
('403',	33,	'en',	'help_search',	23),
('403404',	33,	'en',	'help_search',	27),
('404',	33,	'en',	'help_search',	23.9769),
('40em',	57,	'en',	'help_search',	5),
('5',	58,	'en',	'help_search',	13.1162),
('6',	80,	'en',	'help_search',	1),
('7',	80,	'en',	'help_search',	13),
('7292024',	1,	'en',	'node_search',	1),
('9',	10,	'en',	'help_search',	1),
('916',	1,	'en',	'node_search',	1),
('abbreviation',	80,	'en',	'help_search',	1),
('ability',	11,	'en',	'help_search',	1),
('ability',	17,	'en',	'help_search',	2),
('ability',	18,	'en',	'help_search',	0.857458),
('ability',	20,	'en',	'help_search',	1),
('ability',	22,	'en',	'help_search',	1),
('ability',	30,	'en',	'help_search',	1),
('able',	27,	'en',	'help_search',	0.961087),
('able',	34,	'en',	'help_search',	2),
('about',	1,	'en',	'help_search',	1),
('about',	2,	'en',	'help_search',	1),
('about',	3,	'en',	'help_search',	1),
('about',	4,	'en',	'help_search',	1),
('about',	12,	'en',	'help_search',	1),
('about',	19,	'en',	'help_search',	1),
('about',	22,	'en',	'help_search',	2),
('about',	24,	'en',	'help_search',	0.902857),
('about',	26,	'en',	'help_search',	1),
('about',	29,	'en',	'help_search',	1),
('about',	30,	'en',	'help_search',	0.839384),
('about',	37,	'en',	'help_search',	1),
('about',	46,	'en',	'help_search',	1),
('about',	53,	'en',	'help_search',	1),
('about',	54,	'en',	'help_search',	1),
('about',	55,	'en',	'help_search',	1),
('about',	56,	'en',	'help_search',	1),
('about',	58,	'en',	'help_search',	1.98087),
('about',	70,	'en',	'help_search',	2),
('about',	73,	'en',	'help_search',	1.68557),
('about',	78,	'en',	'help_search',	1),
('about',	79,	'en',	'help_search',	1),
('about',	80,	'en',	'help_search',	9),
('about',	83,	'en',	'help_search',	1),
('aboutus',	78,	'en',	'help_search',	5),
('above',	12,	'en',	'help_search',	0.800068),
('above',	23,	'en',	'help_search',	1),
('above',	24,	'en',	'help_search',	0.879565),
('above',	57,	'en',	'help_search',	1),
('above',	87,	'en',	'help_search',	1),
('access',	11,	'en',	'help_search',	0.705825),
('access',	30,	'en',	'help_search',	1.7974),
('access',	50,	'en',	'help_search',	0.873132),
('access',	53,	'en',	'help_search',	8),
('access',	55,	'en',	'help_search',	8),
('access',	64,	'en',	'help_search',	2),
('access',	73,	'en',	'help_search',	4),
('access',	81,	'en',	'help_search',	1),
('access',	83,	'en',	'help_search',	4),
('accessed',	46,	'en',	'help_search',	1),
('accessibility',	23,	'en',	'help_search',	46),
('accessibility',	24,	'en',	'help_search',	2),
('accessible',	23,	'en',	'help_search',	2),
('accessible',	34,	'en',	'help_search',	1),
('accessing',	42,	'en',	'help_search',	2),
('accomplish',	27,	'en',	'help_search',	1),
('account',	6,	'en',	'help_search',	4),
('account',	8,	'en',	'help_search',	1),
('account',	40,	'en',	'help_search',	36),
('account',	44,	'en',	'help_search',	25.989),
('account',	45,	'en',	'help_search',	41),
('accountname',	44,	'en',	'help_search',	1),
('accounts',	6,	'en',	'help_search',	1),
('accounts',	24,	'en',	'help_search',	0.913226),
('accounts',	25,	'en',	'help_search',	1),
('accounts',	30,	'en',	'help_search',	0.845322),
('accounts',	40,	'en',	'help_search',	1),
('accounts',	42,	'en',	'help_search',	46),
('accounts',	44,	'en',	'help_search',	30.9849),
('accounts',	45,	'en',	'help_search',	1),
('accounts',	71,	'en',	'help_search',	1),
('action',	18,	'en',	'help_search',	1),
('action',	42,	'en',	'help_search',	1),
('action',	55,	'en',	'help_search',	8.88977),
('action',	64,	'en',	'help_search',	0.96498),
('action',	73,	'en',	'help_search',	0.836446),
('action',	83,	'en',	'help_search',	1.98493),
('actions',	55,	'en',	'help_search',	0.98493),
('actions',	73,	'en',	'help_search',	4.06626),
('actions',	81,	'en',	'help_search',	1),
('actions',	83,	'en',	'help_search',	8),
('active',	3,	'en',	'help_search',	1),
('active',	11,	'en',	'help_search',	8.73661),
('active',	50,	'en',	'help_search',	0.792123),
('active',	57,	'en',	'help_search',	1),
('active',	58,	'en',	'help_search',	11.0194),
('activity',	24,	'en',	'help_search',	0.889397),
('acts',	10,	'en',	'help_search',	1),
('add',	5,	'en',	'help_search',	3),
('add',	6,	'en',	'help_search',	1),
('add',	7,	'en',	'help_search',	5),
('add',	12,	'en',	'help_search',	0.873132),
('add',	16,	'en',	'help_search',	3),
('add',	17,	'en',	'help_search',	1),
('add',	22,	'en',	'help_search',	1),
('add',	26,	'en',	'help_search',	1),
('add',	27,	'en',	'help_search',	1),
('add',	28,	'en',	'help_search',	5),
('add',	30,	'en',	'help_search',	0.810915),
('add',	40,	'en',	'help_search',	8),
('add',	41,	'en',	'help_search',	4),
('add',	47,	'en',	'help_search',	1),
('add',	50,	'en',	'help_search',	3.69535),
('add',	51,	'en',	'help_search',	4),
('add',	52,	'en',	'help_search',	5),
('add',	53,	'en',	'help_search',	4),
('add',	54,	'en',	'help_search',	5),
('add',	56,	'en',	'help_search',	1),
('add',	58,	'en',	'help_search',	2.73092),
('add',	65,	'en',	'help_search',	13),
('add',	66,	'en',	'help_search',	2),
('add',	67,	'en',	'help_search',	2),
('add',	68,	'en',	'help_search',	13),
('add',	70,	'en',	'help_search',	14),
('add',	72,	'en',	'help_search',	13),
('add',	75,	'en',	'help_search',	15),
('add',	76,	'en',	'help_search',	5),
('add',	79,	'en',	'help_search',	1),
('add',	81,	'en',	'help_search',	2),
('add',	82,	'en',	'help_search',	6),
('add',	83,	'en',	'help_search',	6),
('add',	84,	'en',	'help_search',	4),
('add',	85,	'en',	'help_search',	5),
('add',	86,	'en',	'help_search',	17.0669),
('add',	87,	'en',	'help_search',	6),
('added',	12,	'en',	'help_search',	0.997306),
('added',	17,	'en',	'help_search',	1),
('added',	50,	'en',	'help_search',	1.61652),
('added',	71,	'en',	'help_search',	1),
('added',	72,	'en',	'help_search',	2),
('added',	74,	'en',	'help_search',	1),
('added',	75,	'en',	'help_search',	1),
('added',	81,	'en',	'help_search',	1),
('added',	82,	'en',	'help_search',	1),
('added',	84,	'en',	'help_search',	1),
('added',	87,	'en',	'help_search',	2),
('adding',	25,	'en',	'help_search',	1),
('adding',	41,	'en',	'help_search',	26),
('adding',	54,	'en',	'help_search',	11),
('adding',	65,	'en',	'help_search',	26),
('adding',	68,	'en',	'help_search',	26),
('adding',	70,	'en',	'help_search',	5),
('adding',	71,	'en',	'help_search',	0.927431),
('adding',	72,	'en',	'help_search',	26),
('adding',	75,	'en',	'help_search',	26),
('adding',	82,	'en',	'help_search',	26),
('adding',	83,	'en',	'help_search',	26),
('adding',	87,	'en',	'help_search',	27),
('addition',	30,	'en',	'help_search',	1.81959),
('addition',	33,	'en',	'help_search',	1),
('addition',	53,	'en',	'help_search',	1),
('addition',	55,	'en',	'help_search',	1),
('additional',	5,	'en',	'help_search',	1),
('additional',	10,	'en',	'help_search',	18.8293),
('additional',	11,	'en',	'help_search',	12.9539),
('additional',	12,	'en',	'help_search',	11.6723),
('additional',	13,	'en',	'help_search',	18.5602),
('additional',	14,	'en',	'help_search',	20),
('additional',	15,	'en',	'help_search',	19),
('additional',	16,	'en',	'help_search',	18.1873),
('additional',	17,	'en',	'help_search',	19),
('additional',	18,	'en',	'help_search',	16.1756),
('additional',	19,	'en',	'help_search',	19),
('additional',	22,	'en',	'help_search',	1),
('additional',	24,	'en',	'help_search',	2),
('additional',	25,	'en',	'help_search',	19),
('additional',	27,	'en',	'help_search',	17.8997),
('additional',	30,	'en',	'help_search',	15.9024),
('additional',	31,	'en',	'help_search',	19),
('additional',	32,	'en',	'help_search',	19),
('additional',	35,	'en',	'help_search',	1),
('additional',	37,	'en',	'help_search',	19),
('additional',	46,	'en',	'help_search',	19),
('additional',	47,	'en',	'help_search',	1),
('additional',	48,	'en',	'help_search',	19),
('additional',	50,	'en',	'help_search',	0.774192),
('additional',	53,	'en',	'help_search',	19),
('additional',	54,	'en',	'help_search',	19),
('additional',	55,	'en',	'help_search',	18.3346),
('additional',	57,	'en',	'help_search',	19.0423),
('additional',	58,	'en',	'help_search',	0.869951),
('additional',	70,	'en',	'help_search',	19),
('additional',	71,	'en',	'help_search',	16.9618),
('additional',	72,	'en',	'help_search',	1),
('additional',	73,	'en',	'help_search',	17.6775),
('additional',	78,	'en',	'help_search',	19),
('additional',	80,	'en',	'help_search',	19),
('additional',	85,	'en',	'help_search',	18.5602),
('additional',	86,	'en',	'help_search',	15.7274),
('additional',	87,	'en',	'help_search',	2),
('address',	8,	'en',	'help_search',	1),
('address',	32,	'en',	'help_search',	2),
('address',	40,	'en',	'help_search',	4),
('address',	45,	'en',	'help_search',	1),
('address',	80,	'en',	'help_search',	1),
('addresses',	12,	'en',	'help_search',	0.839384),
('addresses',	42,	'en',	'help_search',	1),
('adds',	14,	'en',	'help_search',	1),
('adjust',	32,	'en',	'help_search',	1),
('adjust',	50,	'en',	'help_search',	0.794753),
('adjust',	54,	'en',	'help_search',	1),
('admin',	1,	'en',	'node_search',	1),
('admin',	24,	'en',	'help_search',	15),
('admin',	26,	'en',	'help_search',	4),
('administer',	24,	'en',	'help_search',	0.96498),
('administer',	44,	'en',	'help_search',	4),
('administer',	53,	'en',	'help_search',	4),
('administer',	54,	'en',	'help_search',	4),
('administer',	55,	'en',	'help_search',	4),
('administer',	70,	'en',	'help_search',	8),
('administer',	79,	'en',	'help_search',	4),
('administer',	81,	'en',	'help_search',	8),
('administer',	83,	'en',	'help_search',	4),
('administering',	42,	'en',	'help_search',	1),
('administration',	13,	'en',	'help_search',	1),
('administration',	38,	'en',	'help_search',	5),
('administration',	39,	'en',	'help_search',	4),
('administration',	53,	'en',	'help_search',	1),
('administration',	75,	'en',	'help_search',	2),
('administration',	76,	'en',	'help_search',	1),
('administration',	77,	'en',	'help_search',	1),
('administration',	79,	'en',	'help_search',	1),
('administrative',	1,	'en',	'help_search',	1),
('administrative',	2,	'en',	'help_search',	1),
('administrative',	3,	'en',	'help_search',	1),
('administrative',	4,	'en',	'help_search',	1),
('administrative',	5,	'en',	'help_search',	1),
('administrative',	6,	'en',	'help_search',	2),
('administrative',	7,	'en',	'help_search',	1),
('administrative',	9,	'en',	'help_search',	1),
('administrative',	11,	'en',	'help_search',	2.53983),
('administrative',	13,	'en',	'help_search',	1),
('administrative',	18,	'en',	'help_search',	0.886095),
('administrative',	23,	'en',	'help_search',	28),
('administrative',	24,	'en',	'help_search',	91.3775),
('administrative',	26,	'en',	'help_search',	5),
('administrative',	27,	'en',	'help_search',	1.97808),
('administrative',	28,	'en',	'help_search',	1),
('administrative',	29,	'en',	'help_search',	1),
('administrative',	31,	'en',	'help_search',	1),
('administrative',	32,	'en',	'help_search',	3),
('administrative',	33,	'en',	'help_search',	1.93838),
('administrative',	34,	'en',	'help_search',	2),
('administrative',	35,	'en',	'help_search',	1),
('administrative',	36,	'en',	'help_search',	1),
('administrative',	37,	'en',	'help_search',	3),
('administrative',	38,	'en',	'help_search',	5),
('administrative',	39,	'en',	'help_search',	1),
('administrative',	40,	'en',	'help_search',	1),
('administrative',	41,	'en',	'help_search',	1),
('administrative',	43,	'en',	'help_search',	1),
('administrative',	44,	'en',	'help_search',	2),
('administrative',	45,	'en',	'help_search',	1),
('administrative',	47,	'en',	'help_search',	1),
('administrative',	48,	'en',	'help_search',	1),
('administrative',	49,	'en',	'help_search',	1),
('administrative',	50,	'en',	'help_search',	0.98493),
('administrative',	51,	'en',	'help_search',	1),
('administrative',	52,	'en',	'help_search',	2),
('administrative',	53,	'en',	'help_search',	1),
('administrative',	54,	'en',	'help_search',	2),
('administrative',	55,	'en',	'help_search',	1),
('administrative',	58,	'en',	'help_search',	1),
('administrative',	64,	'en',	'help_search',	6.9658),
('administrative',	65,	'en',	'help_search',	1),
('administrative',	66,	'en',	'help_search',	1),
('administrative',	67,	'en',	'help_search',	1),
('administrative',	68,	'en',	'help_search',	1),
('administrative',	70,	'en',	'help_search',	3),
('administrative',	72,	'en',	'help_search',	1),
('administrative',	73,	'en',	'help_search',	1.63414),
('administrative',	74,	'en',	'help_search',	1),
('administrative',	76,	'en',	'help_search',	1),
('administrative',	81,	'en',	'help_search',	30.9496),
('administrative',	82,	'en',	'help_search',	2),
('administrative',	83,	'en',	'help_search',	1),
('administrative',	84,	'en',	'help_search',	2),
('administrative',	85,	'en',	'help_search',	1),
('administrative',	86,	'en',	'help_search',	1),
('administrative',	87,	'en',	'help_search',	1),
('administrator',	11,	'en',	'help_search',	1),
('administrator',	12,	'en',	'help_search',	0.993146),
('administrator',	81,	'en',	'help_search',	1),
('administrators',	8,	'en',	'help_search',	1),
('administrators',	11,	'en',	'help_search',	1),
('administrators',	17,	'en',	'help_search',	1),
('administrators',	42,	'en',	'help_search',	2),
('administrators',	44,	'en',	'help_search',	1),
('administrators',	50,	'en',	'help_search',	2),
('administrators',	51,	'en',	'help_search',	1),
('administrators',	54,	'en',	'help_search',	1),
('advanced',	30,	'en',	'help_search',	3.59781),
('advanced',	73,	'en',	'help_search',	10.801),
('advisories',	19,	'en',	'help_search',	20),
('advisory',	19,	'en',	'help_search',	14),
('affected',	64,	'en',	'help_search',	1),
('after',	11,	'en',	'help_search',	0.766757),
('after',	18,	'en',	'help_search',	1),
('after',	29,	'en',	'help_search',	0.906287),
('after',	30,	'en',	'help_search',	1),
('after',	33,	'en',	'help_search',	0.997306),
('after',	50,	'en',	'help_search',	0.810915),
('after',	66,	'en',	'help_search',	1),
('after',	67,	'en',	'help_search',	1),
('after',	72,	'en',	'help_search',	1),
('after',	73,	'en',	'help_search',	1),
('afterwards',	18,	'en',	'help_search',	0.913226),
('again',	31,	'en',	'help_search',	1),
('again',	55,	'en',	'help_search',	1),
('again',	64,	'en',	'help_search',	1),
('against',	25,	'en',	'help_search',	1),
('against',	50,	'en',	'help_search',	1),
('aggregation',	18,	'en',	'help_search',	20.8513),
('alias',	44,	'en',	'help_search',	1),
('alias',	78,	'en',	'help_search',	35),
('alias',	79,	'en',	'help_search',	30),
('alias',	80,	'en',	'help_search',	20),
('aliases',	78,	'en',	'help_search',	26),
('aliases',	79,	'en',	'help_search',	32),
('aliases',	80,	'en',	'help_search',	61),
('aliasing',	80,	'en',	'help_search',	1),
('all',	1,	'en',	'help_search',	1),
('all',	3,	'en',	'help_search',	4),
('all',	12,	'en',	'help_search',	2.28248),
('all',	14,	'en',	'help_search',	1),
('all',	19,	'en',	'help_search',	1),
('all',	20,	'en',	'help_search',	1),
('all',	24,	'en',	'help_search',	1),
('all',	31,	'en',	'help_search',	4),
('all',	42,	'en',	'help_search',	2),
('all',	45,	'en',	'help_search',	1),
('all',	47,	'en',	'help_search',	1),
('all',	53,	'en',	'help_search',	1),
('all',	55,	'en',	'help_search',	1),
('all',	64,	'en',	'help_search',	1),
('all',	65,	'en',	'help_search',	1),
('all',	70,	'en',	'help_search',	1),
('all',	71,	'en',	'help_search',	2.96498),
('all',	72,	'en',	'help_search',	1),
('all',	79,	'en',	'help_search',	1),
('all',	81,	'en',	'help_search',	2),
('all',	83,	'en',	'help_search',	5),
('all',	85,	'en',	'help_search',	1),
('all',	86,	'en',	'help_search',	1.90286),
('allow',	8,	'en',	'help_search',	2),
('allow',	10,	'en',	'help_search',	0.980874),
('allow',	12,	'en',	'help_search',	1),
('allow',	50,	'en',	'help_search',	1.89945),
('allow',	64,	'en',	'help_search',	1),
('allow',	70,	'en',	'help_search',	1),
('allow',	73,	'en',	'help_search',	1),
('allow',	82,	'en',	'help_search',	1),
('allow',	86,	'en',	'help_search',	1),
('allowed',	12,	'en',	'help_search',	2.9266),
('allowed',	50,	'en',	'help_search',	1),
('allowed',	65,	'en',	'help_search',	4),
('allowed',	68,	'en',	'help_search',	4),
('allows',	10,	'en',	'help_search',	1),
('allows',	12,	'en',	'help_search',	0.876337),
('allows',	16,	'en',	'help_search',	1),
('allows',	18,	'en',	'help_search',	1.90974),
('allows',	23,	'en',	'help_search',	1),
('allows',	25,	'en',	'help_search',	1),
('allows',	30,	'en',	'help_search',	1),
('allows',	42,	'en',	'help_search',	3),
('allows',	48,	'en',	'help_search',	2),
('allows',	56,	'en',	'help_search',	2),
('allows',	57,	'en',	'help_search',	0.976851),
('allows',	69,	'en',	'help_search',	1),
('allows',	71,	'en',	'help_search',	0.945829),
('allows',	73,	'en',	'help_search',	2.65179),
('allows',	80,	'en',	'help_search',	2),
('allows',	81,	'en',	'help_search',	1),
('along',	7,	'en',	'help_search',	1),
('along',	25,	'en',	'help_search',	1),
('already',	26,	'en',	'help_search',	2),
('already',	34,	'en',	'help_search',	1),
('already',	35,	'en',	'help_search',	2),
('already',	38,	'en',	'help_search',	2),
('already',	81,	'en',	'help_search',	1),
('already',	82,	'en',	'help_search',	1),
('already',	83,	'en',	'help_search',	2),
('already',	85,	'en',	'help_search',	1),
('already',	87,	'en',	'help_search',	1),
('alreadyconfigured',	28,	'en',	'help_search',	1),
('alreadyrendered',	18,	'en',	'help_search',	1),
('also',	8,	'en',	'help_search',	1),
('also',	11,	'en',	'help_search',	1.58702),
('also',	12,	'en',	'help_search',	3.37064),
('also',	13,	'en',	'help_search',	1),
('also',	15,	'en',	'help_search',	1),
('also',	16,	'en',	'help_search',	1),
('also',	17,	'en',	'help_search',	2),
('also',	18,	'en',	'help_search',	1),
('also',	19,	'en',	'help_search',	1),
('also',	20,	'en',	'help_search',	1),
('also',	22,	'en',	'help_search',	3),
('also',	24,	'en',	'help_search',	1),
('also',	25,	'en',	'help_search',	1),
('also',	27,	'en',	'help_search',	2),
('also',	30,	'en',	'help_search',	1.7001),
('also',	31,	'en',	'help_search',	1),
('also',	34,	'en',	'help_search',	1),
('also',	35,	'en',	'help_search',	1),
('also',	42,	'en',	'help_search',	1),
('also',	50,	'en',	'help_search',	1),
('also',	53,	'en',	'help_search',	1),
('also',	54,	'en',	'help_search',	1),
('also',	58,	'en',	'help_search',	1),
('also',	64,	'en',	'help_search',	2),
('also',	65,	'en',	'help_search',	1),
('also',	66,	'en',	'help_search',	1),
('also',	68,	'en',	'help_search',	1),
('also',	69,	'en',	'help_search',	1),
('also',	70,	'en',	'help_search',	2),
('also',	72,	'en',	'help_search',	1),
('also',	73,	'en',	'help_search',	1),
('also',	75,	'en',	'help_search',	1),
('also',	76,	'en',	'help_search',	1),
('also',	78,	'en',	'help_search',	1),
('also',	79,	'en',	'help_search',	1),
('also',	81,	'en',	'help_search',	2),
('also',	86,	'en',	'help_search',	1.91323),
('alter',	30,	'en',	'help_search',	0.857458),
('alternative',	30,	'en',	'help_search',	1),
('alternatively',	64,	'en',	'help_search',	1),
('alternatively',	85,	'en',	'help_search',	1),
('always',	5,	'en',	'help_search',	1),
('always',	6,	'en',	'help_search',	1),
('always',	7,	'en',	'help_search',	1),
('always',	46,	'en',	'help_search',	1),
('american',	30,	'en',	'help_search',	0.976851),
('anchor',	72,	'en',	'help_search',	4),
('and',	1,	'en',	'help_search',	3),
('and',	2,	'en',	'help_search',	3),
('and',	3,	'en',	'help_search',	5),
('and',	4,	'en',	'help_search',	1),
('and',	5,	'en',	'help_search',	4),
('and',	6,	'en',	'help_search',	3),
('and',	7,	'en',	'help_search',	2),
('and',	8,	'en',	'help_search',	2),
('and',	9,	'en',	'help_search',	1),
('and',	10,	'en',	'help_search',	23.1993),
('and',	11,	'en',	'help_search',	40.2271),
('and',	12,	'en',	'help_search',	19.524),
('and',	13,	'en',	'help_search',	29.9973),
('and',	14,	'en',	'help_search',	62),
('and',	15,	'en',	'help_search',	70),
('and',	16,	'en',	'help_search',	9.99315),
('and',	17,	'en',	'help_search',	2),
('and',	18,	'en',	'help_search',	10.5892),
('and',	19,	'en',	'help_search',	26),
('and',	20,	'en',	'help_search',	3),
('and',	21,	'en',	'help_search',	2),
('and',	22,	'en',	'help_search',	34),
('and',	23,	'en',	'help_search',	3),
('and',	24,	'en',	'help_search',	11.5995),
('and',	25,	'en',	'help_search',	19),
('and',	26,	'en',	'help_search',	9),
('and',	27,	'en',	'help_search',	8.95792),
('and',	28,	'en',	'help_search',	6),
('and',	29,	'en',	'help_search',	13.7539),
('and',	30,	'en',	'help_search',	9.36877),
('and',	31,	'en',	'help_search',	1),
('and',	32,	'en',	'help_search',	16),
('and',	33,	'en',	'help_search',	26.7011),
('and',	34,	'en',	'help_search',	30),
('and',	36,	'en',	'help_search',	3),
('and',	37,	'en',	'help_search',	15),
('and',	38,	'en',	'help_search',	29),
('and',	40,	'en',	'help_search',	1),
('and',	41,	'en',	'help_search',	1),
('and',	42,	'en',	'help_search',	52),
('and',	43,	'en',	'help_search',	1),
('and',	44,	'en',	'help_search',	47),
('and',	45,	'en',	'help_search',	4),
('and',	46,	'en',	'help_search',	3),
('and',	47,	'en',	'help_search',	2),
('and',	48,	'en',	'help_search',	4),
('and',	49,	'en',	'help_search',	3),
('and',	50,	'en',	'help_search',	59.5847),
('and',	51,	'en',	'help_search',	1),
('and',	52,	'en',	'help_search',	2),
('and',	53,	'en',	'help_search',	3),
('and',	54,	'en',	'help_search',	6),
('and',	55,	'en',	'help_search',	22),
('and',	56,	'en',	'help_search',	11),
('and',	57,	'en',	'help_search',	56.4734),
('and',	58,	'en',	'help_search',	15.3423),
('and',	64,	'en',	'help_search',	3.97685),
('and',	65,	'en',	'help_search',	8),
('and',	66,	'en',	'help_search',	3),
('and',	67,	'en',	'help_search',	2),
('and',	68,	'en',	'help_search',	8),
('and',	69,	'en',	'help_search',	1),
('and',	70,	'en',	'help_search',	9),
('and',	71,	'en',	'help_search',	9.71009),
('and',	72,	'en',	'help_search',	5),
('and',	73,	'en',	'help_search',	8.05703),
('and',	74,	'en',	'help_search',	1),
('and',	75,	'en',	'help_search',	4),
('and',	77,	'en',	'help_search',	27),
('and',	78,	'en',	'help_search',	6),
('and',	79,	'en',	'help_search',	5),
('and',	80,	'en',	'help_search',	31),
('and',	81,	'en',	'help_search',	30.9973),
('and',	82,	'en',	'help_search',	4),
('and',	83,	'en',	'help_search',	5),
('and',	84,	'en',	'help_search',	5),
('and',	85,	'en',	'help_search',	3.98902),
('and',	86,	'en',	'help_search',	9.54809),
('and',	87,	'en',	'help_search',	5),
('announcement',	19,	'en',	'help_search',	1),
('announcement',	46,	'en',	'help_search',	11),
('announcements',	46,	'en',	'help_search',	93),
('anonymous',	6,	'en',	'help_search',	4),
('anonymous',	18,	'en',	'help_search',	2.93498),
('anonymous',	42,	'en',	'help_search',	5),
('anonymous',	50,	'en',	'help_search',	0.886095),
('another',	8,	'en',	'help_search',	1),
('another',	11,	'en',	'help_search',	2.4152),
('another',	14,	'en',	'help_search',	1),
('another',	22,	'en',	'help_search',	1),
('another',	27,	'en',	'help_search',	0.997306),
('another',	36,	'en',	'help_search',	1),
('another',	38,	'en',	'help_search',	1),
('another',	39,	'en',	'help_search',	1),
('another',	57,	'en',	'help_search',	1),
('another',	58,	'en',	'help_search',	0.968904),
('another',	64,	'en',	'help_search',	1),
('another',	75,	'en',	'help_search',	2),
('any',	3,	'en',	'help_search',	1),
('any',	10,	'en',	'help_search',	1),
('any',	11,	'en',	'help_search',	0.876337),
('any',	19,	'en',	'help_search',	1),
('any',	28,	'en',	'help_search',	1),
('any',	30,	'en',	'help_search',	0.920273),
('any',	32,	'en',	'help_search',	2),
('any',	37,	'en',	'help_search',	3),
('any',	55,	'en',	'help_search',	4),
('any',	58,	'en',	'help_search',	1),
('any',	66,	'en',	'help_search',	1),
('any',	67,	'en',	'help_search',	1),
('any',	71,	'en',	'help_search',	1),
('any',	75,	'en',	'help_search',	1),
('any',	79,	'en',	'help_search',	1),
('any',	81,	'en',	'help_search',	5.95723),
('any',	87,	'en',	'help_search',	1),
('anyone',	34,	'en',	'help_search',	1),
('anyone',	42,	'en',	'help_search',	1),
('apache',	30,	'en',	'help_search',	12),
('api',	25,	'en',	'help_search',	34),
('api',	57,	'en',	'help_search',	0.961087),
('appear',	20,	'en',	'help_search',	2),
('appear',	66,	'en',	'help_search',	1),
('appear',	79,	'en',	'help_search',	1),
('appear',	86,	'en',	'help_search',	0.857458),
('appearance',	10,	'en',	'help_search',	46.9579),
('appearance',	24,	'en',	'help_search',	3.8289),
('appearance',	38,	'en',	'help_search',	8),
('appearance',	39,	'en',	'help_search',	4),
('applications',	25,	'en',	'help_search',	3),
('applied',	16,	'en',	'help_search',	1),
('applied',	50,	'en',	'help_search',	1),
('applied',	83,	'en',	'help_search',	1),
('apply',	19,	'en',	'help_search',	1),
('apply',	55,	'en',	'help_search',	4.97258),
('apply',	57,	'en',	'help_search',	1),
('apply',	72,	'en',	'help_search',	1),
('apply',	73,	'en',	'help_search',	0.842342),
('apply',	83,	'en',	'help_search',	4),
('appropriate',	30,	'en',	'help_search',	1),
('appropriately',	33,	'en',	'help_search',	1),
('approval',	44,	'en',	'help_search',	1),
('approved',	44,	'en',	'help_search',	1),
('archive',	1,	'en',	'help_search',	2),
('archive',	3,	'en',	'help_search',	6),
('archive',	11,	'en',	'help_search',	1.60282),
('are',	5,	'en',	'help_search',	19),
('are',	6,	'en',	'help_search',	1),
('are',	8,	'en',	'help_search',	21),
('are',	10,	'en',	'help_search',	1),
('are',	11,	'en',	'help_search',	24.2128),
('are',	12,	'en',	'help_search',	59.5296),
('are',	13,	'en',	'help_search',	39.9973),
('are',	14,	'en',	'help_search',	19),
('are',	15,	'en',	'help_search',	3),
('are',	16,	'en',	'help_search',	23),
('are',	18,	'en',	'help_search',	4.78255),
('are',	19,	'en',	'help_search',	44),
('are',	22,	'en',	'help_search',	2),
('are',	23,	'en',	'help_search',	3.98902),
('are',	24,	'en',	'help_search',	41),
('are',	25,	'en',	'help_search',	2),
('are',	26,	'en',	'help_search',	2),
('are',	27,	'en',	'help_search',	61),
('are',	29,	'en',	'help_search',	1),
('are',	30,	'en',	'help_search',	58.7594),
('are',	31,	'en',	'help_search',	2),
('are',	32,	'en',	'help_search',	1),
('are',	33,	'en',	'help_search',	19.9097),
('are',	34,	'en',	'help_search',	1),
('are',	35,	'en',	'help_search',	1),
('are',	36,	'en',	'help_search',	2),
('are',	37,	'en',	'help_search',	2),
('are',	40,	'en',	'help_search',	1),
('are',	42,	'en',	'help_search',	6),
('are',	44,	'en',	'help_search',	69.9769),
('are',	46,	'en',	'help_search',	19),
('are',	48,	'en',	'help_search',	41),
('are',	50,	'en',	'help_search',	42),
('are',	56,	'en',	'help_search',	2),
('are',	57,	'en',	'help_search',	62),
('are',	58,	'en',	'help_search',	2),
('are',	64,	'en',	'help_search',	19),
('are',	65,	'en',	'help_search',	1),
('are',	66,	'en',	'help_search',	1),
('are',	67,	'en',	'help_search',	1),
('are',	68,	'en',	'help_search',	1),
('are',	69,	'en',	'help_search',	39),
('are',	70,	'en',	'help_search',	1),
('are',	71,	'en',	'help_search',	4.96109),
('are',	72,	'en',	'help_search',	1),
('are',	73,	'en',	'help_search',	37.225),
('are',	80,	'en',	'help_search',	2),
('are',	81,	'en',	'help_search',	21),
('are',	82,	'en',	'help_search',	2),
('are',	83,	'en',	'help_search',	2),
('are',	85,	'en',	'help_search',	2),
('are',	86,	'en',	'help_search',	20.7335),
('are',	87,	'en',	'help_search',	1),
('area',	45,	'en',	'help_search',	1),
('area',	48,	'en',	'help_search',	1),
('area',	64,	'en',	'help_search',	5.98902),
('areas',	64,	'en',	'help_search',	1),
('arrows',	66,	'en',	'help_search',	1),
('arrows',	67,	'en',	'help_search',	1),
('article',	53,	'en',	'help_search',	2),
('article',	55,	'en',	'help_search',	11),
('articles',	56,	'en',	'help_search',	1),
('aspect',	24,	'en',	'help_search',	0.869951),
('aspects',	24,	'en',	'help_search',	0.857458),
('asset',	10,	'en',	'help_search',	1),
('assign',	50,	'en',	'help_search',	1),
('assign',	57,	'en',	'help_search',	0.953396),
('assigned',	42,	'en',	'help_search',	2),
('assigned',	81,	'en',	'help_search',	1),
('assistive',	23,	'en',	'help_search',	1),
('associate',	12,	'en',	'help_search',	0.78951),
('associate',	16,	'en',	'help_search',	1),
('associate',	50,	'en',	'help_search',	1),
('associated',	58,	'en',	'help_search',	1),
('associates',	12,	'en',	'help_search',	0.729424),
('association',	46,	'en',	'help_search',	2),
('assume',	58,	'en',	'help_search',	0.957226),
('assuming',	54,	'en',	'help_search',	1),
('assumptions',	31,	'en',	'help_search',	1),
('attach',	48,	'en',	'help_search',	1),
('attach',	56,	'en',	'help_search',	1),
('attached',	12,	'en',	'help_search',	1),
('attached',	56,	'en',	'help_search',	1),
('attached',	71,	'en',	'help_search',	2),
('attention',	43,	'en',	'help_search',	1),
('attribute',	12,	'en',	'help_search',	0.687638),
('audio',	16,	'en',	'help_search',	1),
('authenticated',	6,	'en',	'help_search',	4),
('authenticated',	18,	'en',	'help_search',	0.968904),
('authenticated',	25,	'en',	'help_search',	1),
('authenticated',	42,	'en',	'help_search',	5),
('authenticating',	25,	'en',	'help_search',	1),
('authentication',	25,	'en',	'help_search',	34),
('authoring',	50,	'en',	'help_search',	3.85992),
('authoring',	58,	'en',	'help_search',	4),
('authorized',	33,	'en',	'help_search',	1),
('automated',	13,	'en',	'help_search',	3.98776),
('automatic',	18,	'en',	'help_search',	1),
('automatic',	22,	'en',	'help_search',	1),
('automatically',	13,	'en',	'help_search',	1),
('automatically',	27,	'en',	'help_search',	1.98902),
('automatically',	71,	'en',	'help_search',	0.98493),
('automatically',	75,	'en',	'help_search',	1),
('automaticallygenerated',	52,	'en',	'help_search',	1),
('automaticallygenerated',	80,	'en',	'help_search',	1),
('available',	12,	'en',	'help_search',	47.9205),
('available',	13,	'en',	'help_search',	19),
('available',	22,	'en',	'help_search',	1),
('available',	24,	'en',	'help_search',	20),
('available',	28,	'en',	'help_search',	2),
('available',	37,	'en',	'help_search',	6),
('available',	47,	'en',	'help_search',	1),
('available',	50,	'en',	'help_search',	19),
('available',	58,	'en',	'help_search',	4.73881),
('available',	69,	'en',	'help_search',	19),
('available',	73,	'en',	'help_search',	0.827757),
('available',	74,	'en',	'help_search',	2),
('available',	83,	'en',	'help_search',	1.98493),
('available',	86,	'en',	'help_search',	0.931053),
('avoid',	50,	'en',	'help_search',	0.808176),
('aware',	33,	'en',	'help_search',	0.906287),
('away',	31,	'en',	'help_search',	1),
('back',	34,	'en',	'help_search',	1),
('background',	66,	'en',	'help_search',	1),
('background',	67,	'en',	'help_search',	1),
('ban',	42,	'en',	'help_search',	2),
('bar',	81,	'en',	'help_search',	0.957226),
('base',	10,	'en',	'help_search',	21),
('base',	39,	'en',	'help_search',	1),
('base',	73,	'en',	'help_search',	6.70772),
('base',	84,	'en',	'help_search',	1),
('basic',	10,	'en',	'help_search',	1),
('basic',	25,	'en',	'help_search',	33),
('basic',	32,	'en',	'help_search',	31),
('basic',	33,	'en',	'help_search',	4),
('basic',	53,	'en',	'help_search',	11),
('basic',	55,	'en',	'help_search',	10.5295),
('because',	16,	'en',	'help_search',	1),
('because',	18,	'en',	'help_search',	1),
('because',	39,	'en',	'help_search',	1),
('become',	23,	'en',	'help_search',	1),
('becomes',	16,	'en',	'help_search',	1),
('been',	11,	'en',	'help_search',	2.61181),
('been',	27,	'en',	'help_search',	1),
('been',	29,	'en',	'help_search',	2.7263),
('been',	35,	'en',	'help_search',	1),
('been',	38,	'en',	'help_search',	1),
('been',	42,	'en',	'help_search',	1),
('been',	69,	'en',	'help_search',	1),
('been',	72,	'en',	'help_search',	1),
('been',	75,	'en',	'help_search',	1),
('been',	81,	'en',	'help_search',	1),
('before',	15,	'en',	'help_search',	1),
('before',	18,	'en',	'help_search',	1),
('behaves',	11,	'en',	'help_search',	1),
('behaving',	15,	'en',	'help_search',	1),
('behavior',	30,	'en',	'help_search',	1),
('behavior',	73,	'en',	'help_search',	3.8289),
('behind',	12,	'en',	'help_search',	0.759465),
('being',	8,	'en',	'help_search',	1),
('being',	11,	'en',	'help_search',	0.78951),
('being',	34,	'en',	'help_search',	1),
('being',	39,	'en',	'help_search',	3),
('being',	50,	'en',	'help_search',	0.819249),
('being',	73,	'en',	'help_search',	1),
('believe',	29,	'en',	'help_search',	0.931053),
('belong',	12,	'en',	'help_search',	0.923838),
('below',	2,	'en',	'help_search',	1),
('below',	8,	'en',	'help_search',	1),
('below',	10,	'en',	'help_search',	0.949597),
('below',	11,	'en',	'help_search',	0.685676),
('below',	12,	'en',	'help_search',	2.89048),
('below',	14,	'en',	'help_search',	1),
('below',	15,	'en',	'help_search',	1),
('below',	16,	'en',	'help_search',	0.968904),
('below',	17,	'en',	'help_search',	1),
('below',	19,	'en',	'help_search',	1),
('below',	21,	'en',	'help_search',	1),
('below',	22,	'en',	'help_search',	1),
('below',	24,	'en',	'help_search',	0.863659),
('below',	30,	'en',	'help_search',	0.792123),
('below',	42,	'en',	'help_search',	1),
('below',	48,	'en',	'help_search',	1),
('below',	56,	'en',	'help_search',	1),
('below',	65,	'en',	'help_search',	1),
('below',	68,	'en',	'help_search',	1),
('below',	71,	'en',	'help_search',	0.902857),
('below',	72,	'en',	'help_search',	1),
('below',	73,	'en',	'help_search',	0.786915),
('below',	80,	'en',	'help_search',	1),
('below',	84,	'en',	'help_search',	1),
('below',	86,	'en',	'help_search',	1),
('below',	87,	'en',	'help_search',	2),
('besides',	12,	'en',	'help_search',	0.630018),
('besides',	58,	'en',	'help_search',	1),
('best',	23,	'en',	'help_search',	2),
('best',	57,	'en',	'help_search',	1),
('best',	83,	'en',	'help_search',	1),
('between',	3,	'en',	'help_search',	1),
('between',	11,	'en',	'help_search',	3.79218),
('between',	12,	'en',	'help_search',	1.8477),
('between',	24,	'en',	'help_search',	0.949597),
('between',	57,	'en',	'help_search',	1),
('between',	58,	'en',	'help_search',	1.81472),
('big',	18,	'en',	'help_search',	0.949597),
('bigpipe',	18,	'en',	'help_search',	9.23322),
('blank',	33,	'en',	'help_search',	1),
('block',	5,	'en',	'help_search',	1),
('block',	12,	'en',	'help_search',	8.62029),
('block',	17,	'en',	'help_search',	2),
('block',	20,	'en',	'help_search',	2),
('block',	22,	'en',	'help_search',	4),
('block',	24,	'en',	'help_search',	1),
('block',	26,	'en',	'help_search',	9),
('block',	27,	'en',	'help_search',	1.98493),
('block',	30,	'en',	'help_search',	1.73835),
('block',	47,	'en',	'help_search',	52),
('block',	48,	'en',	'help_search',	57),
('block',	49,	'en',	'help_search',	53),
('block',	51,	'en',	'help_search',	34),
('block',	52,	'en',	'help_search',	43),
('block',	64,	'en',	'help_search',	5),
('block',	73,	'en',	'help_search',	6),
('block',	76,	'en',	'help_search',	2),
('block',	82,	'en',	'help_search',	5),
('block',	84,	'en',	'help_search',	1),
('block',	86,	'en',	'help_search',	9.0616),
('blocked',	44,	'en',	'help_search',	1),
('blocks',	10,	'en',	'help_search',	2),
('blocks',	22,	'en',	'help_search',	1),
('blocks',	24,	'en',	'help_search',	0.989021),
('blocks',	47,	'en',	'help_search',	8),
('blocks',	48,	'en',	'help_search',	102),
('blocks',	51,	'en',	'help_search',	1),
('blocks',	71,	'en',	'help_search',	1),
('blocks',	86,	'en',	'help_search',	10.2549),
('blog',	56,	'en',	'help_search',	1),
('blog',	71,	'en',	'help_search',	4),
('body',	27,	'en',	'help_search',	1),
('body',	51,	'en',	'help_search',	1),
('boolean',	12,	'en',	'help_search',	0.899454),
('both',	5,	'en',	'help_search',	1),
('both',	6,	'en',	'help_search',	1),
('both',	18,	'en',	'help_search',	0.972861),
('both',	23,	'en',	'help_search',	0.997306),
('both',	29,	'en',	'help_search',	1),
('both',	30,	'en',	'help_search',	1),
('both',	33,	'en',	'help_search',	1),
('both',	50,	'en',	'help_search',	1),
('both',	65,	'en',	'help_search',	1),
('both',	68,	'en',	'help_search',	1),
('bottom',	35,	'en',	'help_search',	1),
('bottom',	36,	'en',	'help_search',	1),
('bottom',	38,	'en',	'help_search',	1),
('bottom',	45,	'en',	'help_search',	1),
('bottom',	73,	'en',	'help_search',	0.96498),
('bottom',	86,	'en',	'help_search',	0.957226),
('box',	2,	'en',	'help_search',	2),
('box',	4,	'en',	'help_search',	1),
('box',	6,	'en',	'help_search',	1),
('box',	35,	'en',	'help_search',	3),
('box',	36,	'en',	'help_search',	2),
('box',	44,	'en',	'help_search',	1),
('box',	47,	'en',	'help_search',	1),
('box',	86,	'en',	'help_search',	1),
('boxes',	48,	'en',	'help_search',	1),
('boxes',	55,	'en',	'help_search',	1),
('brackets',	44,	'en',	'help_search',	1),
('break',	50,	'en',	'help_search',	1),
('breakpoint',	10,	'en',	'help_search',	0.976851),
('breakpoint',	16,	'en',	'help_search',	0.997306),
('breakpoint',	57,	'en',	'help_search',	52.2799),
('breakpointenabled',	16,	'en',	'help_search',	0.993146),
('breakpoints',	16,	'en',	'help_search',	1),
('breakpoints',	57,	'en',	'help_search',	85.8495),
('breaks',	29,	'en',	'help_search',	1),
('breaks',	50,	'en',	'help_search',	3),
('browse',	3,	'en',	'help_search',	1),
('browser',	2,	'en',	'help_search',	1),
('browser',	16,	'en',	'help_search',	1.98087),
('browser',	18,	'en',	'help_search',	0.909743),
('browser',	80,	'en',	'help_search',	1),
('bugs',	19,	'en',	'help_search',	3),
('bugs',	33,	'en',	'help_search',	1),
('builder',	10,	'en',	'help_search',	1.98087),
('builder',	12,	'en',	'help_search',	0.600219),
('builder',	86,	'en',	'help_search',	12.9201),
('building',	10,	'en',	'help_search',	1),
('building',	86,	'en',	'help_search',	8.98097),
('builtin',	22,	'en',	'help_search',	1),
('builtin',	23,	'en',	'help_search',	1),
('bulk',	18,	'en',	'help_search',	0.902857),
('bulk',	55,	'en',	'help_search',	2),
('bulk',	73,	'en',	'help_search',	18.9762),
('bulk',	83,	'en',	'help_search',	37.9822),
('but',	10,	'en',	'help_search',	1),
('but',	12,	'en',	'help_search',	1),
('but',	13,	'en',	'help_search',	1),
('but',	22,	'en',	'help_search',	1),
('but',	31,	'en',	'help_search',	1),
('but',	33,	'en',	'help_search',	2),
('but',	39,	'en',	'help_search',	1),
('but',	47,	'en',	'help_search',	1),
('but',	66,	'en',	'help_search',	1),
('but',	83,	'en',	'help_search',	1),
('but',	86,	'en',	'help_search',	1),
('butter',	70,	'en',	'help_search',	1),
('button',	12,	'en',	'help_search',	2.54671),
('button',	20,	'en',	'help_search',	1),
('button',	30,	'en',	'help_search',	1),
('button',	54,	'en',	'help_search',	1),
('button',	58,	'en',	'help_search',	1.81268),
('button',	64,	'en',	'help_search',	4.99731),
('button',	79,	'en',	'help_search',	1),
('button',	83,	'en',	'help_search',	1),
('button',	86,	'en',	'help_search',	1),
('buttons',	58,	'en',	'help_search',	10.2472),
('buttons',	64,	'en',	'help_search',	1),
('bypass',	53,	'en',	'help_search',	4),
('bypass',	55,	'en',	'help_search',	4),
('cache',	15,	'en',	'help_search',	1),
('cache',	18,	'en',	'help_search',	22.2999),
('cache',	26,	'en',	'help_search',	1),
('cache',	31,	'en',	'help_search',	58),
('cache',	34,	'en',	'help_search',	2),
('cacheable',	18,	'en',	'help_search',	0.934703),
('cached',	18,	'en',	'help_search',	2),
('cached',	31,	'en',	'help_search',	7),
('caches',	18,	'en',	'help_search',	1.97286),
('caches',	31,	'en',	'help_search',	4),
('caching',	18,	'en',	'help_search',	21),
('calculated',	18,	'en',	'help_search',	1.9496),
('calculation',	31,	'en',	'help_search',	1),
('calculations',	18,	'en',	'help_search',	1),
('calculations',	31,	'en',	'help_search',	2),
('calendar',	73,	'en',	'help_search',	1),
('called',	11,	'en',	'help_search',	0.886095),
('called',	13,	'en',	'help_search',	1),
('called',	25,	'en',	'help_search',	1),
('called',	27,	'en',	'help_search',	1),
('called',	29,	'en',	'help_search',	1),
('called',	58,	'en',	'help_search',	1),
('called',	80,	'en',	'help_search',	1),
('called',	85,	'en',	'help_search',	1),
('called',	86,	'en',	'help_search',	0.923838),
('can',	5,	'en',	'help_search',	2),
('can',	6,	'en',	'help_search',	1),
('can',	8,	'en',	'help_search',	3),
('can',	10,	'en',	'help_search',	3),
('can',	11,	'en',	'help_search',	5.18083),
('can',	12,	'en',	'help_search',	8.51489),
('can',	13,	'en',	'help_search',	4),
('can',	14,	'en',	'help_search',	2),
('can',	15,	'en',	'help_search',	2),
('can',	16,	'en',	'help_search',	4.98493),
('can',	17,	'en',	'help_search',	3),
('can',	18,	'en',	'help_search',	21),
('can',	20,	'en',	'help_search',	19),
('can',	21,	'en',	'help_search',	1),
('can',	22,	'en',	'help_search',	26),
('can',	23,	'en',	'help_search',	1),
('can',	24,	'en',	'help_search',	3),
('can',	25,	'en',	'help_search',	1),
('can',	26,	'en',	'help_search',	2),
('can',	27,	'en',	'help_search',	21),
('can',	29,	'en',	'help_search',	1),
('can',	30,	'en',	'help_search',	4.67183),
('can',	31,	'en',	'help_search',	2),
('can',	33,	'en',	'help_search',	23),
('can',	35,	'en',	'help_search',	1),
('can',	36,	'en',	'help_search',	1),
('can',	37,	'en',	'help_search',	1),
('can',	42,	'en',	'help_search',	1),
('can',	44,	'en',	'help_search',	8),
('can',	45,	'en',	'help_search',	1),
('can',	46,	'en',	'help_search',	40),
('can',	47,	'en',	'help_search',	1),
('can',	48,	'en',	'help_search',	3),
('can',	50,	'en',	'help_search',	5.89945),
('can',	51,	'en',	'help_search',	1),
('can',	53,	'en',	'help_search',	21),
('can',	54,	'en',	'help_search',	20),
('can',	55,	'en',	'help_search',	22),
('can',	56,	'en',	'help_search',	1),
('can',	57,	'en',	'help_search',	3.96109),
('can',	65,	'en',	'help_search',	3),
('can',	66,	'en',	'help_search',	2),
('can',	68,	'en',	'help_search',	3),
('can',	69,	'en',	'help_search',	1),
('can',	70,	'en',	'help_search',	20),
('can',	71,	'en',	'help_search',	7),
('can',	72,	'en',	'help_search',	3),
('can',	73,	'en',	'help_search',	6.85746),
('can',	74,	'en',	'help_search',	1),
('can',	75,	'en',	'help_search',	1),
('can',	78,	'en',	'help_search',	22),
('can',	79,	'en',	'help_search',	21),
('can',	80,	'en',	'help_search',	1),
('can',	81,	'en',	'help_search',	2),
('can',	83,	'en',	'help_search',	19),
('can',	84,	'en',	'help_search',	1),
('can',	86,	'en',	'help_search',	5.73295),
('can',	87,	'en',	'help_search',	3),
('cancel',	45,	'en',	'help_search',	8),
('cancel',	64,	'en',	'help_search',	0.968904),
('cancel',	85,	'en',	'help_search',	3.9235),
('canceled',	44,	'en',	'help_search',	5.98902),
('cannot',	14,	'en',	'help_search',	1),
('cannot',	36,	'en',	'help_search',	1),
('cannot',	39,	'en',	'help_search',	1),
('cannot',	73,	'en',	'help_search',	1),
('cannot',	84,	'en',	'help_search',	1),
('carefully',	50,	'en',	'help_search',	0.833529),
('case',	12,	'en',	'help_search',	0.646943),
('categorize',	71,	'en',	'help_search',	1),
('certain',	23,	'en',	'help_search',	1),
('certain',	42,	'en',	'help_search',	1),
('challenge',	23,	'en',	'help_search',	1),
('change',	5,	'en',	'help_search',	2),
('change',	8,	'en',	'help_search',	1),
('change',	10,	'en',	'help_search',	1.96621),
('change',	34,	'en',	'help_search',	1),
('change',	40,	'en',	'help_search',	1),
('change',	41,	'en',	'help_search',	1),
('change',	47,	'en',	'help_search',	4),
('change',	52,	'en',	'help_search',	1),
('change',	53,	'en',	'help_search',	1),
('change',	55,	'en',	'help_search',	1.98493),
('change',	66,	'en',	'help_search',	1),
('change',	67,	'en',	'help_search',	1),
('change',	72,	'en',	'help_search',	1),
('change',	77,	'en',	'help_search',	1),
('change',	79,	'en',	'help_search',	2),
('change',	81,	'en',	'help_search',	0.96498),
('change',	85,	'en',	'help_search',	5),
('change',	86,	'en',	'help_search',	0.851346),
('changed',	29,	'en',	'help_search',	0.938382),
('changed',	31,	'en',	'help_search',	1),
('changed',	32,	'en',	'help_search',	1),
('changed',	38,	'en',	'help_search',	2),
('changed',	73,	'en',	'help_search',	1),
('changed',	84,	'en',	'help_search',	2),
('changes',	3,	'en',	'help_search',	1),
('changes',	11,	'en',	'help_search',	2),
('changes',	18,	'en',	'help_search',	1.94209),
('changes',	57,	'en',	'help_search',	2),
('changes',	66,	'en',	'help_search',	1),
('changes',	67,	'en',	'help_search',	1),
('changes',	77,	'en',	'help_search',	1),
('changes',	79,	'en',	'help_search',	1),
('changes',	85,	'en',	'help_search',	0.98493),
('changing',	10,	'en',	'help_search',	45),
('changing',	32,	'en',	'help_search',	26),
('changing',	85,	'en',	'help_search',	1),
('changing',	86,	'en',	'help_search',	26),
('channel',	46,	'en',	'help_search',	1),
('character',	12,	'en',	'help_search',	0.693594),
('character',	78,	'en',	'help_search',	1),
('characteristics',	12,	'en',	'help_search',	1.409),
('characters',	12,	'en',	'help_search',	0.699655),
('check',	6,	'en',	'help_search',	1),
('check',	9,	'en',	'help_search',	1),
('check',	26,	'en',	'help_search',	1),
('check',	29,	'en',	'help_search',	1),
('check',	34,	'en',	'help_search',	1),
('check',	35,	'en',	'help_search',	2),
('check',	36,	'en',	'help_search',	1),
('check',	37,	'en',	'help_search',	4),
('check',	40,	'en',	'help_search',	1),
('check',	43,	'en',	'help_search',	1),
('check',	44,	'en',	'help_search',	1),
('check',	47,	'en',	'help_search',	2),
('check',	50,	'en',	'help_search',	1.74863),
('check',	55,	'en',	'help_search',	1),
('check',	68,	'en',	'help_search',	1),
('check',	74,	'en',	'help_search',	1),
('check',	75,	'en',	'help_search',	1),
('check',	77,	'en',	'help_search',	1),
('check',	83,	'en',	'help_search',	1),
('check',	86,	'en',	'help_search',	2.89945),
('checkbox',	35,	'en',	'help_search',	1),
('checkbox',	47,	'en',	'help_search',	1),
('checked',	37,	'en',	'help_search',	4),
('checked',	40,	'en',	'help_search',	1),
('checked',	53,	'en',	'help_search',	1),
('checked',	75,	'en',	'help_search',	1),
('child',	75,	'en',	'help_search',	1),
('children',	75,	'en',	'help_search',	1),
('chinese',	29,	'en',	'help_search',	1),
('choice',	35,	'en',	'help_search',	1),
('choice',	70,	'en',	'help_search',	1),
('choices',	12,	'en',	'help_search',	0.643484),
('choices',	68,	'en',	'help_search',	2),
('choose',	26,	'en',	'help_search',	1),
('choose',	38,	'en',	'help_search',	1),
('choose',	50,	'en',	'help_search',	1.83353),
('choose',	66,	'en',	'help_search',	1),
('choose',	68,	'en',	'help_search',	2),
('choose',	70,	'en',	'help_search',	1),
('choose',	72,	'en',	'help_search',	2),
('choose',	73,	'en',	'help_search',	2),
('choose',	76,	'en',	'help_search',	1),
('choosing',	23,	'en',	'help_search',	1),
('choosing',	58,	'en',	'help_search',	1),
('choosing',	73,	'en',	'help_search',	1),
('chose',	35,	'en',	'help_search',	2),
('chosen',	12,	'en',	'help_search',	1.55879),
('chosen',	50,	'en',	'help_search',	1),
('chosen',	85,	'en',	'help_search',	1),
('cjk',	29,	'en',	'help_search',	3.97258),
('ckeditor',	58,	'en',	'help_search',	13.1162),
('claro',	26,	'en',	'help_search',	1),
('claro',	27,	'en',	'help_search',	0.989021),
('claro',	81,	'en',	'help_search',	1),
('classic',	86,	'en',	'help_search',	1),
('classified',	71,	'en',	'help_search',	0.961087),
('classify',	42,	'en',	'help_search',	1),
('classify',	71,	'en',	'help_search',	4.99731),
('clean',	58,	'en',	'help_search',	1),
('clear',	15,	'en',	'help_search',	1),
('clear',	31,	'en',	'help_search',	11),
('clear',	34,	'en',	'help_search',	1),
('cleared',	31,	'en',	'help_search',	1),
('clearing',	26,	'en',	'help_search',	1),
('clearing',	31,	'en',	'help_search',	26),
('clearing',	34,	'en',	'help_search',	1),
('cli',	11,	'en',	'help_search',	0.725015),
('click',	1,	'en',	'help_search',	1),
('click',	3,	'en',	'help_search',	2),
('click',	4,	'en',	'help_search',	1),
('click',	5,	'en',	'help_search',	2),
('click',	6,	'en',	'help_search',	2),
('click',	7,	'en',	'help_search',	2),
('click',	9,	'en',	'help_search',	2),
('click',	13,	'en',	'help_search',	1.98087),
('click',	20,	'en',	'help_search',	3),
('click',	26,	'en',	'help_search',	2),
('click',	28,	'en',	'help_search',	4),
('click',	29,	'en',	'help_search',	1.91473),
('click',	31,	'en',	'help_search',	1),
('click',	32,	'en',	'help_search',	4),
('click',	33,	'en',	'help_search',	1.86836),
('click',	34,	'en',	'help_search',	2),
('click',	35,	'en',	'help_search',	1),
('click',	36,	'en',	'help_search',	2),
('click',	37,	'en',	'help_search',	1),
('click',	38,	'en',	'help_search',	3),
('click',	39,	'en',	'help_search',	1),
('click',	40,	'en',	'help_search',	2),
('click',	41,	'en',	'help_search',	3),
('click',	43,	'en',	'help_search',	1),
('click',	44,	'en',	'help_search',	0.972861),
('click',	45,	'en',	'help_search',	5),
('click',	47,	'en',	'help_search',	5),
('click',	49,	'en',	'help_search',	5),
('click',	50,	'en',	'help_search',	1.71539),
('click',	51,	'en',	'help_search',	3),
('click',	52,	'en',	'help_search',	4),
('click',	53,	'en',	'help_search',	4),
('click',	54,	'en',	'help_search',	2),
('click',	55,	'en',	'help_search',	4.99315),
('click',	64,	'en',	'help_search',	2.98633),
('click',	65,	'en',	'help_search',	5),
('click',	66,	'en',	'help_search',	3),
('click',	67,	'en',	'help_search',	3),
('click',	68,	'en',	'help_search',	5),
('click',	70,	'en',	'help_search',	4),
('click',	72,	'en',	'help_search',	5),
('click',	74,	'en',	'help_search',	2),
('click',	75,	'en',	'help_search',	4),
('click',	76,	'en',	'help_search',	2),
('click',	77,	'en',	'help_search',	2),
('click',	78,	'en',	'help_search',	1),
('click',	79,	'en',	'help_search',	2),
('click',	81,	'en',	'help_search',	3.94216),
('click',	82,	'en',	'help_search',	4),
('click',	83,	'en',	'help_search',	4.98902),
('click',	84,	'en',	'help_search',	2),
('click',	85,	'en',	'help_search',	10.9809),
('click',	86,	'en',	'help_search',	8.60396),
('click',	87,	'en',	'help_search',	4),
('clicked',	64,	'en',	'help_search',	1),
('clicking',	23,	'en',	'help_search',	1),
('clicking',	55,	'en',	'help_search',	1),
('clicking',	64,	'en',	'help_search',	1),
('clicking',	81,	'en',	'help_search',	1),
('clicking',	85,	'en',	'help_search',	1),
('clicking',	86,	'en',	'help_search',	0.997306),
('clicking',	87,	'en',	'help_search',	1),
('clicks',	30,	'en',	'help_search',	1),
('clipboard',	2,	'en',	'help_search',	1),
('clipboard',	4,	'en',	'help_search',	2),
('cloned',	11,	'en',	'help_search',	0.842342),
('clones',	11,	'en',	'help_search',	0.860547),
('cloning',	11,	'en',	'help_search',	0.857458),
('code',	12,	'en',	'help_search',	0.752312),
('code',	33,	'en',	'help_search',	4),
('codebase',	11,	'en',	'help_search',	0.854391),
('codes',	12,	'en',	'help_search',	0.781775),
('codes',	32,	'en',	'help_search',	12),
('codes',	33,	'en',	'help_search',	1),
('collection',	12,	'en',	'help_search',	0.972861),
('collection',	17,	'en',	'help_search',	1),
('collectively',	29,	'en',	'help_search',	1),
('column',	28,	'en',	'help_search',	1),
('column',	29,	'en',	'help_search',	0.873132),
('column',	36,	'en',	'help_search',	2),
('column',	43,	'en',	'help_search',	1),
('column',	55,	'en',	'help_search',	3),
('column',	58,	'en',	'help_search',	1),
('column',	66,	'en',	'help_search',	2),
('column',	67,	'en',	'help_search',	1),
('column',	86,	'en',	'help_search',	1.94209),
('columns',	86,	'en',	'help_search',	5.9267),
('combinations',	12,	'en',	'help_search',	0.683725),
('come',	15,	'en',	'help_search',	1),
('come',	73,	'en',	'help_search',	0.913226),
('comes',	75,	'en',	'help_search',	1),
('command',	13,	'en',	'help_search',	1),
('command',	58,	'en',	'help_search',	1),
('commandline',	11,	'en',	'help_search',	0.729424),
('comment',	12,	'en',	'help_search',	2.38267),
('comments',	12,	'en',	'help_search',	0.869951),
('comments',	24,	'en',	'help_search',	1),
('comments',	73,	'en',	'help_search',	1),
('common',	68,	'en',	'help_search',	1),
('common',	71,	'en',	'help_search',	1),
('common',	82,	'en',	'help_search',	1),
('commonly',	12,	'en',	'help_search',	1),
('commonly',	50,	'en',	'help_search',	1),
('commonlyused',	24,	'en',	'help_search',	1),
('commonlyused',	44,	'en',	'help_search',	1),
('communitymembers',	22,	'en',	'help_search',	1),
('communityprovided',	22,	'en',	'help_search',	2),
('compact',	86,	'en',	'help_search',	0.839384),
('compares',	11,	'en',	'help_search',	0.759465),
('comparison',	25,	'en',	'help_search',	11),
('complete',	1,	'en',	'help_search',	26),
('complete',	3,	'en',	'help_search',	28),
('complete',	26,	'en',	'help_search',	1),
('complete',	58,	'en',	'help_search',	0.839384),
('complete',	64,	'en',	'help_search',	0.98493),
('complete',	81,	'en',	'help_search',	0.993146),
('completely',	12,	'en',	'help_search',	0.664818),
('complex',	11,	'en',	'help_search',	1),
('complex',	25,	'en',	'help_search',	1),
('complex',	30,	'en',	'help_search',	0.892724),
('compliance',	23,	'en',	'help_search',	1),
('compliant',	25,	'en',	'help_search',	1),
('components',	24,	'en',	'help_search',	20),
('components',	73,	'en',	'help_search',	20),
('composed',	32,	'en',	'help_search',	1),
('compressed',	18,	'en',	'help_search',	1),
('computer',	2,	'en',	'help_search',	1),
('computer',	4,	'en',	'help_search',	1),
('concept',	11,	'en',	'help_search',	14.7488),
('concept',	12,	'en',	'help_search',	12.7),
('concept',	13,	'en',	'help_search',	10.6579),
('concept',	14,	'en',	'help_search',	11),
('concept',	17,	'en',	'help_search',	11),
('concept',	27,	'en',	'help_search',	1),
('concept',	31,	'en',	'help_search',	11),
('concept',	71,	'en',	'help_search',	9.74705),
('concept',	80,	'en',	'help_search',	11),
('concepts',	11,	'en',	'help_search',	0.819249),
('conditions',	31,	'en',	'help_search',	1),
('conditions',	47,	'en',	'help_search',	1),
('config',	11,	'en',	'help_search',	8),
('configurable',	24,	'en',	'help_search',	1),
('configuration',	1,	'en',	'help_search',	37),
('configuration',	2,	'en',	'help_search',	49),
('configuration',	3,	'en',	'help_search',	46),
('configuration',	4,	'en',	'help_search',	47),
('configuration',	5,	'en',	'help_search',	1),
('configuration',	6,	'en',	'help_search',	8),
('configuration',	11,	'en',	'help_search',	172.074),
('configuration',	12,	'en',	'help_search',	5),
('configuration',	13,	'en',	'help_search',	7.9074),
('configuration',	14,	'en',	'help_search',	1),
('configuration',	18,	'en',	'help_search',	3.49253),
('configuration',	22,	'en',	'help_search',	7),
('configuration',	24,	'en',	'help_search',	4.70972),
('configuration',	26,	'en',	'help_search',	4),
('configuration',	28,	'en',	'help_search',	4),
('configuration',	29,	'en',	'help_search',	8.77905),
('configuration',	30,	'en',	'help_search',	2),
('configuration',	31,	'en',	'help_search',	4),
('configuration',	32,	'en',	'help_search',	20),
('configuration',	33,	'en',	'help_search',	16.1957),
('configuration',	34,	'en',	'help_search',	16),
('configuration',	36,	'en',	'help_search',	1),
('configuration',	38,	'en',	'help_search',	4),
('configuration',	44,	'en',	'help_search',	7.85992),
('configuration',	49,	'en',	'help_search',	1),
('configuration',	50,	'en',	'help_search',	11.2476),
('configuration',	58,	'en',	'help_search',	10.3077),
('configuration',	72,	'en',	'help_search',	5),
('configuration',	79,	'en',	'help_search',	4),
('configuration',	86,	'en',	'help_search',	0.848323),
('configuration',	87,	'en',	'help_search',	4),
('configure',	6,	'en',	'help_search',	1),
('configure',	13,	'en',	'help_search',	4),
('configure',	15,	'en',	'help_search',	1),
('configure',	22,	'en',	'help_search',	1),
('configure',	24,	'en',	'help_search',	2.85752),
('configure',	27,	'en',	'help_search',	1),
('configure',	28,	'en',	'help_search',	2),
('configure',	30,	'en',	'help_search',	2.73993),
('configure',	32,	'en',	'help_search',	1),
('configure',	33,	'en',	'help_search',	1),
('configure',	44,	'en',	'help_search',	2),
('configure',	47,	'en',	'help_search',	5),
('configure',	48,	'en',	'help_search',	1),
('configure',	49,	'en',	'help_search',	5),
('configure',	50,	'en',	'help_search',	7.40885),
('configure',	54,	'en',	'help_search',	1),
('configure',	58,	'en',	'help_search',	2.99315),
('configure',	64,	'en',	'help_search',	2),
('configure',	65,	'en',	'help_search',	1),
('configure',	66,	'en',	'help_search',	2),
('configure',	67,	'en',	'help_search',	2),
('configure',	70,	'en',	'help_search',	21),
('configure',	72,	'en',	'help_search',	1),
('configure',	74,	'en',	'help_search',	28),
('configure',	80,	'en',	'help_search',	1),
('configure',	86,	'en',	'help_search',	1.91323),
('configured',	17,	'en',	'help_search',	1),
('configured',	22,	'en',	'help_search',	1),
('configured',	29,	'en',	'help_search',	0.909743),
('configured',	30,	'en',	'help_search',	2.74449),
('configured',	44,	'en',	'help_search',	1),
('configured',	48,	'en',	'help_search',	1),
('configured',	75,	'en',	'help_search',	1),
('configured',	86,	'en',	'help_search',	0.920273),
('configuring',	6,	'en',	'help_search',	26),
('configuring',	12,	'en',	'help_search',	0.597248),
('configuring',	13,	'en',	'help_search',	37.4847),
('configuring',	26,	'en',	'help_search',	28),
('configuring',	27,	'en',	'help_search',	0.953396),
('configuring',	28,	'en',	'help_search',	26),
('configuring',	29,	'en',	'help_search',	1.91323),
('configuring',	30,	'en',	'help_search',	42.7117),
('configuring',	33,	'en',	'help_search',	26),
('configuring',	44,	'en',	'help_search',	26),
('configuring',	47,	'en',	'help_search',	26),
('configuring',	49,	'en',	'help_search',	1),
('configuring',	66,	'en',	'help_search',	26),
('configuring',	67,	'en',	'help_search',	26),
('configuring',	70,	'en',	'help_search',	26),
('configuring',	71,	'en',	'help_search',	0.920273),
('configuring',	73,	'en',	'help_search',	0.805455),
('configuring',	78,	'en',	'help_search',	1),
('configuring',	79,	'en',	'help_search',	1),
('configuring',	80,	'en',	'help_search',	45),
('configuring',	83,	'en',	'help_search',	1),
('confirm',	35,	'en',	'help_search',	1),
('confirm',	86,	'en',	'help_search',	1),
('confirmation',	36,	'en',	'help_search',	1),
('confirmation',	70,	'en',	'help_search',	1),
('confused',	83,	'en',	'help_search',	1),
('connect',	50,	'en',	'help_search',	0.848323),
('connected',	58,	'en',	'help_search',	1),
('connecting',	58,	'en',	'help_search',	26),
('consist',	12,	'en',	'help_search',	1),
('consists',	86,	'en',	'help_search',	1),
('consume',	57,	'en',	'help_search',	1),
('contact',	5,	'en',	'help_search',	51),
('contact',	6,	'en',	'help_search',	44),
('contact',	7,	'en',	'help_search',	38),
('contact',	8,	'en',	'help_search',	98),
('contact',	9,	'en',	'help_search',	47),
('contact',	12,	'en',	'help_search',	0.609315),
('contain',	12,	'en',	'help_search',	1.44349),
('contain',	24,	'en',	'help_search',	1),
('contain',	71,	'en',	'help_search',	1),
('contain',	83,	'en',	'help_search',	1),
('containing',	1,	'en',	'help_search',	1),
('containing',	30,	'en',	'help_search',	0.949597),
('containing',	72,	'en',	'help_search',	1),
('containing',	85,	'en',	'help_search',	2),
('containing',	86,	'en',	'help_search',	1),
('contains',	11,	'en',	'help_search',	0.824901),
('contains',	47,	'en',	'help_search',	1),
('contains',	64,	'en',	'help_search',	1),
('contains',	81,	'en',	'help_search',	1),
('content',	5,	'en',	'help_search',	2),
('content',	10,	'en',	'help_search',	4.97685),
('content',	11,	'en',	'help_search',	1),
('content',	12,	'en',	'help_search',	89.8735),
('content',	13,	'en',	'help_search',	1),
('content',	14,	'en',	'help_search',	2),
('content',	16,	'en',	'help_search',	5),
('content',	17,	'en',	'help_search',	2),
('content',	20,	'en',	'help_search',	1),
('content',	21,	'en',	'help_search',	28),
('content',	22,	'en',	'help_search',	6),
('content',	24,	'en',	'help_search',	4.98087),
('content',	25,	'en',	'help_search',	3),
('content',	28,	'en',	'help_search',	8),
('content',	29,	'en',	'help_search',	7.89272),
('content',	30,	'en',	'help_search',	8.21653),
('content',	33,	'en',	'help_search',	1),
('content',	36,	'en',	'help_search',	1),
('content',	42,	'en',	'help_search',	2),
('content',	44,	'en',	'help_search',	1.98902),
('content',	45,	'en',	'help_search',	1),
('content',	46,	'en',	'help_search',	4),
('content',	48,	'en',	'help_search',	28),
('content',	50,	'en',	'help_search',	3.87562),
('content',	51,	'en',	'help_search',	36),
('content',	53,	'en',	'help_search',	99.8792),
('content',	54,	'en',	'help_search',	88),
('content',	55,	'en',	'help_search',	107.333),
('content',	56,	'en',	'help_search',	105),
('content',	57,	'en',	'help_search',	1),
('content',	58,	'en',	'help_search',	4),
('content',	65,	'en',	'help_search',	11),
('content',	66,	'en',	'help_search',	6),
('content',	67,	'en',	'help_search',	6),
('content',	68,	'en',	'help_search',	19),
('content',	69,	'en',	'help_search',	62),
('content',	70,	'en',	'help_search',	3),
('content',	71,	'en',	'help_search',	11.9596),
('content',	73,	'en',	'help_search',	31.6669),
('content',	74,	'en',	'help_search',	33),
('content',	75,	'en',	'help_search',	3),
('content',	78,	'en',	'help_search',	43),
('content',	80,	'en',	'help_search',	4),
('content',	84,	'en',	'help_search',	1),
('content',	85,	'en',	'help_search',	1),
('content',	86,	'en',	'help_search',	12.0989),
('content',	87,	'en',	'help_search',	4),
('context',	18,	'en',	'help_search',	1),
('context',	73,	'en',	'help_search',	3.62515),
('contextual',	20,	'en',	'help_search',	9),
('contextual',	24,	'en',	'help_search',	1),
('contextual',	64,	'en',	'help_search',	66),
('contextual',	73,	'en',	'help_search',	3.70972),
('contextual',	86,	'en',	'help_search',	0.860547),
('continue',	13,	'en',	'help_search',	1),
('continue',	65,	'en',	'help_search',	4),
('continue',	68,	'en',	'help_search',	4),
('continue',	70,	'en',	'help_search',	1),
('continue',	86,	'en',	'help_search',	0.909743),
('contributed',	10,	'en',	'help_search',	4),
('contributed',	12,	'en',	'help_search',	1.49425),
('contributed',	14,	'en',	'help_search',	5),
('contributed',	16,	'en',	'help_search',	1),
('contributed',	19,	'en',	'help_search',	2),
('contributed',	20,	'en',	'help_search',	1),
('contributed',	24,	'en',	'help_search',	3.8775),
('contributed',	25,	'en',	'help_search',	1),
('contributed',	27,	'en',	'help_search',	1),
('contributed',	30,	'en',	'help_search',	3),
('contributed',	35,	'en',	'help_search',	1),
('contributed',	38,	'en',	'help_search',	1),
('contributed',	53,	'en',	'help_search',	1),
('contributed',	55,	'en',	'help_search',	1),
('contributed',	56,	'en',	'help_search',	1),
('contributed',	58,	'en',	'help_search',	1),
('contributed',	64,	'en',	'help_search',	1),
('contributed',	73,	'en',	'help_search',	1),
('contributed',	80,	'en',	'help_search',	1),
('contributed',	81,	'en',	'help_search',	1),
('control',	53,	'en',	'help_search',	4),
('control',	55,	'en',	'help_search',	4),
('convert',	50,	'en',	'help_search',	2),
('converted',	18,	'en',	'help_search',	0.957226),
('converting',	25,	'en',	'help_search',	1),
('converting',	50,	'en',	'help_search',	1),
('converts',	50,	'en',	'help_search',	1),
('cookies',	12,	'en',	'help_search',	1),
('cooking',	71,	'en',	'help_search',	1),
('copied',	2,	'en',	'help_search',	1),
('copied',	11,	'en',	'help_search',	0.851346),
('copy',	2,	'en',	'help_search',	1),
('copy',	4,	'en',	'help_search',	1),
('copy',	13,	'en',	'help_search',	1),
('core',	8,	'en',	'help_search',	1),
('core',	10,	'en',	'help_search',	6.95772),
('core',	11,	'en',	'help_search',	1.70451),
('core',	12,	'en',	'help_search',	9.59002),
('core',	13,	'en',	'help_search',	1.99731),
('core',	14,	'en',	'help_search',	6),
('core',	15,	'en',	'help_search',	1),
('core',	16,	'en',	'help_search',	7.99461),
('core',	17,	'en',	'help_search',	2),
('core',	18,	'en',	'help_search',	1),
('core',	19,	'en',	'help_search',	3),
('core',	20,	'en',	'help_search',	4),
('core',	21,	'en',	'help_search',	1),
('core',	22,	'en',	'help_search',	4),
('core',	23,	'en',	'help_search',	1.98493),
('core',	24,	'en',	'help_search',	7.88282),
('core',	25,	'en',	'help_search',	1),
('core',	26,	'en',	'help_search',	1),
('core',	27,	'en',	'help_search',	6.98902),
('core',	29,	'en',	'help_search',	1),
('core',	30,	'en',	'help_search',	26.7867),
('core',	33,	'en',	'help_search',	1),
('core',	35,	'en',	'help_search',	1),
('core',	37,	'en',	'help_search',	4),
('core',	38,	'en',	'help_search',	1),
('core',	42,	'en',	'help_search',	2),
('core',	50,	'en',	'help_search',	3.81085),
('core',	54,	'en',	'help_search',	3),
('core',	56,	'en',	'help_search',	3),
('core',	58,	'en',	'help_search',	2),
('core',	64,	'en',	'help_search',	2),
('core',	69,	'en',	'help_search',	1),
('core',	70,	'en',	'help_search',	1),
('core',	71,	'en',	'help_search',	1.8881),
('core',	73,	'en',	'help_search',	2.41392),
('core',	76,	'en',	'help_search',	1),
('core',	80,	'en',	'help_search',	2),
('core',	81,	'en',	'help_search',	4),
('core',	83,	'en',	'help_search',	2),
('corner',	20,	'en',	'help_search',	1),
('corner',	64,	'en',	'help_search',	1),
('correct',	6,	'en',	'help_search',	1),
('correct',	8,	'en',	'help_search',	1),
('correct',	28,	'en',	'help_search',	2),
('correct',	40,	'en',	'help_search',	1),
('correct',	44,	'en',	'help_search',	0.976851),
('correct',	50,	'en',	'help_search',	1.83353),
('correct',	75,	'en',	'help_search',	2),
('correct',	79,	'en',	'help_search',	1),
('correct',	85,	'en',	'help_search',	1),
('corresponding',	24,	'en',	'help_search',	0.873132),
('corresponding',	64,	'en',	'help_search',	0.989021),
('corresponds',	12,	'en',	'help_search',	0.747619),
('corrupted',	29,	'en',	'help_search',	0.920273),
('could',	71,	'en',	'help_search',	6),
('could',	73,	'en',	'help_search',	0.824901),
('counterparts',	11,	'en',	'help_search',	0.747619),
('country',	32,	'en',	'help_search',	2),
('covered',	19,	'en',	'help_search',	2),
('create',	1,	'en',	'help_search',	1),
('create',	7,	'en',	'help_search',	1),
('create',	10,	'en',	'help_search',	1),
('create',	11,	'en',	'help_search',	0.848323),
('create',	12,	'en',	'help_search',	0.949597),
('create',	24,	'en',	'help_search',	1),
('create',	33,	'en',	'help_search',	2),
('create',	40,	'en',	'help_search',	6),
('create',	41,	'en',	'help_search',	1),
('create',	50,	'en',	'help_search',	0.920273),
('create',	51,	'en',	'help_search',	2),
('create',	53,	'en',	'help_search',	26),
('create',	54,	'en',	'help_search',	21),
('create',	70,	'en',	'help_search',	1),
('create',	71,	'en',	'help_search',	0.942091),
('create',	72,	'en',	'help_search',	4),
('create',	73,	'en',	'help_search',	1.7974),
('create',	76,	'en',	'help_search',	1),
('create',	78,	'en',	'help_search',	26),
('create',	81,	'en',	'help_search',	1),
('create',	84,	'en',	'help_search',	1),
('create',	86,	'en',	'help_search',	1),
('create',	87,	'en',	'help_search',	5),
('created',	14,	'en',	'help_search',	1),
('created',	36,	'en',	'help_search',	1),
('created',	44,	'en',	'help_search',	29.989),
('created',	54,	'en',	'help_search',	1),
('created',	55,	'en',	'help_search',	2),
('created',	69,	'en',	'help_search',	1),
('created',	70,	'en',	'help_search',	3),
('created',	71,	'en',	'help_search',	1),
('created',	73,	'en',	'help_search',	0.876337),
('created',	84,	'en',	'help_search',	1),
('creates',	57,	'en',	'help_search',	1),
('creates',	58,	'en',	'help_search',	1),
('creating',	7,	'en',	'help_search',	26),
('creating',	17,	'en',	'help_search',	1),
('creating',	40,	'en',	'help_search',	26),
('creating',	42,	'en',	'help_search',	1),
('creating',	44,	'en',	'help_search',	1),
('creating',	51,	'en',	'help_search',	26),
('creating',	53,	'en',	'help_search',	37.8792),
('creating',	54,	'en',	'help_search',	26),
('creating',	65,	'en',	'help_search',	1),
('creating',	67,	'en',	'help_search',	1),
('creating',	68,	'en',	'help_search',	1),
('creating',	69,	'en',	'help_search',	1),
('creating',	73,	'en',	'help_search',	8.57154),
('creating',	76,	'en',	'help_search',	26),
('creating',	78,	'en',	'help_search',	38),
('creating',	81,	'en',	'help_search',	26),
('creating',	84,	'en',	'help_search',	26),
('creating',	85,	'en',	'help_search',	10.6579),
('creating',	86,	'en',	'help_search',	9.04272),
('creation',	44,	'en',	'help_search',	19),
('criteria',	73,	'en',	'help_search',	10.8666),
('criteria',	85,	'en',	'help_search',	8),
('critical',	37,	'en',	'help_search',	2),
('cron',	12,	'en',	'help_search',	4),
('cron',	13,	'en',	'help_search',	127.986),
('cron',	15,	'en',	'help_search',	1),
('cron',	26,	'en',	'help_search',	2),
('cron',	29,	'en',	'help_search',	11.7259),
('crop',	72,	'en',	'help_search',	5),
('cropping',	16,	'en',	'help_search',	1),
('css',	10,	'en',	'help_search',	1),
('css',	14,	'en',	'help_search',	1),
('css',	18,	'en',	'help_search',	1.85135),
('curated',	71,	'en',	'help_search',	1),
('current',	11,	'en',	'help_search',	1),
('current',	73,	'en',	'help_search',	0.902857),
('current',	81,	'en',	'help_search',	8),
('current',	85,	'en',	'help_search',	1),
('currently',	12,	'en',	'help_search',	0.591395),
('currently',	24,	'en',	'help_search',	1),
('currently',	47,	'en',	'help_search',	1),
('currently',	58,	'en',	'help_search',	1),
('currently',	85,	'en',	'help_search',	1),
('custom',	12,	'en',	'help_search',	0.620288),
('custom',	17,	'en',	'help_search',	2),
('custom',	27,	'en',	'help_search',	1),
('custom',	76,	'en',	'help_search',	1),
('customize',	11,	'en',	'help_search',	1),
('customized',	86,	'en',	'help_search',	1),
('customizing',	10,	'en',	'help_search',	10.2416),
('customizing',	14,	'en',	'help_search',	11),
('data',	10,	'en',	'help_search',	1),
('data',	11,	'en',	'help_search',	31.9136),
('data',	12,	'en',	'help_search',	32.3651),
('data',	18,	'en',	'help_search',	6.93009),
('data',	25,	'en',	'help_search',	5),
('data',	31,	'en',	'help_search',	4),
('data',	44,	'en',	'help_search',	1),
('data',	56,	'en',	'help_search',	1),
('data',	73,	'en',	'help_search',	13.4291),
('data',	82,	'en',	'help_search',	1),
('data',	84,	'en',	'help_search',	1),
('data',	85,	'en',	'help_search',	1),
('database',	10,	'en',	'help_search',	1),
('database',	11,	'en',	'help_search',	1.85135),
('database',	12,	'en',	'help_search',	0.749958),
('database',	15,	'en',	'help_search',	1),
('database',	27,	'en',	'help_search',	1),
('database',	29,	'en',	'help_search',	1),
('database',	31,	'en',	'help_search',	1),
('database',	37,	'en',	'help_search',	1),
('date',	12,	'en',	'help_search',	2.57253),
('date',	32,	'en',	'help_search',	21),
('date',	73,	'en',	'help_search',	0.899454),
('dates',	12,	'en',	'help_search',	1.85746),
('datetime',	12,	'en',	'help_search',	1.71189),
('death',	33,	'en',	'help_search',	4),
('default',	9,	'en',	'help_search',	43),
('default',	10,	'en',	'help_search',	0.98493),
('default',	11,	'en',	'help_search',	4.66762),
('default',	16,	'en',	'help_search',	1),
('default',	22,	'en',	'help_search',	2),
('default',	23,	'en',	'help_search',	2),
('default',	28,	'en',	'help_search',	8),
('default',	29,	'en',	'help_search',	7.93972),
('default',	32,	'en',	'help_search',	5),
('default',	33,	'en',	'help_search',	1),
('default',	38,	'en',	'help_search',	38),
('default',	39,	'en',	'help_search',	1),
('default',	65,	'en',	'help_search',	1),
('default',	74,	'en',	'help_search',	5),
('default',	76,	'en',	'help_search',	2),
('default',	81,	'en',	'help_search',	1),
('default',	86,	'en',	'help_search',	3),
('defaults',	86,	'en',	'help_search',	9.01173),
('defend',	50,	'en',	'help_search',	1),
('define',	10,	'en',	'help_search',	1.97685),
('define',	11,	'en',	'help_search',	1),
('define',	12,	'en',	'help_search',	2.07234),
('define',	48,	'en',	'help_search',	1),
('define',	52,	'en',	'help_search',	1),
('define',	56,	'en',	'help_search',	1),
('define',	57,	'en',	'help_search',	3.9223),
('defined',	11,	'en',	'help_search',	2),
('defined',	51,	'en',	'help_search',	1),
('defined',	53,	'en',	'help_search',	1),
('defined',	57,	'en',	'help_search',	1),
('defines',	10,	'en',	'help_search',	1),
('defines',	12,	'en',	'help_search',	1),
('defines',	57,	'en',	'help_search',	1),
('defining',	11,	'en',	'help_search',	0.72066),
('defining',	16,	'en',	'help_search',	1),
('defining',	52,	'en',	'help_search',	26),
('defining',	57,	'en',	'help_search',	1),
('delete',	14,	'en',	'help_search',	1),
('delete',	18,	'en',	'help_search',	1),
('delete',	28,	'en',	'help_search',	1),
('delete',	36,	'en',	'help_search',	1),
('delete',	45,	'en',	'help_search',	3),
('delete',	73,	'en',	'help_search',	0.797402),
('delete',	81,	'en',	'help_search',	1),
('delete',	85,	'en',	'help_search',	1),
('deleted',	18,	'en',	'help_search',	1),
('deleted',	36,	'en',	'help_search',	1),
('deleted',	44,	'en',	'help_search',	28),
('deleting',	28,	'en',	'help_search',	1),
('deleting',	45,	'en',	'help_search',	26),
('deleting',	50,	'en',	'help_search',	0.805455),
('deletion',	44,	'en',	'help_search',	19),
('demonstrate',	47,	'en',	'help_search',	4),
('demonstrate',	49,	'en',	'help_search',	4),
('dependencies',	35,	'en',	'help_search',	1),
('dependent',	14,	'en',	'help_search',	1),
('depending',	12,	'en',	'help_search',	0.592848),
('depending',	13,	'en',	'help_search',	1),
('depending',	24,	'en',	'help_search',	1),
('depending',	42,	'en',	'help_search',	1),
('depending',	47,	'en',	'help_search',	1),
('depending',	65,	'en',	'help_search',	1),
('depends',	14,	'en',	'help_search',	1),
('deploying',	1,	'en',	'help_search',	1),
('deploying',	2,	'en',	'help_search',	1),
('deploying',	3,	'en',	'help_search',	1),
('deploying',	4,	'en',	'help_search',	1),
('deploying',	11,	'en',	'help_search',	26),
('deploying',	22,	'en',	'help_search',	1),
('deploying',	58,	'en',	'help_search',	1),
('derived',	76,	'en',	'help_search',	1),
('described',	11,	'en',	'help_search',	0.769219),
('described',	53,	'en',	'help_search',	1),
('describes',	11,	'en',	'help_search',	2),
('describes',	27,	'en',	'help_search',	1),
('description',	35,	'en',	'help_search',	1),
('description',	36,	'en',	'help_search',	5),
('description',	47,	'en',	'help_search',	1),
('description',	48,	'en',	'help_search',	20),
('description',	51,	'en',	'help_search',	1),
('description',	52,	'en',	'help_search',	1),
('description',	54,	'en',	'help_search',	4),
('description',	70,	'en',	'help_search',	1),
('description',	75,	'en',	'help_search',	4),
('description',	87,	'en',	'help_search',	4),
('descriptive',	72,	'en',	'help_search',	1),
('deserialization',	25,	'en',	'help_search',	4),
('design',	50,	'en',	'help_search',	1),
('desired',	5,	'en',	'help_search',	1),
('desired',	13,	'en',	'help_search',	1),
('desired',	28,	'en',	'help_search',	2),
('desired',	29,	'en',	'help_search',	1),
('desired',	30,	'en',	'help_search',	0.854391),
('desired',	33,	'en',	'help_search',	1),
('desired',	37,	'en',	'help_search',	1),
('desired',	41,	'en',	'help_search',	2),
('desired',	44,	'en',	'help_search',	0.997306),
('desired',	47,	'en',	'help_search',	1),
('desired',	50,	'en',	'help_search',	0.909743),
('desired',	52,	'en',	'help_search',	1),
('desired',	55,	'en',	'help_search',	1),
('desired',	58,	'en',	'help_search',	0.892724),
('desired',	66,	'en',	'help_search',	1),
('desired',	67,	'en',	'help_search',	1),
('desired',	75,	'en',	'help_search',	1),
('desired',	76,	'en',	'help_search',	1),
('desired',	78,	'en',	'help_search',	1),
('desired',	81,	'en',	'help_search',	1),
('desired',	86,	'en',	'help_search',	2.77299),
('destination',	11,	'en',	'help_search',	1.58432),
('details',	18,	'en',	'help_search',	0.896076),
('details',	24,	'en',	'help_search',	0.860547),
('details',	36,	'en',	'help_search',	1),
('details',	49,	'en',	'help_search',	1),
('details',	58,	'en',	'help_search',	1),
('details',	85,	'en',	'help_search',	1),
('determine',	10,	'en',	'help_search',	1),
('determines',	10,	'en',	'help_search',	1),
('dev',	11,	'en',	'help_search',	1.83938),
('development',	1,	'en',	'help_search',	4),
('development',	2,	'en',	'help_search',	4),
('development',	3,	'en',	'help_search',	4),
('development',	4,	'en',	'help_search',	4),
('development',	11,	'en',	'help_search',	16.539),
('development',	14,	'en',	'help_search',	1),
('development',	18,	'en',	'help_search',	3.4798),
('development',	31,	'en',	'help_search',	4),
('development',	33,	'en',	'help_search',	4.67026),
('development',	34,	'en',	'help_search',	8),
('device',	2,	'en',	'help_search',	1),
('device',	4,	'en',	'help_search',	1),
('device',	57,	'en',	'help_search',	2),
('deviceindependent',	57,	'en',	'help_search',	11),
('devices',	10,	'en',	'help_search',	0.96498),
('diagnose',	15,	'en',	'help_search',	2),
('dialog',	49,	'en',	'help_search',	2),
('dialog',	86,	'en',	'help_search',	1.92372),
('differences',	3,	'en',	'help_search',	1),
('different',	8,	'en',	'help_search',	1),
('different',	11,	'en',	'help_search',	1.65177),
('different',	12,	'en',	'help_search',	3.64749),
('different',	16,	'en',	'help_search',	1),
('different',	18,	'en',	'help_search',	1.95772),
('different',	57,	'en',	'help_search',	0.997306),
('different',	73,	'en',	'help_search',	1),
('different',	81,	'en',	'help_search',	1),
('differentsized',	10,	'en',	'help_search',	0.968904),
('difficult',	23,	'en',	'help_search',	1),
('direct',	46,	'en',	'help_search',	1),
('directly',	10,	'en',	'help_search',	1),
('directly',	46,	'en',	'help_search',	1),
('directly',	64,	'en',	'help_search',	1),
('directly',	81,	'en',	'help_search',	0.953396),
('directories',	11,	'en',	'help_search',	1),
('directory',	3,	'en',	'help_search',	1),
('directory',	11,	'en',	'help_search',	4.53613),
('disable',	6,	'en',	'help_search',	1),
('disable',	28,	'en',	'help_search',	1),
('disable',	77,	'en',	'help_search',	2),
('disabled',	23,	'en',	'help_search',	1),
('disabled',	35,	'en',	'help_search',	1),
('disabled',	66,	'en',	'help_search',	4),
('disabled',	67,	'en',	'help_search',	4),
('disabling',	17,	'en',	'help_search',	1),
('disabling',	23,	'en',	'help_search',	1),
('disabling',	28,	'en',	'help_search',	1),
('disabling',	34,	'en',	'help_search',	26),
('disabling',	36,	'en',	'help_search',	1),
('disabling',	77,	'en',	'help_search',	26),
('discard',	85,	'en',	'help_search',	0.989021),
('discovery',	10,	'en',	'help_search',	1.98087),
('display',	5,	'en',	'help_search',	5),
('display',	12,	'en',	'help_search',	3.12375),
('display',	17,	'en',	'help_search',	1),
('display',	23,	'en',	'help_search',	1),
('display',	24,	'en',	'help_search',	0.906287),
('display',	30,	'en',	'help_search',	1),
('display',	33,	'en',	'help_search',	3.68109),
('display',	34,	'en',	'help_search',	4),
('display',	47,	'en',	'help_search',	4),
('display',	52,	'en',	'help_search',	9),
('display',	54,	'en',	'help_search',	1),
('display',	56,	'en',	'help_search',	2),
('display',	58,	'en',	'help_search',	0.909743),
('display',	64,	'en',	'help_search',	0.997306),
('display',	65,	'en',	'help_search',	1),
('display',	66,	'en',	'help_search',	37),
('display',	67,	'en',	'help_search',	4),
('display',	68,	'en',	'help_search',	1),
('display',	69,	'en',	'help_search',	1),
('display',	70,	'en',	'help_search',	2),
('display',	71,	'en',	'help_search',	0.916736),
('display',	72,	'en',	'help_search',	1),
('display',	73,	'en',	'help_search',	13.1563),
('display',	75,	'en',	'help_search',	1),
('display',	80,	'en',	'help_search',	1),
('display',	81,	'en',	'help_search',	1),
('display',	82,	'en',	'help_search',	38),
('display',	83,	'en',	'help_search',	1),
('display',	84,	'en',	'help_search',	2),
('display',	85,	'en',	'help_search',	30),
('display',	86,	'en',	'help_search',	9),
('displayed',	9,	'en',	'help_search',	11),
('displayed',	10,	'en',	'help_search',	2),
('displayed',	11,	'en',	'help_search',	1),
('displayed',	12,	'en',	'help_search',	5.31879),
('displayed',	17,	'en',	'help_search',	1),
('displayed',	32,	'en',	'help_search',	4),
('displayed',	44,	'en',	'help_search',	1),
('displayed',	47,	'en',	'help_search',	3),
('displayed',	48,	'en',	'help_search',	1),
('displayed',	50,	'en',	'help_search',	1),
('displayed',	53,	'en',	'help_search',	2),
('displayed',	65,	'en',	'help_search',	1),
('displayed',	68,	'en',	'help_search',	1),
('displayed',	73,	'en',	'help_search',	1.89608),
('displayed',	75,	'en',	'help_search',	3),
('displayed',	76,	'en',	'help_search',	2),
('displayed',	81,	'en',	'help_search',	1),
('displayed',	85,	'en',	'help_search',	2),
('displayed',	86,	'en',	'help_search',	1.90286),
('displaying',	66,	'en',	'help_search',	1),
('displayname',	44,	'en',	'help_search',	1),
('displays',	24,	'en',	'help_search',	2),
('displays',	64,	'en',	'help_search',	1),
('displays',	69,	'en',	'help_search',	1),
('displays',	72,	'en',	'help_search',	1),
('displays',	73,	'en',	'help_search',	5),
('displays',	82,	'en',	'help_search',	4),
('displays',	83,	'en',	'help_search',	4),
('displays',	85,	'en',	'help_search',	4),
('distributed',	14,	'en',	'help_search',	1),
('divided',	12,	'en',	'help_search',	2),
('divided',	16,	'en',	'help_search',	1),
('divided',	56,	'en',	'help_search',	1),
('divisions',	12,	'en',	'help_search',	1),
('documentation',	18,	'en',	'help_search',	27.7322),
('documentation',	25,	'en',	'help_search',	22),
('documentation',	30,	'en',	'help_search',	8.57154),
('documented',	46,	'en',	'help_search',	1),
('documents',	16,	'en',	'help_search',	1),
('does',	11,	'en',	'help_search',	1),
('does',	12,	'en',	'help_search',	20),
('does',	32,	'en',	'help_search',	1),
('does',	33,	'en',	'help_search',	1),
('does',	58,	'en',	'help_search',	0.899454),
('don',	83,	'en',	'help_search',	1),
('done',	11,	'en',	'help_search',	0.736141),
('done',	26,	'en',	'help_search',	1),
('done',	31,	'en',	'help_search',	2),
('done',	55,	'en',	'help_search',	1),
('done',	66,	'en',	'help_search',	1),
('done',	67,	'en',	'help_search',	1),
('down',	28,	'en',	'help_search',	1),
('download',	1,	'en',	'help_search',	1),
('download',	10,	'en',	'help_search',	22),
('download',	14,	'en',	'help_search',	12),
('download',	22,	'en',	'help_search',	2),
('download',	35,	'en',	'help_search',	1),
('download',	58,	'en',	'help_search',	1),
('downloaded',	10,	'en',	'help_search',	2),
('downloaded',	14,	'en',	'help_search',	2),
('downloaded',	35,	'en',	'help_search',	1),
('downloaded',	38,	'en',	'help_search',	2),
('downloads',	22,	'en',	'help_search',	1),
('drag',	47,	'en',	'help_search',	1),
('drag',	50,	'en',	'help_search',	0.836446),
('drag',	58,	'en',	'help_search',	2.7113),
('drag',	66,	'en',	'help_search',	2),
('drag',	67,	'en',	'help_search',	2),
('drag',	72,	'en',	'help_search',	1),
('drag',	75,	'en',	'help_search',	1),
('drag',	77,	'en',	'help_search',	1),
('draganddrop',	23,	'en',	'help_search',	3),
('dragging',	23,	'en',	'help_search',	1),
('dragging',	58,	'en',	'help_search',	0.882818),
('dragging',	86,	'en',	'help_search',	0.876337),
('drastic',	33,	'en',	'help_search',	1),
('dropdown',	79,	'en',	'help_search',	1),
('dropdown',	83,	'en',	'help_search',	1),
('dropdown',	85,	'en',	'help_search',	2),
('dropped',	29,	'en',	'help_search',	1),
('drupal',	10,	'en',	'help_search',	20.2472),
('drupal',	11,	'en',	'help_search',	22.041),
('drupal',	12,	'en',	'help_search',	19.0044),
('drupal',	13,	'en',	'help_search',	21.0603),
('drupal',	14,	'en',	'help_search',	22),
('drupal',	15,	'en',	'help_search',	22),
('drupal',	17,	'en',	'help_search',	11),
('drupal',	19,	'en',	'help_search',	23),
('drupal',	31,	'en',	'help_search',	11),
('drupal',	37,	'en',	'help_search',	11),
('drupal',	46,	'en',	'help_search',	54),
('drupal',	48,	'en',	'help_search',	11),
('drupal',	53,	'en',	'help_search',	21.8496),
('drupal',	54,	'en',	'help_search',	22),
('drupal',	55,	'en',	'help_search',	20.8086),
('drupal',	57,	'en',	'help_search',	10.363),
('drupal',	70,	'en',	'help_search',	11),
('drupal',	71,	'en',	'help_search',	9.711),
('drupal',	73,	'en',	'help_search',	8.54373),
('drupal',	78,	'en',	'help_search',	11),
('drupal',	80,	'en',	'help_search',	11),
('drupal',	85,	'en',	'help_search',	10.572),
('drupalorg',	10,	'en',	'help_search',	22),
('drupalorg',	14,	'en',	'help_search',	11),
('drush',	11,	'en',	'help_search',	7.43636),
('due',	33,	'en',	'help_search',	1),
('during',	29,	'en',	'help_search',	1),
('during',	74,	'en',	'help_search',	1),
('dynamic',	18,	'en',	'help_search',	10.2101),
('each',	8,	'en',	'help_search',	1),
('each',	11,	'en',	'help_search',	2.89272),
('each',	12,	'en',	'help_search',	1.74762),
('each',	17,	'en',	'help_search',	1),
('each',	27,	'en',	'help_search',	1),
('each',	29,	'en',	'help_search',	0.879565),
('each',	30,	'en',	'help_search',	2),
('each',	33,	'en',	'help_search',	1),
('each',	38,	'en',	'help_search',	1),
('each',	42,	'en',	'help_search',	1),
('each',	48,	'en',	'help_search',	2),
('each',	50,	'en',	'help_search',	1.79212),
('each',	53,	'en',	'help_search',	1),
('each',	55,	'en',	'help_search',	1),
('each',	56,	'en',	'help_search',	3),
('each',	57,	'en',	'help_search',	1),
('each',	58,	'en',	'help_search',	1),
('each',	66,	'en',	'help_search',	3),
('each',	67,	'en',	'help_search',	2),
('each',	69,	'en',	'help_search',	3),
('each',	71,	'en',	'help_search',	2.93781),
('each',	73,	'en',	'help_search',	2),
('each',	81,	'en',	'help_search',	1),
('each',	83,	'en',	'help_search',	1),
('each',	85,	'en',	'help_search',	1),
('each',	86,	'en',	'help_search',	8.63894),
('each',	87,	'en',	'help_search',	1),
('easier',	23,	'en',	'help_search',	2),
('easier',	58,	'en',	'help_search',	1),
('easier',	68,	'en',	'help_search',	1),
('easy',	30,	'en',	'help_search',	0.800068),
('edit',	9,	'en',	'help_search',	4),
('edit',	12,	'en',	'help_search',	1.59803),
('edit',	20,	'en',	'help_search',	39),
('edit',	24,	'en',	'help_search',	0.993146),
('edit',	28,	'en',	'help_search',	4),
('edit',	32,	'en',	'help_search',	5),
('edit',	41,	'en',	'help_search',	4),
('edit',	44,	'en',	'help_search',	1.98493),
('edit',	45,	'en',	'help_search',	4),
('edit',	47,	'en',	'help_search',	1),
('edit',	48,	'en',	'help_search',	1),
('edit',	52,	'en',	'help_search',	1),
('edit',	53,	'en',	'help_search',	2),
('edit',	54,	'en',	'help_search',	1),
('edit',	55,	'en',	'help_search',	38),
('edit',	56,	'en',	'help_search',	2),
('edit',	64,	'en',	'help_search',	1),
('edit',	65,	'en',	'help_search',	2),
('edit',	67,	'en',	'help_search',	27),
('edit',	68,	'en',	'help_search',	1),
('edit',	71,	'en',	'help_search',	0.938382),
('edit',	73,	'en',	'help_search',	1.7974),
('edit',	74,	'en',	'help_search',	4),
('edit',	75,	'en',	'help_search',	5),
('edit',	76,	'en',	'help_search',	1),
('edit',	77,	'en',	'help_search',	5),
('edit',	78,	'en',	'help_search',	7),
('edit',	79,	'en',	'help_search',	5),
('edit',	81,	'en',	'help_search',	12.9397),
('edit',	82,	'en',	'help_search',	6),
('edit',	83,	'en',	'help_search',	26),
('edit',	84,	'en',	'help_search',	5),
('edit',	85,	'en',	'help_search',	7),
('edit',	87,	'en',	'help_search',	4),
('edited',	12,	'en',	'help_search',	0.63333),
('editing',	12,	'en',	'help_search',	0.635),
('editing',	16,	'en',	'help_search',	1),
('editing',	17,	'en',	'help_search',	1),
('editing',	20,	'en',	'help_search',	46),
('editing',	24,	'en',	'help_search',	3),
('editing',	42,	'en',	'help_search',	1),
('editing',	50,	'en',	'help_search',	1),
('editing',	52,	'en',	'help_search',	1),
('editing',	54,	'en',	'help_search',	1),
('editing',	55,	'en',	'help_search',	37.363),
('editing',	58,	'en',	'help_search',	2),
('editing',	64,	'en',	'help_search',	1),
('editing',	65,	'en',	'help_search',	3),
('editing',	67,	'en',	'help_search',	5),
('editing',	68,	'en',	'help_search',	3),
('editing',	69,	'en',	'help_search',	1),
('editing',	71,	'en',	'help_search',	3.91674),
('editing',	74,	'en',	'help_search',	3),
('editing',	76,	'en',	'help_search',	1),
('editing',	78,	'en',	'help_search',	1),
('editing',	79,	'en',	'help_search',	26),
('editing',	81,	'en',	'help_search',	1),
('editing',	82,	'en',	'help_search',	3),
('editing',	85,	'en',	'help_search',	28),
('editor',	2,	'en',	'help_search',	1),
('editor',	50,	'en',	'help_search',	3.65618),
('editor',	58,	'en',	'help_search',	35.8406),
('editors',	50,	'en',	'help_search',	7.96127),
('editors',	58,	'en',	'help_search',	35.9809),
('editors',	68,	'en',	'help_search',	1),
('edits',	20,	'en',	'help_search',	1),
('edits',	55,	'en',	'help_search',	1),
('effect',	72,	'en',	'help_search',	11),
('effects',	16,	'en',	'help_search',	5),
('effects',	72,	'en',	'help_search',	3),
('efficiently',	29,	'en',	'help_search',	1),
('either',	11,	'en',	'help_search',	0.733888),
('either',	12,	'en',	'help_search',	0.725015),
('either',	20,	'en',	'help_search',	1),
('either',	39,	'en',	'help_search',	1),
('either',	50,	'en',	'help_search',	1.86995),
('either',	64,	'en',	'help_search',	1),
('either',	81,	'en',	'help_search',	1),
('element',	83,	'en',	'help_search',	1),
('else',	55,	'en',	'help_search',	1),
('email',	8,	'en',	'help_search',	2),
('email',	12,	'en',	'help_search',	1.68173),
('email',	32,	'en',	'help_search',	2),
('email',	40,	'en',	'help_search',	5),
('email',	44,	'en',	'help_search',	24.9849),
('email',	45,	'en',	'help_search',	1),
('embed',	50,	'en',	'help_search',	0.899454),
('empty',	86,	'en',	'help_search',	1),
('enable',	6,	'en',	'help_search',	1),
('enable',	24,	'en',	'help_search',	1),
('enable',	27,	'en',	'help_search',	1),
('enable',	77,	'en',	'help_search',	1),
('enabled',	8,	'en',	'help_search',	1),
('enabled',	12,	'en',	'help_search',	0.71),
('enabled',	27,	'en',	'help_search',	1),
('enabled',	46,	'en',	'help_search',	2),
('enabled',	50,	'en',	'help_search',	4.36937),
('enabled',	75,	'en',	'help_search',	4),
('enabled',	77,	'en',	'help_search',	4),
('enables',	6,	'en',	'help_search',	2),
('enabling',	23,	'en',	'help_search',	1),
('enabling',	25,	'en',	'help_search',	26),
('enabling',	34,	'en',	'help_search',	26),
('enabling',	36,	'en',	'help_search',	1),
('enclosed',	44,	'en',	'help_search',	1),
('encode',	57,	'en',	'help_search',	1),
('end',	12,	'en',	'help_search',	0.845322),
('end',	18,	'en',	'help_search',	1),
('end',	64,	'en',	'help_search',	2),
('end',	81,	'en',	'help_search',	1.95373),
('enforces',	58,	'en',	'help_search',	1),
('enforcing',	50,	'en',	'help_search',	1),
('engines',	66,	'en',	'help_search',	1),
('english',	22,	'en',	'help_search',	3),
('english',	30,	'en',	'help_search',	0.972861),
('enhances',	24,	'en',	'help_search',	1),
('ensure',	13,	'en',	'help_search',	1),
('ensure',	50,	'en',	'help_search',	0.889397),
('enter',	26,	'en',	'help_search',	1),
('enter',	28,	'en',	'help_search',	1),
('enter',	29,	'en',	'help_search',	1),
('enter',	32,	'en',	'help_search',	1),
('enter',	33,	'en',	'help_search',	1.9689),
('enter',	35,	'en',	'help_search',	1),
('enter',	36,	'en',	'help_search',	1),
('enter',	40,	'en',	'help_search',	1),
('enter',	41,	'en',	'help_search',	1),
('enter',	45,	'en',	'help_search',	2),
('enter',	47,	'en',	'help_search',	1),
('enter',	50,	'en',	'help_search',	0.913226),
('enter',	51,	'en',	'help_search',	1),
('enter',	52,	'en',	'help_search',	1),
('enter',	53,	'en',	'help_search',	1),
('enter',	54,	'en',	'help_search',	2),
('enter',	55,	'en',	'help_search',	1),
('enter',	65,	'en',	'help_search',	2),
('enter',	68,	'en',	'help_search',	2),
('enter',	70,	'en',	'help_search',	2),
('enter',	71,	'en',	'help_search',	1),
('enter',	72,	'en',	'help_search',	2),
('enter',	75,	'en',	'help_search',	3),
('enter',	76,	'en',	'help_search',	2),
('enter',	78,	'en',	'help_search',	1),
('enter',	82,	'en',	'help_search',	1),
('enter',	84,	'en',	'help_search',	2),
('enter',	86,	'en',	'help_search',	1),
('enter',	87,	'en',	'help_search',	1),
('entered',	65,	'en',	'help_search',	1),
('entered',	68,	'en',	'help_search',	1),
('entering',	33,	'en',	'help_search',	1),
('enters',	30,	'en',	'help_search',	1),
('entities',	10,	'en',	'help_search',	1),
('entities',	11,	'en',	'help_search',	2),
('entities',	12,	'en',	'help_search',	4.71418),
('entities',	16,	'en',	'help_search',	3),
('entities',	25,	'en',	'help_search',	6),
('entities',	56,	'en',	'help_search',	1),
('entities',	68,	'en',	'help_search',	1),
('entities',	70,	'en',	'help_search',	1),
('entities',	71,	'en',	'help_search',	3.92384),
('entities',	86,	'en',	'help_search',	1),
('entities',	87,	'en',	'help_search',	1),
('entity',	10,	'en',	'help_search',	2),
('entity',	11,	'en',	'help_search',	1),
('entity',	12,	'en',	'help_search',	49.9515),
('entity',	16,	'en',	'help_search',	1),
('entity',	56,	'en',	'help_search',	3),
('entity',	65,	'en',	'help_search',	30),
('entity',	66,	'en',	'help_search',	30),
('entity',	67,	'en',	'help_search',	30),
('entity',	68,	'en',	'help_search',	34),
('entity',	70,	'en',	'help_search',	7),
('entity',	71,	'en',	'help_search',	3),
('entity',	86,	'en',	'help_search',	32),
('entity',	87,	'en',	'help_search',	2),
('entries',	56,	'en',	'help_search',	1),
('error',	15,	'en',	'help_search',	1),
('error',	23,	'en',	'help_search',	1),
('error',	33,	'en',	'help_search',	36.6811),
('error',	37,	'en',	'help_search',	1),
('errors',	23,	'en',	'help_search',	4.98493),
('errors',	33,	'en',	'help_search',	28.6271),
('errors',	37,	'en',	'help_search',	1),
('etc',	12,	'en',	'help_search',	1),
('etc',	22,	'en',	'help_search',	1),
('etc',	73,	'en',	'help_search',	3.89608),
('etc',	82,	'en',	'help_search',	1),
('events',	56,	'en',	'help_search',	1),
('every',	13,	'en',	'help_search',	3.93972),
('exact',	30,	'en',	'help_search',	1),
('exact',	83,	'en',	'help_search',	1),
('example',	9,	'en',	'help_search',	1),
('example',	10,	'en',	'help_search',	1),
('example',	11,	'en',	'help_search',	2.89272),
('example',	12,	'en',	'help_search',	4.76159),
('example',	20,	'en',	'help_search',	1),
('example',	30,	'en',	'help_search',	1.96498),
('example',	33,	'en',	'help_search',	0.989021),
('example',	36,	'en',	'help_search',	1),
('example',	50,	'en',	'help_search',	0.830633),
('example',	53,	'en',	'help_search',	1),
('example',	55,	'en',	'help_search',	2),
('example',	56,	'en',	'help_search',	1),
('example',	64,	'en',	'help_search',	1),
('example',	65,	'en',	'help_search',	1),
('example',	66,	'en',	'help_search',	1),
('example',	67,	'en',	'help_search',	1),
('example',	68,	'en',	'help_search',	2),
('example',	70,	'en',	'help_search',	2),
('example',	71,	'en',	'help_search',	3),
('example',	72,	'en',	'help_search',	1),
('example',	73,	'en',	'help_search',	1.8249),
('example',	78,	'en',	'help_search',	2),
('example',	80,	'en',	'help_search',	3),
('example',	85,	'en',	'help_search',	1),
('example',	86,	'en',	'help_search',	1),
('examplecom',	33,	'en',	'help_search',	7.8309),
('examplecom',	78,	'en',	'help_search',	4),
('examplecom',	80,	'en',	'help_search',	12),
('examples',	12,	'en',	'help_search',	0.677939),
('examples',	16,	'en',	'help_search',	1),
('examples',	71,	'en',	'help_search',	2),
('examples',	80,	'en',	'help_search',	1),
('except',	73,	'en',	'help_search',	0.916736),
('exchanged',	25,	'en',	'help_search',	2),
('exist',	12,	'en',	'help_search',	0.681785),
('exist',	33,	'en',	'help_search',	1),
('existing',	24,	'en',	'help_search',	0.938382),
('existing',	28,	'en',	'help_search',	1),
('existing',	43,	'en',	'help_search',	1),
('existing',	45,	'en',	'help_search',	1),
('existing',	50,	'en',	'help_search',	0.927431),
('existing',	58,	'en',	'help_search',	0.993146),
('existing',	71,	'en',	'help_search',	1),
('existing',	74,	'en',	'help_search',	1),
('existing',	79,	'en',	'help_search',	1),
('existing',	82,	'en',	'help_search',	29),
('existing',	83,	'en',	'help_search',	2),
('existing',	85,	'en',	'help_search',	28),
('existing',	87,	'en',	'help_search',	1),
('exists',	33,	'en',	'help_search',	1),
('exists',	83,	'en',	'help_search',	1),
('expand',	35,	'en',	'help_search',	1),
('expanded',	75,	'en',	'help_search',	4),
('expect',	30,	'en',	'help_search',	1),
('expected',	15,	'en',	'help_search',	1),
('experience',	83,	'en',	'help_search',	0.997306),
('experimental',	14,	'en',	'help_search',	24),
('experimental',	35,	'en',	'help_search',	1),
('expiring',	44,	'en',	'help_search',	1),
('explaining',	58,	'en',	'help_search',	0.902857),
('export',	1,	'en',	'help_search',	8),
('export',	2,	'en',	'help_search',	7),
('export',	11,	'en',	'help_search',	1.51419),
('exported',	1,	'en',	'help_search',	1),
('exported',	3,	'en',	'help_search',	1),
('exported',	4,	'en',	'help_search',	1),
('exported',	11,	'en',	'help_search',	7.41884),
('exporting',	1,	'en',	'help_search',	26),
('exporting',	2,	'en',	'help_search',	26),
('exporting',	3,	'en',	'help_search',	1),
('exporting',	4,	'en',	'help_search',	1),
('exporting',	11,	'en',	'help_search',	1.65163),
('expose',	20,	'en',	'help_search',	1),
('exposed',	73,	'en',	'help_search',	9.36248),
('exposes',	25,	'en',	'help_search',	2),
('extend',	10,	'en',	'help_search',	22),
('extend',	14,	'en',	'help_search',	11),
('extend',	24,	'en',	'help_search',	3.73881),
('extend',	26,	'en',	'help_search',	4),
('extend',	35,	'en',	'help_search',	8),
('extend',	36,	'en',	'help_search',	4),
('extending',	10,	'en',	'help_search',	10.2817),
('extending',	14,	'en',	'help_search',	57),
('extends',	14,	'en',	'help_search',	1),
('extension',	11,	'en',	'help_search',	4.70731),
('external',	75,	'en',	'help_search',	1),
('facilitate',	18,	'en',	'help_search',	1),
('factors',	18,	'en',	'help_search',	1),
('factors',	28,	'en',	'help_search',	1),
('false',	12,	'en',	'help_search',	0.889397),
('far',	37,	'en',	'help_search',	1),
('faster',	18,	'en',	'help_search',	2),
('faster',	29,	'en',	'help_search',	1),
('faulty',	50,	'en',	'help_search',	1),
('feature',	27,	'en',	'help_search',	1),
('features',	14,	'en',	'help_search',	2),
('features',	24,	'en',	'help_search',	2),
('feed',	46,	'en',	'help_search',	3),
('feed',	73,	'en',	'help_search',	2),
('feed',	82,	'en',	'help_search',	1),
('feel',	10,	'en',	'help_search',	1),
('few',	55,	'en',	'help_search',	1),
('fewer',	29,	'en',	'help_search',	1),
('field',	12,	'en',	'help_search',	90.2698),
('field',	16,	'en',	'help_search',	5),
('field',	21,	'en',	'help_search',	1),
('field',	23,	'en',	'help_search',	1),
('field',	50,	'en',	'help_search',	3),
('field',	52,	'en',	'help_search',	1),
('field',	53,	'en',	'help_search',	1),
('field',	54,	'en',	'help_search',	4),
('field',	55,	'en',	'help_search',	1),
('field',	56,	'en',	'help_search',	1),
('field',	65,	'en',	'help_search',	58),
('field',	66,	'en',	'help_search',	30),
('field',	67,	'en',	'help_search',	3),
('field',	68,	'en',	'help_search',	54.9931),
('field',	69,	'en',	'help_search',	1),
('field',	70,	'en',	'help_search',	13),
('field',	71,	'en',	'help_search',	4.77171),
('field',	72,	'en',	'help_search',	2),
('field',	83,	'en',	'help_search',	3),
('field',	84,	'en',	'help_search',	1),
('field',	86,	'en',	'help_search',	4.74672),
('field',	87,	'en',	'help_search',	12),
('fields',	5,	'en',	'help_search',	55),
('fields',	6,	'en',	'help_search',	3),
('fields',	7,	'en',	'help_search',	3),
('fields',	8,	'en',	'help_search',	2),
('fields',	10,	'en',	'help_search',	2),
('fields',	12,	'en',	'help_search',	36.2034),
('fields',	16,	'en',	'help_search',	5),
('fields',	23,	'en',	'help_search',	1),
('fields',	24,	'en',	'help_search',	0.976851),
('fields',	25,	'en',	'help_search',	1),
('fields',	48,	'en',	'help_search',	1),
('fields',	50,	'en',	'help_search',	1),
('fields',	52,	'en',	'help_search',	6),
('fields',	53,	'en',	'help_search',	1),
('fields',	54,	'en',	'help_search',	9),
('fields',	56,	'en',	'help_search',	4),
('fields',	65,	'en',	'help_search',	9),
('fields',	66,	'en',	'help_search',	3),
('fields',	67,	'en',	'help_search',	3),
('fields',	68,	'en',	'help_search',	9),
('fields',	70,	'en',	'help_search',	4),
('fields',	71,	'en',	'help_search',	3.92384),
('fields',	73,	'en',	'help_search',	5),
('fields',	83,	'en',	'help_search',	8),
('fields',	85,	'en',	'help_search',	4),
('fields',	86,	'en',	'help_search',	10.4668),
('fields',	87,	'en',	'help_search',	10),
('file',	1,	'en',	'help_search',	1),
('file',	2,	'en',	'help_search',	2),
('file',	3,	'en',	'help_search',	1),
('file',	11,	'en',	'help_search',	2.47298),
('file',	12,	'en',	'help_search',	0.615536),
('file',	16,	'en',	'help_search',	2),
('file',	18,	'en',	'help_search',	19.8513),
('file',	27,	'en',	'help_search',	1),
('files',	1,	'en',	'help_search',	1),
('files',	10,	'en',	'help_search',	2),
('files',	11,	'en',	'help_search',	2.57767),
('files',	12,	'en',	'help_search',	2),
('files',	14,	'en',	'help_search',	1),
('files',	16,	'en',	'help_search',	1),
('files',	18,	'en',	'help_search',	1),
('files',	24,	'en',	'help_search',	1),
('files',	56,	'en',	'help_search',	1),
('files',	57,	'en',	'help_search',	0.96498),
('fill',	5,	'en',	'help_search',	1),
('fill',	7,	'en',	'help_search',	1),
('fill',	8,	'en',	'help_search',	1),
('fill',	18,	'en',	'help_search',	0.899454),
('fill',	53,	'en',	'help_search',	1),
('filling',	23,	'en',	'help_search',	1),
('filter',	12,	'en',	'help_search',	1.30788),
('filter',	21,	'en',	'help_search',	1),
('filter',	35,	'en',	'help_search',	1),
('filter',	36,	'en',	'help_search',	1),
('filter',	37,	'en',	'help_search',	1),
('filter',	45,	'en',	'help_search',	5),
('filter',	50,	'en',	'help_search',	12.7833),
('filter',	55,	'en',	'help_search',	5),
('filter',	69,	'en',	'help_search',	1),
('filter',	73,	'en',	'help_search',	5.9534),
('filter',	85,	'en',	'help_search',	8),
('filtering',	30,	'en',	'help_search',	0.889397),
('filtering',	84,	'en',	'help_search',	1),
('filters',	12,	'en',	'help_search',	3.57125),
('filters',	50,	'en',	'help_search',	72.0452),
('filters',	55,	'en',	'help_search',	2),
('filters',	58,	'en',	'help_search',	2.83669),
('filters',	73,	'en',	'help_search',	6.48204),
('finally',	30,	'en',	'help_search',	0.822065),
('find',	3,	'en',	'help_search',	1),
('find',	18,	'en',	'help_search',	0.866793),
('find',	20,	'en',	'help_search',	2),
('find',	23,	'en',	'help_search',	1),
('find',	24,	'en',	'help_search',	2),
('find',	45,	'en',	'help_search',	1),
('find',	47,	'en',	'help_search',	1),
('find',	49,	'en',	'help_search',	2),
('find',	55,	'en',	'help_search',	21),
('find',	65,	'en',	'help_search',	1),
('find',	66,	'en',	'help_search',	1),
('find',	67,	'en',	'help_search',	1),
('find',	68,	'en',	'help_search',	1),
('find',	80,	'en',	'help_search',	1),
('find',	82,	'en',	'help_search',	1),
('find',	83,	'en',	'help_search',	1),
('find',	85,	'en',	'help_search',	2),
('find',	86,	'en',	'help_search',	2),
('finish',	13,	'en',	'help_search',	1),
('finished',	34,	'en',	'help_search',	1),
('finished',	85,	'en',	'help_search',	1),
('first',	11,	'en',	'help_search',	0.76431),
('first',	14,	'en',	'help_search',	1),
('first',	18,	'en',	'help_search',	1.92384),
('first',	30,	'en',	'help_search',	1),
('first',	31,	'en',	'help_search',	1),
('first',	36,	'en',	'help_search',	2),
('first',	50,	'en',	'help_search',	0.802752),
('first',	73,	'en',	'help_search',	1),
('first',	85,	'en',	'help_search',	1),
('fix',	37,	'en',	'help_search',	1),
('fixed',	19,	'en',	'help_search',	1),
('fixed',	71,	'en',	'help_search',	1),
('fixing',	15,	'en',	'help_search',	11),
('flat',	71,	'en',	'help_search',	2),
('flexible',	12,	'en',	'help_search',	0.59873),
('focusing',	58,	'en',	'help_search',	0.923838),
('follow',	6,	'en',	'help_search',	1),
('follow',	7,	'en',	'help_search',	1),
('follow',	20,	'en',	'help_search',	1),
('follow',	26,	'en',	'help_search',	1),
('follow',	28,	'en',	'help_search',	1),
('follow',	29,	'en',	'help_search',	0.916736),
('follow',	54,	'en',	'help_search',	1),
('follow',	58,	'en',	'help_search',	1),
('follow',	70,	'en',	'help_search',	1),
('follow',	78,	'en',	'help_search',	2),
('follow',	82,	'en',	'help_search',	1),
('following',	11,	'en',	'help_search',	0.830633),
('following',	12,	'en',	'help_search',	0.920273),
('following',	16,	'en',	'help_search',	1),
('following',	18,	'en',	'help_search',	1),
('following',	24,	'en',	'help_search',	2),
('following',	25,	'en',	'help_search',	1),
('following',	73,	'en',	'help_search',	1),
('following',	75,	'en',	'help_search',	1),
('following',	84,	'en',	'help_search',	1),
('footer',	73,	'en',	'help_search',	3.89144),
('for',	1,	'en',	'help_search',	1),
('for',	2,	'en',	'help_search',	1),
('for',	3,	'en',	'help_search',	1),
('for',	4,	'en',	'help_search',	1),
('for',	5,	'en',	'help_search',	2),
('for',	6,	'en',	'help_search',	3),
('for',	7,	'en',	'help_search',	1),
('for',	8,	'en',	'help_search',	1),
('for',	9,	'en',	'help_search',	2),
('for',	10,	'en',	'help_search',	6.89158),
('for',	11,	'en',	'help_search',	9.15176),
('for',	12,	'en',	'help_search',	28.7994),
('for',	13,	'en',	'help_search',	20.9931),
('for',	14,	'en',	'help_search',	1),
('for',	15,	'en',	'help_search',	2),
('for',	16,	'en',	'help_search',	6.94585),
('for',	17,	'en',	'help_search',	3),
('for',	18,	'en',	'help_search',	31.5331),
('for',	19,	'en',	'help_search',	2),
('for',	20,	'en',	'help_search',	5),
('for',	21,	'en',	'help_search',	1),
('for',	22,	'en',	'help_search',	1),
('for',	23,	'en',	'help_search',	3),
('for',	24,	'en',	'help_search',	5.78798),
('for',	25,	'en',	'help_search',	28),
('for',	26,	'en',	'help_search',	4),
('for',	27,	'en',	'help_search',	20.9496),
('for',	28,	'en',	'help_search',	3),
('for',	29,	'en',	'help_search',	5.6446),
('for',	30,	'en',	'help_search',	24.6358),
('for',	32,	'en',	'help_search',	4),
('for',	33,	'en',	'help_search',	7.83681),
('for',	34,	'en',	'help_search',	1),
('for',	35,	'en',	'help_search',	2),
('for',	36,	'en',	'help_search',	3),
('for',	37,	'en',	'help_search',	1),
('for',	38,	'en',	'help_search',	6),
('for',	39,	'en',	'help_search',	1),
('for',	40,	'en',	'help_search',	2),
('for',	41,	'en',	'help_search',	1),
('for',	42,	'en',	'help_search',	2),
('for',	43,	'en',	'help_search',	28),
('for',	44,	'en',	'help_search',	5.98633),
('for',	46,	'en',	'help_search',	2),
('for',	47,	'en',	'help_search',	4),
('for',	48,	'en',	'help_search',	22),
('for',	49,	'en',	'help_search',	1),
('for',	50,	'en',	'help_search',	5.52904),
('for',	51,	'en',	'help_search',	1),
('for',	52,	'en',	'help_search',	2),
('for',	53,	'en',	'help_search',	5),
('for',	54,	'en',	'help_search',	4),
('for',	55,	'en',	'help_search',	5.99731),
('for',	56,	'en',	'help_search',	8),
('for',	57,	'en',	'help_search',	17.2169),
('for',	58,	'en',	'help_search',	2),
('for',	64,	'en',	'help_search',	5.98902),
('for',	65,	'en',	'help_search',	10),
('for',	66,	'en',	'help_search',	33),
('for',	67,	'en',	'help_search',	33),
('for',	68,	'en',	'help_search',	9),
('for',	69,	'en',	'help_search',	22),
('for',	70,	'en',	'help_search',	7),
('for',	71,	'en',	'help_search',	7.79579),
('for',	72,	'en',	'help_search',	4),
('for',	73,	'en',	'help_search',	5.41199),
('for',	74,	'en',	'help_search',	27),
('for',	75,	'en',	'help_search',	1),
('for',	76,	'en',	'help_search',	3),
('for',	77,	'en',	'help_search',	1),
('for',	78,	'en',	'help_search',	32),
('for',	79,	'en',	'help_search',	4),
('for',	80,	'en',	'help_search',	35),
('for',	81,	'en',	'help_search',	1),
('for',	82,	'en',	'help_search',	3),
('for',	83,	'en',	'help_search',	3),
('for',	84,	'en',	'help_search',	1),
('for',	85,	'en',	'help_search',	6),
('for',	86,	'en',	'help_search',	38.7602),
('for',	87,	'en',	'help_search',	8),
('force',	26,	'en',	'help_search',	1),
('forcing',	18,	'en',	'help_search',	1),
('form',	5,	'en',	'help_search',	8),
('form',	6,	'en',	'help_search',	2),
('form',	7,	'en',	'help_search',	34),
('form',	8,	'en',	'help_search',	42),
('form',	9,	'en',	'help_search',	44),
('form',	11,	'en',	'help_search',	1),
('form',	20,	'en',	'help_search',	2),
('form',	23,	'en',	'help_search',	4.98493),
('form',	26,	'en',	'help_search',	5),
('form',	30,	'en',	'help_search',	8.95339),
('form',	33,	'en',	'help_search',	1),
('form',	40,	'en',	'help_search',	1),
('form',	45,	'en',	'help_search',	1),
('form',	52,	'en',	'help_search',	5),
('form',	53,	'en',	'help_search',	2),
('form',	54,	'en',	'help_search',	1),
('form',	56,	'en',	'help_search',	1),
('form',	57,	'en',	'help_search',	1),
('form',	67,	'en',	'help_search',	35),
('form',	70,	'en',	'help_search',	1),
('form',	71,	'en',	'help_search',	2),
('form',	73,	'en',	'help_search',	5.21371),
('form',	78,	'en',	'help_search',	2),
('form',	83,	'en',	'help_search',	32),
('formal',	57,	'en',	'help_search',	1),
('format',	4,	'en',	'help_search',	1),
('format',	11,	'en',	'help_search',	0.810915),
('format',	18,	'en',	'help_search',	1),
('format',	25,	'en',	'help_search',	2),
('format',	32,	'en',	'help_search',	25),
('format',	50,	'en',	'help_search',	15.6114),
('format',	58,	'en',	'help_search',	7.64925),
('format',	66,	'en',	'help_search',	4),
('format',	72,	'en',	'help_search',	1),
('format',	73,	'en',	'help_search',	6.85746),
('format',	83,	'en',	'help_search',	1),
('format',	85,	'en',	'help_search',	15),
('formats',	25,	'en',	'help_search',	2),
('formats',	32,	'en',	'help_search',	7),
('formats',	50,	'en',	'help_search',	63.3271),
('formats',	58,	'en',	'help_search',	33.8367),
('formats',	73,	'en',	'help_search',	2),
('formatted',	12,	'en',	'help_search',	8.81776),
('formatted',	50,	'en',	'help_search',	5),
('formatted',	58,	'en',	'help_search',	1),
('formatted',	73,	'en',	'help_search',	1),
('formatter',	12,	'en',	'help_search',	15.5412),
('formatter',	66,	'en',	'help_search',	3),
('formatter',	86,	'en',	'help_search',	0.913226),
('formatters',	12,	'en',	'help_search',	1.33517),
('formatters',	66,	'en',	'help_search',	5),
('formatting',	27,	'en',	'help_search',	1),
('forms',	5,	'en',	'help_search',	51),
('forms',	6,	'en',	'help_search',	34),
('forms',	7,	'en',	'help_search',	5),
('forms',	8,	'en',	'help_search',	49),
('forms',	9,	'en',	'help_search',	4),
('forms',	11,	'en',	'help_search',	0.695602),
('forms',	58,	'en',	'help_search',	0.842342),
('found',	27,	'en',	'help_search',	1),
('four',	12,	'en',	'help_search',	1),
('four',	86,	'en',	'help_search',	1.98087),
('framework',	25,	'en',	'help_search',	1),
('framework',	58,	'en',	'help_search',	1),
('free',	71,	'en',	'help_search',	1),
('from',	3,	'en',	'help_search',	1),
('from',	10,	'en',	'help_search',	2),
('from',	11,	'en',	'help_search',	2.6312),
('from',	12,	'en',	'help_search',	1.48323),
('from',	13,	'en',	'help_search',	5),
('from',	14,	'en',	'help_search',	1),
('from',	18,	'en',	'help_search',	1),
('from',	29,	'en',	'help_search',	1),
('from',	35,	'en',	'help_search',	1),
('from',	36,	'en',	'help_search',	1),
('from',	42,	'en',	'help_search',	1),
('from',	44,	'en',	'help_search',	1),
('from',	46,	'en',	'help_search',	2),
('from',	50,	'en',	'help_search',	1),
('from',	55,	'en',	'help_search',	1),
('from',	57,	'en',	'help_search',	1),
('from',	58,	'en',	'help_search',	2),
('from',	64,	'en',	'help_search',	0.949597),
('from',	71,	'en',	'help_search',	1),
('from',	73,	'en',	'help_search',	1.75209),
('from',	75,	'en',	'help_search',	1),
('from',	76,	'en',	'help_search',	1),
('from',	79,	'en',	'help_search',	1),
('from',	81,	'en',	'help_search',	1),
('from',	83,	'en',	'help_search',	1),
('from',	86,	'en',	'help_search',	2),
('front',	27,	'en',	'help_search',	1),
('front',	75,	'en',	'help_search',	5),
('full',	34,	'en',	'help_search',	2),
('full',	75,	'en',	'help_search',	2),
('full',	80,	'en',	'help_search',	1),
('fullexport',	11,	'en',	'help_search',	0.808176),
('fully',	25,	'en',	'help_search',	1),
('fully',	26,	'en',	'help_search',	1),
('fully',	29,	'en',	'help_search',	1.89272),
('fully',	30,	'en',	'help_search',	0.827757),
('function',	13,	'en',	'help_search',	1),
('function',	42,	'en',	'help_search',	1),
('function',	80,	'en',	'help_search',	1),
('functionality',	14,	'en',	'help_search',	29),
('functionality',	16,	'en',	'help_search',	1),
('functionality',	23,	'en',	'help_search',	1),
('functionality',	24,	'en',	'help_search',	2.92384),
('functionality',	34,	'en',	'help_search',	1),
('functionality',	56,	'en',	'help_search',	1),
('functionality',	80,	'en',	'help_search',	1),
('functions',	58,	'en',	'help_search',	1),
('further',	12,	'en',	'help_search',	1.29999),
('further',	66,	'en',	'help_search',	1),
('further',	67,	'en',	'help_search',	1),
('further',	76,	'en',	'help_search',	1),
('future',	11,	'en',	'help_search',	0.927431),
('future',	26,	'en',	'help_search',	1),
('gear',	66,	'en',	'help_search',	1),
('gear',	67,	'en',	'help_search',	1),
('generally',	53,	'en',	'help_search',	1),
('generate',	33,	'en',	'help_search',	2),
('generated',	33,	'en',	'help_search',	1),
('generated',	37,	'en',	'help_search',	1),
('generated',	44,	'en',	'help_search',	1),
('generated',	46,	'en',	'help_search',	1),
('generating',	33,	'en',	'help_search',	0.902857),
('generic',	6,	'en',	'help_search',	1),
('get',	24,	'en',	'help_search',	0.886095),
('get',	58,	'en',	'help_search',	4),
('give',	30,	'en',	'help_search',	0.802752),
('give',	43,	'en',	'help_search',	4),
('give',	64,	'en',	'help_search',	1),
('give',	78,	'en',	'help_search',	1),
('given',	12,	'en',	'help_search',	0.98493),
('goal',	1,	'en',	'help_search',	19),
('goal',	2,	'en',	'help_search',	19),
('goal',	3,	'en',	'help_search',	19),
('goal',	4,	'en',	'help_search',	19),
('goal',	5,	'en',	'help_search',	19),
('goal',	6,	'en',	'help_search',	19),
('goal',	7,	'en',	'help_search',	19),
('goal',	9,	'en',	'help_search',	19),
('goal',	13,	'en',	'help_search',	19),
('goal',	20,	'en',	'help_search',	19),
('goal',	26,	'en',	'help_search',	19),
('goal',	28,	'en',	'help_search',	19),
('goal',	29,	'en',	'help_search',	19),
('goal',	31,	'en',	'help_search',	19),
('goal',	32,	'en',	'help_search',	19),
('goal',	33,	'en',	'help_search',	19),
('goal',	34,	'en',	'help_search',	19),
('goal',	35,	'en',	'help_search',	19),
('goal',	36,	'en',	'help_search',	19),
('goal',	37,	'en',	'help_search',	19),
('goal',	38,	'en',	'help_search',	19),
('goal',	39,	'en',	'help_search',	19),
('goal',	40,	'en',	'help_search',	19),
('goal',	41,	'en',	'help_search',	19),
('goal',	43,	'en',	'help_search',	19),
('goal',	44,	'en',	'help_search',	19),
('goal',	45,	'en',	'help_search',	19),
('goal',	47,	'en',	'help_search',	19),
('goal',	49,	'en',	'help_search',	19),
('goal',	50,	'en',	'help_search',	19),
('goal',	51,	'en',	'help_search',	19),
('goal',	52,	'en',	'help_search',	19),
('goal',	53,	'en',	'help_search',	19),
('goal',	54,	'en',	'help_search',	19),
('goal',	55,	'en',	'help_search',	19),
('goal',	58,	'en',	'help_search',	19),
('goal',	64,	'en',	'help_search',	19),
('goal',	65,	'en',	'help_search',	19),
('goal',	66,	'en',	'help_search',	19),
('goal',	67,	'en',	'help_search',	19),
('goal',	68,	'en',	'help_search',	19),
('goal',	70,	'en',	'help_search',	19),
('goal',	72,	'en',	'help_search',	19),
('goal',	74,	'en',	'help_search',	19),
('goal',	75,	'en',	'help_search',	19),
('goal',	76,	'en',	'help_search',	19),
('goal',	77,	'en',	'help_search',	19),
('goal',	78,	'en',	'help_search',	19),
('goal',	79,	'en',	'help_search',	19),
('goal',	81,	'en',	'help_search',	19),
('goal',	82,	'en',	'help_search',	19),
('goal',	83,	'en',	'help_search',	19),
('goal',	84,	'en',	'help_search',	19),
('goal',	85,	'en',	'help_search',	19),
('goal',	86,	'en',	'help_search',	19),
('goal',	87,	'en',	'help_search',	19),
('goals',	46,	'en',	'help_search',	1),
('goes',	31,	'en',	'help_search',	1),
('goes',	73,	'en',	'help_search',	1),
('good',	31,	'en',	'help_search',	1),
('governance',	46,	'en',	'help_search',	1),
('granting',	42,	'en',	'help_search',	1),
('green',	71,	'en',	'help_search',	1),
('grid',	73,	'en',	'help_search',	2),
('grid',	85,	'en',	'help_search',	4),
('group',	11,	'en',	'help_search',	1),
('group',	13,	'en',	'help_search',	1),
('group',	42,	'en',	'help_search',	1),
('group',	55,	'en',	'help_search',	1),
('group',	57,	'en',	'help_search',	19),
('group',	58,	'en',	'help_search',	5.25496),
('grouped',	11,	'en',	'help_search',	1),
('grouped',	12,	'en',	'help_search',	1),
('groups',	57,	'en',	'help_search',	22.5589),
('groups',	58,	'en',	'help_search',	0.866793),
('guide',	10,	'en',	'help_search',	10.123),
('guide',	11,	'en',	'help_search',	21.9999),
('guide',	12,	'en',	'help_search',	18.9892),
('guide',	13,	'en',	'help_search',	20.9751),
('guide',	14,	'en',	'help_search',	22),
('guide',	15,	'en',	'help_search',	22),
('guide',	17,	'en',	'help_search',	11),
('guide',	19,	'en',	'help_search',	11),
('guide',	27,	'en',	'help_search',	1),
('guide',	31,	'en',	'help_search',	11),
('guide',	37,	'en',	'help_search',	11),
('guide',	48,	'en',	'help_search',	11),
('guide',	53,	'en',	'help_search',	21.8038),
('guide',	54,	'en',	'help_search',	22),
('guide',	55,	'en',	'help_search',	20.7671),
('guide',	70,	'en',	'help_search',	11),
('guide',	71,	'en',	'help_search',	9.67522),
('guide',	73,	'en',	'help_search',	8.51611),
('guide',	78,	'en',	'help_search',	11),
('guide',	80,	'en',	'help_search',	11),
('guide',	85,	'en',	'help_search',	10.4874),
('handles',	73,	'en',	'help_search',	0.800068),
('handling',	29,	'en',	'help_search',	3.95608),
('happen',	45,	'en',	'help_search',	1),
('happens',	29,	'en',	'help_search',	1),
('happens',	33,	'en',	'help_search',	1),
('happens',	44,	'en',	'help_search',	1.98902),
('has',	8,	'en',	'help_search',	2),
('has',	11,	'en',	'help_search',	5.48026),
('has',	12,	'en',	'help_search',	1),
('has',	18,	'en',	'help_search',	1),
('has',	19,	'en',	'help_search',	1),
('has',	20,	'en',	'help_search',	1),
('has',	23,	'en',	'help_search',	1),
('has',	24,	'en',	'help_search',	1),
('has',	29,	'en',	'help_search',	2.7299),
('has',	30,	'en',	'help_search',	1),
('has',	33,	'en',	'help_search',	1),
('has',	35,	'en',	'help_search',	1),
('has',	37,	'en',	'help_search',	1),
('has',	38,	'en',	'help_search',	1),
('has',	43,	'en',	'help_search',	4),
('has',	50,	'en',	'help_search',	0.78951),
('has',	53,	'en',	'help_search',	1),
('has',	55,	'en',	'help_search',	1),
('has',	56,	'en',	'help_search',	1),
('has',	69,	'en',	'help_search',	36),
('has',	76,	'en',	'help_search',	1),
('have',	5,	'en',	'help_search',	1),
('have',	6,	'en',	'help_search',	1),
('have',	7,	'en',	'help_search',	1),
('have',	8,	'en',	'help_search',	1),
('have',	11,	'en',	'help_search',	0.866793),
('have',	12,	'en',	'help_search',	26.6223),
('have',	13,	'en',	'help_search',	1.99731),
('have',	14,	'en',	'help_search',	1),
('have',	16,	'en',	'help_search',	1),
('have',	19,	'en',	'help_search',	1),
('have',	20,	'en',	'help_search',	1),
('have',	21,	'en',	'help_search',	2),
('have',	22,	'en',	'help_search',	2),
('have',	27,	'en',	'help_search',	1),
('have',	28,	'en',	'help_search',	1),
('have',	29,	'en',	'help_search',	0.942091),
('have',	30,	'en',	'help_search',	2),
('have',	31,	'en',	'help_search',	1),
('have',	36,	'en',	'help_search',	1),
('have',	37,	'en',	'help_search',	3),
('have',	40,	'en',	'help_search',	1),
('have',	42,	'en',	'help_search',	2),
('have',	43,	'en',	'help_search',	2),
('have',	46,	'en',	'help_search',	1),
('have',	50,	'en',	'help_search',	4.42848),
('have',	51,	'en',	'help_search',	1),
('have',	53,	'en',	'help_search',	1),
('have',	54,	'en',	'help_search',	3),
('have',	56,	'en',	'help_search',	1),
('have',	58,	'en',	'help_search',	0.96498),
('have',	64,	'en',	'help_search',	3),
('have',	65,	'en',	'help_search',	1),
('have',	68,	'en',	'help_search',	1),
('have',	70,	'en',	'help_search',	1),
('have',	71,	'en',	'help_search',	3),
('have',	72,	'en',	'help_search',	1),
('have',	73,	'en',	'help_search',	3.66728),
('have',	75,	'en',	'help_search',	1),
('have',	80,	'en',	'help_search',	1),
('have',	81,	'en',	'help_search',	3),
('have',	83,	'en',	'help_search',	1.99731),
('have',	85,	'en',	'help_search',	2.99731),
('have',	86,	'en',	'help_search',	3),
('have',	87,	'en',	'help_search',	1),
('haven',	21,	'en',	'help_search',	1),
('having',	73,	'en',	'help_search',	0.949597),
('header',	55,	'en',	'help_search',	1),
('header',	73,	'en',	'help_search',	3.9074),
('heading',	27,	'en',	'help_search',	1),
('heading',	47,	'en',	'help_search',	1),
('heading',	48,	'en',	'help_search',	1),
('health',	37,	'en',	'help_search',	2),
('height',	57,	'en',	'help_search',	28),
('height',	72,	'en',	'help_search',	4),
('help',	12,	'en',	'help_search',	1.75415),
('help',	14,	'en',	'help_search',	1),
('help',	15,	'en',	'help_search',	1),
('help',	24,	'en',	'help_search',	7.4272),
('help',	26,	'en',	'help_search',	54),
('help',	27,	'en',	'help_search',	151.109),
('help',	29,	'en',	'help_search',	4),
('help',	30,	'en',	'help_search',	2),
('help',	42,	'en',	'help_search',	1),
('help',	65,	'en',	'help_search',	4),
('help',	68,	'en',	'help_search',	4),
('helps',	10,	'en',	'help_search',	0.972861),
('helptopics',	27,	'en',	'help_search',	8),
('here',	2,	'en',	'help_search',	4),
('here',	4,	'en',	'help_search',	4),
('here',	15,	'en',	'help_search',	1),
('here',	46,	'en',	'help_search',	22),
('here',	80,	'en',	'help_search',	1),
('hidden',	66,	'en',	'help_search',	8),
('hide',	12,	'en',	'help_search',	0.662985),
('hide',	58,	'en',	'help_search',	1),
('hide',	66,	'en',	'help_search',	1),
('hiding',	12,	'en',	'help_search',	0.657549),
('hierarchical',	71,	'en',	'help_search',	1),
('hierarchy',	71,	'en',	'help_search',	1),
('hierarchy',	77,	'en',	'help_search',	1),
('highly',	37,	'en',	'help_search',	1),
('highly',	46,	'en',	'help_search',	1),
('hints',	15,	'en',	'help_search',	1),
('history',	21,	'en',	'help_search',	1),
('history',	69,	'en',	'help_search',	1),
('holds',	12,	'en',	'help_search',	1),
('home',	33,	'en',	'help_search',	0.993146),
('home',	38,	'en',	'help_search',	1),
('home',	64,	'en',	'help_search',	1),
('home',	80,	'en',	'help_search',	1),
('horizontal',	50,	'en',	'help_search',	1),
('hour',	13,	'en',	'help_search',	1),
('hourly',	13,	'en',	'help_search',	1),
('hover',	86,	'en',	'help_search',	0.866793),
('hovering',	58,	'en',	'help_search',	0.920273),
('hovering',	64,	'en',	'help_search',	2),
('hovers',	75,	'en',	'help_search',	1),
('how',	11,	'en',	'help_search',	1),
('how',	12,	'en',	'help_search',	3.29815),
('how',	13,	'en',	'help_search',	1),
('how',	21,	'en',	'help_search',	1),
('how',	26,	'en',	'help_search',	1),
('how',	27,	'en',	'help_search',	57),
('how',	37,	'en',	'help_search',	1),
('how',	44,	'en',	'help_search',	27),
('how',	46,	'en',	'help_search',	19),
('how',	54,	'en',	'help_search',	1),
('how',	70,	'en',	'help_search',	1),
('how',	71,	'en',	'help_search',	1),
('how',	73,	'en',	'help_search',	4.74727),
('how',	84,	'en',	'help_search',	1),
('how',	85,	'en',	'help_search',	1),
('however',	23,	'en',	'help_search',	1),
('however',	81,	'en',	'help_search',	1),
('html',	10,	'en',	'help_search',	2),
('html',	12,	'en',	'help_search',	2.44132),
('html',	18,	'en',	'help_search',	1),
('html',	50,	'en',	'help_search',	12.3934),
('html',	56,	'en',	'help_search',	1),
('html',	58,	'en',	'help_search',	4),
('html',	66,	'en',	'help_search',	1),
('html',	73,	'en',	'help_search',	1),
('http',	25,	'en',	'help_search',	44),
('https',	33,	'en',	'help_search',	7.84712),
('https',	78,	'en',	'help_search',	4),
('https',	80,	'en',	'help_search',	12),
('human',	78,	'en',	'help_search',	1),
('humanreadable',	11,	'en',	'help_search',	0.989021),
('icon',	19,	'en',	'help_search',	1),
('icon',	20,	'en',	'help_search',	1),
('icon',	71,	'en',	'help_search',	1),
('identification',	48,	'en',	'help_search',	1),
('identifier',	11,	'en',	'help_search',	0.892724),
('identifier',	58,	'en',	'help_search',	3.49253),
('identifiers',	58,	'en',	'help_search',	0.876337),
('identifies',	11,	'en',	'help_search',	0.879565),
('identifies',	80,	'en',	'help_search',	1),
('image',	11,	'en',	'help_search',	2),
('image',	12,	'en',	'help_search',	1.20828),
('image',	16,	'en',	'help_search',	26.9919),
('image',	50,	'en',	'help_search',	1),
('image',	57,	'en',	'help_search',	0.989021),
('image',	71,	'en',	'help_search',	1),
('image',	72,	'en',	'help_search',	41),
('images',	5,	'en',	'help_search',	1),
('images',	10,	'en',	'help_search',	1),
('images',	12,	'en',	'help_search',	3),
('images',	16,	'en',	'help_search',	4.98087),
('images',	50,	'en',	'help_search',	1.99731),
('images',	56,	'en',	'help_search',	1),
('images',	57,	'en',	'help_search',	1),
('images',	72,	'en',	'help_search',	1),
('immediately',	53,	'en',	'help_search',	1),
('impact',	37,	'en',	'help_search',	1),
('implementation',	25,	'en',	'help_search',	2),
('implemented',	23,	'en',	'help_search',	0.989021),
('implications',	19,	'en',	'help_search',	1),
('implications',	43,	'en',	'help_search',	4),
('import',	3,	'en',	'help_search',	11),
('import',	4,	'en',	'help_search',	11),
('imported',	11,	'en',	'help_search',	5.90265),
('importing',	3,	'en',	'help_search',	26),
('importing',	4,	'en',	'help_search',	26),
('importing',	11,	'en',	'help_search',	1.64815),
('improper',	50,	'en',	'help_search',	3.45463),
('improve',	18,	'en',	'help_search',	20),
('improve',	30,	'en',	'help_search',	1),
('improved',	23,	'en',	'help_search',	1),
('include',	12,	'en',	'help_search',	0.691597),
('include',	16,	'en',	'help_search',	2),
('include',	18,	'en',	'help_search',	1),
('include',	22,	'en',	'help_search',	1),
('include',	23,	'en',	'help_search',	1),
('include',	73,	'en',	'help_search',	0.857458),
('includes',	30,	'en',	'help_search',	1),
('includes',	37,	'en',	'help_search',	1),
('including',	6,	'en',	'help_search',	1),
('including',	10,	'en',	'help_search',	1),
('including',	17,	'en',	'help_search',	1),
('including',	23,	'en',	'help_search',	1),
('including',	24,	'en',	'help_search',	0.923838),
('including',	27,	'en',	'help_search',	2),
('including',	32,	'en',	'help_search',	1),
('including',	33,	'en',	'help_search',	27),
('including',	45,	'en',	'help_search',	1),
('including',	71,	'en',	'help_search',	0.923838),
('including',	86,	'en',	'help_search',	1),
('incorrect',	33,	'en',	'help_search',	1),
('increasing',	23,	'en',	'help_search',	1),
('index',	26,	'en',	'help_search',	4),
('index',	28,	'en',	'help_search',	2),
('index',	29,	'en',	'help_search',	58.9274),
('index',	30,	'en',	'help_search',	0.830633),
('indexed',	26,	'en',	'help_search',	1),
('indexed',	29,	'en',	'help_search',	2.89272),
('indexed',	30,	'en',	'help_search',	0.824901),
('indexing',	26,	'en',	'help_search',	2),
('indexing',	29,	'en',	'help_search',	22.8982),
('indicating',	32,	'en',	'help_search',	3),
('indicating',	33,	'en',	'help_search',	1.85285),
('indicating',	44,	'en',	'help_search',	0.957226),
('individual',	10,	'en',	'help_search',	1),
('individual',	12,	'en',	'help_search',	1),
('individual',	44,	'en',	'help_search',	1),
('individual',	71,	'en',	'help_search',	2),
('individual',	85,	'en',	'help_search',	1),
('individually',	86,	'en',	'help_search',	1),
('influence',	28,	'en',	'help_search',	1),
('information',	1,	'en',	'help_search',	1),
('information',	2,	'en',	'help_search',	1),
('information',	3,	'en',	'help_search',	1),
('information',	4,	'en',	'help_search',	1),
('information',	6,	'en',	'help_search',	4),
('information',	12,	'en',	'help_search',	3.70583),
('information',	15,	'en',	'help_search',	1),
('information',	16,	'en',	'help_search',	1),
('information',	24,	'en',	'help_search',	2.90286),
('information',	25,	'en',	'help_search',	1),
('information',	29,	'en',	'help_search',	1),
('information',	30,	'en',	'help_search',	4.47836),
('information',	35,	'en',	'help_search',	1),
('information',	37,	'en',	'help_search',	1),
('information',	57,	'en',	'help_search',	2),
('information',	66,	'en',	'help_search',	1),
('information',	67,	'en',	'help_search',	1),
('information',	68,	'en',	'help_search',	1),
('information',	69,	'en',	'help_search',	19),
('information',	70,	'en',	'help_search',	1),
('information',	72,	'en',	'help_search',	1),
('information',	83,	'en',	'help_search',	1),
('information',	85,	'en',	'help_search',	1),
('information',	87,	'en',	'help_search',	5),
('informational',	37,	'en',	'help_search',	1),
('ingredients',	70,	'en',	'help_search',	1),
('ingredients',	71,	'en',	'help_search',	4),
('inline',	20,	'en',	'help_search',	27),
('inline',	23,	'en',	'help_search',	1.98493),
('inline',	24,	'en',	'help_search',	1),
('inplace',	24,	'en',	'help_search',	2),
('input',	12,	'en',	'help_search',	0.645209),
('input',	50,	'en',	'help_search',	1),
('insert',	44,	'en',	'help_search',	1),
('install',	11,	'en',	'help_search',	4),
('install',	22,	'en',	'help_search',	1),
('install',	24,	'en',	'help_search',	3.75596),
('install',	26,	'en',	'help_search',	1),
('install',	27,	'en',	'help_search',	1),
('install',	35,	'en',	'help_search',	10),
('install',	38,	'en',	'help_search',	6),
('install',	58,	'en',	'help_search',	1),
('install',	73,	'en',	'help_search',	1),
('installation',	11,	'en',	'help_search',	1),
('installation',	56,	'en',	'help_search',	1),
('installed',	12,	'en',	'help_search',	0.58995),
('installed',	13,	'en',	'help_search',	1.99731),
('installed',	14,	'en',	'help_search',	1),
('installed',	16,	'en',	'help_search',	1),
('installed',	20,	'en',	'help_search',	2),
('installed',	21,	'en',	'help_search',	1),
('installed',	24,	'en',	'help_search',	1),
('installed',	26,	'en',	'help_search',	2),
('installed',	35,	'en',	'help_search',	3),
('installed',	36,	'en',	'help_search',	2),
('installed',	37,	'en',	'help_search',	2),
('installed',	38,	'en',	'help_search',	5),
('installed',	39,	'en',	'help_search',	6),
('installed',	42,	'en',	'help_search',	1),
('installed',	48,	'en',	'help_search',	1),
('installed',	50,	'en',	'help_search',	1.81085),
('installed',	54,	'en',	'help_search',	3),
('installed',	58,	'en',	'help_search',	1.96109),
('installed',	64,	'en',	'help_search',	2),
('installed',	70,	'en',	'help_search',	2),
('installed',	73,	'en',	'help_search',	1.59269),
('installed',	76,	'en',	'help_search',	1),
('installed',	81,	'en',	'help_search',	2),
('installed',	83,	'en',	'help_search',	2),
('installing',	11,	'en',	'help_search',	0.942091),
('installing',	14,	'en',	'help_search',	20),
('installing',	15,	'en',	'help_search',	1),
('installing',	30,	'en',	'help_search',	1),
('installing',	35,	'en',	'help_search',	26),
('installing',	38,	'en',	'help_search',	26),
('installing',	58,	'en',	'help_search',	1),
('instance',	11,	'en',	'help_search',	6.60419),
('instance',	57,	'en',	'help_search',	2),
('instance',	71,	'en',	'help_search',	1),
('instance',	86,	'en',	'help_search',	0.980874),
('instances',	11,	'en',	'help_search',	3.54852),
('instead',	10,	'en',	'help_search',	1),
('instead',	18,	'en',	'help_search',	1),
('instead',	23,	'en',	'help_search',	1),
('instead',	50,	'en',	'help_search',	0.934703),
('instead',	54,	'en',	'help_search',	1),
('instead',	58,	'en',	'help_search',	1),
('instructions',	27,	'en',	'help_search',	0.945829),
('instructions',	34,	'en',	'help_search',	1),
('instructions',	70,	'en',	'help_search',	1),
('integer',	12,	'en',	'help_search',	2.97194),
('integers',	12,	'en',	'help_search',	0.740689),
('interactions',	12,	'en',	'help_search',	1),
('interest',	45,	'en',	'help_search',	3),
('interest',	64,	'en',	'help_search',	1),
('interests',	46,	'en',	'help_search',	1),
('interface',	10,	'en',	'help_search',	1),
('interface',	11,	'en',	'help_search',	0.727213),
('interface',	12,	'en',	'help_search',	1.20198),
('interface',	16,	'en',	'help_search',	2),
('interface',	17,	'en',	'help_search',	1),
('interface',	22,	'en',	'help_search',	3),
('interface',	23,	'en',	'help_search',	32),
('interface',	24,	'en',	'help_search',	66.3775),
('interface',	27,	'en',	'help_search',	2),
('interface',	48,	'en',	'help_search',	1),
('interface',	52,	'en',	'help_search',	1),
('interface',	54,	'en',	'help_search',	1),
('interface',	70,	'en',	'help_search',	2),
('interface',	71,	'en',	'help_search',	0.931053),
('interface',	73,	'en',	'help_search',	0.794753),
('interface',	82,	'en',	'help_search',	1),
('interface',	84,	'en',	'help_search',	1),
('interface',	86,	'en',	'help_search',	0.836446),
('interfaces',	23,	'en',	'help_search',	1),
('internal',	18,	'en',	'help_search',	20.4433),
('internal',	31,	'en',	'help_search',	1),
('internal',	75,	'en',	'help_search',	1),
('into',	2,	'en',	'help_search',	1),
('into',	4,	'en',	'help_search',	1),
('into',	11,	'en',	'help_search',	2.53391),
('into',	12,	'en',	'help_search',	3),
('into',	16,	'en',	'help_search',	1),
('into',	18,	'en',	'help_search',	1),
('into',	22,	'en',	'help_search',	2),
('into',	25,	'en',	'help_search',	1),
('into',	27,	'en',	'help_search',	1),
('into',	29,	'en',	'help_search',	1),
('into',	30,	'en',	'help_search',	3),
('into',	31,	'en',	'help_search',	1),
('into',	34,	'en',	'help_search',	8),
('into',	35,	'en',	'help_search',	1),
('into',	36,	'en',	'help_search',	1),
('into',	44,	'en',	'help_search',	1),
('into',	48,	'en',	'help_search',	1),
('into',	49,	'en',	'help_search',	1),
('into',	50,	'en',	'help_search',	5),
('into',	56,	'en',	'help_search',	1),
('into',	57,	'en',	'help_search',	2),
('into',	77,	'en',	'help_search',	1),
('invalid',	33,	'en',	'help_search',	1),
('item',	2,	'en',	'help_search',	31),
('item',	4,	'en',	'help_search',	32),
('item',	11,	'en',	'help_search',	2),
('item',	12,	'en',	'help_search',	6.85498),
('item',	53,	'en',	'help_search',	39.8792),
('item',	55,	'en',	'help_search',	39.363),
('item',	56,	'en',	'help_search',	24),
('item',	65,	'en',	'help_search',	1),
('item',	68,	'en',	'help_search',	5),
('item',	69,	'en',	'help_search',	1),
('item',	73,	'en',	'help_search',	1.87313),
('item',	74,	'en',	'help_search',	5),
('item',	75,	'en',	'help_search',	1),
('item',	78,	'en',	'help_search',	41),
('item',	80,	'en',	'help_search',	1),
('item',	83,	'en',	'help_search',	1),
('item',	85,	'en',	'help_search',	3),
('item',	86,	'en',	'help_search',	1.92027),
('item',	87,	'en',	'help_search',	1),
('items',	10,	'en',	'help_search',	1),
('items',	11,	'en',	'help_search',	1.75231),
('items',	12,	'en',	'help_search',	3.84729),
('items',	16,	'en',	'help_search',	26),
('items',	17,	'en',	'help_search',	1),
('items',	21,	'en',	'help_search',	1),
('items',	22,	'en',	'help_search',	2),
('items',	29,	'en',	'help_search',	4),
('items',	53,	'en',	'help_search',	2),
('items',	55,	'en',	'help_search',	10.9534),
('items',	56,	'en',	'help_search',	3),
('items',	71,	'en',	'help_search',	3.95959),
('items',	73,	'en',	'help_search',	5.53668),
('items',	74,	'en',	'help_search',	2),
('items',	80,	'en',	'help_search',	1),
('items',	84,	'en',	'help_search',	1),
('items',	85,	'en',	'help_search',	1),
('items',	86,	'en',	'help_search',	1),
('items',	87,	'en',	'help_search',	1),
('its',	8,	'en',	'help_search',	1),
('its',	11,	'en',	'help_search',	2.78177),
('its',	13,	'en',	'help_search',	1),
('its',	14,	'en',	'help_search',	2),
('its',	24,	'en',	'help_search',	1),
('its',	25,	'en',	'help_search',	1),
('its',	46,	'en',	'help_search',	1),
('its',	52,	'en',	'help_search',	1),
('its',	53,	'en',	'help_search',	1),
('its',	55,	'en',	'help_search',	1),
('its',	56,	'en',	'help_search',	1),
('its',	69,	'en',	'help_search',	1),
('its',	71,	'en',	'help_search',	1),
('its',	82,	'en',	'help_search',	1),
('its',	83,	'en',	'help_search',	1),
('its',	85,	'en',	'help_search',	1),
('its',	86,	'en',	'help_search',	2),
('japanese',	29,	'en',	'help_search',	1),
('javascript',	14,	'en',	'help_search',	1),
('javascript',	18,	'en',	'help_search',	1.85135),
('javascript',	58,	'en',	'help_search',	2),
('jobs',	12,	'en',	'help_search',	1),
('json',	25,	'en',	'help_search',	36),
('json',	46,	'en',	'help_search',	1),
('just',	48,	'en',	'help_search',	1),
('just',	57,	'en',	'help_search',	1),
('just',	75,	'en',	'help_search',	1),
('keep',	11,	'en',	'help_search',	0.906287),
('keep',	13,	'en',	'help_search',	1),
('keep',	19,	'en',	'help_search',	1),
('keeping',	19,	'en',	'help_search',	2),
('kept',	69,	'en',	'help_search',	1),
('key',	12,	'en',	'help_search',	0.745294),
('key',	55,	'en',	'help_search',	1),
('keyboardonly',	23,	'en',	'help_search',	1),
('keys',	12,	'en',	'help_search',	3.87487),
('keyword',	29,	'en',	'help_search',	1),
('keyword',	30,	'en',	'help_search',	1),
('keywords',	29,	'en',	'help_search',	1),
('keywords',	30,	'en',	'help_search',	1),
('keywords',	83,	'en',	'help_search',	1),
('kinds',	11,	'en',	'help_search',	19),
('knowing',	8,	'en',	'help_search',	1),
('known',	13,	'en',	'help_search',	1),
('known',	16,	'en',	'help_search',	1),
('known',	71,	'en',	'help_search',	2),
('korean',	29,	'en',	'help_search',	1),
('label',	7,	'en',	'help_search',	4),
('label',	12,	'en',	'help_search',	0.655756),
('label',	28,	'en',	'help_search',	4),
('label',	52,	'en',	'help_search',	1),
('label',	53,	'en',	'help_search',	1),
('label',	65,	'en',	'help_search',	10),
('label',	66,	'en',	'help_search',	7),
('label',	68,	'en',	'help_search',	11),
('labeled',	4,	'en',	'help_search',	1),
('labeled',	23,	'en',	'help_search',	1),
('labeled',	38,	'en',	'help_search',	1),
('labels',	12,	'en',	'help_search',	4.84414),
('langing',	1,	'en',	'node_search',	27),
('language',	22,	'en',	'help_search',	7),
('language',	26,	'en',	'help_search',	1),
('language',	27,	'en',	'help_search',	1),
('language',	30,	'en',	'help_search',	0.993146),
('language',	32,	'en',	'help_search',	8),
('language',	55,	'en',	'help_search',	4),
('language',	76,	'en',	'help_search',	2),
('languages',	20,	'en',	'help_search',	1),
('languages',	22,	'en',	'help_search',	49),
('languages',	24,	'en',	'help_search',	1),
('languages',	29,	'en',	'help_search',	1.9689),
('languages',	55,	'en',	'help_search',	1),
('languages',	64,	'en',	'help_search',	2),
('languages',	81,	'en',	'help_search',	0.968904),
('languagespecific',	30,	'en',	'help_search',	1),
('large',	12,	'en',	'help_search',	0.695602),
('large',	30,	'en',	'help_search',	2),
('larger',	29,	'en',	'help_search',	1),
('last',	12,	'en',	'help_search',	1),
('last',	13,	'en',	'help_search',	4),
('last',	37,	'en',	'help_search',	4),
('last',	69,	'en',	'help_search',	1),
('last',	80,	'en',	'help_search',	1),
('later',	18,	'en',	'help_search',	1.89272),
('later',	29,	'en',	'help_search',	0.934703),
('later',	51,	'en',	'help_search',	1),
('later',	84,	'en',	'help_search',	2),
('layout',	10,	'en',	'help_search',	26.9617),
('layout',	12,	'en',	'help_search',	0.601716),
('layout',	26,	'en',	'help_search',	4),
('layout',	47,	'en',	'help_search',	4),
('layout',	49,	'en',	'help_search',	1),
('layout',	57,	'en',	'help_search',	1),
('layout',	86,	'en',	'help_search',	89.8436),
('layouts',	10,	'en',	'help_search',	2.97685),
('layouts',	57,	'en',	'help_search',	1.98902),
('layouts',	72,	'en',	'help_search',	1),
('layouts',	86,	'en',	'help_search',	8.95041),
('leading',	24,	'en',	'help_search',	1),
('leads',	8,	'en',	'help_search',	1),
('learn',	22,	'en',	'help_search',	2),
('learn',	37,	'en',	'help_search',	1),
('learning',	8,	'en',	'help_search',	1),
('least',	27,	'en',	'help_search',	1),
('least',	83,	'en',	'help_search',	1),
('leave',	53,	'en',	'help_search',	1),
('left',	24,	'en',	'help_search',	1),
('left',	40,	'en',	'help_search',	1),
('left',	55,	'en',	'help_search',	1),
('left',	64,	'en',	'help_search',	2),
('left',	81,	'en',	'help_search',	0.976851),
('left',	86,	'en',	'help_search',	1),
('length',	29,	'en',	'help_search',	5),
('less',	33,	'en',	'help_search',	1),
('let',	20,	'en',	'help_search',	1),
('let',	22,	'en',	'help_search',	1),
('let',	71,	'en',	'help_search',	1),
('let',	73,	'en',	'help_search',	1),
('let',	86,	'en',	'help_search',	0.854391),
('lets',	22,	'en',	'help_search',	1),
('level',	28,	'en',	'help_search',	1),
('library',	16,	'en',	'help_search',	25),
('library',	58,	'en',	'help_search',	2),
('lifetime',	18,	'en',	'help_search',	4.86055),
('like',	20,	'en',	'help_search',	2),
('like',	30,	'en',	'help_search',	1),
('like',	48,	'en',	'help_search',	1),
('like',	64,	'en',	'help_search',	1),
('like',	71,	'en',	'help_search',	1),
('like',	73,	'en',	'help_search',	0.923838),
('like',	79,	'en',	'help_search',	1),
('like',	81,	'en',	'help_search',	1),
('like',	83,	'en',	'help_search',	2),
('like',	86,	'en',	'help_search',	1.8894),
('limit',	12,	'en',	'help_search',	1.39535),
('limit',	50,	'en',	'help_search',	1),
('limit',	65,	'en',	'help_search',	1),
('limit',	68,	'en',	'help_search',	2),
('limit',	73,	'en',	'help_search',	1),
('limitations',	30,	'en',	'help_search',	20),
('limited',	81,	'en',	'help_search',	1),
('limits',	50,	'en',	'help_search',	1),
('limits',	69,	'en',	'help_search',	1),
('line',	47,	'en',	'help_search',	1),
('line',	50,	'en',	'help_search',	4),
('link',	7,	'en',	'help_search',	1),
('link',	8,	'en',	'help_search',	1),
('link',	12,	'en',	'help_search',	2.50061),
('link',	13,	'en',	'help_search',	1),
('link',	20,	'en',	'help_search',	3),
('link',	23,	'en',	'help_search',	1),
('link',	26,	'en',	'help_search',	1),
('link',	38,	'en',	'help_search',	2),
('link',	39,	'en',	'help_search',	2),
('link',	46,	'en',	'help_search',	1),
('link',	50,	'en',	'help_search',	0.949597),
('link',	64,	'en',	'help_search',	4.98902),
('link',	75,	'en',	'help_search',	62),
('link',	81,	'en',	'help_search',	3.95723),
('link',	82,	'en',	'help_search',	3),
('link',	85,	'en',	'help_search',	5),
('links',	12,	'en',	'help_search',	0.617112),
('links',	17,	'en',	'help_search',	10),
('links',	20,	'en',	'help_search',	9),
('links',	24,	'en',	'help_search',	3),
('links',	27,	'en',	'help_search',	1),
('links',	50,	'en',	'help_search',	3.89272),
('links',	64,	'en',	'help_search',	63.989),
('links',	74,	'en',	'help_search',	2),
('links',	75,	'en',	'help_search',	2),
('links',	76,	'en',	'help_search',	2),
('links',	77,	'en',	'help_search',	30),
('links',	81,	'en',	'help_search',	28.965),
('links',	83,	'en',	'help_search',	4),
('links',	85,	'en',	'help_search',	1),
('linuxlike',	13,	'en',	'help_search',	1),
('list',	11,	'en',	'help_search',	0.827757),
('list',	12,	'en',	'help_search',	28.8966),
('list',	24,	'en',	'help_search',	1),
('list',	28,	'en',	'help_search',	2),
('list',	35,	'en',	'help_search',	1),
('list',	36,	'en',	'help_search',	2),
('list',	41,	'en',	'help_search',	1),
('list',	45,	'en',	'help_search',	1),
('list',	55,	'en',	'help_search',	2),
('list',	64,	'en',	'help_search',	1.98217),
('list',	65,	'en',	'help_search',	1),
('list',	66,	'en',	'help_search',	1),
('list',	67,	'en',	'help_search',	1),
('list',	68,	'en',	'help_search',	1.99315),
('list',	71,	'en',	'help_search',	3),
('list',	73,	'en',	'help_search',	3),
('list',	74,	'en',	'help_search',	1),
('list',	75,	'en',	'help_search',	2),
('list',	79,	'en',	'help_search',	2),
('list',	81,	'en',	'help_search',	3.97),
('list',	82,	'en',	'help_search',	1),
('list',	83,	'en',	'help_search',	3),
('list',	84,	'en',	'help_search',	1),
('list',	85,	'en',	'help_search',	10),
('list',	86,	'en',	'help_search',	1.93105),
('listed',	10,	'en',	'help_search',	0.953396),
('listed',	11,	'en',	'help_search',	0.687638),
('listed',	12,	'en',	'help_search',	1.21546),
('listed',	14,	'en',	'help_search',	1),
('listed',	16,	'en',	'help_search',	0.972861),
('listed',	17,	'en',	'help_search',	1),
('listed',	19,	'en',	'help_search',	1),
('listed',	21,	'en',	'help_search',	1),
('listed',	22,	'en',	'help_search',	1),
('listed',	24,	'en',	'help_search',	0.866793),
('listed',	26,	'en',	'help_search',	1),
('listed',	27,	'en',	'help_search',	20),
('listed',	28,	'en',	'help_search',	1),
('listed',	29,	'en',	'help_search',	0.886095),
('listed',	30,	'en',	'help_search',	0.794753),
('listed',	36,	'en',	'help_search',	1),
('listed',	48,	'en',	'help_search',	1),
('listed',	54,	'en',	'help_search',	1),
('listed',	56,	'en',	'help_search',	1),
('listed',	68,	'en',	'help_search',	1),
('listed',	71,	'en',	'help_search',	0.906287),
('listed',	73,	'en',	'help_search',	0.78951),
('listed',	80,	'en',	'help_search',	1),
('listed',	84,	'en',	'help_search',	1),
('listing',	71,	'en',	'help_search',	0.976851),
('listing',	73,	'en',	'help_search',	2),
('listings',	73,	'en',	'help_search',	35.5437),
('listings',	85,	'en',	'help_search',	11.6148),
('lists',	12,	'en',	'help_search',	0.816452),
('lists',	70,	'en',	'help_search',	1),
('lists',	71,	'en',	'help_search',	0.968904),
('lists',	85,	'en',	'help_search',	1),
('live',	11,	'en',	'help_search',	3.73211),
('load',	18,	'en',	'help_search',	1),
('loads',	31,	'en',	'help_search',	1),
('locate',	23,	'en',	'help_search',	1),
('locate',	35,	'en',	'help_search',	1),
('locate',	36,	'en',	'help_search',	1),
('locate',	38,	'en',	'help_search',	2),
('locate',	39,	'en',	'help_search',	1),
('locate',	64,	'en',	'help_search',	1),
('locate',	74,	'en',	'help_search',	1),
('locate',	75,	'en',	'help_search',	2),
('locate',	78,	'en',	'help_search',	1),
('locate',	80,	'en',	'help_search',	1),
('located',	16,	'en',	'help_search',	1),
('located',	26,	'en',	'help_search',	1),
('located',	47,	'en',	'help_search',	2),
('location',	11,	'en',	'help_search',	0.774192),
('location',	12,	'en',	'help_search',	0.754681),
('location',	74,	'en',	'help_search',	1),
('locations',	12,	'en',	'help_search',	0.76431),
('locations',	86,	'en',	'help_search',	0.869951),
('locator',	80,	'en',	'help_search',	1),
('log',	34,	'en',	'help_search',	1),
('log',	37,	'en',	'help_search',	4),
('log',	42,	'en',	'help_search',	2),
('log',	44,	'en',	'help_search',	2),
('logged',	12,	'en',	'help_search',	1),
('logged',	18,	'en',	'help_search',	0.997306),
('logged',	34,	'en',	'help_search',	1),
('logged',	42,	'en',	'help_search',	2),
('loggedin',	69,	'en',	'help_search',	1),
('logging',	15,	'en',	'help_search',	2),
('logging',	33,	'en',	'help_search',	3.73881),
('logging',	37,	'en',	'help_search',	1),
('loginurl',	44,	'en',	'help_search',	1),
('long',	11,	'en',	'help_search',	0.869951),
('long',	12,	'en',	'help_search',	6.20151),
('long',	31,	'en',	'help_search',	1),
('long',	32,	'en',	'help_search',	1),
('longer',	18,	'en',	'help_search',	1),
('longer',	39,	'en',	'help_search',	1),
('longer',	86,	'en',	'help_search',	1),
('look',	10,	'en',	'help_search',	1),
('look',	30,	'en',	'help_search',	1),
('look',	32,	'en',	'help_search',	1),
('look',	86,	'en',	'help_search',	0.892724),
('looks',	20,	'en',	'help_search',	1),
('looks',	64,	'en',	'help_search',	1),
('looks',	81,	'en',	'help_search',	1),
('looks',	86,	'en',	'help_search',	1),
('machine',	41,	'en',	'help_search',	4),
('machine',	52,	'en',	'help_search',	1),
('machine',	76,	'en',	'help_search',	1),
('machinereadable',	25,	'en',	'help_search',	1),
('made',	85,	'en',	'help_search',	0.997306),
('mail',	44,	'en',	'help_search',	1),
('main',	10,	'en',	'help_search',	1),
('main',	12,	'en',	'help_search',	2.32097),
('main',	26,	'en',	'help_search',	1),
('main',	27,	'en',	'help_search',	0.980874),
('main',	30,	'en',	'help_search',	2),
('main',	32,	'en',	'help_search',	2),
('maintaining',	15,	'en',	'help_search',	46),
('maintenance',	13,	'en',	'help_search',	10.4874),
('maintenance',	15,	'en',	'help_search',	13),
('maintenance',	19,	'en',	'help_search',	11),
('maintenance',	34,	'en',	'help_search',	75),
('maintenance',	36,	'en',	'help_search',	5),
('maintenance',	37,	'en',	'help_search',	11),
('make',	9,	'en',	'help_search',	4),
('make',	13,	'en',	'help_search',	1),
('make',	20,	'en',	'help_search',	1),
('make',	23,	'en',	'help_search',	2),
('make',	26,	'en',	'help_search',	1),
('make',	28,	'en',	'help_search',	1),
('make',	29,	'en',	'help_search',	3.91323),
('make',	30,	'en',	'help_search',	0.836446),
('make',	35,	'en',	'help_search',	1),
('make',	36,	'en',	'help_search',	1),
('make',	44,	'en',	'help_search',	2),
('make',	53,	'en',	'help_search',	1),
('make',	55,	'en',	'help_search',	0.989021),
('make',	58,	'en',	'help_search',	1),
('make',	64,	'en',	'help_search',	4),
('make',	65,	'en',	'help_search',	1),
('make',	68,	'en',	'help_search',	1),
('make',	75,	'en',	'help_search',	1),
('make',	78,	'en',	'help_search',	1),
('make',	79,	'en',	'help_search',	1),
('make',	81,	'en',	'help_search',	2),
('make',	83,	'en',	'help_search',	1),
('makes',	30,	'en',	'help_search',	0.968904),
('making',	11,	'en',	'help_search',	7.33326),
('making',	19,	'en',	'help_search',	26),
('making',	66,	'en',	'help_search',	1),
('making',	67,	'en',	'help_search',	1),
('malicious',	50,	'en',	'help_search',	0.896076),
('manage',	1,	'en',	'help_search',	4),
('manage',	2,	'en',	'help_search',	4),
('manage',	3,	'en',	'help_search',	4),
('manage',	4,	'en',	'help_search',	4),
('manage',	5,	'en',	'help_search',	12),
('manage',	6,	'en',	'help_search',	8),
('manage',	7,	'en',	'help_search',	4),
('manage',	9,	'en',	'help_search',	4),
('manage',	12,	'en',	'help_search',	0.623497),
('manage',	13,	'en',	'help_search',	4),
('manage',	18,	'en',	'help_search',	3.55759),
('manage',	24,	'en',	'help_search',	2.91674),
('manage',	26,	'en',	'help_search',	16),
('manage',	28,	'en',	'help_search',	4),
('manage',	29,	'en',	'help_search',	5),
('manage',	31,	'en',	'help_search',	4),
('manage',	32,	'en',	'help_search',	12),
('manage',	33,	'en',	'help_search',	7.75353),
('manage',	34,	'en',	'help_search',	8),
('manage',	35,	'en',	'help_search',	4),
('manage',	36,	'en',	'help_search',	4),
('manage',	37,	'en',	'help_search',	12),
('manage',	38,	'en',	'help_search',	4),
('manage',	39,	'en',	'help_search',	4),
('manage',	40,	'en',	'help_search',	4),
('manage',	41,	'en',	'help_search',	4),
('manage',	42,	'en',	'help_search',	1),
('manage',	43,	'en',	'help_search',	4),
('manage',	44,	'en',	'help_search',	4),
('manage',	45,	'en',	'help_search',	4),
('manage',	47,	'en',	'help_search',	4),
('manage',	48,	'en',	'help_search',	1),
('manage',	49,	'en',	'help_search',	4),
('manage',	50,	'en',	'help_search',	3.95608),
('manage',	51,	'en',	'help_search',	4),
('manage',	52,	'en',	'help_search',	16),
('manage',	53,	'en',	'help_search',	4),
('manage',	54,	'en',	'help_search',	12),
('manage',	55,	'en',	'help_search',	4),
('manage',	56,	'en',	'help_search',	1),
('manage',	58,	'en',	'help_search',	4),
('manage',	65,	'en',	'help_search',	12),
('manage',	66,	'en',	'help_search',	8),
('manage',	67,	'en',	'help_search',	8),
('manage',	68,	'en',	'help_search',	12),
('manage',	70,	'en',	'help_search',	4),
('manage',	72,	'en',	'help_search',	4),
('manage',	74,	'en',	'help_search',	4),
('manage',	75,	'en',	'help_search',	8),
('manage',	76,	'en',	'help_search',	4),
('manage',	77,	'en',	'help_search',	4),
('manage',	79,	'en',	'help_search',	23),
('manage',	82,	'en',	'help_search',	4),
('manage',	83,	'en',	'help_search',	4),
('manage',	84,	'en',	'help_search',	4),
('manage',	85,	'en',	'help_search',	4),
('manage',	86,	'en',	'help_search',	16),
('manage',	87,	'en',	'help_search',	8),
('managed',	16,	'en',	'help_search',	1),
('managed',	19,	'en',	'help_search',	1),
('managed',	50,	'en',	'help_search',	1),
('managed',	71,	'en',	'help_search',	1),
('managed',	81,	'en',	'help_search',	1),
('management',	8,	'en',	'help_search',	19),
('management',	11,	'en',	'help_search',	8.20031),
('management',	53,	'en',	'help_search',	11),
('management',	55,	'en',	'help_search',	10.4874),
('management',	86,	'en',	'help_search',	1),
('manager',	11,	'en',	'help_search',	0.731649),
('manager',	22,	'en',	'help_search',	1),
('manager',	37,	'en',	'help_search',	1),
('manager',	86,	'en',	'help_search',	1),
('managers',	8,	'en',	'help_search',	1),
('manages',	22,	'en',	'help_search',	1),
('managing',	1,	'en',	'help_search',	1),
('managing',	2,	'en',	'help_search',	1),
('managing',	3,	'en',	'help_search',	1),
('managing',	4,	'en',	'help_search',	1),
('managing',	5,	'en',	'help_search',	26),
('managing',	6,	'en',	'help_search',	1),
('managing',	7,	'en',	'help_search',	1),
('managing',	8,	'en',	'help_search',	26),
('managing',	10,	'en',	'help_search',	1),
('managing',	11,	'en',	'help_search',	40.1606),
('managing',	12,	'en',	'help_search',	38.6049),
('managing',	16,	'en',	'help_search',	47),
('managing',	17,	'en',	'help_search',	46),
('managing',	22,	'en',	'help_search',	2),
('managing',	25,	'en',	'help_search',	1),
('managing',	28,	'en',	'help_search',	1),
('managing',	29,	'en',	'help_search',	26),
('managing',	30,	'en',	'help_search',	0.848323),
('managing',	42,	'en',	'help_search',	46),
('managing',	48,	'en',	'help_search',	45),
('managing',	50,	'en',	'help_search',	26),
('managing',	53,	'en',	'help_search',	1),
('managing',	54,	'en',	'help_search',	1),
('managing',	55,	'en',	'help_search',	1),
('managing',	56,	'en',	'help_search',	46),
('managing',	57,	'en',	'help_search',	44.6366),
('managing',	58,	'en',	'help_search',	2.83669),
('managing',	65,	'en',	'help_search',	3),
('managing',	66,	'en',	'help_search',	2),
('managing',	67,	'en',	'help_search',	2),
('managing',	68,	'en',	'help_search',	2),
('managing',	70,	'en',	'help_search',	2),
('managing',	71,	'en',	'help_search',	45.1145),
('managing',	72,	'en',	'help_search',	1),
('managing',	73,	'en',	'help_search',	41.2523),
('managing',	85,	'en',	'help_search',	1),
('managing',	86,	'en',	'help_search',	3),
('managing',	87,	'en',	'help_search',	2),
('manner',	55,	'en',	'help_search',	0.968904),
('manually',	13,	'en',	'help_search',	1),
('manually',	31,	'en',	'help_search',	1),
('manually',	37,	'en',	'help_search',	4),
('many',	12,	'en',	'help_search',	1.53962),
('many',	22,	'en',	'help_search',	1),
('many',	23,	'en',	'help_search',	1),
('many',	56,	'en',	'help_search',	1),
('many',	73,	'en',	'help_search',	0.942091),
('mapped',	87,	'en',	'help_search',	1),
('mapping',	87,	'en',	'help_search',	8),
('mark',	18,	'en',	'help_search',	1),
('marked',	2,	'en',	'help_search',	1),
('marked',	43,	'en',	'help_search',	1),
('marked',	69,	'en',	'help_search',	2),
('marker',	69,	'en',	'help_search',	1),
('markup',	10,	'en',	'help_search',	1),
('markup',	12,	'en',	'help_search',	1),
('markup',	56,	'en',	'help_search',	1),
('match',	11,	'en',	'help_search',	0.781775),
('match',	30,	'en',	'help_search',	0.953396),
('match',	32,	'en',	'help_search',	1),
('match',	44,	'en',	'help_search',	1),
('matched',	29,	'en',	'help_search',	1),
('matches',	32,	'en',	'help_search',	1),
('matching',	30,	'en',	'help_search',	1),
('matter',	27,	'en',	'help_search',	1),
('maximum',	18,	'en',	'help_search',	1.86055),
('may',	12,	'en',	'help_search',	1.92384),
('may',	15,	'en',	'help_search',	1),
('may',	16,	'en',	'help_search',	1),
('may',	24,	'en',	'help_search',	1),
('may',	30,	'en',	'help_search',	0.819249),
('may',	33,	'en',	'help_search',	1),
('may',	35,	'en',	'help_search',	1),
('may',	36,	'en',	'help_search',	2),
('may',	37,	'en',	'help_search',	1),
('may',	54,	'en',	'help_search',	1),
('may',	58,	'en',	'help_search',	1),
('may',	70,	'en',	'help_search',	2),
('may',	73,	'en',	'help_search',	1),
('may',	83,	'en',	'help_search',	1),
('meaning',	69,	'en',	'help_search',	2),
('means',	11,	'en',	'help_search',	0.931053),
('means',	14,	'en',	'help_search',	2),
('meant',	10,	'en',	'help_search',	1),
('meant',	12,	'en',	'help_search',	1),
('meant',	57,	'en',	'help_search',	1),
('measure',	57,	'en',	'help_search',	1),
('mechanisms',	18,	'en',	'help_search',	2),
('mechanisms',	31,	'en',	'help_search',	1),
('mechanisms',	58,	'en',	'help_search',	1),
('media',	12,	'en',	'help_search',	0.61241),
('media',	16,	'en',	'help_search',	117.446),
('media',	57,	'en',	'help_search',	33.2416),
('media',	72,	'en',	'help_search',	5),
('media',	87,	'en',	'help_search',	55),
('mediarelated',	16,	'en',	'help_search',	1),
('medium',	32,	'en',	'help_search',	1),
('mentioned',	24,	'en',	'help_search',	0.882818),
('menu',	1,	'en',	'help_search',	1),
('menu',	2,	'en',	'help_search',	1),
('menu',	3,	'en',	'help_search',	1),
('menu',	4,	'en',	'help_search',	1),
('menu',	5,	'en',	'help_search',	1),
('menu',	6,	'en',	'help_search',	2),
('menu',	7,	'en',	'help_search',	1),
('menu',	9,	'en',	'help_search',	1),
('menu',	12,	'en',	'help_search',	0.618696),
('menu',	13,	'en',	'help_search',	1),
('menu',	17,	'en',	'help_search',	41),
('menu',	18,	'en',	'help_search',	0.882818),
('menu',	20,	'en',	'help_search',	1),
('menu',	24,	'en',	'help_search',	22),
('menu',	26,	'en',	'help_search',	4),
('menu',	28,	'en',	'help_search',	1),
('menu',	29,	'en',	'help_search',	1),
('menu',	30,	'en',	'help_search',	0.805455),
('menu',	31,	'en',	'help_search',	1),
('menu',	32,	'en',	'help_search',	3),
('menu',	33,	'en',	'help_search',	1.93838),
('menu',	34,	'en',	'help_search',	2),
('menu',	35,	'en',	'help_search',	1),
('menu',	36,	'en',	'help_search',	1),
('menu',	37,	'en',	'help_search',	3),
('menu',	38,	'en',	'help_search',	1),
('menu',	39,	'en',	'help_search',	1),
('menu',	40,	'en',	'help_search',	1),
('menu',	41,	'en',	'help_search',	1),
('menu',	43,	'en',	'help_search',	1),
('menu',	44,	'en',	'help_search',	1),
('menu',	45,	'en',	'help_search',	1),
('menu',	47,	'en',	'help_search',	1),
('menu',	49,	'en',	'help_search',	1),
('menu',	50,	'en',	'help_search',	1.93047),
('menu',	51,	'en',	'help_search',	1),
('menu',	52,	'en',	'help_search',	1),
('menu',	53,	'en',	'help_search',	1),
('menu',	54,	'en',	'help_search',	1),
('menu',	55,	'en',	'help_search',	1),
('menu',	58,	'en',	'help_search',	1),
('menu',	64,	'en',	'help_search',	4),
('menu',	65,	'en',	'help_search',	1),
('menu',	66,	'en',	'help_search',	1),
('menu',	67,	'en',	'help_search',	1),
('menu',	68,	'en',	'help_search',	1),
('menu',	70,	'en',	'help_search',	1),
('menu',	72,	'en',	'help_search',	1),
('menu',	74,	'en',	'help_search',	32),
('menu',	75,	'en',	'help_search',	45),
('menu',	76,	'en',	'help_search',	39),
('menu',	77,	'en',	'help_search',	36),
('menu',	79,	'en',	'help_search',	1),
('menu',	82,	'en',	'help_search',	1),
('menu',	83,	'en',	'help_search',	1),
('menu',	84,	'en',	'help_search',	1),
('menu',	85,	'en',	'help_search',	1),
('menu',	86,	'en',	'help_search',	1.85746),
('menu',	87,	'en',	'help_search',	1),
('menus',	17,	'en',	'help_search',	50),
('menus',	24,	'en',	'help_search',	0.968904),
('menus',	74,	'en',	'help_search',	3),
('menus',	75,	'en',	'help_search',	2),
('menus',	76,	'en',	'help_search',	5),
('menus',	77,	'en',	'help_search',	1),
('merged',	18,	'en',	'help_search',	1),
('message',	5,	'en',	'help_search',	4),
('message',	6,	'en',	'help_search',	4),
('message',	7,	'en',	'help_search',	4),
('message',	32,	'en',	'help_search',	3),
('message',	33,	'en',	'help_search',	2.85285),
('message',	34,	'en',	'help_search',	5),
('message',	35,	'en',	'help_search',	1),
('message',	36,	'en',	'help_search',	1),
('message',	40,	'en',	'help_search',	1),
('message',	44,	'en',	'help_search',	21.9572),
('messages',	23,	'en',	'help_search',	1),
('messages',	33,	'en',	'help_search',	5.68109),
('messages',	37,	'en',	'help_search',	6),
('messages',	44,	'en',	'help_search',	1.98493),
('metadata',	26,	'en',	'help_search',	4),
('metadata',	27,	'en',	'help_search',	1),
('metadata',	28,	'en',	'help_search',	4),
('metadata',	29,	'en',	'help_search',	4),
('metadata',	57,	'en',	'help_search',	1),
('metadata',	79,	'en',	'help_search',	4),
('metadata',	87,	'en',	'help_search',	4),
('method',	25,	'en',	'help_search',	2),
('method',	44,	'en',	'help_search',	1),
('middle',	86,	'en',	'help_search',	0.96498),
('might',	12,	'en',	'help_search',	0.776703),
('might',	13,	'en',	'help_search',	1),
('might',	38,	'en',	'help_search',	1),
('might',	56,	'en',	'help_search',	1),
('might',	80,	'en',	'help_search',	1),
('might',	86,	'en',	'help_search',	0.976851),
('minimum',	29,	'en',	'help_search',	4),
('minwidth',	57,	'en',	'help_search',	1),
('misbehaving',	31,	'en',	'help_search',	1),
('mistakes',	85,	'en',	'help_search',	0.993146),
('modal',	49,	'en',	'help_search',	2),
('mode',	15,	'en',	'help_search',	1),
('mode',	34,	'en',	'help_search',	75),
('mode',	36,	'en',	'help_search',	5),
('modify',	43,	'en',	'help_search',	1),
('modify',	45,	'en',	'help_search',	1),
('modify',	56,	'en',	'help_search',	1),
('modify',	85,	'en',	'help_search',	2),
('modifying',	14,	'en',	'help_search',	26),
('modifying',	43,	'en',	'help_search',	26),
('modifying',	45,	'en',	'help_search',	26),
('module',	8,	'en',	'help_search',	1),
('module',	10,	'en',	'help_search',	2.97286),
('module',	11,	'en',	'help_search',	2.72942),
('module',	12,	'en',	'help_search',	8.46129),
('module',	13,	'en',	'help_search',	2.99461),
('module',	14,	'en',	'help_search',	48),
('module',	15,	'en',	'help_search',	1),
('module',	16,	'en',	'help_search',	17.436),
('module',	17,	'en',	'help_search',	2),
('module',	18,	'en',	'help_search',	30.5823),
('module',	20,	'en',	'help_search',	4),
('module',	21,	'en',	'help_search',	1),
('module',	22,	'en',	'help_search',	2),
('module',	23,	'en',	'help_search',	0.98493),
('module',	24,	'en',	'help_search',	18),
('module',	25,	'en',	'help_search',	26),
('module',	26,	'en',	'help_search',	1),
('module',	27,	'en',	'help_search',	5),
('module',	30,	'en',	'help_search',	37.3277),
('module',	35,	'en',	'help_search',	38),
('module',	36,	'en',	'help_search',	38),
('module',	37,	'en',	'help_search',	2),
('module',	42,	'en',	'help_search',	3),
('module',	46,	'en',	'help_search',	14),
('module',	47,	'en',	'help_search',	1),
('module',	48,	'en',	'help_search',	2),
('module',	50,	'en',	'help_search',	3.81085),
('module',	54,	'en',	'help_search',	3),
('module',	56,	'en',	'help_search',	2),
('module',	57,	'en',	'help_search',	2.93025),
('module',	58,	'en',	'help_search',	4),
('module',	64,	'en',	'help_search',	4),
('module',	69,	'en',	'help_search',	1),
('module',	70,	'en',	'help_search',	2),
('module',	71,	'en',	'help_search',	1.8843),
('module',	73,	'en',	'help_search',	3.19292),
('module',	76,	'en',	'help_search',	1),
('module',	80,	'en',	'help_search',	2),
('module',	81,	'en',	'help_search',	5),
('module',	83,	'en',	'help_search',	2),
('modules',	10,	'en',	'help_search',	2.98087),
('modules',	11,	'en',	'help_search',	0.7017),
('modules',	12,	'en',	'help_search',	4.85309),
('modules',	13,	'en',	'help_search',	1),
('modules',	14,	'en',	'help_search',	21),
('modules',	15,	'en',	'help_search',	1),
('modules',	16,	'en',	'help_search',	3),
('modules',	17,	'en',	'help_search',	2),
('modules',	18,	'en',	'help_search',	1),
('modules',	19,	'en',	'help_search',	2),
('modules',	21,	'en',	'help_search',	1),
('modules',	22,	'en',	'help_search',	2),
('modules',	24,	'en',	'help_search',	6.68775),
('modules',	25,	'en',	'help_search',	33),
('modules',	26,	'en',	'help_search',	1),
('modules',	27,	'en',	'help_search',	9),
('modules',	30,	'en',	'help_search',	23),
('modules',	35,	'en',	'help_search',	4),
('modules',	36,	'en',	'help_search',	3),
('modules',	37,	'en',	'help_search',	2),
('modules',	42,	'en',	'help_search',	1),
('modules',	48,	'en',	'help_search',	1),
('modules',	50,	'en',	'help_search',	1),
('modules',	53,	'en',	'help_search',	1),
('modules',	55,	'en',	'help_search',	1),
('modules',	56,	'en',	'help_search',	1),
('modules',	57,	'en',	'help_search',	2.96109),
('modules',	58,	'en',	'help_search',	1),
('modules',	73,	'en',	'help_search',	1),
('mon',	1,	'en',	'node_search',	1),
('month',	69,	'en',	'help_search',	2),
('more',	1,	'en',	'help_search',	1),
('more',	2,	'en',	'help_search',	1),
('more',	3,	'en',	'help_search',	1),
('more',	4,	'en',	'help_search',	1),
('more',	5,	'en',	'help_search',	1),
('more',	6,	'en',	'help_search',	1),
('more',	7,	'en',	'help_search',	1),
('more',	8,	'en',	'help_search',	1),
('more',	10,	'en',	'help_search',	1),
('more',	12,	'en',	'help_search',	6.6464),
('more',	15,	'en',	'help_search',	1),
('more',	16,	'en',	'help_search',	2),
('more',	21,	'en',	'help_search',	1),
('more',	22,	'en',	'help_search',	2),
('more',	23,	'en',	'help_search',	1),
('more',	24,	'en',	'help_search',	2.86055),
('more',	25,	'en',	'help_search',	1),
('more',	27,	'en',	'help_search',	1),
('more',	28,	'en',	'help_search',	1),
('more',	29,	'en',	'help_search',	3),
('more',	30,	'en',	'help_search',	2.59912),
('more',	33,	'en',	'help_search',	0.909743),
('more',	35,	'en',	'help_search',	1),
('more',	40,	'en',	'help_search',	1),
('more',	42,	'en',	'help_search',	1),
('more',	48,	'en',	'help_search',	1),
('more',	50,	'en',	'help_search',	1),
('more',	51,	'en',	'help_search',	1),
('more',	53,	'en',	'help_search',	2),
('more',	54,	'en',	'help_search',	1),
('more',	55,	'en',	'help_search',	1),
('more',	56,	'en',	'help_search',	1),
('more',	58,	'en',	'help_search',	1),
('more',	68,	'en',	'help_search',	1),
('more',	70,	'en',	'help_search',	2),
('more',	71,	'en',	'help_search',	1),
('more',	72,	'en',	'help_search',	1),
('more',	73,	'en',	'help_search',	1.64807),
('more',	76,	'en',	'help_search',	1),
('more',	78,	'en',	'help_search',	1),
('more',	79,	'en',	'help_search',	1),
('more',	80,	'en',	'help_search',	1),
('more',	81,	'en',	'help_search',	2),
('more',	83,	'en',	'help_search',	2),
('more',	85,	'en',	'help_search',	1),
('more',	86,	'en',	'help_search',	3.83938),
('more',	87,	'en',	'help_search',	1),
('most',	11,	'en',	'help_search',	0.703756),
('most',	12,	'en',	'help_search',	2.33704),
('most',	20,	'en',	'help_search',	1),
('most',	23,	'en',	'help_search',	2),
('most',	30,	'en',	'help_search',	1),
('most',	34,	'en',	'help_search',	1),
('most',	37,	'en',	'help_search',	1),
('most',	64,	'en',	'help_search',	1),
('most',	68,	'en',	'help_search',	1),
('most',	69,	'en',	'help_search',	1),
('most',	72,	'en',	'help_search',	1),
('most',	73,	'en',	'help_search',	2),
('most',	82,	'en',	'help_search',	1),
('most',	87,	'en',	'help_search',	1),
('mostcommonlyused',	25,	'en',	'help_search',	1),
('mouse',	64,	'en',	'help_search',	1),
('move',	11,	'en',	'help_search',	1),
('move',	86,	'en',	'help_search',	3.38129),
('much',	18,	'en',	'help_search',	1),
('multicolumn',	86,	'en',	'help_search',	0.945829),
('multiple',	22,	'en',	'help_search',	1),
('multiple',	35,	'en',	'help_search',	1),
('multiple',	55,	'en',	'help_search',	1),
('multiple',	73,	'en',	'help_search',	1),
('multiplevalued',	12,	'en',	'help_search',	0.961087),
('multiplier',	57,	'en',	'help_search',	1),
('multipliers',	57,	'en',	'help_search',	22.9496),
('must',	20,	'en',	'help_search',	2),
('must',	46,	'en',	'help_search',	1),
('must',	65,	'en',	'help_search',	1),
('must',	68,	'en',	'help_search',	1),
('must',	70,	'en',	'help_search',	1),
('must',	73,	'en',	'help_search',	0.98493),
('name',	2,	'en',	'help_search',	5),
('name',	11,	'en',	'help_search',	1),
('name',	25,	'en',	'help_search',	1),
('name',	28,	'en',	'help_search',	1),
('name',	30,	'en',	'help_search',	1),
('name',	32,	'en',	'help_search',	2),
('name',	35,	'en',	'help_search',	2),
('name',	36,	'en',	'help_search',	2),
('name',	41,	'en',	'help_search',	8),
('name',	44,	'en',	'help_search',	4),
('name',	45,	'en',	'help_search',	1),
('name',	47,	'en',	'help_search',	1),
('name',	48,	'en',	'help_search',	1),
('name',	49,	'en',	'help_search',	1),
('name',	50,	'en',	'help_search',	4.62515),
('name',	51,	'en',	'help_search',	1),
('name',	52,	'en',	'help_search',	1),
('name',	53,	'en',	'help_search',	1),
('name',	54,	'en',	'help_search',	5),
('name',	57,	'en',	'help_search',	1),
('name',	70,	'en',	'help_search',	10),
('name',	72,	'en',	'help_search',	4),
('name',	76,	'en',	'help_search',	1),
('name',	80,	'en',	'help_search',	1),
('name',	82,	'en',	'help_search',	5),
('name',	83,	'en',	'help_search',	2),
('name',	84,	'en',	'help_search',	5),
('name',	85,	'en',	'help_search',	1),
('name',	87,	'en',	'help_search',	4),
('names',	12,	'en',	'help_search',	0.769219),
('names',	86,	'en',	'help_search',	0.886095),
('navigate',	1,	'en',	'help_search',	1),
('navigate',	2,	'en',	'help_search',	1),
('navigate',	3,	'en',	'help_search',	1),
('navigate',	4,	'en',	'help_search',	1),
('navigate',	5,	'en',	'help_search',	1),
('navigate',	6,	'en',	'help_search',	2),
('navigate',	7,	'en',	'help_search',	1),
('navigate',	9,	'en',	'help_search',	1),
('navigate',	13,	'en',	'help_search',	1),
('navigate',	17,	'en',	'help_search',	1),
('navigate',	18,	'en',	'help_search',	0.876337),
('navigate',	24,	'en',	'help_search',	2),
('navigate',	26,	'en',	'help_search',	4),
('navigate',	28,	'en',	'help_search',	1),
('navigate',	29,	'en',	'help_search',	1),
('navigate',	31,	'en',	'help_search',	1),
('navigate',	32,	'en',	'help_search',	3),
('navigate',	33,	'en',	'help_search',	1.93838),
('navigate',	34,	'en',	'help_search',	2),
('navigate',	35,	'en',	'help_search',	1),
('navigate',	36,	'en',	'help_search',	1),
('navigate',	37,	'en',	'help_search',	3),
('navigate',	38,	'en',	'help_search',	1),
('navigate',	39,	'en',	'help_search',	1),
('navigate',	40,	'en',	'help_search',	1),
('navigate',	41,	'en',	'help_search',	1),
('navigate',	43,	'en',	'help_search',	1),
('navigate',	44,	'en',	'help_search',	1),
('navigate',	45,	'en',	'help_search',	1),
('navigate',	47,	'en',	'help_search',	1),
('navigate',	49,	'en',	'help_search',	1),
('navigate',	50,	'en',	'help_search',	0.976851),
('navigate',	51,	'en',	'help_search',	1),
('navigate',	52,	'en',	'help_search',	1),
('navigate',	53,	'en',	'help_search',	1),
('navigate',	54,	'en',	'help_search',	1),
('navigate',	55,	'en',	'help_search',	1),
('navigate',	58,	'en',	'help_search',	1),
('navigate',	64,	'en',	'help_search',	1),
('navigate',	65,	'en',	'help_search',	2),
('navigate',	66,	'en',	'help_search',	2),
('navigate',	67,	'en',	'help_search',	2),
('navigate',	68,	'en',	'help_search',	2),
('navigate',	70,	'en',	'help_search',	1),
('navigate',	72,	'en',	'help_search',	1),
('navigate',	74,	'en',	'help_search',	1),
('navigate',	75,	'en',	'help_search',	2),
('navigate',	76,	'en',	'help_search',	1),
('navigate',	77,	'en',	'help_search',	1),
('navigate',	79,	'en',	'help_search',	1),
('navigate',	81,	'en',	'help_search',	1),
('navigate',	82,	'en',	'help_search',	1),
('navigate',	83,	'en',	'help_search',	1),
('navigate',	84,	'en',	'help_search',	1),
('navigate',	85,	'en',	'help_search',	1),
('navigate',	86,	'en',	'help_search',	2),
('navigate',	87,	'en',	'help_search',	1),
('navigating',	64,	'en',	'help_search',	1),
('navigation',	30,	'en',	'help_search',	0.808176),
('near',	26,	'en',	'help_search',	1),
('necessary',	24,	'en',	'help_search',	0.896076),
('necessary',	83,	'en',	'help_search',	1),
('necessary',	85,	'en',	'help_search',	1),
('need',	6,	'en',	'help_search',	1),
('need',	13,	'en',	'help_search',	1),
('need',	14,	'en',	'help_search',	1),
('need',	19,	'en',	'help_search',	1),
('need',	20,	'en',	'help_search',	1),
('need',	27,	'en',	'help_search',	1),
('need',	30,	'en',	'help_search',	2.56694),
('need',	31,	'en',	'help_search',	1),
('need',	32,	'en',	'help_search',	1),
('need',	35,	'en',	'help_search',	1),
('need',	36,	'en',	'help_search',	2),
('need',	37,	'en',	'help_search',	1),
('need',	44,	'en',	'help_search',	1),
('need',	47,	'en',	'help_search',	1),
('need',	53,	'en',	'help_search',	1),
('need',	55,	'en',	'help_search',	1),
('need',	57,	'en',	'help_search',	1),
('need',	58,	'en',	'help_search',	1),
('need',	70,	'en',	'help_search',	1),
('need',	78,	'en',	'help_search',	1),
('need',	81,	'en',	'help_search',	1),
('need',	83,	'en',	'help_search',	2),
('need',	87,	'en',	'help_search',	1),
('needed',	18,	'en',	'help_search',	2),
('needed',	30,	'en',	'help_search',	1.80574),
('needed',	66,	'en',	'help_search',	1),
('needed',	67,	'en',	'help_search',	1),
('needed',	86,	'en',	'help_search',	0.882818),
('needing',	64,	'en',	'help_search',	1),
('needs',	18,	'en',	'help_search',	0.989021),
('never',	69,	'en',	'help_search',	1),
('new',	6,	'en',	'help_search',	1),
('new',	7,	'en',	'help_search',	28),
('new',	11,	'en',	'help_search',	0.845322),
('new',	17,	'en',	'help_search',	1),
('new',	22,	'en',	'help_search',	1),
('new',	24,	'en',	'help_search',	1),
('new',	26,	'en',	'help_search',	1),
('new',	28,	'en',	'help_search',	1),
('new',	38,	'en',	'help_search',	3),
('new',	40,	'en',	'help_search',	13),
('new',	41,	'en',	'help_search',	28),
('new',	44,	'en',	'help_search',	2),
('new',	45,	'en',	'help_search',	1),
('new',	50,	'en',	'help_search',	1.71949),
('new',	52,	'en',	'help_search',	1),
('new',	53,	'en',	'help_search',	1),
('new',	54,	'en',	'help_search',	3),
('new',	58,	'en',	'help_search',	5.48567),
('new',	65,	'en',	'help_search',	5),
('new',	68,	'en',	'help_search',	4.99315),
('new',	69,	'en',	'help_search',	16),
('new',	70,	'en',	'help_search',	2),
('new',	71,	'en',	'help_search',	1),
('new',	72,	'en',	'help_search',	6),
('new',	76,	'en',	'help_search',	1),
('new',	77,	'en',	'help_search',	1),
('new',	78,	'en',	'help_search',	2),
('new',	79,	'en',	'help_search',	1),
('new',	82,	'en',	'help_search',	30),
('new',	84,	'en',	'help_search',	27),
('new',	85,	'en',	'help_search',	1),
('new',	86,	'en',	'help_search',	1.85488),
('new',	87,	'en',	'help_search',	28),
('newly',	69,	'en',	'help_search',	1),
('news',	73,	'en',	'help_search',	1),
('next',	18,	'en',	'help_search',	1),
('next',	35,	'en',	'help_search',	2),
('next',	36,	'en',	'help_search',	1),
('next',	45,	'en',	'help_search',	1),
('next',	65,	'en',	'help_search',	2),
('next',	68,	'en',	'help_search',	2),
('next',	72,	'en',	'help_search',	1),
('next',	81,	'en',	'help_search',	1),
('next',	82,	'en',	'help_search',	1),
('next',	85,	'en',	'help_search',	1),
('node',	12,	'en',	'help_search',	0.621888),
('node',	30,	'en',	'help_search',	2),
('node',	56,	'en',	'help_search',	1),
('node',	75,	'en',	'help_search',	4),
('node',	80,	'en',	'help_search',	13),
('nolink',	75,	'en',	'help_search',	4),
('nonadministration',	38,	'en',	'help_search',	1),
('nonadministrative',	24,	'en',	'help_search',	1),
('nonadministrative',	53,	'en',	'help_search',	1),
('nonadministrative',	64,	'en',	'help_search',	2),
('noncacheable',	18,	'en',	'help_search',	0.961087),
('nondefault',	23,	'en',	'help_search',	1),
('none',	33,	'en',	'help_search',	3.69535),
('nonenglish',	27,	'en',	'help_search',	1),
('nonerror',	33,	'en',	'help_search',	1),
('nontoplevel',	27,	'en',	'help_search',	1),
('normal',	33,	'en',	'help_search',	1),
('normal',	34,	'en',	'help_search',	2),
('normally',	68,	'en',	'help_search',	1),
('normally',	71,	'en',	'help_search',	2),
('not',	10,	'en',	'help_search',	1),
('not',	11,	'en',	'help_search',	1.85498),
('not',	12,	'en',	'help_search',	2.72283),
('not',	13,	'en',	'help_search',	1.99731),
('not',	14,	'en',	'help_search',	2),
('not',	15,	'en',	'help_search',	1),
('not',	18,	'en',	'help_search',	1.98902),
('not',	23,	'en',	'help_search',	1),
('not',	24,	'en',	'help_search',	1),
('not',	26,	'en',	'help_search',	4),
('not',	28,	'en',	'help_search',	2),
('not',	30,	'en',	'help_search',	2),
('not',	32,	'en',	'help_search',	1),
('not',	33,	'en',	'help_search',	2),
('not',	35,	'en',	'help_search',	1),
('not',	38,	'en',	'help_search',	1),
('not',	39,	'en',	'help_search',	1),
('not',	42,	'en',	'help_search',	1),
('not',	43,	'en',	'help_search',	1),
('not',	45,	'en',	'help_search',	1),
('not',	46,	'en',	'help_search',	1),
('not',	48,	'en',	'help_search',	1),
('not',	50,	'en',	'help_search',	0.957226),
('not',	53,	'en',	'help_search',	1),
('not',	54,	'en',	'help_search',	1),
('not',	66,	'en',	'help_search',	2),
('not',	67,	'en',	'help_search',	1),
('not',	68,	'en',	'help_search',	2),
('not',	75,	'en',	'help_search',	3),
('not',	82,	'en',	'help_search',	1),
('not',	83,	'en',	'help_search',	2),
('not',	85,	'en',	'help_search',	1),
('not',	87,	'en',	'help_search',	1),
('note',	5,	'en',	'help_search',	1),
('note',	13,	'en',	'help_search',	1),
('note',	33,	'en',	'help_search',	1),
('note',	37,	'en',	'help_search',	1),
('note',	75,	'en',	'help_search',	1),
('note',	79,	'en',	'help_search',	1),
('note',	83,	'en',	'help_search',	1),
('note',	87,	'en',	'help_search',	1),
('noted',	87,	'en',	'help_search',	1),
('notfound',	33,	'en',	'help_search',	7.78302),
('notify',	40,	'en',	'help_search',	4),
('notifying',	40,	'en',	'help_search',	1),
('now',	11,	'en',	'help_search',	0.792123),
('now',	13,	'en',	'help_search',	1),
('now',	38,	'en',	'help_search',	1),
('now',	65,	'en',	'help_search',	1),
('now',	68,	'en',	'help_search',	1),
('now',	72,	'en',	'help_search',	1),
('now',	87,	'en',	'help_search',	1),
('number',	12,	'en',	'help_search',	0.896076),
('number',	29,	'en',	'help_search',	6),
('number',	65,	'en',	'help_search',	5),
('number',	68,	'en',	'help_search',	5),
('number',	81,	'en',	'help_search',	1),
('number',	86,	'en',	'help_search',	0.949597),
('numbers',	12,	'en',	'help_search',	2.49176),
('numbers',	23,	'en',	'help_search',	1),
('numerical',	23,	'en',	'help_search',	1),
('occasionally',	19,	'en',	'help_search',	1),
('occur',	23,	'en',	'help_search',	1),
('occur',	33,	'en',	'help_search',	19),
('off',	14,	'en',	'help_search',	1),
('offer',	12,	'en',	'help_search',	1.31386),
('offer',	24,	'en',	'help_search',	1),
('official',	46,	'en',	'help_search',	4),
('often',	13,	'en',	'help_search',	1),
('often',	85,	'en',	'help_search',	1),
('older',	69,	'en',	'help_search',	1),
('once',	11,	'en',	'help_search',	0.957226),
('once',	12,	'en',	'help_search',	0.736141),
('once',	13,	'en',	'help_search',	2),
('once',	27,	'en',	'help_search',	1),
('once',	44,	'en',	'help_search',	1),
('one',	3,	'en',	'help_search',	1),
('one',	4,	'en',	'help_search',	1),
('one',	5,	'en',	'help_search',	1),
('one',	8,	'en',	'help_search',	1),
('one',	10,	'en',	'help_search',	1),
('one',	11,	'en',	'help_search',	0.836446),
('one',	12,	'en',	'help_search',	5.15836),
('one',	21,	'en',	'help_search',	1),
('one',	27,	'en',	'help_search',	1),
('one',	28,	'en',	'help_search',	1),
('one',	30,	'en',	'help_search',	0.866793),
('one',	33,	'en',	'help_search',	0.916736),
('one',	35,	'en',	'help_search',	1),
('one',	42,	'en',	'help_search',	1),
('one',	48,	'en',	'help_search',	1),
('one',	51,	'en',	'help_search',	1),
('one',	53,	'en',	'help_search',	1),
('one',	55,	'en',	'help_search',	1),
('one',	57,	'en',	'help_search',	3),
('one',	65,	'en',	'help_search',	1),
('one',	68,	'en',	'help_search',	2),
('one',	69,	'en',	'help_search',	2),
('one',	71,	'en',	'help_search',	1),
('one',	73,	'en',	'help_search',	0.848323),
('one',	75,	'en',	'help_search',	1),
('one',	76,	'en',	'help_search',	1),
('one',	81,	'en',	'help_search',	3),
('one',	83,	'en',	'help_search',	1),
('one',	86,	'en',	'help_search',	2.98087),
('onecolumn',	86,	'en',	'help_search',	2.93009),
('onetimeloginurl',	44,	'en',	'help_search',	1),
('online',	18,	'en',	'help_search',	27.765),
('online',	25,	'en',	'help_search',	22),
('online',	30,	'en',	'help_search',	8.59953),
('only',	11,	'en',	'help_search',	0.754681),
('only',	12,	'en',	'help_search',	0.650439),
('only',	22,	'en',	'help_search',	1),
('only',	26,	'en',	'help_search',	1),
('only',	30,	'en',	'help_search',	1),
('only',	37,	'en',	'help_search',	1),
('only',	43,	'en',	'help_search',	4),
('only',	44,	'en',	'help_search',	1),
('only',	47,	'en',	'help_search',	1),
('only',	50,	'en',	'help_search',	0.876337),
('only',	58,	'en',	'help_search',	0.931053),
('only',	71,	'en',	'help_search',	1),
('only',	81,	'en',	'help_search',	1),
('open',	20,	'en',	'help_search',	1),
('open',	51,	'en',	'help_search',	1),
('open',	78,	'en',	'help_search',	1),
('operation',	34,	'en',	'help_search',	1),
('operations',	13,	'en',	'help_search',	2),
('operations',	28,	'en',	'help_search',	4),
('operations',	34,	'en',	'help_search',	2),
('operations',	45,	'en',	'help_search',	4),
('operations',	66,	'en',	'help_search',	4),
('operations',	67,	'en',	'help_search',	4),
('operations',	73,	'en',	'help_search',	17.2639),
('operations',	74,	'en',	'help_search',	4),
('operations',	75,	'en',	'help_search',	8),
('operations',	83,	'en',	'help_search',	40.9822),
('operations',	86,	'en',	'help_search',	4),
('optimizing',	18,	'en',	'help_search',	26),
('option',	12,	'en',	'help_search',	0.661163),
('option',	44,	'en',	'help_search',	0.993146),
('optional',	11,	'en',	'help_search',	4),
('optionally',	7,	'en',	'help_search',	1),
('optionally',	28,	'en',	'help_search',	1),
('optionally',	29,	'en',	'help_search',	1),
('optionally',	34,	'en',	'help_search',	1),
('optionally',	40,	'en',	'help_search',	1),
('optionally',	44,	'en',	'help_search',	0.989021),
('optionally',	47,	'en',	'help_search',	1),
('optionally',	48,	'en',	'help_search',	1),
('optionally',	49,	'en',	'help_search',	1),
('optionally',	52,	'en',	'help_search',	2),
('optionally',	53,	'en',	'help_search',	1),
('optionally',	54,	'en',	'help_search',	1),
('optionally',	55,	'en',	'help_search',	2),
('optionally',	64,	'en',	'help_search',	1),
('optionally',	65,	'en',	'help_search',	1),
('optionally',	68,	'en',	'help_search',	1),
('optionally',	70,	'en',	'help_search',	3),
('optionally',	74,	'en',	'help_search',	1),
('optionally',	75,	'en',	'help_search',	3),
('optionally',	81,	'en',	'help_search',	0.989021),
('optionally',	82,	'en',	'help_search',	1),
('optionally',	84,	'en',	'help_search',	1),
('optionally',	87,	'en',	'help_search',	1),
('options',	12,	'en',	'help_search',	1.4206),
('options',	13,	'en',	'help_search',	19),
('options',	30,	'en',	'help_search',	1),
('options',	33,	'en',	'help_search',	0.913226),
('options',	50,	'en',	'help_search',	0.786915),
('options',	69,	'en',	'help_search',	19),
('options',	74,	'en',	'help_search',	1),
('options',	86,	'en',	'help_search',	4),
('order',	5,	'en',	'help_search',	1),
('order',	6,	'en',	'help_search',	1),
('order',	19,	'en',	'help_search',	1),
('order',	20,	'en',	'help_search',	2),
('order',	23,	'en',	'help_search',	2),
('order',	26,	'en',	'help_search',	1),
('order',	30,	'en',	'help_search',	0.876337),
('order',	47,	'en',	'help_search',	1),
('order',	50,	'en',	'help_search',	5.02459),
('order',	55,	'en',	'help_search',	1),
('order',	58,	'en',	'help_search',	0.889397),
('order',	65,	'en',	'help_search',	1),
('order',	66,	'en',	'help_search',	3),
('order',	67,	'en',	'help_search',	3),
('order',	68,	'en',	'help_search',	1),
('order',	72,	'en',	'help_search',	2),
('order',	73,	'en',	'help_search',	2.98087),
('order',	75,	'en',	'help_search',	2),
('order',	77,	'en',	'help_search',	2),
('order',	81,	'en',	'help_search',	0.961087),
('order',	83,	'en',	'help_search',	1),
('order',	85,	'en',	'help_search',	1),
('ordered',	50,	'en',	'help_search',	1),
('ordering',	23,	'en',	'help_search',	1),
('ordering',	47,	'en',	'help_search',	1),
('organize',	71,	'en',	'help_search',	1),
('organized',	57,	'en',	'help_search',	1),
('organizes',	30,	'en',	'help_search',	1),
('original',	18,	'en',	'help_search',	1),
('other',	2,	'en',	'help_search',	1),
('other',	4,	'en',	'help_search',	1),
('other',	5,	'en',	'help_search',	1),
('other',	7,	'en',	'help_search',	1),
('other',	8,	'en',	'help_search',	1),
('other',	10,	'en',	'help_search',	5),
('other',	11,	'en',	'help_search',	0.716357),
('other',	12,	'en',	'help_search',	5.07468),
('other',	16,	'en',	'help_search',	1),
('other',	18,	'en',	'help_search',	2),
('other',	22,	'en',	'help_search',	1),
('other',	23,	'en',	'help_search',	1),
('other',	25,	'en',	'help_search',	5),
('other',	27,	'en',	'help_search',	1),
('other',	30,	'en',	'help_search',	1),
('other',	32,	'en',	'help_search',	1),
('other',	33,	'en',	'help_search',	19.9132),
('other',	36,	'en',	'help_search',	1),
('other',	40,	'en',	'help_search',	1),
('other',	44,	'en',	'help_search',	0.980874),
('other',	48,	'en',	'help_search',	1),
('other',	53,	'en',	'help_search',	1),
('other',	55,	'en',	'help_search',	1.98493),
('other',	56,	'en',	'help_search',	3),
('other',	57,	'en',	'help_search',	2),
('other',	58,	'en',	'help_search',	2),
('other',	68,	'en',	'help_search',	4),
('other',	71,	'en',	'help_search',	2),
('other',	73,	'en',	'help_search',	1),
('other',	80,	'en',	'help_search',	1),
('other',	81,	'en',	'help_search',	1),
('other',	82,	'en',	'help_search',	1),
('other',	84,	'en',	'help_search',	1),
('other',	87,	'en',	'help_search',	1),
('out',	5,	'en',	'help_search',	1),
('out',	8,	'en',	'help_search',	1),
('out',	18,	'en',	'help_search',	0.927431),
('out',	42,	'en',	'help_search',	1),
('out',	57,	'en',	'help_search',	1),
('outline',	64,	'en',	'help_search',	1),
('output',	18,	'en',	'help_search',	1.97685),
('output',	57,	'en',	'help_search',	1),
('output',	58,	'en',	'help_search',	1),
('output',	73,	'en',	'help_search',	5),
('outreach',	46,	'en',	'help_search',	1),
('outside',	13,	'en',	'help_search',	5.99731),
('outside',	17,	'en',	'help_search',	1),
('outside',	71,	'en',	'help_search',	1),
('over',	20,	'en',	'help_search',	1),
('over',	58,	'en',	'help_search',	0.916736),
('over',	64,	'en',	'help_search',	1),
('over',	75,	'en',	'help_search',	1),
('over',	86,	'en',	'help_search',	0.863659),
('overall',	10,	'en',	'help_search',	0.993146),
('overall',	29,	'en',	'help_search',	0.892724),
('override',	11,	'en',	'help_search',	0.920273),
('override',	47,	'en',	'help_search',	4),
('overview',	10,	'en',	'help_search',	19),
('overview',	11,	'en',	'help_search',	14.1606),
('overview',	12,	'en',	'help_search',	12.0017),
('overview',	14,	'en',	'help_search',	19),
('overview',	15,	'en',	'help_search',	19),
('overview',	16,	'en',	'help_search',	19),
('overview',	17,	'en',	'help_search',	19),
('overview',	21,	'en',	'help_search',	19),
('overview',	22,	'en',	'help_search',	19),
('overview',	23,	'en',	'help_search',	19),
('overview',	24,	'en',	'help_search',	17.7735),
('overview',	30,	'en',	'help_search',	16.7117),
('overview',	42,	'en',	'help_search',	19),
('overview',	46,	'en',	'help_search',	11),
('overview',	48,	'en',	'help_search',	19),
('overview',	53,	'en',	'help_search',	4),
('overview',	55,	'en',	'help_search',	4),
('overview',	56,	'en',	'help_search',	19),
('overview',	57,	'en',	'help_search',	18.6366),
('overview',	65,	'en',	'help_search',	3),
('overview',	71,	'en',	'help_search',	18.1873),
('overview',	72,	'en',	'help_search',	1),
('overview',	73,	'en',	'help_search',	15.2523),
('overview',	80,	'en',	'help_search',	19),
('overview',	87,	'en',	'help_search',	1),
('own',	8,	'en',	'help_search',	1),
('own',	10,	'en',	'help_search',	1),
('own',	11,	'en',	'help_search',	1),
('own',	33,	'en',	'help_search',	1),
('own',	53,	'en',	'help_search',	1),
('own',	55,	'en',	'help_search',	5),
('own',	56,	'en',	'help_search',	1),
('owned',	11,	'en',	'help_search',	0.938382),
('owners',	46,	'en',	'help_search',	2),
('page',	1,	'en',	'node_search',	27),
('page',	3,	'en',	'help_search',	1),
('page',	5,	'en',	'help_search',	1),
('page',	9,	'en',	'help_search',	11),
('page',	10,	'en',	'help_search',	22),
('page',	12,	'en',	'help_search',	0.585658),
('page',	13,	'en',	'help_search',	1),
('page',	14,	'en',	'help_search',	11),
('page',	18,	'en',	'help_search',	27.055),
('page',	19,	'en',	'help_search',	1),
('page',	20,	'en',	'help_search',	4),
('page',	23,	'en',	'help_search',	1),
('page',	24,	'en',	'help_search',	1),
('page',	26,	'en',	'help_search',	7),
('page',	27,	'en',	'help_search',	5.9522),
('page',	28,	'en',	'help_search',	14),
('page',	29,	'en',	'help_search',	1.82593),
('page',	30,	'en',	'help_search',	10.732),
('page',	31,	'en',	'help_search',	1),
('page',	33,	'en',	'help_search',	8.96587),
('page',	34,	'en',	'help_search',	2),
('page',	35,	'en',	'help_search',	3),
('page',	36,	'en',	'help_search',	3),
('page',	38,	'en',	'help_search',	4),
('page',	40,	'en',	'help_search',	1),
('page',	41,	'en',	'help_search',	1),
('page',	46,	'en',	'help_search',	1),
('page',	48,	'en',	'help_search',	1),
('page',	50,	'en',	'help_search',	1.72506),
('page',	52,	'en',	'help_search',	1),
('page',	53,	'en',	'help_search',	19),
('page',	54,	'en',	'help_search',	2),
('page',	55,	'en',	'help_search',	15.4874),
('page',	64,	'en',	'help_search',	9.93833),
('page',	65,	'en',	'help_search',	3),
('page',	66,	'en',	'help_search',	2),
('page',	67,	'en',	'help_search',	1),
('page',	68,	'en',	'help_search',	3),
('page',	69,	'en',	'help_search',	2),
('page',	70,	'en',	'help_search',	2),
('page',	72,	'en',	'help_search',	1),
('page',	73,	'en',	'help_search',	7.89608),
('page',	75,	'en',	'help_search',	3),
('page',	76,	'en',	'help_search',	2),
('page',	78,	'en',	'help_search',	3),
('page',	79,	'en',	'help_search',	2),
('page',	80,	'en',	'help_search',	7),
('page',	81,	'en',	'help_search',	4.9496),
('page',	82,	'en',	'help_search',	5),
('page',	83,	'en',	'help_search',	1),
('page',	84,	'en',	'help_search',	1),
('page',	86,	'en',	'help_search',	2),
('pagelevel',	12,	'en',	'help_search',	1),
('pagelevel',	56,	'en',	'help_search',	1),
('pager',	73,	'en',	'help_search',	3.78332),
('pages',	10,	'en',	'help_search',	1),
('pages',	18,	'en',	'help_search',	1.93838),
('pages',	23,	'en',	'help_search',	2),
('pages',	24,	'en',	'help_search',	4),
('pages',	26,	'en',	'help_search',	12),
('pages',	28,	'en',	'help_search',	42),
('pages',	29,	'en',	'help_search',	11.2782),
('pages',	30,	'en',	'help_search',	29.6242),
('pages',	33,	'en',	'help_search',	34),
('pages',	38,	'en',	'help_search',	4),
('pages',	56,	'en',	'help_search',	1),
('pages',	64,	'en',	'help_search',	1),
('pages',	71,	'en',	'help_search',	1.94177),
('pages',	80,	'en',	'help_search',	2),
('pages',	81,	'en',	'help_search',	2),
('paginate',	73,	'en',	'help_search',	0.938382),
('paragraph',	50,	'en',	'help_search',	1),
('parent',	74,	'en',	'help_search',	4),
('parent',	75,	'en',	'help_search',	4),
('part',	14,	'en',	'help_search',	1),
('part',	19,	'en',	'help_search',	1),
('part',	20,	'en',	'help_search',	1),
('part',	38,	'en',	'help_search',	1),
('part',	45,	'en',	'help_search',	1),
('part',	72,	'en',	'help_search',	1),
('part',	80,	'en',	'help_search',	1),
('particular',	20,	'en',	'help_search',	1),
('particular',	30,	'en',	'help_search',	2),
('particular',	42,	'en',	'help_search',	3),
('particular',	43,	'en',	'help_search',	1),
('particular',	50,	'en',	'help_search',	0.824901),
('particular',	65,	'en',	'help_search',	1),
('particular',	66,	'en',	'help_search',	1),
('particular',	67,	'en',	'help_search',	1),
('particular',	68,	'en',	'help_search',	1),
('particular',	73,	'en',	'help_search',	1),
('particular',	80,	'en',	'help_search',	1),
('particular',	86,	'en',	'help_search',	1),
('parts',	18,	'en',	'help_search',	1.84779),
('parts',	86,	'en',	'help_search',	19),
('password',	25,	'en',	'help_search',	1),
('password',	40,	'en',	'help_search',	4),
('password',	44,	'en',	'help_search',	2),
('past',	37,	'en',	'help_search',	1),
('paste',	2,	'en',	'help_search',	1),
('paste',	4,	'en',	'help_search',	5),
('path',	11,	'en',	'help_search',	0.718502),
('path',	12,	'en',	'help_search',	0.594307),
('path',	28,	'en',	'help_search',	4),
('path',	75,	'en',	'help_search',	1),
('path',	79,	'en',	'help_search',	2),
('path',	80,	'en',	'help_search',	26),
('pathauto',	80,	'en',	'help_search',	11),
('paths',	80,	'en',	'help_search',	31),
('patterns',	32,	'en',	'help_search',	4),
('paying',	43,	'en',	'help_search',	1),
('pencil',	20,	'en',	'help_search',	1),
('pencil',	64,	'en',	'help_search',	1),
('pending',	44,	'en',	'help_search',	1),
('people',	6,	'en',	'help_search',	8),
('people',	24,	'en',	'help_search',	3.68109),
('people',	40,	'en',	'help_search',	4),
('people',	41,	'en',	'help_search',	4),
('people',	43,	'en',	'help_search',	4),
('people',	44,	'en',	'help_search',	4),
('people',	45,	'en',	'help_search',	4),
('people',	83,	'en',	'help_search',	1),
('per',	29,	'en',	'help_search',	4),
('per',	65,	'en',	'help_search',	1),
('per',	68,	'en',	'help_search',	1),
('percentages',	86,	'en',	'help_search',	0.938382),
('perform',	24,	'en',	'help_search',	1),
('perform',	29,	'en',	'help_search',	1),
('perform',	34,	'en',	'help_search',	2),
('perform',	42,	'en',	'help_search',	1),
('perform',	83,	'en',	'help_search',	1),
('performance',	18,	'en',	'help_search',	70.3599),
('performance',	31,	'en',	'help_search',	4),
('performing',	14,	'en',	'help_search',	1),
('performing',	15,	'en',	'help_search',	1),
('performing',	30,	'en',	'help_search',	0.886095),
('periodically',	13,	'en',	'help_search',	3),
('periodically',	15,	'en',	'help_search',	1),
('periods',	12,	'en',	'help_search',	0.851346),
('permanent',	28,	'en',	'help_search',	1),
('permission',	20,	'en',	'help_search',	2),
('permission',	27,	'en',	'help_search',	0.968904),
('permission',	30,	'en',	'help_search',	4.55671),
('permission',	34,	'en',	'help_search',	1),
('permission',	42,	'en',	'help_search',	23),
('permission',	43,	'en',	'help_search',	5),
('permission',	44,	'en',	'help_search',	1),
('permission',	46,	'en',	'help_search',	1),
('permission',	53,	'en',	'help_search',	5),
('permission',	54,	'en',	'help_search',	1),
('permission',	55,	'en',	'help_search',	5),
('permission',	56,	'en',	'help_search',	1),
('permission',	64,	'en',	'help_search',	3),
('permission',	70,	'en',	'help_search',	2),
('permission',	73,	'en',	'help_search',	1.85135),
('permission',	78,	'en',	'help_search',	2),
('permission',	79,	'en',	'help_search',	1),
('permission',	81,	'en',	'help_search',	5),
('permission',	83,	'en',	'help_search',	2.99731),
('permissions',	6,	'en',	'help_search',	9),
('permissions',	8,	'en',	'help_search',	1),
('permissions',	19,	'en',	'help_search',	11),
('permissions',	24,	'en',	'help_search',	1.90974),
('permissions',	27,	'en',	'help_search',	0.972861),
('permissions',	30,	'en',	'help_search',	19.4502),
('permissions',	42,	'en',	'help_search',	1),
('permissions',	43,	'en',	'help_search',	39),
('permissions',	50,	'en',	'help_search',	1),
('permissions',	53,	'en',	'help_search',	1),
('permissions',	55,	'en',	'help_search',	1),
('permissions',	83,	'en',	'help_search',	1),
('personal',	5,	'en',	'help_search',	2),
('personal',	6,	'en',	'help_search',	32),
('personal',	8,	'en',	'help_search',	24),
('personalized',	18,	'en',	'help_search',	0.920273),
('php',	14,	'en',	'help_search',	1),
('php',	32,	'en',	'help_search',	12),
('php',	33,	'en',	'help_search',	1),
('physical',	57,	'en',	'help_search',	1),
('piece',	80,	'en',	'help_search',	1),
('piece',	87,	'en',	'help_search',	1),
('pieces',	10,	'en',	'help_search',	1),
('pipe',	18,	'en',	'help_search',	0.945829),
('pixel',	57,	'en',	'help_search',	12),
('place',	20,	'en',	'help_search',	22),
('place',	24,	'en',	'help_search',	0.997306),
('place',	26,	'en',	'help_search',	1),
('place',	30,	'en',	'help_search',	0.813674),
('place',	48,	'en',	'help_search',	1),
('place',	49,	'en',	'help_search',	11),
('place',	86,	'en',	'help_search',	1),
('placed',	3,	'en',	'help_search',	1),
('placed',	24,	'en',	'help_search',	1),
('placed',	47,	'en',	'help_search',	1),
('placed',	48,	'en',	'help_search',	3),
('placed',	51,	'en',	'help_search',	1),
('placed',	64,	'en',	'help_search',	1),
('placeholders',	18,	'en',	'help_search',	1.87723),
('placing',	10,	'en',	'help_search',	1),
('placing',	17,	'en',	'help_search',	1),
('placing',	49,	'en',	'help_search',	26),
('plain',	12,	'en',	'help_search',	7.98578),
('plain',	50,	'en',	'help_search',	1.86995),
('plain',	75,	'en',	'help_search',	1),
('plaintext',	2,	'en',	'help_search',	1),
('planning',	12,	'en',	'help_search',	6.33474),
('plugin',	27,	'en',	'help_search',	2),
('plugin',	58,	'en',	'help_search',	3.44219),
('pluginbased',	27,	'en',	'help_search',	1),
('plugins',	27,	'en',	'help_search',	2),
('plus',	86,	'en',	'help_search',	0.927431),
('point',	57,	'en',	'help_search',	1),
('point',	72,	'en',	'help_search',	1),
('policy',	19,	'en',	'help_search',	13),
('policy',	46,	'en',	'help_search',	1),
('pop',	49,	'en',	'help_search',	2),
('popup',	82,	'en',	'help_search',	1),
('popup',	86,	'en',	'help_search',	1.92785),
('porter',	30,	'en',	'help_search',	10.8342),
('position',	66,	'en',	'help_search',	1),
('positions',	47,	'en',	'help_search',	1),
('possibility',	29,	'en',	'help_search',	1),
('possible',	12,	'en',	'help_search',	1.35049),
('possible',	37,	'en',	'help_search',	1),
('possible',	44,	'en',	'help_search',	1),
('possible',	57,	'en',	'help_search',	1),
('post',	71,	'en',	'help_search',	1),
('posts',	16,	'en',	'help_search',	1),
('posts',	71,	'en',	'help_search',	1),
('potentiallydangerous',	50,	'en',	'help_search',	1),
('practice',	23,	'en',	'help_search',	2),
('practices',	23,	'en',	'help_search',	0.993146),
('predefined',	12,	'en',	'help_search',	1.60616),
('predefined',	56,	'en',	'help_search',	1),
('prefer',	33,	'en',	'help_search',	1),
('preferred',	66,	'en',	'help_search',	1),
('preferred',	67,	'en',	'help_search',	1),
('preindex',	29,	'en',	'help_search',	1),
('presents',	23,	'en',	'help_search',	1),
('preventing',	15,	'en',	'help_search',	11),
('preview',	53,	'en',	'help_search',	5),
('preview',	85,	'en',	'help_search',	4),
('preview',	86,	'en',	'help_search',	4.47703),
('previous',	12,	'en',	'help_search',	0.62674),
('previous',	32,	'en',	'help_search',	1),
('previous',	72,	'en',	'help_search',	1),
('previously',	3,	'en',	'help_search',	1),
('previously',	4,	'en',	'help_search',	1),
('previously',	39,	'en',	'help_search',	1),
('previously',	47,	'en',	'help_search',	1),
('previouslyplaced',	47,	'en',	'help_search',	26),
('previouslyplaced',	49,	'en',	'help_search',	1),
('printers',	57,	'en',	'help_search',	1),
('problem',	15,	'en',	'help_search',	1),
('problem',	19,	'en',	'help_search',	1),
('problem',	31,	'en',	'help_search',	1),
('problems',	15,	'en',	'help_search',	13),
('problems',	83,	'en',	'help_search',	0.993146),
('process',	11,	'en',	'help_search',	1.91323),
('process',	19,	'en',	'help_search',	11),
('process',	25,	'en',	'help_search',	2),
('process',	29,	'en',	'help_search',	1),
('process',	72,	'en',	'help_search',	1),
('processed',	12,	'en',	'help_search',	0.72066),
('processed',	50,	'en',	'help_search',	1),
('processing',	16,	'en',	'help_search',	1),
('processing',	50,	'en',	'help_search',	4.35754),
('production',	14,	'en',	'help_search',	1),
('production',	33,	'en',	'help_search',	0.931053),
('profile',	8,	'en',	'help_search',	2),
('profile',	11,	'en',	'help_search',	1),
('profile',	12,	'en',	'help_search',	1),
('profile',	22,	'en',	'help_search',	1),
('profile',	80,	'en',	'help_search',	1),
('profile',	81,	'en',	'help_search',	1),
('profiles',	6,	'en',	'help_search',	2),
('profiles',	30,	'en',	'help_search',	1),
('profiles',	56,	'en',	'help_search',	1),
('programs',	46,	'en',	'help_search',	1),
('progress',	29,	'en',	'help_search',	7.0238),
('project',	19,	'en',	'help_search',	2),
('project',	27,	'en',	'help_search',	1),
('project',	46,	'en',	'help_search',	3),
('projects',	19,	'en',	'help_search',	1),
('promote',	46,	'en',	'help_search',	1),
('provide',	11,	'en',	'help_search',	1.38922),
('provide',	12,	'en',	'help_search',	1.20063),
('provide',	16,	'en',	'help_search',	2),
('provide',	24,	'en',	'help_search',	1),
('provide',	25,	'en',	'help_search',	22),
('provide',	27,	'en',	'help_search',	1),
('provide',	29,	'en',	'help_search',	0.98493),
('provide',	30,	'en',	'help_search',	22),
('provide',	46,	'en',	'help_search',	1),
('provide',	56,	'en',	'help_search',	2),
('provide',	57,	'en',	'help_search',	1),
('provide',	58,	'en',	'help_search',	1.84832),
('provide',	80,	'en',	'help_search',	1),
('provided',	8,	'en',	'help_search',	1),
('provided',	11,	'en',	'help_search',	1.73165),
('provided',	12,	'en',	'help_search',	4.30399),
('provided',	17,	'en',	'help_search',	2),
('provided',	22,	'en',	'help_search',	5),
('provided',	24,	'en',	'help_search',	2),
('provided',	27,	'en',	'help_search',	25.989),
('provided',	29,	'en',	'help_search',	1),
('provided',	30,	'en',	'help_search',	1),
('provided',	48,	'en',	'help_search',	1),
('provided',	50,	'en',	'help_search',	1),
('provided',	57,	'en',	'help_search',	0.957226),
('provides',	10,	'en',	'help_search',	1),
('provides',	11,	'en',	'help_search',	1),
('provides',	12,	'en',	'help_search',	1.20498),
('provides',	16,	'en',	'help_search',	3.99731),
('provides',	17,	'en',	'help_search',	3),
('provides',	20,	'en',	'help_search',	1),
('provides',	21,	'en',	'help_search',	1),
('provides',	22,	'en',	'help_search',	2),
('provides',	24,	'en',	'help_search',	1),
('provides',	25,	'en',	'help_search',	2),
('provides',	30,	'en',	'help_search',	1),
('provides',	33,	'en',	'help_search',	1),
('provides',	47,	'en',	'help_search',	1),
('provides',	58,	'en',	'help_search',	3),
('provides',	71,	'en',	'help_search',	0.934703),
('provides',	80,	'en',	'help_search',	1),
('providing',	11,	'en',	'help_search',	2),
('public',	19,	'en',	'help_search',	1),
('publish',	53,	'en',	'help_search',	2),
('publish',	55,	'en',	'help_search',	4.97258),
('published',	30,	'en',	'help_search',	3.61143),
('published',	53,	'en',	'help_search',	4),
('published',	55,	'en',	'help_search',	4),
('published',	73,	'en',	'help_search',	1),
('publishing',	73,	'en',	'help_search',	0.822065),
('pull',	73,	'en',	'help_search',	0.892724),
('purpose',	46,	'en',	'help_search',	1),
('purposes',	11,	'en',	'help_search',	0.961087),
('purposes',	12,	'en',	'help_search',	1),
('purposes',	57,	'en',	'help_search',	0.993146),
('put',	15,	'en',	'help_search',	1),
('put',	23,	'en',	'help_search',	1),
('put',	34,	'en',	'help_search',	9),
('put',	74,	'en',	'help_search',	1),
('putting',	27,	'en',	'help_search',	1),
('queries',	29,	'en',	'help_search',	1),
('queries',	57,	'en',	'help_search',	31.2416),
('query',	57,	'en',	'help_search',	1),
('quick',	20,	'en',	'help_search',	49),
('quick',	24,	'en',	'help_search',	5),
('quick',	64,	'en',	'help_search',	1),
('quick',	81,	'en',	'help_search',	1),
('quickly',	18,	'en',	'help_search',	1.89945),
('quickly',	20,	'en',	'help_search',	1),
('radio',	12,	'en',	'help_search',	2.55346),
('ran',	12,	'en',	'help_search',	1),
('range',	12,	'en',	'help_search',	1.70574),
('ranging',	13,	'en',	'help_search',	1),
('ranking',	28,	'en',	'help_search',	5),
('rather',	34,	'en',	'help_search',	1),
('ratio',	57,	'en',	'help_search',	1),
('reach',	58,	'en',	'help_search',	0.989021),
('read',	11,	'en',	'help_search',	0.71),
('read',	66,	'en',	'help_search',	1),
('readers',	23,	'en',	'help_search',	1),
('readers',	66,	'en',	'help_search',	1),
('ready',	76,	'en',	'help_search',	1),
('really',	57,	'en',	'help_search',	1),
('rearrange',	5,	'en',	'help_search',	1),
('rearrange',	85,	'en',	'help_search',	4),
('reasons',	36,	'en',	'help_search',	2),
('rebuild',	26,	'en',	'help_search',	4),
('recalculated',	18,	'en',	'help_search',	1),
('recalculation',	18,	'en',	'help_search',	1),
('receive',	40,	'en',	'help_search',	1),
('receive',	70,	'en',	'help_search',	1),
('recent',	37,	'en',	'help_search',	4),
('recent',	73,	'en',	'help_search',	1),
('recently',	21,	'en',	'help_search',	1),
('recently',	69,	'en',	'help_search',	1),
('recipe',	71,	'en',	'help_search',	3),
('recipes',	56,	'en',	'help_search',	1),
('recipes',	71,	'en',	'help_search',	1),
('recipient',	8,	'en',	'help_search',	1),
('recipients',	7,	'en',	'help_search',	4),
('recipients',	8,	'en',	'help_search',	1),
('recommended',	13,	'en',	'help_search',	1),
('recommended',	14,	'en',	'help_search',	1),
('recommended',	16,	'en',	'help_search',	1),
('records',	69,	'en',	'help_search',	1),
('red',	71,	'en',	'help_search',	1),
('redirected',	3,	'en',	'help_search',	1),
('reduce',	29,	'en',	'help_search',	1),
('reduce',	55,	'en',	'help_search',	1),
('reference',	12,	'en',	'help_search',	32.2871),
('reference',	16,	'en',	'help_search',	5),
('reference',	32,	'en',	'help_search',	11),
('reference',	68,	'en',	'help_search',	45),
('reference',	70,	'en',	'help_search',	7),
('reference',	71,	'en',	'help_search',	3.92027),
('reference',	87,	'en',	'help_search',	2),
('referenced',	16,	'en',	'help_search',	1),
('referenced',	68,	'en',	'help_search',	1),
('referenced',	87,	'en',	'help_search',	1),
('references',	12,	'en',	'help_search',	0.802752),
('refers',	18,	'en',	'help_search',	1),
('refine',	66,	'en',	'help_search',	1),
('refine',	67,	'en',	'help_search',	1),
('region',	17,	'en',	'help_search',	1),
('region',	26,	'en',	'help_search',	2),
('region',	32,	'en',	'help_search',	8),
('region',	47,	'en',	'help_search',	9),
('region',	48,	'en',	'help_search',	2),
('region',	49,	'en',	'help_search',	3),
('regional',	32,	'en',	'help_search',	4),
('regions',	47,	'en',	'help_search',	5),
('regions',	48,	'en',	'help_search',	1),
('regions',	49,	'en',	'help_search',	5),
('register',	10,	'en',	'help_search',	1),
('register',	42,	'en',	'help_search',	1),
('register',	44,	'en',	'help_search',	2),
('registered',	6,	'en',	'help_search',	1),
('registered',	8,	'en',	'help_search',	1),
('registered',	73,	'en',	'help_search',	1),
('regular',	71,	'en',	'help_search',	1.99731),
('regular',	73,	'en',	'help_search',	0.920273),
('regularlength',	12,	'en',	'help_search',	0.705825),
('reindex',	29,	'en',	'help_search',	3.78332),
('reindexed',	26,	'en',	'help_search',	1),
('related',	8,	'en',	'help_search',	1),
('related',	10,	'en',	'help_search',	0.961087),
('related',	11,	'en',	'help_search',	1.50606),
('related',	12,	'en',	'help_search',	2.87785),
('related',	14,	'en',	'help_search',	2),
('related',	15,	'en',	'help_search',	2),
('related',	16,	'en',	'help_search',	0.980874),
('related',	17,	'en',	'help_search',	1),
('related',	19,	'en',	'help_search',	1),
('related',	21,	'en',	'help_search',	1),
('related',	22,	'en',	'help_search',	1),
('related',	23,	'en',	'help_search',	1),
('related',	24,	'en',	'help_search',	1.86679),
('related',	26,	'en',	'help_search',	1),
('related',	27,	'en',	'help_search',	2.9534),
('related',	30,	'en',	'help_search',	0.797402),
('related',	42,	'en',	'help_search',	2),
('related',	44,	'en',	'help_search',	20.9849),
('related',	46,	'en',	'help_search',	4),
('related',	48,	'en',	'help_search',	1),
('related',	50,	'en',	'help_search',	0.854391),
('related',	54,	'en',	'help_search',	1),
('related',	56,	'en',	'help_search',	1),
('related',	64,	'en',	'help_search',	2),
('related',	70,	'en',	'help_search',	2),
('related',	71,	'en',	'help_search',	0.913226),
('related',	72,	'en',	'help_search',	1),
('related',	73,	'en',	'help_search',	2.4897),
('related',	76,	'en',	'help_search',	1),
('related',	78,	'en',	'help_search',	1),
('related',	80,	'en',	'help_search',	1),
('related',	83,	'en',	'help_search',	1),
('related',	84,	'en',	'help_search',	1),
('related',	87,	'en',	'help_search',	2),
('relationship',	12,	'en',	'help_search',	1.85133),
('relationships',	73,	'en',	'help_search',	3.5843),
('released',	19,	'en',	'help_search',	1),
('releases',	19,	'en',	'help_search',	1),
('releases',	37,	'en',	'help_search',	1),
('relevant',	46,	'en',	'help_search',	1),
('remote',	16,	'en',	'help_search',	1),
('remove',	5,	'en',	'help_search',	2),
('remove',	81,	'en',	'help_search',	1.96498),
('remove',	86,	'en',	'help_search',	9.81791),
('removing',	14,	'en',	'help_search',	1),
('render',	18,	'en',	'help_search',	0.906287),
('rendered',	48,	'en',	'help_search',	1),
('rendering',	18,	'en',	'help_search',	1),
('renders',	29,	'en',	'help_search',	1),
('reorder',	86,	'en',	'help_search',	0.879565),
('reordering',	17,	'en',	'help_search',	1),
('reordering',	77,	'en',	'help_search',	26),
('repeat',	32,	'en',	'help_search',	1),
('repeat',	40,	'en',	'help_search',	1),
('repeat',	50,	'en',	'help_search',	0.779231),
('repeat',	72,	'en',	'help_search',	1),
('repeat',	81,	'en',	'help_search',	1),
('replacement',	20,	'en',	'help_search',	1),
('replacement',	23,	'en',	'help_search',	1),
('replacement',	64,	'en',	'help_search',	1),
('replacement',	81,	'en',	'help_search',	1),
('replacements',	24,	'en',	'help_search',	1),
('report',	37,	'en',	'help_search',	10),
('reported',	19,	'en',	'help_search',	1),
('reports',	15,	'en',	'help_search',	1),
('reports',	24,	'en',	'help_search',	3.63897),
('reports',	37,	'en',	'help_search',	39),
('reproduced',	11,	'en',	'help_search',	0.863659),
('request',	25,	'en',	'help_search',	1),
('request',	44,	'en',	'help_search',	1),
('requested',	18,	'en',	'help_search',	1.9496),
('requests',	25,	'en',	'help_search',	1),
('require',	58,	'en',	'help_search',	0.863659),
('require',	72,	'en',	'help_search',	1),
('require',	73,	'en',	'help_search',	1),
('required',	23,	'en',	'help_search',	1),
('required',	30,	'en',	'help_search',	0.923838),
('required',	65,	'en',	'help_search',	4),
('required',	68,	'en',	'help_search',	4),
('required',	79,	'en',	'help_search',	1),
('requires',	11,	'en',	'help_search',	0.712106),
('requires',	20,	'en',	'help_search',	1),
('requires',	35,	'en',	'help_search',	1),
('requires',	36,	'en',	'help_search',	1),
('requires',	44,	'en',	'help_search',	1),
('reset',	44,	'en',	'help_search',	2),
('resides',	11,	'en',	'help_search',	1),
('resized',	57,	'en',	'help_search',	1),
('resolution',	57,	'en',	'help_search',	47.9496),
('resource',	80,	'en',	'help_search',	1),
('resources',	10,	'en',	'help_search',	17.8293),
('resources',	11,	'en',	'help_search',	12.9173),
('resources',	12,	'en',	'help_search',	11.0471),
('resources',	13,	'en',	'help_search',	18.4844),
('resources',	14,	'en',	'help_search',	19),
('resources',	15,	'en',	'help_search',	19),
('resources',	16,	'en',	'help_search',	18.1145),
('resources',	17,	'en',	'help_search',	19),
('resources',	18,	'en',	'help_search',	16.1181),
('resources',	19,	'en',	'help_search',	19),
('resources',	25,	'en',	'help_search',	20),
('resources',	27,	'en',	'help_search',	17.8293),
('resources',	30,	'en',	'help_search',	14.9024),
('resources',	31,	'en',	'help_search',	19),
('resources',	32,	'en',	'help_search',	19),
('resources',	37,	'en',	'help_search',	19),
('resources',	46,	'en',	'help_search',	19),
('resources',	48,	'en',	'help_search',	19),
('resources',	53,	'en',	'help_search',	19),
('resources',	54,	'en',	'help_search',	19),
('resources',	55,	'en',	'help_search',	18.2607),
('resources',	57,	'en',	'help_search',	18.0423),
('resources',	70,	'en',	'help_search',	19),
('resources',	71,	'en',	'help_search',	16.8985),
('resources',	73,	'en',	'help_search',	14.8537),
('resources',	78,	'en',	'help_search',	19),
('resources',	80,	'en',	'help_search',	19),
('resources',	85,	'en',	'help_search',	18.4844),
('resources',	86,	'en',	'help_search',	15.6731),
('respective',	58,	'en',	'help_search',	0.845322),
('respectively',	22,	'en',	'help_search',	1),
('respond',	33,	'en',	'help_search',	1),
('respond',	57,	'en',	'help_search',	2),
('response',	18,	'en',	'help_search',	1),
('response',	33,	'en',	'help_search',	5),
('responses',	33,	'en',	'help_search',	48),
('responsive',	12,	'en',	'help_search',	0.595774),
('responsive',	16,	'en',	'help_search',	3.97954),
('responsive',	72,	'en',	'help_search',	1),
('rest',	25,	'en',	'help_search',	11),
('rest',	58,	'en',	'help_search',	0.961087),
('restful',	25,	'en',	'help_search',	23),
('restrict',	50,	'en',	'help_search',	1.86995),
('restrictions',	58,	'en',	'help_search',	1),
('restrictive',	83,	'en',	'help_search',	1),
('restricts',	50,	'en',	'help_search',	1.80818),
('result',	33,	'en',	'help_search',	1),
('result',	73,	'en',	'help_search',	0.953396),
('results',	28,	'en',	'help_search',	1),
('results',	29,	'en',	'help_search',	1),
('results',	30,	'en',	'help_search',	1),
('results',	31,	'en',	'help_search',	1),
('results',	50,	'en',	'help_search',	0.827757),
('results',	73,	'en',	'help_search',	3.84435),
('retrieved',	18,	'en',	'help_search',	1),
('return',	34,	'en',	'help_search',	1),
('return',	50,	'en',	'help_search',	0.781775),
('return',	58,	'en',	'help_search',	1.82026),
('return',	66,	'en',	'help_search',	1),
('return',	67,	'en',	'help_search',	1),
('return',	85,	'en',	'help_search',	1),
('returned',	28,	'en',	'help_search',	1),
('returned',	29,	'en',	'help_search',	0.953396),
('returned',	35,	'en',	'help_search',	1),
('returned',	36,	'en',	'help_search',	1),
('returned',	38,	'en',	'help_search',	1),
('returned',	41,	'en',	'help_search',	1),
('returned',	52,	'en',	'help_search',	1),
('returned',	64,	'en',	'help_search',	0.957226),
('returned',	65,	'en',	'help_search',	1),
('returned',	68,	'en',	'help_search',	1),
('returned',	75,	'en',	'help_search',	1),
('returned',	79,	'en',	'help_search',	1),
('returned',	86,	'en',	'help_search',	1),
('reuse',	87,	'en',	'help_search',	1),
('reusing',	16,	'en',	'help_search',	1),
('reverse',	25,	'en',	'help_search',	1),
('reverse',	55,	'en',	'help_search',	1),
('review',	3,	'en',	'help_search',	1),
('review',	43,	'en',	'help_search',	1),
('right',	13,	'en',	'help_search',	1),
('right',	24,	'en',	'help_search',	1),
('right',	55,	'en',	'help_search',	1),
('right',	64,	'en',	'help_search',	2),
('right',	71,	'en',	'help_search',	1),
('right',	81,	'en',	'help_search',	0.98493),
('righttoleft',	20,	'en',	'help_search',	1),
('righttoleft',	24,	'en',	'help_search',	1),
('righttoleft',	55,	'en',	'help_search',	1),
('righttoleft',	64,	'en',	'help_search',	2),
('righttoleft',	81,	'en',	'help_search',	0.972861),
('risk',	50,	'en',	'help_search',	3.44219),
('role',	41,	'en',	'help_search',	38),
('role',	42,	'en',	'help_search',	21),
('role',	43,	'en',	'help_search',	31),
('role',	64,	'en',	'help_search',	1),
('role',	73,	'en',	'help_search',	0.997306),
('role',	81,	'en',	'help_search',	1),
('roles',	6,	'en',	'help_search',	1),
('roles',	30,	'en',	'help_search',	1.68779),
('roles',	40,	'en',	'help_search',	4),
('roles',	41,	'en',	'help_search',	8),
('roles',	42,	'en',	'help_search',	7),
('roles',	43,	'en',	'help_search',	4),
('roles',	50,	'en',	'help_search',	3.61143),
('row',	23,	'en',	'help_search',	4),
('row',	32,	'en',	'help_search',	1),
('row',	43,	'en',	'help_search',	1),
('row',	52,	'en',	'help_search',	1),
('row',	55,	'en',	'help_search',	1),
('row',	66,	'en',	'help_search',	1),
('row',	67,	'en',	'help_search',	1),
('row',	83,	'en',	'help_search',	1),
('rows',	23,	'en',	'help_search',	1),
('rss',	73,	'en',	'help_search',	1),
('run',	10,	'en',	'help_search',	1),
('run',	13,	'en',	'help_search',	22.9397),
('run',	26,	'en',	'help_search',	1),
('run',	29,	'en',	'help_search',	4.89945),
('run',	31,	'en',	'help_search',	1),
('run',	37,	'en',	'help_search',	1),
('run',	50,	'en',	'help_search',	0.813674),
('running',	13,	'en',	'help_search',	51),
('running',	26,	'en',	'help_search',	1),
('running',	29,	'en',	'help_search',	1.91323),
('running',	37,	'en',	'help_search',	26),
('runs',	13,	'en',	'help_search',	0.993146),
('runs',	15,	'en',	'help_search',	1),
('runs',	29,	'en',	'help_search',	2),
('runtime',	33,	'en',	'help_search',	1),
('safe',	50,	'en',	'help_search',	0.869951),
('same',	11,	'en',	'help_search',	2.67583),
('same',	12,	'en',	'help_search',	1.89712),
('same',	18,	'en',	'help_search',	1),
('same',	20,	'en',	'help_search',	1),
('same',	35,	'en',	'help_search',	1),
('same',	86,	'en',	'help_search',	1),
('satisfied',	86,	'en',	'help_search',	0.830633),
('save',	1,	'en',	'help_search',	1),
('save',	2,	'en',	'help_search',	1),
('save',	6,	'en',	'help_search',	8),
('save',	7,	'en',	'help_search',	4),
('save',	9,	'en',	'help_search',	4),
('save',	13,	'en',	'help_search',	3.9235),
('save',	28,	'en',	'help_search',	4),
('save',	29,	'en',	'help_search',	3.85992),
('save',	31,	'en',	'help_search',	1),
('save',	32,	'en',	'help_search',	12),
('save',	33,	'en',	'help_search',	7.45773),
('save',	34,	'en',	'help_search',	8),
('save',	38,	'en',	'help_search',	4),
('save',	41,	'en',	'help_search',	4),
('save',	43,	'en',	'help_search',	4),
('save',	44,	'en',	'help_search',	3.87562),
('save',	45,	'en',	'help_search',	4),
('save',	47,	'en',	'help_search',	8),
('save',	49,	'en',	'help_search',	4),
('save',	50,	'en',	'help_search',	3.13735),
('save',	51,	'en',	'help_search',	4),
('save',	52,	'en',	'help_search',	4),
('save',	53,	'en',	'help_search',	4),
('save',	54,	'en',	'help_search',	8),
('save',	55,	'en',	'help_search',	4),
('save',	58,	'en',	'help_search',	0.833529),
('save',	64,	'en',	'help_search',	0.976851),
('save',	65,	'en',	'help_search',	13),
('save',	66,	'en',	'help_search',	4),
('save',	67,	'en',	'help_search',	4),
('save',	68,	'en',	'help_search',	13),
('save',	70,	'en',	'help_search',	8),
('save',	72,	'en',	'help_search',	5),
('save',	74,	'en',	'help_search',	4),
('save',	75,	'en',	'help_search',	8),
('save',	76,	'en',	'help_search',	4),
('save',	77,	'en',	'help_search',	5),
('save',	78,	'en',	'help_search',	4),
('save',	79,	'en',	'help_search',	4),
('save',	83,	'en',	'help_search',	3.95608),
('save',	84,	'en',	'help_search',	4),
('save',	85,	'en',	'help_search',	4),
('save',	86,	'en',	'help_search',	7.31103),
('save',	87,	'en',	'help_search',	8),
('saved',	32,	'en',	'help_search',	3),
('saved',	33,	'en',	'help_search',	1.84154),
('saved',	44,	'en',	'help_search',	0.949597),
('saves',	18,	'en',	'help_search',	1),
('saving',	18,	'en',	'help_search',	1),
('say',	54,	'en',	'help_search',	1),
('saying',	35,	'en',	'help_search',	1),
('saying',	36,	'en',	'help_search',	1),
('says',	13,	'en',	'help_search',	1),
('scaffolding',	10,	'en',	'help_search',	1),
('scaling',	16,	'en',	'help_search',	1),
('scan',	37,	'en',	'help_search',	1),
('scan',	68,	'en',	'help_search',	1),
('scenes',	12,	'en',	'help_search',	0.757065),
('schedule',	13,	'en',	'help_search',	4.99315),
('screen',	23,	'en',	'help_search',	1),
('screen',	33,	'en',	'help_search',	4),
('screen',	45,	'en',	'help_search',	1),
('screen',	58,	'en',	'help_search',	1),
('screen',	65,	'en',	'help_search',	2),
('screen',	66,	'en',	'help_search',	1),
('screen',	68,	'en',	'help_search',	2),
('screens',	53,	'en',	'help_search',	1),
('screens',	57,	'en',	'help_search',	1),
('screens',	74,	'en',	'help_search',	1),
('scripts',	50,	'en',	'help_search',	0.892724),
('scroll',	28,	'en',	'help_search',	1),
('scroll',	45,	'en',	'help_search',	1),
('search',	26,	'en',	'help_search',	55),
('search',	27,	'en',	'help_search',	28.8536),
('search',	28,	'en',	'help_search',	62),
('search',	29,	'en',	'help_search',	69.082),
('search',	30,	'en',	'help_search',	197.652),
('search',	42,	'en',	'help_search',	1),
('search',	66,	'en',	'help_search',	1),
('search',	79,	'en',	'help_search',	4),
('searchable',	27,	'en',	'help_search',	1),
('searches',	29,	'en',	'help_search',	1),
('searches',	30,	'en',	'help_search',	0.882818),
('searching',	26,	'en',	'help_search',	1),
('searching',	29,	'en',	'help_search',	2.89272),
('searching',	30,	'en',	'help_search',	4.80231),
('second',	30,	'en',	'help_search',	1),
('second',	85,	'en',	'help_search',	1),
('section',	6,	'en',	'help_search',	3),
('section',	12,	'en',	'help_search',	3.02548),
('section',	26,	'en',	'help_search',	1),
('section',	28,	'en',	'help_search',	1),
('section',	29,	'en',	'help_search',	0.869951),
('section',	33,	'en',	'help_search',	1),
('section',	38,	'en',	'help_search',	2),
('section',	39,	'en',	'help_search',	1),
('section',	54,	'en',	'help_search',	1),
('section',	58,	'en',	'help_search',	0.854391),
('section',	66,	'en',	'help_search',	1),
('section',	67,	'en',	'help_search',	1),
('section',	68,	'en',	'help_search',	2),
('section',	83,	'en',	'help_search',	1),
('section',	85,	'en',	'help_search',	1),
('section',	86,	'en',	'help_search',	19.9816),
('section',	87,	'en',	'help_search',	1),
('sections',	24,	'en',	'help_search',	20),
('sections',	85,	'en',	'help_search',	2),
('sections',	86,	'en',	'help_search',	6.82925),
('secure',	19,	'en',	'help_search',	28),
('security',	15,	'en',	'help_search',	11),
('security',	19,	'en',	'help_search',	102),
('security',	24,	'en',	'help_search',	0.899454),
('security',	37,	'en',	'help_search',	13),
('security',	43,	'en',	'help_search',	4),
('security',	50,	'en',	'help_search',	5.32828),
('see',	1,	'en',	'help_search',	1),
('see',	2,	'en',	'help_search',	1),
('see',	3,	'en',	'help_search',	2),
('see',	4,	'en',	'help_search',	2),
('see',	7,	'en',	'help_search',	1),
('see',	8,	'en',	'help_search',	2),
('see',	10,	'en',	'help_search',	1.96109),
('see',	11,	'en',	'help_search',	0.691597),
('see',	12,	'en',	'help_search',	3.69525),
('see',	14,	'en',	'help_search',	1),
('see',	15,	'en',	'help_search',	1),
('see',	16,	'en',	'help_search',	1.98087),
('see',	17,	'en',	'help_search',	1),
('see',	19,	'en',	'help_search',	1),
('see',	21,	'en',	'help_search',	1),
('see',	22,	'en',	'help_search',	3),
('see',	24,	'en',	'help_search',	2.86679),
('see',	25,	'en',	'help_search',	1),
('see',	26,	'en',	'help_search',	1),
('see',	27,	'en',	'help_search',	0.957226),
('see',	28,	'en',	'help_search',	1),
('see',	29,	'en',	'help_search',	1),
('see',	30,	'en',	'help_search',	3.64573),
('see',	31,	'en',	'help_search',	1),
('see',	32,	'en',	'help_search',	3),
('see',	33,	'en',	'help_search',	1.85668),
('see',	34,	'en',	'help_search',	2),
('see',	35,	'en',	'help_search',	1),
('see',	36,	'en',	'help_search',	2),
('see',	37,	'en',	'help_search',	4),
('see',	44,	'en',	'help_search',	0.961087),
('see',	46,	'en',	'help_search',	39),
('see',	47,	'en',	'help_search',	1),
('see',	48,	'en',	'help_search',	1),
('see',	49,	'en',	'help_search',	2),
('see',	50,	'en',	'help_search',	0.857458),
('see',	53,	'en',	'help_search',	2),
('see',	54,	'en',	'help_search',	1),
('see',	55,	'en',	'help_search',	1),
('see',	56,	'en',	'help_search',	2),
('see',	58,	'en',	'help_search',	5),
('see',	65,	'en',	'help_search',	2),
('see',	66,	'en',	'help_search',	2),
('see',	67,	'en',	'help_search',	2),
('see',	68,	'en',	'help_search',	1),
('see',	70,	'en',	'help_search',	3),
('see',	71,	'en',	'help_search',	1.91323),
('see',	72,	'en',	'help_search',	2),
('see',	73,	'en',	'help_search',	2.58117),
('see',	76,	'en',	'help_search',	1),
('see',	78,	'en',	'help_search',	2),
('see',	79,	'en',	'help_search',	1),
('see',	80,	'en',	'help_search',	2),
('see',	83,	'en',	'help_search',	2),
('see',	85,	'en',	'help_search',	1),
('see',	86,	'en',	'help_search',	4.81715),
('see',	87,	'en',	'help_search',	3),
('seen',	21,	'en',	'help_search',	1),
('sees',	12,	'en',	'help_search',	0.779231),
('select',	2,	'en',	'help_search',	2),
('select',	4,	'en',	'help_search',	1),
('select',	12,	'en',	'help_search',	2.56025),
('select',	13,	'en',	'help_search',	0.997306),
('select',	28,	'en',	'help_search',	2),
('select',	29,	'en',	'help_search',	1),
('select',	32,	'en',	'help_search',	1),
('select',	33,	'en',	'help_search',	1.84417),
('select',	38,	'en',	'help_search',	1),
('select',	44,	'en',	'help_search',	1.99731),
('select',	45,	'en',	'help_search',	1),
('select',	55,	'en',	'help_search',	2.99315),
('select',	58,	'en',	'help_search',	0.972861),
('select',	65,	'en',	'help_search',	1),
('select',	66,	'en',	'help_search',	2),
('select',	67,	'en',	'help_search',	1),
('select',	68,	'en',	'help_search',	3),
('select',	71,	'en',	'help_search',	1),
('select',	73,	'en',	'help_search',	0.851346),
('select',	74,	'en',	'help_search',	1),
('select',	75,	'en',	'help_search',	2),
('select',	81,	'en',	'help_search',	6),
('select',	84,	'en',	'help_search',	2),
('select',	87,	'en',	'help_search',	4),
('selected',	38,	'en',	'help_search',	1),
('selected',	55,	'en',	'help_search',	3.97258),
('selected',	58,	'en',	'help_search',	0.953396),
('selected',	83,	'en',	'help_search',	4),
('selecting',	66,	'en',	'help_search',	1),
('selecting',	67,	'en',	'help_search',	1),
('selects',	58,	'en',	'help_search',	1),
('send',	18,	'en',	'help_search',	0.98493),
('sending',	25,	'en',	'help_search',	1),
('sends',	33,	'en',	'help_search',	1),
('sent',	18,	'en',	'help_search',	1.86581),
('sent',	44,	'en',	'help_search',	1),
('seofriendly',	78,	'en',	'help_search',	1),
('separate',	57,	'en',	'help_search',	1),
('separately',	10,	'en',	'help_search',	1),
('separately',	14,	'en',	'help_search',	1),
('separates',	57,	'en',	'help_search',	1),
('sequence',	50,	'en',	'help_search',	1),
('serialization',	11,	'en',	'help_search',	0.98493),
('serialization',	25,	'en',	'help_search',	24),
('serialized',	25,	'en',	'help_search',	1),
('serve',	16,	'en',	'help_search',	0.98493),
('serve',	46,	'en',	'help_search',	1),
('server',	13,	'en',	'help_search',	2),
('server',	33,	'en',	'help_search',	1),
('servers',	13,	'en',	'help_search',	1),
('service',	25,	'en',	'help_search',	20),
('services',	25,	'en',	'help_search',	72),
('serving',	16,	'en',	'help_search',	1),
('session',	12,	'en',	'help_search',	4),
('set',	9,	'en',	'help_search',	1),
('set',	10,	'en',	'help_search',	1),
('set',	11,	'en',	'help_search',	2.3646),
('set',	13,	'en',	'help_search',	2),
('set',	14,	'en',	'help_search',	2),
('set',	16,	'en',	'help_search',	1),
('set',	24,	'en',	'help_search',	0.98493),
('set',	26,	'en',	'help_search',	1),
('set',	28,	'en',	'help_search',	4),
('set',	33,	'en',	'help_search',	1),
('set',	38,	'en',	'help_search',	4),
('set',	50,	'en',	'help_search',	0.866793),
('set',	54,	'en',	'help_search',	1),
('set',	56,	'en',	'help_search',	1),
('set',	65,	'en',	'help_search',	2),
('set',	68,	'en',	'help_search',	2),
('set',	71,	'en',	'help_search',	5.98087),
('set',	80,	'en',	'help_search',	1),
('set',	81,	'en',	'help_search',	20),
('set',	86,	'en',	'help_search',	1.94209),
('sets',	81,	'en',	'help_search',	5),
('setting',	8,	'en',	'help_search',	1),
('setting',	9,	'en',	'help_search',	26),
('setting',	12,	'en',	'help_search',	0.733888),
('setting',	18,	'en',	'help_search',	0.863659),
('setting',	38,	'en',	'help_search',	26),
('setting',	54,	'en',	'help_search',	11),
('setting',	70,	'en',	'help_search',	11),
('setting',	73,	'en',	'help_search',	1),
('setting',	85,	'en',	'help_search',	1),
('settings',	6,	'en',	'help_search',	8),
('settings',	7,	'en',	'help_search',	1),
('settings',	11,	'en',	'help_search',	6.6956),
('settings',	12,	'en',	'help_search',	16.9432),
('settings',	13,	'en',	'help_search',	3.95608),
('settings',	18,	'en',	'help_search',	0.892724),
('settings',	20,	'en',	'help_search',	54),
('settings',	22,	'en',	'help_search',	1),
('settings',	24,	'en',	'help_search',	2.92743),
('settings',	29,	'en',	'help_search',	7.93972),
('settings',	32,	'en',	'help_search',	37),
('settings',	33,	'en',	'help_search',	5.84528),
('settings',	40,	'en',	'help_search',	1),
('settings',	42,	'en',	'help_search',	1),
('settings',	44,	'en',	'help_search',	26.9276),
('settings',	47,	'en',	'help_search',	4),
('settings',	48,	'en',	'help_search',	1),
('settings',	50,	'en',	'help_search',	3.99239),
('settings',	54,	'en',	'help_search',	1),
('settings',	56,	'en',	'help_search',	1),
('settings',	58,	'en',	'help_search',	3.42983),
('settings',	64,	'en',	'help_search',	0.972861),
('settings',	65,	'en',	'help_search',	9),
('settings',	66,	'en',	'help_search',	3),
('settings',	67,	'en',	'help_search',	3),
('settings',	68,	'en',	'help_search',	9),
('settings',	70,	'en',	'help_search',	1),
('settings',	73,	'en',	'help_search',	10),
('settings',	74,	'en',	'help_search',	30),
('settings',	75,	'en',	'help_search',	1),
('settings',	82,	'en',	'help_search',	2),
('settings',	83,	'en',	'help_search',	2),
('settings',	84,	'en',	'help_search',	5),
('settings',	85,	'en',	'help_search',	14),
('settingsphp',	11,	'en',	'help_search',	5.90181),
('several',	10,	'en',	'help_search',	1),
('several',	11,	'en',	'help_search',	0.96498),
('several',	12,	'en',	'help_search',	2.16248),
('several',	15,	'en',	'help_search',	1),
('several',	29,	'en',	'help_search',	1.89945),
('several',	55,	'en',	'help_search',	1),
('severity',	37,	'en',	'help_search',	4),
('share',	11,	'en',	'help_search',	0.839384),
('shared',	81,	'en',	'help_search',	2),
('shield',	19,	'en',	'help_search',	1),
('shift',	57,	'en',	'help_search',	1),
('short',	32,	'en',	'help_search',	1),
('short',	44,	'en',	'help_search',	1),
('short',	45,	'en',	'help_search',	1),
('shortcut',	81,	'en',	'help_search',	54.9341),
('shortcuts',	24,	'en',	'help_search',	1),
('shortcuts',	81,	'en',	'help_search',	47.937),
('should',	7,	'en',	'help_search',	1),
('should',	10,	'en',	'help_search',	1),
('should',	13,	'en',	'help_search',	2),
('should',	20,	'en',	'help_search',	2),
('should',	26,	'en',	'help_search',	1),
('should',	29,	'en',	'help_search',	0.957226),
('should',	32,	'en',	'help_search',	3),
('should',	33,	'en',	'help_search',	1.86054),
('should',	35,	'en',	'help_search',	1),
('should',	36,	'en',	'help_search',	2),
('should',	37,	'en',	'help_search',	1),
('should',	38,	'en',	'help_search',	2),
('should',	41,	'en',	'help_search',	2),
('should',	43,	'en',	'help_search',	2),
('should',	44,	'en',	'help_search',	0.96498),
('should',	45,	'en',	'help_search',	1),
('should',	47,	'en',	'help_search',	1),
('should',	50,	'en',	'help_search',	1.69324),
('should',	57,	'en',	'help_search',	3),
('should',	64,	'en',	'help_search',	0.961087),
('should',	65,	'en',	'help_search',	2),
('should',	68,	'en',	'help_search',	2),
('should',	75,	'en',	'help_search',	1),
('show',	21,	'en',	'help_search',	1),
('show',	23,	'en',	'help_search',	4),
('show',	53,	'en',	'help_search',	1),
('show',	58,	'en',	'help_search',	1),
('show',	75,	'en',	'help_search',	5),
('show',	84,	'en',	'help_search',	4),
('show',	86,	'en',	'help_search',	4.49054),
('showing',	12,	'en',	'help_search',	0.659351),
('showing',	73,	'en',	'help_search',	1),
('shown',	8,	'en',	'help_search',	1),
('shown',	27,	'en',	'help_search',	0.98493),
('shown',	29,	'en',	'help_search',	0.876337),
('shown',	45,	'en',	'help_search',	1),
('shown',	48,	'en',	'help_search',	2),
('shown',	50,	'en',	'help_search',	1),
('shown',	51,	'en',	'help_search',	1),
('shown',	52,	'en',	'help_search',	1),
('shown',	53,	'en',	'help_search',	2),
('shown',	55,	'en',	'help_search',	1),
('shown',	58,	'en',	'help_search',	1.92384),
('shown',	68,	'en',	'help_search',	1),
('shown',	70,	'en',	'help_search',	1),
('shown',	74,	'en',	'help_search',	1),
('shown',	75,	'en',	'help_search',	1),
('shown',	82,	'en',	'help_search',	1),
('shown',	83,	'en',	'help_search',	1),
('shown',	85,	'en',	'help_search',	1),
('shows',	12,	'en',	'help_search',	0.771698),
('shows',	58,	'en',	'help_search',	1),
('shows',	68,	'en',	'help_search',	1),
('shows',	85,	'en',	'help_search',	1),
('side',	24,	'en',	'help_search',	2),
('similar',	11,	'en',	'help_search',	1),
('similar',	55,	'en',	'help_search',	0.972861),
('similar',	78,	'en',	'help_search',	1),
('similar',	82,	'en',	'help_search',	2),
('simple',	11,	'en',	'help_search',	4),
('simple',	29,	'en',	'help_search',	3.98922),
('simple',	34,	'en',	'help_search',	1),
('since',	69,	'en',	'help_search',	1),
('single',	2,	'en',	'help_search',	31),
('single',	4,	'en',	'help_search',	32),
('single',	73,	'en',	'help_search',	1),
('single',	86,	'en',	'help_search',	1),
('singleitem',	11,	'en',	'help_search',	0.805455),
('singleline',	12,	'en',	'help_search',	1.29741),
('singlevalued',	12,	'en',	'help_search',	1.60675),
('site',	1,	'en',	'help_search',	27),
('site',	3,	'en',	'help_search',	28),
('site',	6,	'en',	'help_search',	1),
('site',	8,	'en',	'help_search',	5),
('site',	10,	'en',	'help_search',	61.1676),
('site',	11,	'en',	'help_search',	32.2666),
('site',	12,	'en',	'help_search',	30.9082),
('site',	13,	'en',	'help_search',	9),
('site',	14,	'en',	'help_search',	40),
('site',	15,	'en',	'help_search',	33),
('site',	16,	'en',	'help_search',	1),
('site',	17,	'en',	'help_search',	2),
('site',	18,	'en',	'help_search',	66.989),
('site',	19,	'en',	'help_search',	29),
('site',	20,	'en',	'help_search',	1),
('site',	21,	'en',	'help_search',	1),
('site',	22,	'en',	'help_search',	21),
('site',	24,	'en',	'help_search',	4.71269),
('site',	25,	'en',	'help_search',	2),
('site',	26,	'en',	'help_search',	2),
('site',	28,	'en',	'help_search',	2),
('site',	29,	'en',	'help_search',	6.76836),
('site',	30,	'en',	'help_search',	69.9142),
('site',	31,	'en',	'help_search',	31),
('site',	32,	'en',	'help_search',	36),
('site',	33,	'en',	'help_search',	12.7251),
('site',	34,	'en',	'help_search',	21),
('site',	36,	'en',	'help_search',	1),
('site',	37,	'en',	'help_search',	32),
('site',	38,	'en',	'help_search',	6),
('site',	39,	'en',	'help_search',	2),
('site',	42,	'en',	'help_search',	31),
('site',	44,	'en',	'help_search',	5.99731),
('site',	46,	'en',	'help_search',	21),
('site',	47,	'en',	'help_search',	1),
('site',	48,	'en',	'help_search',	3),
('site',	50,	'en',	'help_search',	6.99315),
('site',	51,	'en',	'help_search',	2),
('site',	53,	'en',	'help_search',	2),
('site',	56,	'en',	'help_search',	1),
('site',	57,	'en',	'help_search',	1),
('site',	58,	'en',	'help_search',	3),
('site',	64,	'en',	'help_search',	2),
('site',	69,	'en',	'help_search',	1),
('site',	71,	'en',	'help_search',	0.993146),
('site',	73,	'en',	'help_search',	1),
('site',	75,	'en',	'help_search',	1),
('site',	76,	'en',	'help_search',	1),
('site',	79,	'en',	'help_search',	2),
('site',	80,	'en',	'help_search',	2),
('site',	81,	'en',	'help_search',	1),
('site',	84,	'en',	'help_search',	1),
('site',	86,	'en',	'help_search',	1.92743),
('site',	87,	'en',	'help_search',	1),
('sites',	11,	'en',	'help_search',	8.33326),
('sites',	14,	'en',	'help_search',	1),
('sites',	25,	'en',	'help_search',	1),
('sites',	30,	'en',	'help_search',	1),
('sitewide',	5,	'en',	'help_search',	2),
('sitewide',	7,	'en',	'help_search',	1),
('sitewide',	8,	'en',	'help_search',	2),
('sitewide',	9,	'en',	'help_search',	2),
('situations',	33,	'en',	'help_search',	1),
('size',	16,	'en',	'help_search',	1),
('size',	57,	'en',	'help_search',	2),
('sized',	16,	'en',	'help_search',	1.98087),
('sizes',	16,	'en',	'help_search',	1),
('sizing',	57,	'en',	'help_search',	0.98493),
('slogan',	32,	'en',	'help_search',	2),
('smaller',	12,	'en',	'help_search',	1),
('smaller',	18,	'en',	'help_search',	1),
('smaller',	29,	'en',	'help_search',	2),
('smaller',	35,	'en',	'help_search',	1),
('smaller',	36,	'en',	'help_search',	1),
('social',	16,	'en',	'help_search',	1),
('software',	10,	'en',	'help_search',	2),
('software',	11,	'en',	'help_search',	0.968904),
('software',	14,	'en',	'help_search',	1),
('software',	18,	'en',	'help_search',	1),
('software',	19,	'en',	'help_search',	4),
('software',	22,	'en',	'help_search',	2),
('software',	24,	'en',	'help_search',	1),
('software',	25,	'en',	'help_search',	1),
('software',	29,	'en',	'help_search',	1),
('software',	33,	'en',	'help_search',	2),
('software',	37,	'en',	'help_search',	3),
('software',	58,	'en',	'help_search',	1),
('software',	80,	'en',	'help_search',	1),
('solr',	30,	'en',	'help_search',	12),
('some',	12,	'en',	'help_search',	1.6522),
('some',	15,	'en',	'help_search',	1),
('some',	17,	'en',	'help_search',	1),
('some',	23,	'en',	'help_search',	2),
('some',	24,	'en',	'help_search',	4.73496),
('some',	29,	'en',	'help_search',	0.980874),
('some',	30,	'en',	'help_search',	1),
('some',	31,	'en',	'help_search',	1),
('some',	33,	'en',	'help_search',	2),
('some',	44,	'en',	'help_search',	1),
('some',	47,	'en',	'help_search',	1),
('some',	50,	'en',	'help_search',	2.89945),
('some',	53,	'en',	'help_search',	1),
('some',	54,	'en',	'help_search',	1),
('some',	55,	'en',	'help_search',	1),
('some',	57,	'en',	'help_search',	1),
('some',	58,	'en',	'help_search',	1),
('some',	72,	'en',	'help_search',	1),
('some',	73,	'en',	'help_search',	1.8861),
('some',	80,	'en',	'help_search',	1),
('someone',	55,	'en',	'help_search',	1),
('sometimes',	19,	'en',	'help_search',	1),
('sometimes',	23,	'en',	'help_search',	1),
('soon',	37,	'en',	'help_search',	1),
('sort',	55,	'en',	'help_search',	1),
('sort',	68,	'en',	'help_search',	1),
('sort',	73,	'en',	'help_search',	4),
('sorting',	73,	'en',	'help_search',	1),
('sorting',	84,	'en',	'help_search',	1),
('sorts',	73,	'en',	'help_search',	0.869951),
('source',	11,	'en',	'help_search',	0.794753),
('source',	50,	'en',	'help_search',	1),
('source',	87,	'en',	'help_search',	8),
('sources',	46,	'en',	'help_search',	1),
('sources',	87,	'en',	'help_search',	1),
('spaces',	50,	'en',	'help_search',	1),
('special',	42,	'en',	'help_search',	1),
('special',	86,	'en',	'help_search',	1),
('specific',	2,	'en',	'help_search',	1),
('specific',	8,	'en',	'help_search',	1),
('specific',	10,	'en',	'help_search',	0.945829),
('specific',	11,	'en',	'help_search',	0.683725),
('specific',	16,	'en',	'help_search',	0.96498),
('specific',	17,	'en',	'help_search',	1),
('specific',	19,	'en',	'help_search',	1),
('specific',	21,	'en',	'help_search',	1),
('specific',	22,	'en',	'help_search',	1),
('specific',	25,	'en',	'help_search',	1),
('specific',	30,	'en',	'help_search',	0.78951),
('specific',	48,	'en',	'help_search',	1),
('specific',	53,	'en',	'help_search',	1),
('specific',	56,	'en',	'help_search',	1),
('specific',	71,	'en',	'help_search',	0.899454),
('specific',	73,	'en',	'help_search',	2.60924),
('specific',	80,	'en',	'help_search',	2),
('specifically',	48,	'en',	'help_search',	1),
('specification',	25,	'en',	'help_search',	11),
('specify',	73,	'en',	'help_search',	2),
('specifying',	12,	'en',	'help_search',	0.942091),
('specifying',	30,	'en',	'help_search',	1),
('speed',	18,	'en',	'help_search',	1),
('sphinx',	30,	'en',	'help_search',	11),
('square',	44,	'en',	'help_search',	1),
('stable',	10,	'en',	'help_search',	1),
('stable',	14,	'en',	'help_search',	1),
('stable',	19,	'en',	'help_search',	1),
('staging',	11,	'en',	'help_search',	1),
('standard',	11,	'en',	'help_search',	0.980874),
('standards',	23,	'en',	'help_search',	1),
('standards',	27,	'en',	'help_search',	10.2817),
('standards',	57,	'en',	'help_search',	10.2817),
('star',	81,	'en',	'help_search',	1),
('start',	12,	'en',	'help_search',	0.848323),
('start',	75,	'en',	'help_search',	1),
('start',	86,	'en',	'help_search',	1),
('started',	64,	'en',	'help_search',	0.953396),
('starting',	33,	'en',	'help_search',	1),
('starts',	30,	'en',	'help_search',	1),
('starts',	78,	'en',	'help_search',	1),
('state',	12,	'en',	'help_search',	6),
('state',	23,	'en',	'help_search',	1),
('status',	26,	'en',	'help_search',	1),
('status',	28,	'en',	'help_search',	4),
('status',	29,	'en',	'help_search',	1.76896),
('status',	37,	'en',	'help_search',	6),
('status',	55,	'en',	'help_search',	4),
('status',	69,	'en',	'help_search',	1),
('stemmer',	30,	'en',	'help_search',	10.7896),
('stemming',	30,	'en',	'help_search',	1),
('step',	31,	'en',	'help_search',	1),
('step',	50,	'en',	'help_search',	1),
('step',	58,	'en',	'help_search',	0.98493),
('stepbystep',	27,	'en',	'help_search',	0.949597),
('steps',	1,	'en',	'help_search',	19),
('steps',	2,	'en',	'help_search',	19),
('steps',	3,	'en',	'help_search',	19),
('steps',	4,	'en',	'help_search',	19),
('steps',	5,	'en',	'help_search',	19),
('steps',	6,	'en',	'help_search',	20),
('steps',	7,	'en',	'help_search',	20),
('steps',	9,	'en',	'help_search',	19),
('steps',	13,	'en',	'help_search',	19),
('steps',	16,	'en',	'help_search',	1),
('steps',	20,	'en',	'help_search',	20),
('steps',	26,	'en',	'help_search',	20),
('steps',	27,	'en',	'help_search',	1),
('steps',	28,	'en',	'help_search',	20),
('steps',	29,	'en',	'help_search',	19.9132),
('steps',	31,	'en',	'help_search',	19),
('steps',	32,	'en',	'help_search',	20),
('steps',	33,	'en',	'help_search',	19),
('steps',	34,	'en',	'help_search',	19),
('steps',	35,	'en',	'help_search',	19),
('steps',	36,	'en',	'help_search',	19),
('steps',	37,	'en',	'help_search',	19),
('steps',	38,	'en',	'help_search',	19),
('steps',	39,	'en',	'help_search',	19),
('steps',	40,	'en',	'help_search',	20),
('steps',	41,	'en',	'help_search',	19),
('steps',	43,	'en',	'help_search',	19),
('steps',	44,	'en',	'help_search',	19),
('steps',	45,	'en',	'help_search',	19),
('steps',	47,	'en',	'help_search',	19),
('steps',	49,	'en',	'help_search',	19),
('steps',	50,	'en',	'help_search',	19.644),
('steps',	51,	'en',	'help_search',	19),
('steps',	52,	'en',	'help_search',	19),
('steps',	53,	'en',	'help_search',	19),
('steps',	54,	'en',	'help_search',	20),
('steps',	55,	'en',	'help_search',	19),
('steps',	57,	'en',	'help_search',	2),
('steps',	58,	'en',	'help_search',	20.9545),
('steps',	64,	'en',	'help_search',	19),
('steps',	65,	'en',	'help_search',	19),
('steps',	66,	'en',	'help_search',	20),
('steps',	67,	'en',	'help_search',	20),
('steps',	68,	'en',	'help_search',	19),
('steps',	70,	'en',	'help_search',	19),
('steps',	72,	'en',	'help_search',	20),
('steps',	74,	'en',	'help_search',	19),
('steps',	75,	'en',	'help_search',	19),
('steps',	76,	'en',	'help_search',	19),
('steps',	77,	'en',	'help_search',	19),
('steps',	78,	'en',	'help_search',	21),
('steps',	79,	'en',	'help_search',	19),
('steps',	81,	'en',	'help_search',	19),
('steps',	82,	'en',	'help_search',	20),
('steps',	83,	'en',	'help_search',	19),
('steps',	84,	'en',	'help_search',	20),
('steps',	85,	'en',	'help_search',	19),
('steps',	86,	'en',	'help_search',	19),
('steps',	87,	'en',	'help_search',	19),
('still',	14,	'en',	'help_search',	1),
('storage',	11,	'en',	'help_search',	2),
('store',	29,	'en',	'help_search',	1),
('store',	56,	'en',	'help_search',	1),
('store',	87,	'en',	'help_search',	2),
('stored',	10,	'en',	'help_search',	1),
('stored',	11,	'en',	'help_search',	1.76676),
('stored',	12,	'en',	'help_search',	2.49525),
('stored',	25,	'en',	'help_search',	1),
('stored',	87,	'en',	'help_search',	1),
('stores',	12,	'en',	'help_search',	11.822),
('strategic',	46,	'en',	'help_search',	1),
('streamed',	18,	'en',	'help_search',	0.916736),
('string',	26,	'en',	'help_search',	1),
('string',	32,	'en',	'help_search',	4),
('strings',	12,	'en',	'help_search',	0.738408),
('strings',	25,	'en',	'help_search',	1),
('strings',	32,	'en',	'help_search',	1),
('strings',	44,	'en',	'help_search',	1),
('structure',	5,	'en',	'help_search',	4),
('structure',	7,	'en',	'help_search',	4),
('structure',	9,	'en',	'help_search',	4),
('structure',	10,	'en',	'help_search',	1),
('structure',	11,	'en',	'help_search',	2),
('structure',	12,	'en',	'help_search',	39.205),
('structure',	16,	'en',	'help_search',	1),
('structure',	22,	'en',	'help_search',	1),
('structure',	24,	'en',	'help_search',	4),
('structure',	25,	'en',	'help_search',	1),
('structure',	26,	'en',	'help_search',	4),
('structure',	47,	'en',	'help_search',	4),
('structure',	49,	'en',	'help_search',	4),
('structure',	52,	'en',	'help_search',	4),
('structure',	53,	'en',	'help_search',	1),
('structure',	54,	'en',	'help_search',	15),
('structure',	55,	'en',	'help_search',	1),
('structure',	56,	'en',	'help_search',	2),
('structure',	65,	'en',	'help_search',	6),
('structure',	66,	'en',	'help_search',	5),
('structure',	67,	'en',	'help_search',	5),
('structure',	68,	'en',	'help_search',	5),
('structure',	70,	'en',	'help_search',	5),
('structure',	71,	'en',	'help_search',	2),
('structure',	74,	'en',	'help_search',	5),
('structure',	75,	'en',	'help_search',	8),
('structure',	76,	'en',	'help_search',	4),
('structure',	77,	'en',	'help_search',	4),
('structure',	82,	'en',	'help_search',	4),
('structure',	83,	'en',	'help_search',	4),
('structure',	84,	'en',	'help_search',	4),
('structure',	85,	'en',	'help_search',	4),
('structure',	86,	'en',	'help_search',	5),
('structure',	87,	'en',	'help_search',	5),
('structures',	25,	'en',	'help_search',	1),
('style',	11,	'en',	'help_search',	1),
('style',	16,	'en',	'help_search',	20),
('style',	72,	'en',	'help_search',	41),
('style',	73,	'en',	'help_search',	1),
('styles',	11,	'en',	'help_search',	1),
('styles',	16,	'en',	'help_search',	4.97954),
('styles',	72,	'en',	'help_search',	2),
('styling',	10,	'en',	'help_search',	1),
('subdirectory',	27,	'en',	'help_search',	1),
('subject',	5,	'en',	'help_search',	4),
('subject',	6,	'en',	'help_search',	4),
('subject',	7,	'en',	'help_search',	4),
('submit',	20,	'en',	'help_search',	1),
('submit',	23,	'en',	'help_search',	1),
('subset',	12,	'en',	'help_search',	1),
('substituted',	44,	'en',	'help_search',	1),
('subterm',	71,	'en',	'help_search',	1),
('subtype',	12,	'en',	'help_search',	0.980874),
('subtype',	65,	'en',	'help_search',	29),
('subtype',	66,	'en',	'help_search',	29),
('subtype',	67,	'en',	'help_search',	29),
('subtype',	68,	'en',	'help_search',	29),
('subtype',	70,	'en',	'help_search',	4),
('subtype',	86,	'en',	'help_search',	5),
('subtype',	87,	'en',	'help_search',	1),
('subtypes',	10,	'en',	'help_search',	1),
('subtypes',	12,	'en',	'help_search',	6.98902),
('subtypes',	16,	'en',	'help_search',	1),
('subtypes',	56,	'en',	'help_search',	1),
('subtypes',	65,	'en',	'help_search',	1),
('subtypes',	68,	'en',	'help_search',	1),
('subtypes',	71,	'en',	'help_search',	1),
('such',	3,	'en',	'help_search',	1),
('such',	4,	'en',	'help_search',	1),
('such',	5,	'en',	'help_search',	1),
('such',	11,	'en',	'help_search',	2.73841),
('such',	12,	'en',	'help_search',	4.6522),
('such',	13,	'en',	'help_search',	1),
('such',	15,	'en',	'help_search',	1),
('such',	16,	'en',	'help_search',	1),
('such',	18,	'en',	'help_search',	1),
('such',	23,	'en',	'help_search',	1),
('such',	24,	'en',	'help_search',	1),
('such',	25,	'en',	'help_search',	2),
('such',	26,	'en',	'help_search',	1),
('such',	30,	'en',	'help_search',	0.989021),
('such',	33,	'en',	'help_search',	1),
('such',	42,	'en',	'help_search',	2),
('such',	50,	'en',	'help_search',	2),
('such',	57,	'en',	'help_search',	1.98902),
('such',	58,	'en',	'help_search',	1),
('such',	64,	'en',	'help_search',	1),
('such',	71,	'en',	'help_search',	1),
('such',	73,	'en',	'help_search',	4.78568),
('such',	75,	'en',	'help_search',	1),
('such',	85,	'en',	'help_search',	3),
('sufficient',	73,	'en',	'help_search',	0.854391),
('suggested',	2,	'en',	'help_search',	1),
('summarizes',	37,	'en',	'help_search',	1),
('summary',	12,	'en',	'help_search',	5.47787),
('summary',	23,	'en',	'help_search',	1),
('summary',	76,	'en',	'help_search',	1),
('supplied',	10,	'en',	'help_search',	1),
('support',	29,	'en',	'help_search',	0.976851),
('support',	73,	'en',	'help_search',	1.82206),
('supports',	30,	'en',	'help_search',	1),
('sure',	13,	'en',	'help_search',	1),
('sure',	28,	'en',	'help_search',	1),
('sure',	29,	'en',	'help_search',	2.91323),
('sure',	30,	'en',	'help_search',	0.833529),
('sure',	58,	'en',	'help_search',	0.836446),
('sure',	64,	'en',	'help_search',	2),
('sure',	75,	'en',	'help_search',	1),
('sure',	78,	'en',	'help_search',	1),
('sure',	81,	'en',	'help_search',	2),
('sustainability',	46,	'en',	'help_search',	1),
('switch',	10,	'en',	'help_search',	0.989021),
('switch',	24,	'en',	'help_search',	0.953396),
('switch',	85,	'en',	'help_search',	1),
('switcher',	22,	'en',	'help_search',	4),
('sync',	11,	'en',	'help_search',	4.53866),
('synchronization',	1,	'en',	'help_search',	4),
('synchronization',	2,	'en',	'help_search',	4),
('synchronization',	3,	'en',	'help_search',	5),
('synchronization',	4,	'en',	'help_search',	4),
('synchronization',	11,	'en',	'help_search',	22.3776),
('synchronize',	3,	'en',	'help_search',	4),
('synchronize',	11,	'en',	'help_search',	1),
('synchronized',	11,	'en',	'help_search',	0.902857),
('synchronizing',	11,	'en',	'help_search',	0.738408),
('syslog',	15,	'en',	'help_search',	1),
('system',	11,	'en',	'help_search',	21.6358),
('system',	12,	'en',	'help_search',	4.4446),
('system',	13,	'en',	'help_search',	5),
('system',	16,	'en',	'help_search',	1),
('system',	17,	'en',	'help_search',	1),
('system',	24,	'en',	'help_search',	1),
('system',	30,	'en',	'help_search',	1),
('system',	32,	'en',	'help_search',	4),
('system',	33,	'en',	'help_search',	4),
('system',	64,	'en',	'help_search',	1),
('systems',	18,	'en',	'help_search',	1),
('tab',	8,	'en',	'help_search',	1),
('tab',	26,	'en',	'help_search',	1),
('tab',	51,	'en',	'help_search',	1),
('table',	7,	'en',	'help_search',	1),
('table',	23,	'en',	'help_search',	4),
('table',	45,	'en',	'help_search',	1),
('table',	58,	'en',	'help_search',	1),
('table',	73,	'en',	'help_search',	2.85746),
('table',	83,	'en',	'help_search',	1),
('table',	85,	'en',	'help_search',	4),
('table',	86,	'en',	'help_search',	1),
('tables',	23,	'en',	'help_search',	1),
('tables',	29,	'en',	'help_search',	1),
('tablestyle',	83,	'en',	'help_search',	1),
('tabs',	54,	'en',	'help_search',	1),
('tag',	50,	'en',	'help_search',	0.822065),
('tag',	58,	'en',	'help_search',	1),
('tagging',	71,	'en',	'help_search',	1),
('tags',	50,	'en',	'help_search',	7.37404),
('tags',	71,	'en',	'help_search',	4),
('take',	31,	'en',	'help_search',	1),
('take',	37,	'en',	'help_search',	1),
('taken',	54,	'en',	'help_search',	1),
('takes',	50,	'en',	'help_search',	1),
('takes',	64,	'en',	'help_search',	1),
('task',	13,	'en',	'help_search',	3.99731),
('task',	27,	'en',	'help_search',	1),
('task',	29,	'en',	'help_search',	0.913226),
('task',	64,	'en',	'help_search',	0.980874),
('tasks',	8,	'en',	'help_search',	20),
('tasks',	10,	'en',	'help_search',	0.942091),
('tasks',	11,	'en',	'help_search',	1.42247),
('tasks',	12,	'en',	'help_search',	0.582831),
('tasks',	13,	'en',	'help_search',	32.4456),
('tasks',	14,	'en',	'help_search',	1),
('tasks',	15,	'en',	'help_search',	1),
('tasks',	16,	'en',	'help_search',	0.961087),
('tasks',	17,	'en',	'help_search',	1),
('tasks',	19,	'en',	'help_search',	20),
('tasks',	21,	'en',	'help_search',	1),
('tasks',	22,	'en',	'help_search',	1),
('tasks',	24,	'en',	'help_search',	4),
('tasks',	30,	'en',	'help_search',	0.786915),
('tasks',	42,	'en',	'help_search',	1),
('tasks',	48,	'en',	'help_search',	1),
('tasks',	56,	'en',	'help_search',	1),
('tasks',	64,	'en',	'help_search',	2),
('tasks',	71,	'en',	'help_search',	0.896076),
('tasks',	73,	'en',	'help_search',	0.784336),
('tasks',	76,	'en',	'help_search',	1),
('tasks',	80,	'en',	'help_search',	1),
('taxonomy',	12,	'en',	'help_search',	0.610858),
('taxonomy',	24,	'en',	'help_search',	0.961087),
('taxonomy',	70,	'en',	'help_search',	64),
('taxonomy',	71,	'en',	'help_search',	89.5416),
('taxonomy',	78,	'en',	'help_search',	1),
('taxonomy',	80,	'en',	'help_search',	2),
('team',	19,	'en',	'help_search',	11),
('technically',	71,	'en',	'help_search',	1),
('technologies',	30,	'en',	'help_search',	1),
('technology',	23,	'en',	'help_search',	1),
('technology',	30,	'en',	'help_search',	1),
('telephone',	12,	'en',	'help_search',	2.38691),
('template',	10,	'en',	'help_search',	1),
('temporarily',	64,	'en',	'help_search',	1),
('temporary',	12,	'en',	'help_search',	1),
('temporary',	28,	'en',	'help_search',	1),
('term',	70,	'en',	'help_search',	7),
('term',	71,	'en',	'help_search',	2.92613),
('term',	78,	'en',	'help_search',	1),
('term',	80,	'en',	'help_search',	2),
('terms',	11,	'en',	'help_search',	0.822065),
('terms',	70,	'en',	'help_search',	6),
('terms',	71,	'en',	'help_search',	13.9347),
('test',	1,	'en',	'node_search',	2),
('test',	66,	'en',	'help_search',	1),
('test',	67,	'en',	'help_search',	1),
('text',	2,	'en',	'help_search',	3),
('text',	4,	'en',	'help_search',	1),
('text',	5,	'en',	'help_search',	1),
('text',	10,	'en',	'help_search',	1),
('text',	12,	'en',	'help_search',	39.8545),
('text',	22,	'en',	'help_search',	23),
('text',	25,	'en',	'help_search',	1),
('text',	26,	'en',	'help_search',	1),
('text',	27,	'en',	'help_search',	2),
('text',	44,	'en',	'help_search',	21.9849),
('text',	45,	'en',	'help_search',	1),
('text',	50,	'en',	'help_search',	163.01),
('text',	51,	'en',	'help_search',	1),
('text',	56,	'en',	'help_search',	1),
('text',	58,	'en',	'help_search',	108.144),
('text',	65,	'en',	'help_search',	5),
('text',	66,	'en',	'help_search',	1),
('text',	68,	'en',	'help_search',	5),
('text',	75,	'en',	'help_search',	1),
('than',	8,	'en',	'help_search',	1),
('than',	11,	'en',	'help_search',	1.46654),
('than',	18,	'en',	'help_search',	1),
('than',	29,	'en',	'help_search',	1),
('than',	34,	'en',	'help_search',	1),
('than',	35,	'en',	'help_search',	1),
('than',	51,	'en',	'help_search',	1),
('than',	53,	'en',	'help_search',	1),
('than',	69,	'en',	'help_search',	1),
('than',	76,	'en',	'help_search',	1),
('that',	2,	'en',	'help_search',	1),
('that',	3,	'en',	'help_search',	2),
('that',	4,	'en',	'help_search',	3),
('that',	5,	'en',	'help_search',	1),
('that',	6,	'en',	'help_search',	1),
('that',	8,	'en',	'help_search',	1),
('that',	10,	'en',	'help_search',	5),
('that',	11,	'en',	'help_search',	6.30646),
('that',	12,	'en',	'help_search',	8.69588),
('that',	13,	'en',	'help_search',	3),
('that',	14,	'en',	'help_search',	3),
('that',	15,	'en',	'help_search',	4),
('that',	16,	'en',	'help_search',	1),
('that',	18,	'en',	'help_search',	2.9347),
('that',	19,	'en',	'help_search',	1),
('that',	20,	'en',	'help_search',	3),
('that',	21,	'en',	'help_search',	2),
('that',	22,	'en',	'help_search',	4),
('that',	23,	'en',	'help_search',	2),
('that',	24,	'en',	'help_search',	1),
('that',	25,	'en',	'help_search',	2),
('that',	26,	'en',	'help_search',	5),
('that',	28,	'en',	'help_search',	3),
('that',	29,	'en',	'help_search',	3.82016),
('that',	30,	'en',	'help_search',	7.47776),
('that',	31,	'en',	'help_search',	2),
('that',	32,	'en',	'help_search',	5),
('that',	33,	'en',	'help_search',	3.67553),
('that',	35,	'en',	'help_search',	3),
('that',	36,	'en',	'help_search',	2),
('that',	37,	'en',	'help_search',	3),
('that',	38,	'en',	'help_search',	6),
('that',	39,	'en',	'help_search',	2),
('that',	40,	'en',	'help_search',	1),
('that',	42,	'en',	'help_search',	1),
('that',	43,	'en',	'help_search',	2),
('that',	44,	'en',	'help_search',	7.92329),
('that',	47,	'en',	'help_search',	3),
('that',	48,	'en',	'help_search',	1),
('that',	49,	'en',	'help_search',	2),
('that',	50,	'en',	'help_search',	8.85086),
('that',	53,	'en',	'help_search',	1),
('that',	56,	'en',	'help_search',	1),
('that',	57,	'en',	'help_search',	2),
('that',	58,	'en',	'help_search',	5.82864),
('that',	64,	'en',	'help_search',	6.98902),
('that',	65,	'en',	'help_search',	1),
('that',	66,	'en',	'help_search',	3),
('that',	67,	'en',	'help_search',	2),
('that',	68,	'en',	'help_search',	3),
('that',	69,	'en',	'help_search',	2),
('that',	70,	'en',	'help_search',	3),
('that',	71,	'en',	'help_search',	1.92221),
('that',	73,	'en',	'help_search',	0.993146),
('that',	74,	'en',	'help_search',	2),
('that',	75,	'en',	'help_search',	3),
('that',	77,	'en',	'help_search',	1),
('that',	78,	'en',	'help_search',	1),
('that',	79,	'en',	'help_search',	2),
('that',	80,	'en',	'help_search',	1),
('that',	81,	'en',	'help_search',	4.99315),
('that',	82,	'en',	'help_search',	1),
('that',	83,	'en',	'help_search',	3),
('that',	85,	'en',	'help_search',	3),
('that',	86,	'en',	'help_search',	1.85439),
('that',	87,	'en',	'help_search',	4),
('the',	1,	'en',	'help_search',	2),
('the',	2,	'en',	'help_search',	9),
('the',	3,	'en',	'help_search',	8),
('the',	4,	'en',	'help_search',	6),
('the',	5,	'en',	'help_search',	53),
('the',	6,	'en',	'help_search',	12),
('the',	7,	'en',	'help_search',	8),
('the',	8,	'en',	'help_search',	30),
('the',	9,	'en',	'help_search',	30),
('the',	10,	'en',	'help_search',	44.8969),
('the',	11,	'en',	'help_search',	63.3085),
('the',	12,	'en',	'help_search',	40.0589),
('the',	13,	'en',	'help_search',	14.9946),
('the',	14,	'en',	'help_search',	6),
('the',	15,	'en',	'help_search',	3),
('the',	16,	'en',	'help_search',	37.9564),
('the',	17,	'en',	'help_search',	7),
('the',	18,	'en',	'help_search',	50.6047),
('the',	19,	'en',	'help_search',	6),
('the',	20,	'en',	'help_search',	23),
('the',	21,	'en',	'help_search',	28),
('the',	22,	'en',	'help_search',	9),
('the',	23,	'en',	'help_search',	40.9849),
('the',	24,	'en',	'help_search',	85.1542),
('the',	25,	'en',	'help_search',	40),
('the',	26,	'en',	'help_search',	25),
('the',	27,	'en',	'help_search',	10.9206),
('the',	28,	'en',	'help_search',	17),
('the',	29,	'en',	'help_search',	65.133),
('the',	30,	'en',	'help_search',	94.7056),
('the',	31,	'en',	'help_search',	53),
('the',	32,	'en',	'help_search',	18),
('the',	33,	'en',	'help_search',	20.4958),
('the',	34,	'en',	'help_search',	13),
('the',	35,	'en',	'help_search',	18),
('the',	36,	'en',	'help_search',	18),
('the',	37,	'en',	'help_search',	15),
('the',	38,	'en',	'help_search',	25),
('the',	39,	'en',	'help_search',	10),
('the',	40,	'en',	'help_search',	9),
('the',	41,	'en',	'help_search',	6),
('the',	42,	'en',	'help_search',	6),
('the',	43,	'en',	'help_search',	35),
('the',	44,	'en',	'help_search',	34.9138),
('the',	45,	'en',	'help_search',	15),
('the',	46,	'en',	'help_search',	54),
('the',	47,	'en',	'help_search',	25),
('the',	48,	'en',	'help_search',	47),
('the',	49,	'en',	'help_search',	10),
('the',	50,	'en',	'help_search',	25.6562),
('the',	51,	'en',	'help_search',	6),
('the',	52,	'en',	'help_search',	8),
('the',	53,	'en',	'help_search',	24),
('the',	54,	'en',	'help_search',	20),
('the',	55,	'en',	'help_search',	25.963),
('the',	56,	'en',	'help_search',	7),
('the',	57,	'en',	'help_search',	14.8913),
('the',	58,	'en',	'help_search',	25.0258),
('the',	64,	'en',	'help_search',	30.8869),
('the',	65,	'en',	'help_search',	22),
('the',	66,	'en',	'help_search',	28),
('the',	67,	'en',	'help_search',	49),
('the',	68,	'en',	'help_search',	27.9931),
('the',	69,	'en',	'help_search',	6),
('the',	70,	'en',	'help_search',	25),
('the',	71,	'en',	'help_search',	14.6866),
('the',	72,	'en',	'help_search',	13),
('the',	73,	'en',	'help_search',	56.4415),
('the',	74,	'en',	'help_search',	7),
('the',	75,	'en',	'help_search',	22),
('the',	76,	'en',	'help_search',	14),
('the',	77,	'en',	'help_search',	3),
('the',	78,	'en',	'help_search',	10),
('the',	79,	'en',	'help_search',	9),
('the',	80,	'en',	'help_search',	17),
('the',	81,	'en',	'help_search',	18.8617),
('the',	82,	'en',	'help_search',	12),
('the',	83,	'en',	'help_search',	22.9672),
('the',	84,	'en',	'help_search',	7),
('the',	85,	'en',	'help_search',	17),
('the',	86,	'en',	'help_search',	87.4092),
('the',	87,	'en',	'help_search',	7),
('their',	8,	'en',	'help_search',	1),
('their',	11,	'en',	'help_search',	0.749958),
('their',	12,	'en',	'help_search',	0.60322),
('their',	19,	'en',	'help_search',	1),
('their',	23,	'en',	'help_search',	1),
('their',	24,	'en',	'help_search',	1),
('their',	27,	'en',	'help_search',	1),
('their',	29,	'en',	'help_search',	1),
('their',	31,	'en',	'help_search',	1),
('their',	44,	'en',	'help_search',	3.98902),
('their',	47,	'en',	'help_search',	1),
('their',	58,	'en',	'help_search',	0.848323),
('their',	66,	'en',	'help_search',	1),
('their',	67,	'en',	'help_search',	1),
('their',	81,	'en',	'help_search',	1.96109),
('them',	6,	'en',	'help_search',	2),
('them',	18,	'en',	'help_search',	1),
('them',	23,	'en',	'help_search',	1),
('them',	26,	'en',	'help_search',	1),
('them',	32,	'en',	'help_search',	1),
('them',	37,	'en',	'help_search',	2),
('them',	40,	'en',	'help_search',	1),
('them',	46,	'en',	'help_search',	1),
('them',	50,	'en',	'help_search',	1.86995),
('them',	58,	'en',	'help_search',	0.879565),
('them',	71,	'en',	'help_search',	1.99731),
('them',	73,	'en',	'help_search',	0.833529),
('them',	81,	'en',	'help_search',	1),
('them',	86,	'en',	'help_search',	0.873132),
('theme',	10,	'en',	'help_search',	47.9809),
('theme',	11,	'en',	'help_search',	2),
('theme',	16,	'en',	'help_search',	1.98902),
('theme',	17,	'en',	'help_search',	1),
('theme',	26,	'en',	'help_search',	3),
('theme',	27,	'en',	'help_search',	2.98493),
('theme',	38,	'en',	'help_search',	47),
('theme',	39,	'en',	'help_search',	37),
('theme',	47,	'en',	'help_search',	4),
('theme',	48,	'en',	'help_search',	1),
('theme',	49,	'en',	'help_search',	3),
('theme',	81,	'en',	'help_search',	1),
('themes',	10,	'en',	'help_search',	8.9689),
('themes',	11,	'en',	'help_search',	0.699655),
('themes',	17,	'en',	'help_search',	1),
('themes',	19,	'en',	'help_search',	2),
('themes',	20,	'en',	'help_search',	1),
('themes',	22,	'en',	'help_search',	1),
('themes',	24,	'en',	'help_search',	2.82262),
('themes',	27,	'en',	'help_search',	5),
('themes',	37,	'en',	'help_search',	2),
('themes',	38,	'en',	'help_search',	37),
('themes',	39,	'en',	'help_search',	4),
('themes',	48,	'en',	'help_search',	1),
('themes',	57,	'en',	'help_search',	2.96109),
('themes',	64,	'en',	'help_search',	1),
('theming',	10,	'en',	'help_search',	10.0841),
('themselves',	44,	'en',	'help_search',	1),
('then',	2,	'en',	'help_search',	1),
('then',	11,	'en',	'help_search',	0.800068),
('then',	27,	'en',	'help_search',	0.976851),
('then',	29,	'en',	'help_search',	1),
('then',	34,	'en',	'help_search',	1),
('then',	72,	'en',	'help_search',	1),
('then',	86,	'en',	'help_search',	0.961087),
('there',	8,	'en',	'help_search',	1),
('there',	11,	'en',	'help_search',	19),
('there',	12,	'en',	'help_search',	2.35233),
('there',	15,	'en',	'help_search',	2),
('there',	22,	'en',	'help_search',	1),
('there',	24,	'en',	'help_search',	1),
('there',	25,	'en',	'help_search',	1),
('there',	26,	'en',	'help_search',	1),
('there',	30,	'en',	'help_search',	1),
('there',	31,	'en',	'help_search',	1),
('there',	36,	'en',	'help_search',	3),
('there',	37,	'en',	'help_search',	1),
('there',	39,	'en',	'help_search',	1),
('there',	42,	'en',	'help_search',	1),
('there',	53,	'en',	'help_search',	1),
('there',	69,	'en',	'help_search',	2),
('there',	73,	'en',	'help_search',	0.934703),
('there',	81,	'en',	'help_search',	2),
('there',	83,	'en',	'help_search',	1),
('there',	85,	'en',	'help_search',	2),
('there',	87,	'en',	'help_search',	2),
('thereby',	11,	'en',	'help_search',	0.786915),
('these',	11,	'en',	'help_search',	1),
('these',	12,	'en',	'help_search',	1.39601),
('these',	13,	'en',	'help_search',	1),
('these',	16,	'en',	'help_search',	0.989021),
('these',	19,	'en',	'help_search',	1),
('these',	20,	'en',	'help_search',	1),
('these',	23,	'en',	'help_search',	2.99315),
('these',	27,	'en',	'help_search',	1),
('these',	29,	'en',	'help_search',	0.972861),
('these',	31,	'en',	'help_search',	1),
('these',	33,	'en',	'help_search',	2),
('these',	38,	'en',	'help_search',	1),
('these',	40,	'en',	'help_search',	1),
('these',	50,	'en',	'help_search',	0.776703),
('these',	58,	'en',	'help_search',	1.95723),
('these',	66,	'en',	'help_search',	1),
('these',	67,	'en',	'help_search',	1),
('these',	69,	'en',	'help_search',	1),
('these',	71,	'en',	'help_search',	2.9689),
('these',	74,	'en',	'help_search',	1),
('these',	81,	'en',	'help_search',	1),
('these',	84,	'en',	'help_search',	1),
('they',	6,	'en',	'help_search',	1),
('they',	11,	'en',	'help_search',	0.693594),
('they',	12,	'en',	'help_search',	1.96498),
('they',	16,	'en',	'help_search',	1),
('they',	19,	'en',	'help_search',	1),
('they',	21,	'en',	'help_search',	1),
('they',	23,	'en',	'help_search',	1),
('they',	25,	'en',	'help_search',	1),
('they',	26,	'en',	'help_search',	1),
('they',	27,	'en',	'help_search',	1),
('they',	30,	'en',	'help_search',	2),
('they',	44,	'en',	'help_search',	2),
('they',	55,	'en',	'help_search',	1),
('they',	69,	'en',	'help_search',	1),
('they',	72,	'en',	'help_search',	1),
('they',	81,	'en',	'help_search',	1),
('thirdparty',	30,	'en',	'help_search',	1),
('thirdparty',	58,	'en',	'help_search',	1),
('this',	8,	'en',	'help_search',	1),
('this',	9,	'en',	'help_search',	4),
('this',	11,	'en',	'help_search',	2.73112),
('this',	12,	'en',	'help_search',	0.648686),
('this',	13,	'en',	'help_search',	1),
('this',	16,	'en',	'help_search',	2),
('this',	18,	'en',	'help_search',	3.90974),
('this',	19,	'en',	'help_search',	1),
('this',	24,	'en',	'help_search',	1),
('this',	26,	'en',	'help_search',	2),
('this',	29,	'en',	'help_search',	1),
('this',	30,	'en',	'help_search',	1.92384),
('this',	36,	'en',	'help_search',	3),
('this',	43,	'en',	'help_search',	6),
('this',	46,	'en',	'help_search',	2),
('this',	50,	'en',	'help_search',	4.73792),
('this',	52,	'en',	'help_search',	1),
('this',	53,	'en',	'help_search',	2),
('this',	58,	'en',	'help_search',	1.97685),
('this',	64,	'en',	'help_search',	1),
('this',	69,	'en',	'help_search',	20),
('this',	70,	'en',	'help_search',	1),
('this',	74,	'en',	'help_search',	2),
('this',	75,	'en',	'help_search',	3),
('this',	78,	'en',	'help_search',	1),
('this',	79,	'en',	'help_search',	1),
('this',	82,	'en',	'help_search',	2),
('this',	84,	'en',	'help_search',	1),
('this',	86,	'en',	'help_search',	1),
('this',	87,	'en',	'help_search',	2),
('three',	22,	'en',	'help_search',	1),
('three',	32,	'en',	'help_search',	1),
('throttle',	29,	'en',	'help_search',	4),
('through',	11,	'en',	'help_search',	1.67748),
('through',	12,	'en',	'help_search',	0.718502),
('through',	16,	'en',	'help_search',	1),
('through',	23,	'en',	'help_search',	1),
('through',	64,	'en',	'help_search',	1),
('time',	12,	'en',	'help_search',	1.85135),
('time',	13,	'en',	'help_search',	1),
('time',	18,	'en',	'help_search',	6),
('time',	31,	'en',	'help_search',	2),
('time',	32,	'en',	'help_search',	6),
('time',	35,	'en',	'help_search',	1),
('time',	69,	'en',	'help_search',	1),
('timeout',	29,	'en',	'help_search',	1),
('times',	12,	'en',	'help_search',	0.857458),
('times',	29,	'en',	'help_search',	0.899454),
('timestamp',	12,	'en',	'help_search',	0.863659),
('title',	7,	'en',	'help_search',	1),
('title',	27,	'en',	'help_search',	1),
('title',	47,	'en',	'help_search',	14),
('title',	48,	'en',	'help_search',	20),
('title',	50,	'en',	'help_search',	0.942091),
('title',	53,	'en',	'help_search',	5),
('title',	55,	'en',	'help_search',	6),
('title',	68,	'en',	'help_search',	1),
('title',	75,	'en',	'help_search',	10),
('title',	76,	'en',	'help_search',	3),
('title',	81,	'en',	'help_search',	1),
('title',	85,	'en',	'help_search',	4),
('title',	86,	'en',	'help_search',	3.66694),
('together',	18,	'en',	'help_search',	1),
('toggle',	64,	'en',	'help_search',	1),
('tomatoes',	71,	'en',	'help_search',	3),
('tool',	11,	'en',	'help_search',	0.722831),
('toolbar',	20,	'en',	'help_search',	2),
('toolbar',	24,	'en',	'help_search',	15),
('toolbar',	46,	'en',	'help_search',	3),
('toolbar',	58,	'en',	'help_search',	15.6581),
('toolbar',	64,	'en',	'help_search',	3),
('toolbar',	81,	'en',	'help_search',	3),
('tooltip',	58,	'en',	'help_search',	0.906287),
('top',	23,	'en',	'help_search',	1),
('top',	24,	'en',	'help_search',	1),
('top',	26,	'en',	'help_search',	1),
('top',	73,	'en',	'help_search',	0.968904),
('top',	86,	'en',	'help_search',	0.972861),
('topic',	12,	'en',	'help_search',	0.707906),
('topic',	26,	'en',	'help_search',	2),
('topic',	27,	'en',	'help_search',	22.9534),
('topic',	50,	'en',	'help_search',	0.851346),
('topic',	53,	'en',	'help_search',	1),
('topic',	58,	'en',	'help_search',	0.976851),
('topic',	70,	'en',	'help_search',	1),
('topic',	73,	'en',	'help_search',	0.808176),
('topic',	78,	'en',	'help_search',	1),
('topic',	83,	'en',	'help_search',	1),
('topic',	87,	'en',	'help_search',	2),
('topics',	8,	'en',	'help_search',	1),
('topics',	10,	'en',	'help_search',	0.957226),
('topics',	11,	'en',	'help_search',	0.689612),
('topics',	12,	'en',	'help_search',	1.17559),
('topics',	14,	'en',	'help_search',	1),
('topics',	15,	'en',	'help_search',	1),
('topics',	16,	'en',	'help_search',	0.976851),
('topics',	17,	'en',	'help_search',	1),
('topics',	19,	'en',	'help_search',	1),
('topics',	21,	'en',	'help_search',	1),
('topics',	22,	'en',	'help_search',	1),
('topics',	24,	'en',	'help_search',	1.86679),
('topics',	27,	'en',	'help_search',	121.282),
('topics',	30,	'en',	'help_search',	1.79475),
('topics',	42,	'en',	'help_search',	1),
('topics',	48,	'en',	'help_search',	1),
('topics',	54,	'en',	'help_search',	1),
('topics',	56,	'en',	'help_search',	1),
('topics',	70,	'en',	'help_search',	1),
('topics',	71,	'en',	'help_search',	0.909743),
('topics',	72,	'en',	'help_search',	1),
('topics',	73,	'en',	'help_search',	0.792123),
('topics',	76,	'en',	'help_search',	1),
('topics',	78,	'en',	'help_search',	1),
('topics',	80,	'en',	'help_search',	1),
('topics',	84,	'en',	'help_search',	1),
('topleft',	20,	'en',	'help_search',	1),
('toplevel',	27,	'en',	'help_search',	1),
('topright',	20,	'en',	'help_search',	1),
('totally',	33,	'en',	'help_search',	1),
('track',	19,	'en',	'help_search',	1),
('tracked',	69,	'en',	'help_search',	19),
('tracking',	21,	'en',	'help_search',	46),
('tracking',	69,	'en',	'help_search',	45),
('tracks',	21,	'en',	'help_search',	1),
('tracks',	69,	'en',	'help_search',	1),
('traditional',	72,	'en',	'help_search',	1),
('transferred',	25,	'en',	'help_search',	1),
('transform',	50,	'en',	'help_search',	1),
('translatable',	27,	'en',	'help_search',	3),
('translate',	22,	'en',	'help_search',	1),
('translated',	22,	'en',	'help_search',	23),
('translated',	27,	'en',	'help_search',	19),
('translation',	22,	'en',	'help_search',	3),
('translation',	26,	'en',	'help_search',	1),
('translation',	27,	'en',	'help_search',	3),
('translations',	22,	'en',	'help_search',	29),
('translations',	38,	'en',	'help_search',	1),
('transmission',	18,	'en',	'help_search',	1),
('transported',	25,	'en',	'help_search',	1),
('tray',	20,	'en',	'help_search',	2),
('tray',	24,	'en',	'help_search',	1),
('triggers',	27,	'en',	'help_search',	1),
('troubleshooting',	15,	'en',	'help_search',	46),
('true',	12,	'en',	'help_search',	0.892724),
('trusted',	43,	'en',	'help_search',	4),
('try',	26,	'en',	'help_search',	1),
('trying',	15,	'en',	'help_search',	1),
('trying',	35,	'en',	'help_search',	1),
('turn',	18,	'en',	'help_search',	0.854391),
('turning',	14,	'en',	'help_search',	2),
('turns',	50,	'en',	'help_search',	1),
('twice',	40,	'en',	'help_search',	1),
('twig',	27,	'en',	'help_search',	1),
('twigfilebased',	27,	'en',	'help_search',	1),
('two',	8,	'en',	'help_search',	1),
('two',	12,	'en',	'help_search',	0.679856),
('two',	15,	'en',	'help_search',	1),
('two',	25,	'en',	'help_search',	1),
('two',	30,	'en',	'help_search',	1),
('two',	57,	'en',	'help_search',	1),
('two',	68,	'en',	'help_search',	1),
('two',	71,	'en',	'help_search',	1),
('two',	72,	'en',	'help_search',	1),
('two',	85,	'en',	'help_search',	1),
('twocolumn',	86,	'en',	'help_search',	0.968904),
('type',	2,	'en',	'help_search',	4),
('type',	4,	'en',	'help_search',	4),
('type',	11,	'en',	'help_search',	2),
('type',	12,	'en',	'help_search',	13.0673),
('type',	17,	'en',	'help_search',	1),
('type',	26,	'en',	'help_search',	1),
('type',	28,	'en',	'help_search',	4),
('type',	30,	'en',	'help_search',	2),
('type',	42,	'en',	'help_search',	1),
('type',	48,	'en',	'help_search',	1),
('type',	50,	'en',	'help_search',	1),
('type',	51,	'en',	'help_search',	2),
('type',	52,	'en',	'help_search',	35),
('type',	53,	'en',	'help_search',	5),
('type',	54,	'en',	'help_search',	66),
('type',	55,	'en',	'help_search',	6),
('type',	56,	'en',	'help_search',	24),
('type',	65,	'en',	'help_search',	3),
('type',	66,	'en',	'help_search',	2),
('type',	67,	'en',	'help_search',	2),
('type',	68,	'en',	'help_search',	16),
('type',	70,	'en',	'help_search',	1),
('type',	71,	'en',	'help_search',	1),
('type',	73,	'en',	'help_search',	4.8249),
('type',	74,	'en',	'help_search',	30),
('type',	75,	'en',	'help_search',	1),
('type',	82,	'en',	'help_search',	1),
('type',	84,	'en',	'help_search',	1),
('type',	85,	'en',	'help_search',	1),
('type',	86,	'en',	'help_search',	2),
('type',	87,	'en',	'help_search',	39),
('types',	8,	'en',	'help_search',	1),
('types',	11,	'en',	'help_search',	8.39477),
('types',	12,	'en',	'help_search',	88.542),
('types',	16,	'en',	'help_search',	4),
('types',	22,	'en',	'help_search',	1),
('types',	24,	'en',	'help_search',	0.980874),
('types',	29,	'en',	'help_search',	1),
('types',	30,	'en',	'help_search',	3),
('types',	48,	'en',	'help_search',	5),
('types',	52,	'en',	'help_search',	8),
('types',	53,	'en',	'help_search',	2),
('types',	54,	'en',	'help_search',	10),
('types',	55,	'en',	'help_search',	3),
('types',	56,	'en',	'help_search',	7),
('types',	57,	'en',	'help_search',	1),
('types',	65,	'en',	'help_search',	7),
('types',	66,	'en',	'help_search',	4),
('types',	67,	'en',	'help_search',	4),
('types',	68,	'en',	'help_search',	5),
('types',	73,	'en',	'help_search',	1),
('types',	74,	'en',	'help_search',	1),
('types',	82,	'en',	'help_search',	1),
('types',	86,	'en',	'help_search',	1),
('types',	87,	'en',	'help_search',	4),
('typically',	25,	'en',	'help_search',	1),
('typically',	54,	'en',	'help_search',	1),
('typically',	58,	'en',	'help_search',	1),
('typing',	75,	'en',	'help_search',	1),
('uncacheable',	18,	'en',	'help_search',	0.923838),
('uncheck',	6,	'en',	'help_search',	1),
('uncheck',	34,	'en',	'help_search',	1),
('uncheck',	43,	'en',	'help_search',	1),
('uncheck',	44,	'en',	'help_search',	1),
('uncheck',	53,	'en',	'help_search',	1),
('uncheck',	77,	'en',	'help_search',	1),
('uncheck',	86,	'en',	'help_search',	0.889397),
('unchecked',	86,	'en',	'help_search',	1),
('under',	26,	'en',	'help_search',	1),
('under',	27,	'en',	'help_search',	1),
('under',	29,	'en',	'help_search',	3.86775),
('under',	33,	'en',	'help_search',	1.92027),
('under',	50,	'en',	'help_search',	2.48477),
('under',	55,	'en',	'help_search',	0.980874),
('under',	58,	'en',	'help_search',	0.949597),
('under',	71,	'en',	'help_search',	1),
('under',	72,	'en',	'help_search',	1),
('under',	74,	'en',	'help_search',	2),
('under',	78,	'en',	'help_search',	1),
('under',	82,	'en',	'help_search',	1),
('under',	85,	'en',	'help_search',	1),
('under',	86,	'en',	'help_search',	1),
('under',	87,	'en',	'help_search',	2),
('underlying',	18,	'en',	'help_search',	1),
('understand',	23,	'en',	'help_search',	2),
('understandable',	80,	'en',	'help_search',	1),
('unformatted',	12,	'en',	'help_search',	0.794753),
('unformatted',	85,	'en',	'help_search',	8),
('uniform',	80,	'en',	'help_search',	1),
('uninstall',	13,	'en',	'help_search',	1),
('uninstall',	14,	'en',	'help_search',	1),
('uninstall',	24,	'en',	'help_search',	0.931053),
('uninstall',	36,	'en',	'help_search',	24),
('uninstall',	39,	'en',	'help_search',	11),
('uninstalled',	14,	'en',	'help_search',	1),
('uninstalled',	36,	'en',	'help_search',	5),
('uninstalled',	38,	'en',	'help_search',	4),
('uninstalled',	39,	'en',	'help_search',	1),
('uninstalling',	14,	'en',	'help_search',	20),
('uninstalling',	15,	'en',	'help_search',	1),
('uninstalling',	36,	'en',	'help_search',	26),
('uninstalling',	39,	'en',	'help_search',	26),
('unique',	11,	'en',	'help_search',	1.89272),
('unique',	13,	'en',	'help_search',	1),
('unique',	80,	'en',	'help_search',	1),
('unlimited',	65,	'en',	'help_search',	1),
('unlimited',	68,	'en',	'help_search',	1),
('unpacked',	3,	'en',	'help_search',	1),
('unpublished',	53,	'en',	'help_search',	2),
('unpublished',	55,	'en',	'help_search',	1),
('unpublishing',	73,	'en',	'help_search',	0.819249),
('until',	26,	'en',	'help_search',	1),
('until',	32,	'en',	'help_search',	1),
('until',	45,	'en',	'help_search',	1),
('until',	64,	'en',	'help_search',	1),
('until',	72,	'en',	'help_search',	1),
('until',	75,	'en',	'help_search',	1),
('until',	81,	'en',	'help_search',	1),
('until',	86,	'en',	'help_search',	0.906287),
('untrusted',	50,	'en',	'help_search',	0.882818),
('unused',	39,	'en',	'help_search',	26),
('upcoming',	37,	'en',	'help_search',	1),
('update',	19,	'en',	'help_search',	4),
('update',	22,	'en',	'help_search',	1),
('update',	24,	'en',	'help_search',	1.87314),
('update',	37,	'en',	'help_search',	4),
('update',	45,	'en',	'help_search',	3),
('update',	47,	'en',	'help_search',	1),
('update',	55,	'en',	'help_search',	2),
('update',	83,	'en',	'help_search',	1),
('update',	85,	'en',	'help_search',	4),
('updated',	13,	'en',	'help_search',	1),
('updated',	26,	'en',	'help_search',	1),
('updated',	27,	'en',	'help_search',	2),
('updated',	28,	'en',	'help_search',	1),
('updated',	69,	'en',	'help_search',	9),
('updates',	11,	'en',	'help_search',	1.92384),
('updates',	19,	'en',	'help_search',	21),
('updates',	24,	'en',	'help_search',	0.892724),
('updates',	37,	'en',	'help_search',	6),
('updating',	11,	'en',	'help_search',	1.47793),
('updating',	15,	'en',	'help_search',	1),
('updating',	19,	'en',	'help_search',	2),
('upload',	3,	'en',	'help_search',	4),
('uploaded',	3,	'en',	'help_search',	1),
('uploaded',	10,	'en',	'help_search',	1),
('upper',	64,	'en',	'help_search',	2),
('url',	8,	'en',	'help_search',	1),
('url',	13,	'en',	'help_search',	6),
('url',	16,	'en',	'help_search',	1),
('url',	28,	'en',	'help_search',	1),
('url',	30,	'en',	'help_search',	1),
('url',	33,	'en',	'help_search',	2.97395),
('url',	44,	'en',	'help_search',	4),
('url',	73,	'en',	'help_search',	1),
('url',	75,	'en',	'help_search',	1),
('url',	78,	'en',	'help_search',	54),
('url',	79,	'en',	'help_search',	55),
('url',	80,	'en',	'help_search',	25),
('urls',	12,	'en',	'help_search',	0.833529),
('urls',	33,	'en',	'help_search',	1),
('urls',	50,	'en',	'help_search',	3.99731),
('urls',	78,	'en',	'help_search',	1),
('urls',	79,	'en',	'help_search',	1),
('urls',	80,	'en',	'help_search',	58),
('use',	2,	'en',	'help_search',	1),
('use',	5,	'en',	'help_search',	1),
('use',	6,	'en',	'help_search',	6),
('use',	12,	'en',	'help_search',	1.26527),
('use',	13,	'en',	'help_search',	1),
('use',	14,	'en',	'help_search',	1),
('use',	16,	'en',	'help_search',	2),
('use',	18,	'en',	'help_search',	1.98902),
('use',	20,	'en',	'help_search',	4),
('use',	23,	'en',	'help_search',	1),
('use',	24,	'en',	'help_search',	0.876337),
('use',	25,	'en',	'help_search',	1),
('use',	27,	'en',	'help_search',	1.98902),
('use',	30,	'en',	'help_search',	18.4099),
('use',	32,	'en',	'help_search',	2),
('use',	33,	'en',	'help_search',	1),
('use',	34,	'en',	'help_search',	6),
('use',	38,	'en',	'help_search',	3),
('use',	44,	'en',	'help_search',	2),
('use',	50,	'en',	'help_search',	3.73884),
('use',	55,	'en',	'help_search',	2),
('use',	57,	'en',	'help_search',	1.96109),
('use',	64,	'en',	'help_search',	9),
('use',	66,	'en',	'help_search',	1),
('use',	67,	'en',	'help_search',	1),
('use',	71,	'en',	'help_search',	2.99731),
('use',	80,	'en',	'help_search',	1),
('use',	81,	'en',	'help_search',	5),
('use',	86,	'en',	'help_search',	5),
('use',	87,	'en',	'help_search',	2),
('used',	10,	'en',	'help_search',	1),
('used',	11,	'en',	'help_search',	0.976851),
('used',	12,	'en',	'help_search',	1),
('used',	15,	'en',	'help_search',	1),
('used',	17,	'en',	'help_search',	1),
('used',	21,	'en',	'help_search',	1),
('used',	38,	'en',	'help_search',	1),
('used',	39,	'en',	'help_search',	3),
('used',	42,	'en',	'help_search',	1),
('used',	50,	'en',	'help_search',	2),
('used',	57,	'en',	'help_search',	1.99731),
('used',	65,	'en',	'help_search',	1),
('used',	66,	'en',	'help_search',	1),
('used',	67,	'en',	'help_search',	1),
('used',	68,	'en',	'help_search',	1),
('used',	71,	'en',	'help_search',	2),
('used',	72,	'en',	'help_search',	3),
('used',	76,	'en',	'help_search',	1),
('useful',	50,	'en',	'help_search',	1),
('user',	6,	'en',	'help_search',	19),
('user',	8,	'en',	'help_search',	4),
('user',	10,	'en',	'help_search',	10.1622),
('user',	11,	'en',	'help_search',	22.0204),
('user',	12,	'en',	'help_search',	27.3552),
('user',	13,	'en',	'help_search',	21.0175),
('user',	14,	'en',	'help_search',	22),
('user',	15,	'en',	'help_search',	22),
('user',	16,	'en',	'help_search',	2),
('user',	17,	'en',	'help_search',	12),
('user',	18,	'en',	'help_search',	1),
('user',	19,	'en',	'help_search',	11),
('user',	22,	'en',	'help_search',	2),
('user',	23,	'en',	'help_search',	1),
('user',	24,	'en',	'help_search',	0.916736),
('user',	25,	'en',	'help_search',	2),
('user',	27,	'en',	'help_search',	1),
('user',	30,	'en',	'help_search',	8.33564),
('user',	31,	'en',	'help_search',	11),
('user',	33,	'en',	'help_search',	3),
('user',	34,	'en',	'help_search',	4),
('user',	37,	'en',	'help_search',	11),
('user',	40,	'en',	'help_search',	43),
('user',	42,	'en',	'help_search',	69),
('user',	44,	'en',	'help_search',	57.974),
('user',	45,	'en',	'help_search',	33),
('user',	48,	'en',	'help_search',	11),
('user',	53,	'en',	'help_search',	22.8038),
('user',	54,	'en',	'help_search',	22),
('user',	55,	'en',	'help_search',	21.7671),
('user',	57,	'en',	'help_search',	1),
('user',	58,	'en',	'help_search',	2.92384),
('user',	69,	'en',	'help_search',	28),
('user',	70,	'en',	'help_search',	11),
('user',	71,	'en',	'help_search',	11.6063),
('user',	73,	'en',	'help_search',	11.2515),
('user',	75,	'en',	'help_search',	1),
('user',	78,	'en',	'help_search',	11),
('user',	80,	'en',	'help_search',	13),
('user',	81,	'en',	'help_search',	1),
('user',	85,	'en',	'help_search',	10.5295),
('userdefined',	11,	'en',	'help_search',	1),
('userinterface',	22,	'en',	'help_search',	1),
('username',	40,	'en',	'help_search',	4),
('users',	5,	'en',	'help_search',	1),
('users',	6,	'en',	'help_search',	6),
('users',	8,	'en',	'help_search',	4),
('users',	12,	'en',	'help_search',	1.87313),
('users',	18,	'en',	'help_search',	4.86555),
('users',	21,	'en',	'help_search',	2),
('users',	23,	'en',	'help_search',	7),
('users',	24,	'en',	'help_search',	1),
('users',	26,	'en',	'help_search',	1),
('users',	27,	'en',	'help_search',	20.9729),
('users',	29,	'en',	'help_search',	1),
('users',	30,	'en',	'help_search',	6.53343),
('users',	34,	'en',	'help_search',	1),
('users',	42,	'en',	'help_search',	8),
('users',	44,	'en',	'help_search',	8),
('users',	46,	'en',	'help_search',	1),
('users',	50,	'en',	'help_search',	3.77902),
('users',	53,	'en',	'help_search',	3),
('users',	54,	'en',	'help_search',	1),
('users',	55,	'en',	'help_search',	2),
('users',	64,	'en',	'help_search',	2),
('users',	70,	'en',	'help_search',	1),
('users',	71,	'en',	'help_search',	2),
('users',	73,	'en',	'help_search',	3.85439),
('users',	78,	'en',	'help_search',	1),
('users',	79,	'en',	'help_search',	1),
('users',	80,	'en',	'help_search',	1),
('users',	81,	'en',	'help_search',	4),
('uses',	19,	'en',	'help_search',	1),
('uses',	29,	'en',	'help_search',	1),
('using',	2,	'en',	'help_search',	1),
('using',	8,	'en',	'help_search',	20),
('using',	11,	'en',	'help_search',	9.24453),
('using',	14,	'en',	'help_search',	2),
('using',	16,	'en',	'help_search',	1.99731),
('using',	20,	'en',	'help_search',	26),
('using',	24,	'en',	'help_search',	28.8828),
('using',	25,	'en',	'help_search',	5),
('using',	27,	'en',	'help_search',	1),
('using',	30,	'en',	'help_search',	0.873132),
('using',	36,	'en',	'help_search',	1),
('using',	38,	'en',	'help_search',	1),
('using',	42,	'en',	'help_search',	1),
('using',	64,	'en',	'help_search',	26),
('using',	69,	'en',	'help_search',	19),
('using',	73,	'en',	'help_search',	0.860547),
('using',	81,	'en',	'help_search',	26),
('using',	82,	'en',	'help_search',	1),
('using',	85,	'en',	'help_search',	1),
('using',	86,	'en',	'help_search',	10.7595),
('usually',	68,	'en',	'help_search',	1),
('uuid',	11,	'en',	'help_search',	5.2071),
('valid',	18,	'en',	'help_search',	1),
('valid',	58,	'en',	'help_search',	1),
('value',	11,	'en',	'help_search',	0.714225),
('value',	12,	'en',	'help_search',	0.784336),
('value',	65,	'en',	'help_search',	4),
('value',	68,	'en',	'help_search',	4),
('value',	79,	'en',	'help_search',	1),
('value',	85,	'en',	'help_search',	2),
('values',	12,	'en',	'help_search',	6.37799),
('values',	33,	'en',	'help_search',	1),
('values',	45,	'en',	'help_search',	1),
('values',	55,	'en',	'help_search',	3),
('values',	65,	'en',	'help_search',	6),
('values',	68,	'en',	'help_search',	6),
('variables',	44,	'en',	'help_search',	25),
('variations',	12,	'en',	'help_search',	1),
('various',	24,	'en',	'help_search',	0.927431),
('various',	58,	'en',	'help_search',	1),
('vary',	47,	'en',	'help_search',	1),
('vary',	65,	'en',	'help_search',	1),
('vary',	83,	'en',	'help_search',	1),
('vegetables',	71,	'en',	'help_search',	1),
('verification',	44,	'en',	'help_search',	2),
('verified',	85,	'en',	'help_search',	1),
('verify',	6,	'en',	'help_search',	1),
('verify',	26,	'en',	'help_search',	4),
('verify',	28,	'en',	'help_search',	1),
('verify',	29,	'en',	'help_search',	0.896076),
('verify',	30,	'en',	'help_search',	0.860547),
('verify',	36,	'en',	'help_search',	1),
('verify',	38,	'en',	'help_search',	2),
('verify',	40,	'en',	'help_search',	1),
('verify',	44,	'en',	'help_search',	0.98493),
('verify',	50,	'en',	'help_search',	0.797402),
('verify',	68,	'en',	'help_search',	1),
('verify',	75,	'en',	'help_search',	1),
('verify',	78,	'en',	'help_search',	1),
('verify',	81,	'en',	'help_search',	0.997306),
('verify',	83,	'en',	'help_search',	1),
('verify',	85,	'en',	'help_search',	1),
('verify',	86,	'en',	'help_search',	0.902857),
('versatile',	16,	'en',	'help_search',	1),
('versions',	11,	'en',	'help_search',	0.896076),
('vertical',	54,	'en',	'help_search',	1),
('very',	12,	'en',	'help_search',	1.6956),
('very',	30,	'en',	'help_search',	1),
('via',	25,	'en',	'help_search',	1),
('videos',	16,	'en',	'help_search',	1),
('view',	6,	'en',	'help_search',	6),
('view',	7,	'en',	'help_search',	1),
('view',	11,	'en',	'help_search',	1),
('view',	27,	'en',	'help_search',	0.96498),
('view',	30,	'en',	'help_search',	7.26433),
('view',	46,	'en',	'help_search',	5),
('view',	64,	'en',	'help_search',	2),
('view',	69,	'en',	'help_search',	2),
('view',	73,	'en',	'help_search',	51.209),
('view',	81,	'en',	'help_search',	2),
('view',	82,	'en',	'help_search',	32),
('view',	83,	'en',	'help_search',	33.9849),
('view',	84,	'en',	'help_search',	42),
('view',	85,	'en',	'help_search',	29),
('view',	86,	'en',	'help_search',	1),
('viewed',	8,	'en',	'help_search',	1),
('viewed',	21,	'en',	'help_search',	1),
('viewed',	27,	'en',	'help_search',	1),
('viewer',	8,	'en',	'help_search',	1),
('viewing',	8,	'en',	'help_search',	1),
('viewing',	27,	'en',	'help_search',	1),
('viewing',	42,	'en',	'help_search',	2),
('viewing',	46,	'en',	'help_search',	26),
('viewing',	66,	'en',	'help_search',	1),
('viewport',	57,	'en',	'help_search',	2),
('viewports',	57,	'en',	'help_search',	1),
('views',	11,	'en',	'help_search',	1),
('views',	21,	'en',	'help_search',	1),
('views',	69,	'en',	'help_search',	1),
('views',	73,	'en',	'help_search',	54.628),
('views',	82,	'en',	'help_search',	4),
('views',	83,	'en',	'help_search',	29),
('views',	84,	'en',	'help_search',	4),
('views',	85,	'en',	'help_search',	15.572),
('visibility',	22,	'en',	'help_search',	2),
('visibility',	26,	'en',	'help_search',	4),
('visibility',	47,	'en',	'help_search',	4),
('visible',	12,	'en',	'help_search',	1),
('visible',	26,	'en',	'help_search',	2),
('visible',	58,	'en',	'help_search',	0.851346),
('visible',	64,	'en',	'help_search',	2.99731),
('visible',	65,	'en',	'help_search',	1),
('visible',	66,	'en',	'help_search',	1),
('visible',	68,	'en',	'help_search',	1),
('visit',	13,	'en',	'help_search',	3),
('visit',	20,	'en',	'help_search',	1),
('visit',	30,	'en',	'help_search',	1),
('visit',	33,	'en',	'help_search',	1),
('visit',	38,	'en',	'help_search',	1),
('visit',	53,	'en',	'help_search',	1),
('visit',	64,	'en',	'help_search',	1.98902),
('visit',	80,	'en',	'help_search',	1),
('visited',	69,	'en',	'help_search',	28),
('visited',	78,	'en',	'help_search',	1),
('visiting',	24,	'en',	'help_search',	1),
('visitors',	8,	'en',	'help_search',	1),
('visitors',	12,	'en',	'help_search',	2),
('visitors',	30,	'en',	'help_search',	0.842342),
('visitors',	34,	'en',	'help_search',	1),
('visitors',	42,	'en',	'help_search',	46),
('visitors',	48,	'en',	'help_search',	1),
('visitors',	80,	'en',	'help_search',	1),
('visits',	33,	'en',	'help_search',	1),
('visits',	69,	'en',	'help_search',	19),
('visual',	10,	'en',	'help_search',	2),
('visual',	16,	'en',	'help_search',	1),
('visual',	50,	'en',	'help_search',	1),
('visual',	58,	'en',	'help_search',	4),
('visually',	66,	'en',	'help_search',	4),
('vocabularies',	70,	'en',	'help_search',	4),
('vocabularies',	71,	'en',	'help_search',	1.9347),
('vocabulary',	70,	'en',	'help_search',	35),
('vocabulary',	71,	'en',	'help_search',	6),
('w3c',	57,	'en',	'help_search',	10.3222),
('wait',	13,	'en',	'help_search',	1),
('wait',	35,	'en',	'help_search',	1),
('wait',	36,	'en',	'help_search',	1),
('wait',	38,	'en',	'help_search',	1),
('waiting',	29,	'en',	'help_search',	0.902857),
('walk',	30,	'en',	'help_search',	1.90318),
('walked',	30,	'en',	'help_search',	0.938382),
('walking',	30,	'en',	'help_search',	0.942091),
('want',	2,	'en',	'help_search',	1),
('want',	3,	'en',	'help_search',	1),
('want',	4,	'en',	'help_search',	2),
('want',	5,	'en',	'help_search',	2),
('want',	6,	'en',	'help_search',	1),
('want',	7,	'en',	'help_search',	1),
('want',	9,	'en',	'help_search',	1),
('want',	13,	'en',	'help_search',	1),
('want',	20,	'en',	'help_search',	2),
('want',	28,	'en',	'help_search',	1),
('want',	32,	'en',	'help_search',	2),
('want',	35,	'en',	'help_search',	2),
('want',	36,	'en',	'help_search',	1),
('want',	38,	'en',	'help_search',	3),
('want',	39,	'en',	'help_search',	1),
('want',	40,	'en',	'help_search',	1),
('want',	44,	'en',	'help_search',	1.99731),
('want',	45,	'en',	'help_search',	2),
('want',	47,	'en',	'help_search',	4),
('want',	49,	'en',	'help_search',	3),
('want',	50,	'en',	'help_search',	0.842342),
('want',	51,	'en',	'help_search',	1),
('want',	53,	'en',	'help_search',	1),
('want',	54,	'en',	'help_search',	1),
('want',	64,	'en',	'help_search',	1),
('want',	65,	'en',	'help_search',	3),
('want',	66,	'en',	'help_search',	3),
('want',	67,	'en',	'help_search',	2),
('want',	68,	'en',	'help_search',	6),
('want',	70,	'en',	'help_search',	1),
('want',	74,	'en',	'help_search',	2),
('want',	77,	'en',	'help_search',	1),
('want',	81,	'en',	'help_search',	1),
('want',	82,	'en',	'help_search',	2),
('want',	83,	'en',	'help_search',	1),
('want',	85,	'en',	'help_search',	3.98902),
('want',	86,	'en',	'help_search',	2.97286),
('want',	87,	'en',	'help_search',	2),
('warning',	43,	'en',	'help_search',	4),
('warnings',	37,	'en',	'help_search',	1),
('was',	3,	'en',	'help_search',	1),
('was',	4,	'en',	'help_search',	1),
('was',	32,	'en',	'help_search',	1),
('was',	36,	'en',	'help_search',	1),
('was',	39,	'en',	'help_search',	1),
('was',	47,	'en',	'help_search',	1),
('was',	69,	'en',	'help_search',	1),
('way',	10,	'en',	'help_search',	1),
('way',	12,	'en',	'help_search',	1.32634),
('way',	13,	'en',	'help_search',	2),
('way',	18,	'en',	'help_search',	0.942091),
('way',	25,	'en',	'help_search',	1),
('way',	50,	'en',	'help_search',	1),
('way',	57,	'en',	'help_search',	1),
('way',	73,	'en',	'help_search',	0.886095),
('ways',	11,	'en',	'help_search',	1),
('ways',	12,	'en',	'help_search',	1),
('ways',	71,	'en',	'help_search',	1),
('web',	13,	'en',	'help_search',	2),
('web',	17,	'en',	'help_search',	1),
('web',	25,	'en',	'help_search',	93),
('web',	33,	'en',	'help_search',	3),
('web',	48,	'en',	'help_search',	1),
('web',	56,	'en',	'help_search',	1),
('web',	80,	'en',	'help_search',	2),
('website',	6,	'en',	'help_search',	1),
('website',	12,	'en',	'help_search',	1),
('website',	21,	'en',	'help_search',	26),
('website',	44,	'en',	'help_search',	2),
('website',	71,	'en',	'help_search',	3),
('website',	80,	'en',	'help_search',	1),
('week',	13,	'en',	'help_search',	1),
('weekly',	13,	'en',	'help_search',	1),
('weights',	23,	'en',	'help_search',	5),
('well',	13,	'en',	'help_search',	2),
('well',	18,	'en',	'help_search',	0.860547),
('well',	20,	'en',	'help_search',	1),
('well',	65,	'en',	'help_search',	1),
('well',	81,	'en',	'help_search',	1),
('went',	31,	'en',	'help_search',	1),
('were',	32,	'en',	'help_search',	2),
('were',	33,	'en',	'help_search',	1.84528),
('were',	35,	'en',	'help_search',	2),
('were',	44,	'en',	'help_search',	0.953396),
('wget',	13,	'en',	'help_search',	4),
('what',	5,	'en',	'help_search',	19),
('what',	8,	'en',	'help_search',	19),
('what',	10,	'en',	'help_search',	57),
('what',	11,	'en',	'help_search',	74.418),
('what',	12,	'en',	'help_search',	146.382),
('what',	13,	'en',	'help_search',	38),
('what',	14,	'en',	'help_search',	57),
('what',	16,	'en',	'help_search',	57),
('what',	17,	'en',	'help_search',	19),
('what',	18,	'en',	'help_search',	76),
('what',	19,	'en',	'help_search',	38),
('what',	20,	'en',	'help_search',	19),
('what',	22,	'en',	'help_search',	19),
('what',	24,	'en',	'help_search',	38),
('what',	25,	'en',	'help_search',	76),
('what',	27,	'en',	'help_search',	19),
('what',	29,	'en',	'help_search',	19),
('what',	30,	'en',	'help_search',	74.7594),
('what',	31,	'en',	'help_search',	19),
('what',	32,	'en',	'help_search',	1),
('what',	33,	'en',	'help_search',	39),
('what',	34,	'en',	'help_search',	19),
('what',	42,	'en',	'help_search',	57),
('what',	44,	'en',	'help_search',	39.989),
('what',	45,	'en',	'help_search',	1),
('what',	46,	'en',	'help_search',	19),
('what',	48,	'en',	'help_search',	76),
('what',	50,	'en',	'help_search',	38),
('what',	56,	'en',	'help_search',	38),
('what',	57,	'en',	'help_search',	76),
('what',	58,	'en',	'help_search',	27.8995),
('what',	64,	'en',	'help_search',	19),
('what',	65,	'en',	'help_search',	1),
('what',	69,	'en',	'help_search',	38),
('what',	71,	'en',	'help_search',	19),
('what',	73,	'en',	'help_search',	58.4225),
('what',	80,	'en',	'help_search',	57),
('what',	81,	'en',	'help_search',	19),
('what',	85,	'en',	'help_search',	1),
('what',	86,	'en',	'help_search',	19.8927),
('when',	8,	'en',	'help_search',	1),
('when',	11,	'en',	'help_search',	5.92719),
('when',	12,	'en',	'help_search',	1.6112),
('when',	15,	'en',	'help_search',	1),
('when',	18,	'en',	'help_search',	2.9496),
('when',	19,	'en',	'help_search',	1),
('when',	23,	'en',	'help_search',	1),
('when',	26,	'en',	'help_search',	1),
('when',	27,	'en',	'help_search',	3),
('when',	29,	'en',	'help_search',	3),
('when',	30,	'en',	'help_search',	1.8861),
('when',	31,	'en',	'help_search',	4),
('when',	33,	'en',	'help_search',	2),
('when',	34,	'en',	'help_search',	6),
('when',	36,	'en',	'help_search',	1),
('when',	44,	'en',	'help_search',	3),
('when',	47,	'en',	'help_search',	1),
('when',	48,	'en',	'help_search',	1),
('when',	50,	'en',	'help_search',	2),
('when',	53,	'en',	'help_search',	1),
('when',	57,	'en',	'help_search',	3),
('when',	58,	'en',	'help_search',	1.98902),
('when',	65,	'en',	'help_search',	1),
('when',	66,	'en',	'help_search',	1),
('when',	67,	'en',	'help_search',	1),
('when',	68,	'en',	'help_search',	1),
('when',	69,	'en',	'help_search',	1),
('when',	71,	'en',	'help_search',	2),
('when',	73,	'en',	'help_search',	1),
('when',	74,	'en',	'help_search',	1),
('when',	75,	'en',	'help_search',	3),
('when',	81,	'en',	'help_search',	1),
('when',	85,	'en',	'help_search',	2),
('when',	86,	'en',	'help_search',	0.833529),
('whenever',	26,	'en',	'help_search',	1),
('where',	10,	'en',	'help_search',	1),
('where',	12,	'en',	'help_search',	0.813674),
('where',	13,	'en',	'help_search',	1),
('where',	27,	'en',	'help_search',	19),
('where',	44,	'en',	'help_search',	1),
('where',	47,	'en',	'help_search',	2),
('where',	49,	'en',	'help_search',	1),
('where',	73,	'en',	'help_search',	1),
('whether',	12,	'en',	'help_search',	1),
('whether',	73,	'en',	'help_search',	2),
('which',	6,	'en',	'help_search',	2),
('which',	8,	'en',	'help_search',	3),
('which',	10,	'en',	'help_search',	1),
('which',	11,	'en',	'help_search',	2.64632),
('which',	12,	'en',	'help_search',	5.65326),
('which',	13,	'en',	'help_search',	1),
('which',	16,	'en',	'help_search',	1),
('which',	18,	'en',	'help_search',	1),
('which',	24,	'en',	'help_search',	3),
('which',	27,	'en',	'help_search',	1),
('which',	29,	'en',	'help_search',	1),
('which',	30,	'en',	'help_search',	1.9689),
('which',	36,	'en',	'help_search',	1),
('which',	37,	'en',	'help_search',	1),
('which',	38,	'en',	'help_search',	1),
('which',	42,	'en',	'help_search',	1),
('which',	48,	'en',	'help_search',	1),
('which',	50,	'en',	'help_search',	1.78178),
('which',	51,	'en',	'help_search',	1),
('which',	53,	'en',	'help_search',	1),
('which',	54,	'en',	'help_search',	1),
('which',	56,	'en',	'help_search',	2),
('which',	57,	'en',	'help_search',	2),
('which',	58,	'en',	'help_search',	2),
('which',	64,	'en',	'help_search',	1),
('which',	65,	'en',	'help_search',	2),
('which',	68,	'en',	'help_search',	1),
('which',	69,	'en',	'help_search',	28),
('which',	70,	'en',	'help_search',	1),
('which',	71,	'en',	'help_search',	1),
('which',	72,	'en',	'help_search',	1),
('which',	73,	'en',	'help_search',	3.85439),
('which',	75,	'en',	'help_search',	1),
('which',	76,	'en',	'help_search',	3),
('which',	80,	'en',	'help_search',	3),
('which',	81,	'en',	'help_search',	2),
('which',	83,	'en',	'help_search',	1),
('which',	84,	'en',	'help_search',	1),
('which',	86,	'en',	'help_search',	1),
('while',	12,	'en',	'help_search',	2.22095),
('while',	17,	'en',	'help_search',	1),
('while',	28,	'en',	'help_search',	1),
('while',	64,	'en',	'help_search',	1),
('while',	71,	'en',	'help_search',	1),
('white',	33,	'en',	'help_search',	4),
('who',	18,	'en',	'help_search',	1),
('who',	20,	'en',	'help_search',	19),
('who',	34,	'en',	'help_search',	1),
('who',	42,	'en',	'help_search',	3),
('who',	46,	'en',	'help_search',	19),
('who',	50,	'en',	'help_search',	1),
('who',	53,	'en',	'help_search',	19),
('who',	54,	'en',	'help_search',	19),
('who',	55,	'en',	'help_search',	19),
('who',	70,	'en',	'help_search',	19),
('who',	73,	'en',	'help_search',	0.879565),
('who',	78,	'en',	'help_search',	19),
('who',	79,	'en',	'help_search',	19),
('who',	83,	'en',	'help_search',	20),
('whose',	8,	'en',	'help_search',	1),
('whose',	48,	'en',	'help_search',	1),
('whose',	80,	'en',	'help_search',	1),
('whose',	85,	'en',	'help_search',	1),
('why',	35,	'en',	'help_search',	1),
('widelyused',	58,	'en',	'help_search',	1),
('widget',	12,	'en',	'help_search',	17.5931),
('widget',	16,	'en',	'help_search',	4),
('widget',	67,	'en',	'help_search',	7),
('widgets',	67,	'en',	'help_search',	5),
('width',	16,	'en',	'help_search',	1),
('width',	57,	'en',	'help_search',	30),
('width',	72,	'en',	'help_search',	4),
('width',	86,	'en',	'help_search',	0.942091),
('widths',	57,	'en',	'help_search',	2),
('will',	3,	'en',	'help_search',	2),
('will',	5,	'en',	'help_search',	1),
('will',	6,	'en',	'help_search',	1),
('will',	7,	'en',	'help_search',	1),
('will',	8,	'en',	'help_search',	1),
('will',	11,	'en',	'help_search',	1.67852),
('will',	12,	'en',	'help_search',	0.584241),
('will',	13,	'en',	'help_search',	2),
('will',	18,	'en',	'help_search',	1.86679),
('will',	19,	'en',	'help_search',	1),
('will',	20,	'en',	'help_search',	2),
('will',	24,	'en',	'help_search',	1),
('will',	27,	'en',	'help_search',	2.96109),
('will',	28,	'en',	'help_search',	2),
('will',	29,	'en',	'help_search',	3),
('will',	30,	'en',	'help_search',	5.57006),
('will',	31,	'en',	'help_search',	1),
('will',	33,	'en',	'help_search',	1),
('will',	34,	'en',	'help_search',	5),
('will',	37,	'en',	'help_search',	1),
('will',	40,	'en',	'help_search',	1),
('will',	42,	'en',	'help_search',	1),
('will',	46,	'en',	'help_search',	1),
('will',	47,	'en',	'help_search',	1),
('will',	49,	'en',	'help_search',	2),
('will',	50,	'en',	'help_search',	1.72016),
('will',	52,	'en',	'help_search',	1),
('will',	53,	'en',	'help_search',	2),
('will',	54,	'en',	'help_search',	4),
('will',	57,	'en',	'help_search',	1),
('will',	58,	'en',	'help_search',	2.68852),
('will',	64,	'en',	'help_search',	2),
('will',	66,	'en',	'help_search',	1),
('will',	68,	'en',	'help_search',	2),
('will',	70,	'en',	'help_search',	6),
('will',	71,	'en',	'help_search',	0.989021),
('will',	73,	'en',	'help_search',	1),
('will',	74,	'en',	'help_search',	1),
('will',	75,	'en',	'help_search',	3),
('will',	76,	'en',	'help_search',	1),
('will',	78,	'en',	'help_search',	1),
('will',	79,	'en',	'help_search',	2),
('will',	80,	'en',	'help_search',	1),
('will',	81,	'en',	'help_search',	1),
('will',	82,	'en',	'help_search',	3),
('will',	83,	'en',	'help_search',	4.98224),
('will',	84,	'en',	'help_search',	2),
('will',	86,	'en',	'help_search',	7.53562),
('will',	87,	'en',	'help_search',	1),
('wish',	30,	'en',	'help_search',	0.816452),
('wish',	66,	'en',	'help_search',	1),
('wish',	67,	'en',	'help_search',	1),
('with',	7,	'en',	'help_search',	1),
('with',	8,	'en',	'help_search',	1),
('with',	10,	'en',	'help_search',	1),
('with',	11,	'en',	'help_search',	0.757065),
('with',	12,	'en',	'help_search',	8.7836),
('with',	15,	'en',	'help_search',	1),
('with',	16,	'en',	'help_search',	2),
('with',	18,	'en',	'help_search',	1.88882),
('with',	19,	'en',	'help_search',	1),
('with',	20,	'en',	'help_search',	1),
('with',	22,	'en',	'help_search',	45),
('with',	23,	'en',	'help_search',	3),
('with',	24,	'en',	'help_search',	2),
('with',	25,	'en',	'help_search',	1),
('with',	27,	'en',	'help_search',	26.9729),
('with',	29,	'en',	'help_search',	1),
('with',	30,	'en',	'help_search',	3.83051),
('with',	34,	'en',	'help_search',	1),
('with',	35,	'en',	'help_search',	2),
('with',	36,	'en',	'help_search',	1),
('with',	42,	'en',	'help_search',	1),
('with',	43,	'en',	'help_search',	1),
('with',	44,	'en',	'help_search',	2),
('with',	46,	'en',	'help_search',	1),
('with',	50,	'en',	'help_search',	1),
('with',	53,	'en',	'help_search',	2),
('with',	54,	'en',	'help_search',	1),
('with',	55,	'en',	'help_search',	2),
('with',	57,	'en',	'help_search',	12.363),
('with',	64,	'en',	'help_search',	3),
('with',	65,	'en',	'help_search',	1),
('with',	68,	'en',	'help_search',	1),
('with',	70,	'en',	'help_search',	1),
('with',	71,	'en',	'help_search',	1.9381),
('with',	73,	'en',	'help_search',	10.3981),
('with',	78,	'en',	'help_search',	3),
('with',	79,	'en',	'help_search',	1),
('with',	80,	'en',	'help_search',	1),
('with',	81,	'en',	'help_search',	1),
('with',	83,	'en',	'help_search',	3),
('with',	85,	'en',	'help_search',	10.6148),
('with',	86,	'en',	'help_search',	4.64564),
('with',	87,	'en',	'help_search',	1),
('within',	11,	'en',	'help_search',	1),
('within',	12,	'en',	'help_search',	2),
('within',	27,	'en',	'help_search',	1),
('within',	47,	'en',	'help_search',	1),
('within',	50,	'en',	'help_search',	0.997306),
('within',	58,	'en',	'help_search',	0.896076),
('within',	86,	'en',	'help_search',	0.842342),
('without',	8,	'en',	'help_search',	1),
('without',	44,	'en',	'help_search',	1),
('without',	64,	'en',	'help_search',	2),
('without',	75,	'en',	'help_search',	1),
('word',	29,	'en',	'help_search',	4),
('word',	30,	'en',	'help_search',	0.96498),
('word',	35,	'en',	'help_search',	1),
('word',	36,	'en',	'help_search',	1),
('word',	55,	'en',	'help_search',	1),
('words',	29,	'en',	'help_search',	2),
('words',	30,	'en',	'help_search',	0.945829),
('work',	55,	'en',	'help_search',	0.976851),
('work',	83,	'en',	'help_search',	1),
('workflow',	11,	'en',	'help_search',	7.45733),
('working',	11,	'en',	'help_search',	1),
('working',	22,	'en',	'help_search',	45),
('working',	27,	'en',	'help_search',	26),
('working',	57,	'en',	'help_search',	10.4041),
('would',	14,	'en',	'help_search',	1),
('would',	20,	'en',	'help_search',	1),
('would',	30,	'en',	'help_search',	0.957226),
('would',	31,	'en',	'help_search',	1),
('would',	33,	'en',	'help_search',	0.972861),
('would',	36,	'en',	'help_search',	2),
('would',	53,	'en',	'help_search',	1),
('would',	55,	'en',	'help_search',	1),
('would',	57,	'en',	'help_search',	1),
('would',	64,	'en',	'help_search',	3),
('would',	79,	'en',	'help_search',	1),
('would',	80,	'en',	'help_search',	1),
('would',	83,	'en',	'help_search',	1),
('wraps',	10,	'en',	'help_search',	1),
('write',	11,	'en',	'help_search',	0.707906),
('writing',	27,	'en',	'help_search',	1),
('written',	22,	'en',	'help_search',	1),
('written',	57,	'en',	'help_search',	1),
('wwwexamplecom',	80,	'en',	'help_search',	4),
('wysiwyg',	58,	'en',	'help_search',	4),
('xml',	25,	'en',	'help_search',	1),
('yaml',	1,	'en',	'help_search',	1),
('yaml',	4,	'en',	'help_search',	1),
('yaml',	11,	'en',	'help_search',	3.56669),
('yaml',	27,	'en',	'help_search',	1),
('yaml',	57,	'en',	'help_search',	0.968904),
('yamlformat',	4,	'en',	'help_search',	1),
('yet',	14,	'en',	'help_search',	1),
('yet',	21,	'en',	'help_search',	1),
('yml',	11,	'en',	'help_search',	0.993146),
('you',	2,	'en',	'help_search',	1),
('you',	3,	'en',	'help_search',	2),
('you',	4,	'en',	'help_search',	2),
('you',	5,	'en',	'help_search',	4),
('you',	6,	'en',	'help_search',	1),
('you',	7,	'en',	'help_search',	2),
('you',	8,	'en',	'help_search',	1),
('you',	9,	'en',	'help_search',	1),
('you',	10,	'en',	'help_search',	1.97685),
('you',	12,	'en',	'help_search',	6.57496),
('you',	13,	'en',	'help_search',	10.9946),
('you',	14,	'en',	'help_search',	3),
('you',	15,	'en',	'help_search',	1),
('you',	16,	'en',	'help_search',	1),
('you',	18,	'en',	'help_search',	1.74636),
('you',	19,	'en',	'help_search',	1),
('you',	20,	'en',	'help_search',	5),
('you',	21,	'en',	'help_search',	1),
('you',	22,	'en',	'help_search',	5),
('you',	23,	'en',	'help_search',	1),
('you',	24,	'en',	'help_search',	3),
('you',	26,	'en',	'help_search',	1),
('you',	27,	'en',	'help_search',	1.98902),
('you',	28,	'en',	'help_search',	3),
('you',	29,	'en',	'help_search',	2.83423),
('you',	30,	'en',	'help_search',	6.3893),
('you',	31,	'en',	'help_search',	1),
('you',	32,	'en',	'help_search',	5),
('you',	33,	'en',	'help_search',	6.74314),
('you',	35,	'en',	'help_search',	8),
('you',	36,	'en',	'help_search',	6),
('you',	37,	'en',	'help_search',	5),
('you',	38,	'en',	'help_search',	7),
('you',	39,	'en',	'help_search',	1),
('you',	40,	'en',	'help_search',	3),
('you',	41,	'en',	'help_search',	1),
('you',	42,	'en',	'help_search',	2),
('you',	44,	'en',	'help_search',	7.96229),
('you',	45,	'en',	'help_search',	3),
('you',	46,	'en',	'help_search',	2),
('you',	47,	'en',	'help_search',	6),
('you',	48,	'en',	'help_search',	4),
('you',	49,	'en',	'help_search',	3),
('you',	50,	'en',	'help_search',	4.18461),
('you',	51,	'en',	'help_search',	2),
('you',	52,	'en',	'help_search',	1),
('you',	53,	'en',	'help_search',	3),
('you',	54,	'en',	'help_search',	5),
('you',	55,	'en',	'help_search',	1),
('you',	56,	'en',	'help_search',	3),
('you',	57,	'en',	'help_search',	0.972861),
('you',	58,	'en',	'help_search',	12.7711),
('you',	64,	'en',	'help_search',	4.91448),
('you',	65,	'en',	'help_search',	8),
('you',	66,	'en',	'help_search',	6),
('you',	67,	'en',	'help_search',	4),
('you',	68,	'en',	'help_search',	11),
('you',	69,	'en',	'help_search',	1),
('you',	70,	'en',	'help_search',	10),
('you',	71,	'en',	'help_search',	6.9394),
('you',	73,	'en',	'help_search',	8.4838),
('you',	74,	'en',	'help_search',	2),
('you',	75,	'en',	'help_search',	3),
('you',	76,	'en',	'help_search',	1),
('you',	77,	'en',	'help_search',	1),
('you',	78,	'en',	'help_search',	2),
('you',	79,	'en',	'help_search',	3),
('you',	80,	'en',	'help_search',	5),
('you',	81,	'en',	'help_search',	2),
('you',	82,	'en',	'help_search',	5),
('you',	83,	'en',	'help_search',	4),
('you',	85,	'en',	'help_search',	6.99731),
('you',	86,	'en',	'help_search',	13.2694),
('you',	87,	'en',	'help_search',	5),
('your',	1,	'en',	'help_search',	27),
('your',	2,	'en',	'help_search',	6),
('your',	3,	'en',	'help_search',	30),
('your',	4,	'en',	'help_search',	5),
('your',	6,	'en',	'help_search',	1),
('your',	7,	'en',	'help_search',	1),
('your',	8,	'en',	'help_search',	1),
('your',	10,	'en',	'help_search',	42.1676),
('your',	11,	'en',	'help_search',	1),
('your',	12,	'en',	'help_search',	8.53008),
('your',	13,	'en',	'help_search',	9),
('your',	14,	'en',	'help_search',	39),
('your',	15,	'en',	'help_search',	32),
('your',	16,	'en',	'help_search',	2),
('your',	18,	'en',	'help_search',	1.98902),
('your',	19,	'en',	'help_search',	29),
('your',	20,	'en',	'help_search',	3),
('your',	21,	'en',	'help_search',	27),
('your',	22,	'en',	'help_search',	22),
('your',	24,	'en',	'help_search',	3),
('your',	25,	'en',	'help_search',	1),
('your',	26,	'en',	'help_search',	2),
('your',	27,	'en',	'help_search',	1),
('your',	28,	'en',	'help_search',	1),
('your',	29,	'en',	'help_search',	2),
('your',	30,	'en',	'help_search',	1.80822),
('your',	31,	'en',	'help_search',	4),
('your',	32,	'en',	'help_search',	4),
('your',	33,	'en',	'help_search',	5.96178),
('your',	34,	'en',	'help_search',	5),
('your',	35,	'en',	'help_search',	2),
('your',	36,	'en',	'help_search',	1),
('your',	37,	'en',	'help_search',	32),
('your',	38,	'en',	'help_search',	3),
('your',	41,	'en',	'help_search',	1),
('your',	42,	'en',	'help_search',	2),
('your',	44,	'en',	'help_search',	4.99731),
('your',	47,	'en',	'help_search',	1),
('your',	48,	'en',	'help_search',	2),
('your',	51,	'en',	'help_search',	3),
('your',	52,	'en',	'help_search',	3),
('your',	53,	'en',	'help_search',	2),
('your',	54,	'en',	'help_search',	1),
('your',	56,	'en',	'help_search',	1),
('your',	57,	'en',	'help_search',	1),
('your',	58,	'en',	'help_search',	2),
('your',	64,	'en',	'help_search',	4.95373),
('your',	65,	'en',	'help_search',	1),
('your',	66,	'en',	'help_search',	2),
('your',	67,	'en',	'help_search',	2),
('your',	68,	'en',	'help_search',	0.997306),
('your',	70,	'en',	'help_search',	2),
('your',	71,	'en',	'help_search',	0.997306),
('your',	72,	'en',	'help_search',	1),
('your',	73,	'en',	'help_search',	1),
('your',	75,	'en',	'help_search',	1),
('your',	76,	'en',	'help_search',	1),
('your',	77,	'en',	'help_search',	1),
('your',	79,	'en',	'help_search',	1),
('your',	80,	'en',	'help_search',	4),
('your',	81,	'en',	'help_search',	5.99731),
('your',	82,	'en',	'help_search',	2),
('your',	84,	'en',	'help_search',	3),
('your',	85,	'en',	'help_search',	4.98493),
('your',	86,	'en',	'help_search',	7.3548),
('your',	87,	'en',	'help_search',	6),
('zone',	32,	'en',	'help_search',	2);

DROP TABLE IF EXISTS `search_total`;
CREATE TABLE `search_total` (
  `word` varchar(50) NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique word in the search index.',
  `count` float DEFAULT NULL COMMENT 'The count of the word in the index using Zipf''s law to equalize the probability distribution.',
  PRIMARY KEY (`word`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores search totals for words.';

INSERT INTO `search_total` (`word`, `count`) VALUES
('1',	0.30103),
('15',	0.30103),
('2',	0.176091),
('200',	0.30103),
('255',	0.30103),
('3',	0.30103),
('403',	0.0184834),
('403404',	0.0157943),
('404',	0.0177455),
('40em',	0.0791812),
('5',	0.0319098),
('6',	0.30103),
('7',	0.0321847),
('7292024',	0.30103),
('9',	0.30103),
('916',	0.30103),
('abbreviation',	0.30103),
('ability',	0.0591189),
('able',	0.126363),
('about',	0.0120952),
('aboutus',	0.0791812),
('above',	0.0841085),
('access',	0.0140668),
('accessed',	0.30103),
('accessibility',	0.00895484),
('accessible',	0.124939),
('accessing',	0.176091),
('accomplish',	0.30103),
('account',	0.00400315),
('accountname',	0.30103),
('accounts',	0.00515529),
('action',	0.0286273),
('actions',	0.0298577),
('active',	0.0188459),
('activity',	0.30103),
('acts',	0.30103),
('add',	0.00233898),
('added',	0.0307837),
('adding',	0.0019096),
('addition',	0.0818822),
('additional',	0.000813852),
('address',	0.0457575),
('addresses',	0.188552),
('adds',	0.30103),
('adjust',	0.13284),
('admin',	0.0211893),
('administer',	0.0104743),
('administering',	0.30103),
('administration',	0.0263289),
('administrative',	0.00183437),
('administrator',	0.125187),
('administrators',	0.0413927),
('advanced',	0.0291605),
('advisories',	0.0211893),
('advisory',	0.0299632),
('affected',	0.30103),
('after',	0.0435474),
('afterwards',	0.30103),
('again',	0.124939),
('against',	0.176091),
('aggregation',	0.0203441),
('alias',	0.0050208),
('aliases',	0.00363428),
('aliasing',	0.30103),
('all',	0.0109537),
('allow',	0.0381864),
('allowed',	0.0349677),
('allows',	0.018204),
('along',	0.176091),
('already',	0.0321847),
('alreadyconfigured',	0.30103),
('alreadyrendered',	0.30103),
('also',	0.00885064),
('alter',	0.30103),
('alternative',	0.30103),
('alternatively',	0.176091),
('always',	0.09691),
('american',	0.30103),
('anchor',	0.09691),
('and',	0.000414368),
('announcement',	0.0347621),
('announcements',	0.00464491),
('anonymous',	0.0326174),
('another',	0.0291947),
('any',	0.0153728),
('anyone',	0.176091),
('apache',	0.0347621),
('api',	0.0122479),
('appear',	0.0813001),
('appearance',	0.00686246),
('applications',	0.124939),
('applied',	0.124939),
('apply',	0.0326325),
('appropriate',	0.30103),
('appropriately',	0.30103),
('approval',	0.30103),
('approved',	0.30103),
('archive',	0.0430226),
('are',	0.000503485),
('area',	0.0512188),
('areas',	0.30103),
('arrows',	0.176091),
('article',	0.0321847),
('articles',	0.30103),
('aspect',	0.30103),
('aspects',	0.30103),
('asset',	0.30103),
('assign',	0.179531),
('assigned',	0.124939),
('assistive',	0.30103),
('associate',	0.133055),
('associated',	0.30103),
('associates',	0.30103),
('association',	0.176091),
('assume',	0.30103),
('assuming',	0.30103),
('assumptions',	0.30103),
('attach',	0.176091),
('attached',	0.09691),
('attention',	0.30103),
('attribute',	0.30103),
('audio',	0.30103),
('authenticated',	0.0378911),
('authenticating',	0.30103),
('authentication',	0.0125891),
('authoring',	0.0520117),
('authorized',	0.30103),
('automated',	0.0971766),
('automatic',	0.176091),
('automatically',	0.0795601),
('automaticallygenerated',	0.176091),
('available',	0.00297661),
('avoid',	0.30103),
('aware',	0.30103),
('away',	0.30103),
('back',	0.30103),
('background',	0.176091),
('ban',	0.176091),
('bar',	0.30103),
('base',	0.0143783),
('basic',	0.00477097),
('because',	0.124939),
('become',	0.30103),
('becomes',	0.30103),
('been',	0.0313976),
('before',	0.176091),
('behaves',	0.30103),
('behaving',	0.30103),
('behavior',	0.0817383),
('behind',	0.30103),
('being',	0.0536267),
('believe',	0.30103),
('belong',	0.30103),
('below',	0.0153259),
('besides',	0.207766),
('best',	0.09691),
('between',	0.0398561),
('big',	0.30103),
('bigpipe',	0.0446591),
('blank',	0.30103),
('block',	0.00145295),
('blocked',	0.30103),
('blocks',	0.00342657),
('blog',	0.0791812),
('body',	0.176091),
('boolean',	0.30103),
('both',	0.0415108),
('bottom',	0.067761),
('box',	0.0347621),
('boxes',	0.176091),
('brackets',	0.30103),
('break',	0.30103),
('breakpoint',	0.00793195),
('breakpointenabled',	0.30103),
('breakpoints',	0.00497197),
('breaks',	0.09691),
('browse',	0.30103),
('browser',	0.0807971),
('bugs',	0.09691),
('builder',	0.0271503),
('building',	0.041468),
('builtin',	0.176091),
('bulk',	0.00719509),
('but',	0.0347621),
('butter',	0.30103),
('button',	0.0273978),
('buttons',	0.0369925),
('bypass',	0.0511525),
('cache',	0.00512147),
('cacheable',	0.30103),
('cached',	0.0457575),
('caches',	0.0672286),
('caching',	0.0202034),
('calculated',	0.179818),
('calculation',	0.30103),
('calculations',	0.124939),
('calendar',	0.30103),
('called',	0.0466934),
('can',	0.00103575),
('cancel',	0.0324435),
('canceled',	0.0670605),
('cannot',	0.0791812),
('carefully',	0.30103),
('case',	0.30103),
('categorize',	0.30103),
('certain',	0.176091),
('challenge',	0.30103),
('change',	0.0148403),
('changed',	0.0515269),
('changes',	0.0349665),
('changing',	0.00440912),
('channel',	0.30103),
('character',	0.201523),
('characteristics',	0.232926),
('characters',	0.30103),
('check',	0.0154305),
('checkbox',	0.176091),
('checked',	0.0579919),
('child',	0.30103),
('children',	0.30103),
('chinese',	0.30103),
('choice',	0.176091),
('choices',	0.13934),
('choose',	0.0325869),
('choosing',	0.124939),
('chose',	0.176091),
('chosen',	0.107547),
('cjk',	0.097509),
('ckeditor',	0.0319098),
('claro',	0.125337),
('classic',	0.30103),
('classified',	0.30103),
('classify',	0.0669747),
('clean',	0.30103),
('clear',	0.0321847),
('cleared',	0.30103),
('clearing',	0.01524),
('cli',	0.30103),
('click',	0.00265709),
('clicked',	0.30103),
('clicking',	0.0580128),
('clicks',	0.30103),
('clipboard',	0.124939),
('cloned',	0.30103),
('clones',	0.30103),
('cloning',	0.30103),
('code',	0.0829375),
('codebase',	0.30103),
('codes',	0.0304214),
('collection',	0.178078),
('collectively',	0.30103),
('column',	0.0303503),
('columns',	0.0677134),
('combinations',	0.30103),
('come',	0.182608),
('comes',	0.30103),
('command',	0.176091),
('commandline',	0.30103),
('comment',	0.152196),
('comments',	0.129831),
('common',	0.124939),
('commonly',	0.176091),
('commonlyused',	0.176091),
('communitymembers',	0.30103),
('communityprovided',	0.176091),
('compact',	0.30103),
('compares',	0.30103),
('comparison',	0.0377886),
('complete',	0.00744726),
('completely',	0.30103),
('complex',	0.128947),
('compliance',	0.30103),
('compliant',	0.30103),
('components',	0.0107239),
('composed',	0.30103),
('compressed',	0.30103),
('computer',	0.176091),
('concept',	0.00465218),
('concepts',	0.30103),
('conditions',	0.176091),
('config',	0.0511525),
('configurable',	0.30103),
('configuration',	0.00084506),
('configure',	0.00424067),
('configured',	0.0431437),
('configuring',	0.00117097),
('confirm',	0.176091),
('confirmation',	0.176091),
('confused',	0.30103),
('connect',	0.30103),
('connected',	0.30103),
('connecting',	0.0163904),
('consist',	0.30103),
('consists',	0.30103),
('consume',	0.30103),
('contact',	0.001556),
('contain',	0.0881532),
('containing',	0.0674721),
('contains',	0.100868),
('content',	0.000476596),
('context',	0.0850083),
('contextual',	0.00535708),
('continue',	0.0380879),
('contributed',	0.0128227),
('control',	0.0511525),
('convert',	0.176091),
('converted',	0.30103),
('converting',	0.176091),
('converts',	0.30103),
('cookies',	0.30103),
('cooking',	0.30103),
('copied',	0.187562),
('copy',	0.124939),
('core',	0.00318165),
('corner',	0.176091),
('correct',	0.0352981),
('corresponding',	0.186677),
('corresponds',	0.30103),
('corrupted',	0.30103),
('could',	0.0593825),
('counterparts',	0.30103),
('country',	0.176091),
('covered',	0.176091),
('create',	0.00402285),
('created',	0.0102516),
('creates',	0.176091),
('creating',	0.00147895),
('creation',	0.0222764),
('criteria',	0.0224299),
('critical',	0.176091),
('cron',	0.00295015),
('crop',	0.0791812),
('cropping',	0.30103),
('css',	0.10025),
('curated',	0.30103),
('current',	0.0381109),
('currently',	0.0855755),
('custom',	0.0850895),
('customize',	0.30103),
('customized',	0.30103),
('customizing',	0.0199788),
('data',	0.004337),
('database',	0.0477659),
('date',	0.0173936),
('dates',	0.187061),
('datetime',	0.199796),
('death',	0.09691),
('default',	0.00341718),
('defaults',	0.0457009),
('defend',	0.30103),
('define',	0.0348417),
('defined',	0.0791812),
('defines',	0.124939),
('defining',	0.014864),
('delete',	0.0422083),
('deleted',	0.0142404),
('deleting',	0.0153447),
('deletion',	0.0222764),
('demonstrate',	0.0511525),
('dependencies',	0.30103),
('dependent',	0.30103),
('depending',	0.07144),
('depends',	0.30103),
('deploying',	0.013364),
('derived',	0.30103),
('described',	0.194576),
('describes',	0.124939),
('description',	0.0102192),
('descriptive',	0.30103),
('deserialization',	0.09691),
('design',	0.30103),
('desired',	0.0174249),
('destination',	0.212504),
('details',	0.0695619),
('determine',	0.30103),
('determines',	0.30103),
('dev',	0.188552),
('development',	0.00801466),
('device',	0.09691),
('deviceindependent',	0.0377886),
('devices',	0.30103),
('diagnose',	0.176091),
('dialog',	0.0985953),
('differences',	0.30103),
('different',	0.0340683),
('differentsized',	0.30103),
('difficult',	0.30103),
('direct',	0.30103),
('directly',	0.0979327),
('directories',	0.30103),
('directory',	0.0721144),
('disable',	0.09691),
('disabled',	0.0413927),
('disabling',	0.00768683),
('discard',	0.30103),
('discovery',	0.177487),
('display',	0.00238374),
('displayed',	0.00931644),
('displaying',	0.30103),
('displayname',	0.30103),
('displays',	0.0193052),
('distributed',	0.30103),
('divided',	0.09691),
('divisions',	0.30103),
('documentation',	0.00738567),
('documented',	0.30103),
('documents',	0.30103),
('does',	0.0178018),
('don',	0.30103),
('done',	0.0601132),
('down',	0.30103),
('download',	0.0109954),
('downloaded',	0.0579919),
('downloads',	0.30103),
('drag',	0.0360685),
('draganddrop',	0.124939),
('dragging',	0.134314),
('drastic',	0.30103),
('dropdown',	0.09691),
('dropped',	0.30103),
('drupal',	0.00112892),
('drupalorg',	0.012965),
('drush',	0.0547947),
('due',	0.30103),
('during',	0.176091),
('dynamic',	0.0405796),
('each',	0.00861916),
('easier',	0.09691),
('easy',	0.30103),
('edit',	0.00186592),
('edited',	0.30103),
('editing',	0.00247582),
('editor',	0.0105939),
('editors',	0.00955747),
('edits',	0.176091),
('effect',	0.0377886),
('effects',	0.0511525),
('efficiently',	0.30103),
('either',	0.0555492),
('element',	0.30103),
('else',	0.30103),
('email',	0.0116858),
('embed',	0.30103),
('empty',	0.30103),
('enable',	0.09691),
('enabled',	0.0247114),
('enables',	0.176091),
('enabling',	0.00796893),
('enclosed',	0.30103),
('encode',	0.30103),
('end',	0.0690913),
('enforces',	0.30103),
('enforcing',	0.30103),
('engines',	0.30103),
('english',	0.0975029),
('enhances',	0.30103),
('ensure',	0.184484),
('enter',	0.0107552),
('entered',	0.176091),
('entering',	0.30103),
('enters',	0.30103),
('entities',	0.0166175),
('entity',	0.00192634),
('entries',	0.30103),
('error',	0.010809),
('errors',	0.0123697),
('etc',	0.0588093),
('events',	0.30103),
('every',	0.0982369),
('exact',	0.176091),
('example',	0.0106544),
('examplecom',	0.017852),
('examples',	0.0841362),
('except',	0.30103),
('exchanged',	0.176091),
('exist',	0.202653),
('existing',	0.00626166),
('exists',	0.176091),
('expand',	0.30103),
('expanded',	0.09691),
('expect',	0.30103),
('expected',	0.30103),
('experience',	0.30103),
('experimental',	0.0170333),
('expiring',	0.30103),
('explaining',	0.30103),
('export',	0.0255328),
('exported',	0.0398026),
('exporting',	0.00773452),
('expose',	0.30103),
('exposed',	0.0440728),
('exposes',	0.176091),
('extend',	0.00815772),
('extending',	0.00640737),
('extends',	0.30103),
('extension',	0.0836586),
('external',	0.30103),
('facilitate',	0.30103),
('factors',	0.176091),
('false',	0.30103),
('far',	0.30103),
('faster',	0.124939),
('faulty',	0.30103),
('feature',	0.30103),
('features',	0.09691),
('feed',	0.0669468),
('feel',	0.30103),
('few',	0.30103),
('fewer',	0.30103),
('field',	0.00146582),
('fields',	0.00215991),
('file',	0.0142686),
('files',	0.0309399),
('fill',	0.0806641),
('filling',	0.30103),
('filter',	0.009974),
('filtering',	0.184484),
('filters',	0.0049671),
('finally',	0.30103),
('find',	0.0100149),
('finish',	0.30103),
('finished',	0.176091),
('first',	0.0395413),
('fix',	0.30103),
('fixed',	0.176091),
('fixing',	0.0377886),
('flat',	0.176091),
('flexible',	0.30103),
('focusing',	0.30103),
('follow',	0.0349955),
('following',	0.0424001),
('footer',	0.0993263),
('for',	0.00064497),
('force',	0.30103),
('forcing',	0.30103),
('form',	0.00178979),
('formal',	0.30103),
('format',	0.00533348),
('formats',	0.00399671),
('formatted',	0.0266232),
('formatter',	0.0217689),
('formatters',	0.0636519),
('formatting',	0.30103),
('forms',	0.00299436),
('found',	0.30103),
('four',	0.125635),
('framework',	0.176091),
('free',	0.30103),
('from',	0.011639),
('front',	0.0669468),
('full',	0.0791812),
('fullexport',	0.30103),
('fully',	0.0834463),
('function',	0.124939),
('functionality',	0.0116054),
('functions',	0.30103),
('further',	0.0908076),
('future',	0.181508),
('gear',	0.176091),
('generally',	0.30103),
('generate',	0.176091),
('generated',	0.09691),
('generating',	0.30103),
('generic',	0.30103),
('get',	0.0808654),
('give',	0.0595632),
('given',	0.30103),
('goal',	0.00040798),
('goals',	0.30103),
('goes',	0.176091),
('good',	0.30103),
('governance',	0.30103),
('granting',	0.30103),
('green',	0.30103),
('grid',	0.0669468),
('group',	0.0151048),
('grouped',	0.176091),
('groups',	0.0181544),
('guide',	0.00145328),
('handles',	0.30103),
('handling',	0.0978732),
('happen',	0.30103),
('happens',	0.097149),
('has',	0.0065309),
('have',	0.00447805),
('haven',	0.30103),
('having',	0.30103),
('header',	0.0805449),
('heading',	0.124939),
('health',	0.176091),
('height',	0.013364),
('help',	0.00187366),
('helps',	0.30103),
('helptopics',	0.0511525),
('here',	0.013364),
('hidden',	0.0511525),
('hide',	0.138466),
('hiding',	0.30103),
('hierarchical',	0.30103),
('hierarchy',	0.176091),
('highly',	0.176091),
('hints',	0.30103),
('history',	0.176091),
('holds',	0.30103),
('home',	0.0970591),
('horizontal',	0.30103),
('hour',	0.30103),
('hourly',	0.30103),
('hover',	0.30103),
('hovering',	0.127893),
('hovers',	0.30103),
('how',	0.00357312),
('however',	0.176091),
('html',	0.0171445),
('http',	0.00975984),
('https',	0.0178401),
('human',	0.30103),
('humanreadable',	0.30103),
('icon',	0.124939),
('identification',	0.30103),
('identifier',	0.0892115),
('identifiers',	0.30103),
('identifies',	0.18527),
('image',	0.00581477),
('images',	0.0280683),
('immediately',	0.30103),
('impact',	0.30103),
('implementation',	0.176091),
('implemented',	0.30103),
('implications',	0.0791812),
('import',	0.0193052),
('imported',	0.0679688),
('importing',	0.00802071),
('improper',	0.11041),
('improve',	0.0202034),
('improved',	0.30103),
('include',	0.061714),
('includes',	0.176091),
('including',	0.0113258),
('incorrect',	0.30103),
('increasing',	0.30103),
('index',	0.00655471),
('indexed',	0.0834923),
('indexing',	0.0171016),
('indicating',	0.0689701),
('individual',	0.0669468),
('individually',	0.30103),
('influence',	0.30103),
('information',	0.00741299),
('informational',	0.30103),
('ingredients',	0.0791812),
('inline',	0.0142475),
('inplace',	0.176091),
('input',	0.206239),
('insert',	0.30103),
('install',	0.0148461),
('installation',	0.176091),
('installed',	0.00896374),
('installing',	0.00568143),
('instance',	0.0392049),
('instances',	0.107823),
('instead',	0.0676289),
('instructions',	0.126931),
('integer',	0.125963),
('integers',	0.30103),
('interactions',	0.30103),
('interest',	0.09691),
('interests',	0.30103),
('interface',	0.00363827),
('interfaces',	0.30103),
('internal',	0.018932),
('into',	0.0105843),
('invalid',	0.30103),
('item',	0.00181417),
('items',	0.0059049),
('its',	0.0204106),
('japanese',	0.30103),
('javascript',	0.0813935),
('jobs',	0.30103),
('json',	0.0115819),
('just',	0.124939),
('keep',	0.128426),
('keeping',	0.176091),
('kept',	0.30103),
('key',	0.19672),
('keyboardonly',	0.30103),
('keys',	0.0997059),
('keyword',	0.176091),
('keywords',	0.124939),
('kinds',	0.0222764),
('knowing',	0.30103),
('known',	0.09691),
('korean',	0.30103),
('label',	0.0110921),
('labeled',	0.124939),
('labels',	0.081504),
('langing',	0.0157943),
('language',	0.0177337),
('languages',	0.00756132),
('languagespecific',	0.30103),
('large',	0.137029),
('larger',	0.30103),
('last',	0.0377886),
('later',	0.0687802),
('layout',	0.00339541),
('layouts',	0.028181),
('leading',	0.30103),
('leads',	0.30103),
('learn',	0.124939),
('learning',	0.30103),
('least',	0.176091),
('leave',	0.30103),
('left',	0.058172),
('length',	0.0791812),
('less',	0.30103),
('let',	0.081347),
('lets',	0.30103),
('level',	0.30103),
('library',	0.0157943),
('lifetime',	0.081253),
('like',	0.0326366),
('limit',	0.0630944),
('limitations',	0.0211893),
('limited',	0.30103),
('limits',	0.176091),
('line',	0.0791812),
('link',	0.00452883),
('links',	0.00268144),
('linuxlike',	0.30103),
('list',	0.00549047),
('listed',	0.0102017),
('listing',	0.125782),
('listings',	0.00911297),
('lists',	0.101808),
('live',	0.1031),
('load',	0.30103),
('loads',	0.30103),
('locate',	0.0347621),
('located',	0.09691),
('location',	0.144709),
('locations',	0.207337),
('locator',	0.30103),
('log',	0.0457575),
('logged',	0.0792203),
('loggedin',	0.30103),
('logging',	0.060091),
('loginurl',	0.30103),
('long',	0.0454152),
('longer',	0.124939),
('look',	0.0992971),
('looks',	0.09691),
('machine',	0.0669468),
('machinereadable',	0.30103),
('made',	0.30103),
('mail',	0.30103),
('main',	0.0443459),
('maintaining',	0.00934003),
('maintenance',	0.00344715),
('make',	0.0126852),
('makes',	0.30103),
('making',	0.0121207),
('malicious',	0.30103),
('manage',	0.00123975),
('managed',	0.0791812),
('management',	0.0086537),
('manager',	0.103112),
('managers',	0.30103),
('manages',	0.30103),
('managing',	0.000748843),
('manner',	0.30103),
('manually',	0.0669468),
('many',	0.0727736),
('mapped',	0.30103),
('mapping',	0.0511525),
('mark',	0.30103),
('marked',	0.09691),
('marker',	0.30103),
('markup',	0.124939),
('match',	0.103025),
('matched',	0.30103),
('matches',	0.30103),
('matching',	0.30103),
('matter',	0.30103),
('maximum',	0.186808),
('may',	0.0251936),
('meaning',	0.176091),
('means',	0.127485),
('meant',	0.124939),
('measure',	0.30103),
('mechanisms',	0.09691),
('media',	0.0020505),
('mediarelated',	0.30103),
('medium',	0.30103),
('mentioned',	0.30103),
('menu',	0.00153715),
('menus',	0.00695232),
('merged',	0.30103),
('message',	0.00899005),
('messages',	0.0286464),
('metadata',	0.0193052),
('method',	0.124939),
('middle',	0.30103),
('might',	0.0695962),
('minimum',	0.09691),
('minwidth',	0.30103),
('misbehaving',	0.30103),
('mistakes',	0.30103),
('modal',	0.176091),
('mode',	0.00532883),
('modify',	0.0791812),
('modifying',	0.00553249),
('module',	0.00124508),
('modules',	0.00320078),
('mon',	0.30103),
('month',	0.176091),
('more',	0.00638649),
('most',	0.0247658),
('mostcommonlyused',	0.30103),
('mouse',	0.30103),
('move',	0.0892844),
('much',	0.30103),
('multicolumn',	0.30103),
('multiple',	0.09691),
('multiplevalued',	0.30103),
('multiplier',	0.30103),
('multipliers',	0.0185231),
('must',	0.0581091),
('name',	0.00555903),
('names',	0.205235),
('navigate',	0.0058459),
('navigating',	0.30103),
('navigation',	0.30103),
('near',	0.30103),
('necessary',	0.128817),
('need',	0.016047),
('needed',	0.0605124),
('needing',	0.30103),
('needs',	0.30103),
('never',	0.30103),
('new',	0.00195278),
('newly',	0.30103),
('news',	0.30103),
('next',	0.0321847),
('node',	0.0205652),
('nolink',	0.09691),
('nonadministration',	0.30103),
('nonadministrative',	0.09691),
('noncacheable',	0.30103),
('nondefault',	0.30103),
('none',	0.104012),
('nonenglish',	0.30103),
('nonerror',	0.30103),
('nontoplevel',	0.30103),
('normal',	0.124939),
('normally',	0.124939),
('not',	0.00868247),
('note',	0.0511525),
('noted',	0.30103),
('notfound',	0.0524957),
('notify',	0.09691),
('notifying',	0.30103),
('now',	0.0596503),
('number',	0.0224542),
('numbers',	0.109372),
('numerical',	0.30103),
('occasionally',	0.30103),
('occur',	0.0211893),
('off',	0.30103),
('offer',	0.155997),
('official',	0.09691),
('often',	0.176091),
('older',	0.30103),
('once',	0.0702755),
('one',	0.0105654),
('onecolumn',	0.127522),
('onetimeloginurl',	0.30103),
('online',	0.00737804),
('only',	0.0276494),
('open',	0.124939),
('operation',	0.30103),
('operations',	0.00458381),
('optimizing',	0.0163904),
('option',	0.205335),
('optional',	0.09691),
('optionally',	0.0147342),
('options',	0.00912019),
('order',	0.0116652),
('ordered',	0.30103),
('ordering',	0.176091),
('organize',	0.30103),
('organized',	0.30103),
('organizes',	0.30103),
('original',	0.30103),
('other',	0.00577758),
('out',	0.080246),
('outline',	0.30103),
('output',	0.0458695),
('outreach',	0.30103),
('outside',	0.0511688),
('over',	0.0824937),
('overall',	0.184765),
('override',	0.0803525),
('overview',	0.00118912),
('own',	0.0377886),
('owned',	0.30103),
('owners',	0.176091),
('page',	0.00157004),
('pagelevel',	0.176091),
('pager',	0.101856),
('pages',	0.00288986),
('paginate',	0.30103),
('paragraph',	0.30103),
('parent',	0.0511525),
('part',	0.0579919),
('particular',	0.0283492),
('parts',	0.0203475),
('password',	0.0579919),
('past',	0.30103),
('paste',	0.0669468),
('path',	0.012476),
('pathauto',	0.0377886),
('paths',	0.0137883),
('patterns',	0.09691),
('paying',	0.30103),
('pencil',	0.176091),
('pending',	0.30103),
('people',	0.0130896),
('per',	0.0669468),
('percentages',	0.30103),
('perform',	0.0669468),
('performance',	0.00580152),
('performing',	0.129203),
('periodically',	0.09691),
('periods',	0.30103),
('permanent',	0.30103),
('permission',	0.00630572),
('permissions',	0.00494461),
('personal',	0.00742402),
('personalized',	0.30103),
('php',	0.0299632),
('physical',	0.30103),
('piece',	0.176091),
('pieces',	0.30103),
('pipe',	0.30103),
('pixel',	0.0347621),
('place',	0.0113367),
('placed',	0.0511525),
('placeholders',	0.185457),
('placing',	0.01524),
('plain',	0.0382693),
('plaintext',	0.30103),
('planning',	0.063656),
('plugin',	0.0732599),
('pluginbased',	0.30103),
('plugins',	0.176091),
('plus',	0.30103),
('point',	0.176091),
('policy',	0.0299632),
('pop',	0.176091),
('popup',	0.127606),
('porter',	0.0383419),
('position',	0.30103),
('positions',	0.30103),
('possibility',	0.30103),
('possible',	0.0898553),
('post',	0.30103),
('posts',	0.176091),
('potentiallydangerous',	0.30103),
('practice',	0.176091),
('practices',	0.30103),
('predefined',	0.141044),
('prefer',	0.30103),
('preferred',	0.176091),
('preindex',	0.30103),
('presents',	0.30103),
('preventing',	0.0377886),
('preview',	0.0310853),
('previous',	0.140099),
('previously',	0.09691),
('previouslyplaced',	0.0157943),
('printers',	0.30103),
('problem',	0.124939),
('problems',	0.0299774),
('process',	0.0249474),
('processed',	0.198979),
('processing',	0.0743237),
('production',	0.18123),
('profile',	0.0579919),
('profiles',	0.09691),
('programs',	0.30103),
('progress',	0.057808),
('project',	0.0669468),
('projects',	0.30103),
('promote',	0.30103),
('provide',	0.00737071),
('provided',	0.00914687),
('provides',	0.0169423),
('providing',	0.176091),
('public',	0.30103),
('publish',	0.0582053),
('published',	0.0331394),
('publishing',	0.30103),
('pull',	0.30103),
('purpose',	0.30103),
('purposes',	0.126618),
('put',	0.0347621),
('putting',	0.30103),
('queries',	0.0132653),
('query',	0.30103),
('quick',	0.00768683),
('quickly',	0.128688),
('radio',	0.143522),
('ran',	0.30103),
('range',	0.200374),
('ranging',	0.30103),
('ranking',	0.0791812),
('rather',	0.30103),
('ratio',	0.30103),
('reach',	0.30103),
('read',	0.199973),
('readers',	0.176091),
('ready',	0.30103),
('really',	0.30103),
('rearrange',	0.0791812),
('reasons',	0.176091),
('rebuild',	0.09691),
('recalculated',	0.30103),
('recalculation',	0.30103),
('receive',	0.176091),
('recent',	0.0791812),
('recently',	0.176091),
('recipe',	0.124939),
('recipes',	0.176091),
('recipient',	0.30103),
('recipients',	0.0791812),
('recommended',	0.124939),
('records',	0.30103),
('red',	0.30103),
('redirected',	0.30103),
('reduce',	0.176091),
('reference',	0.00406999),
('referenced',	0.124939),
('references',	0.30103),
('refers',	0.30103),
('refine',	0.176091),
('region',	0.0170333),
('regional',	0.09691),
('regions',	0.0377886),
('register',	0.09691),
('registered',	0.124939),
('regular',	0.127995),
('regularlength',	0.30103),
('reindex',	0.101856),
('reindexed',	0.30103),
('related',	0.0062323),
('relationship',	0.187564),
('relationships',	0.106869),
('released',	0.30103),
('releases',	0.176091),
('relevant',	0.30103),
('remote',	0.30103),
('remove',	0.0304191),
('removing',	0.30103),
('render',	0.30103),
('rendered',	0.30103),
('rendering',	0.30103),
('renders',	0.30103),
('reorder',	0.30103),
('reordering',	0.0157943),
('repeat',	0.082512),
('replacement',	0.09691),
('replacements',	0.30103),
('report',	0.0413927),
('reported',	0.30103),
('reports',	0.00983967),
('reproduced',	0.30103),
('request',	0.176091),
('requested',	0.179818),
('requests',	0.30103),
('require',	0.130078),
('required',	0.0380408),
('requires',	0.0835812),
('reset',	0.176091),
('resides',	0.30103),
('resized',	0.30103),
('resolution',	0.00896416),
('resource',	0.30103),
('resources',	0.000841729),
('respective',	0.30103),
('respectively',	0.30103),
('respond',	0.124939),
('response',	0.0669468),
('responses',	0.00895484),
('responsive',	0.0716471),
('rest',	0.0348708),
('restful',	0.0184834),
('restrict',	0.186044),
('restrictions',	0.30103),
('restrictive',	0.30103),
('restricts',	0.191184),
('result',	0.179531),
('results',	0.0473965),
('retrieved',	0.30103),
('return',	0.0612521),
('returned',	0.0323994),
('reuse',	0.30103),
('reusing',	0.30103),
('reverse',	0.176091),
('review',	0.176091),
('right',	0.0581091),
('righttoleft',	0.0672286),
('risk',	0.110762),
('role',	0.00464504),
('roles',	0.0145754),
('row',	0.0377886),
('rows',	0.30103),
('rss',	0.30103),
('run',	0.0131008),
('running',	0.00540085),
('runs',	0.0970591),
('runtime',	0.30103),
('safe',	0.30103),
('same',	0.0479155),
('satisfied',	0.30103),
('save',	0.00194898),
('saved',	0.0691786),
('saves',	0.30103),
('saving',	0.30103),
('say',	0.30103),
('saying',	0.176091),
('says',	0.30103),
('scaffolding',	0.30103),
('scaling',	0.30103),
('scan',	0.176091),
('scenes',	0.30103),
('schedule',	0.0792806),
('screen',	0.0347621),
('screens',	0.124939),
('scripts',	0.30103),
('scroll',	0.176091),
('search',	0.00103629),
('searchable',	0.30103),
('searches',	0.185009),
('searching',	0.047278),
('second',	0.176091),
('section',	0.0102842),
('sections',	0.014809),
('secure',	0.01524),
('security',	0.00317636),
('see',	0.0030739),
('seen',	0.30103),
('sees',	0.30103),
('select',	0.0097126),
('selected',	0.041687),
('selecting',	0.176091),
('selects',	0.30103),
('send',	0.30103),
('sending',	0.30103),
('sends',	0.30103),
('sent',	0.129993),
('seofriendly',	0.30103),
('separate',	0.30103),
('separately',	0.176091),
('separates',	0.30103),
('sequence',	0.30103),
('serialization',	0.0170434),
('serialized',	0.30103),
('serve',	0.177189),
('server',	0.124939),
('servers',	0.30103),
('service',	0.0211893),
('services',	0.00599036),
('serving',	0.30103),
('session',	0.09691),
('set',	0.00766792),
('sets',	0.0791812),
('setting',	0.00549069),
('settings',	0.00155093),
('settingsphp',	0.0679777),
('several',	0.0509907),
('severity',	0.09691),
('share',	0.30103),
('shared',	0.176091),
('shield',	0.30103),
('shift',	0.30103),
('short',	0.124939),
('shortcut',	0.00783464),
('shortcuts',	0.0087851),
('should',	0.0117584),
('show',	0.0206939),
('showing',	0.204837),
('shown',	0.0204074),
('shows',	0.102136),
('side',	0.176091),
('similar',	0.0795761),
('simple',	0.0458095),
('since',	0.30103),
('single',	0.00663058),
('singleitem',	0.30103),
('singleline',	0.248161),
('singlevalued',	0.210151),
('site',	0.000609226),
('sites',	0.036723),
('sitewide',	0.0579919),
('situations',	0.30103),
('size',	0.124939),
('sized',	0.177487),
('sizes',	0.30103),
('sizing',	0.30103),
('slogan',	0.176091),
('smaller',	0.0669468),
('social',	0.30103),
('software',	0.0202327),
('solr',	0.0347621),
('some',	0.014647),
('someone',	0.30103),
('sometimes',	0.176091),
('soon',	0.30103),
('sort',	0.0669468),
('sorting',	0.176091),
('sorts',	0.30103),
('source',	0.0422192),
('sources',	0.176091),
('spaces',	0.30103),
('special',	0.176091),
('specific',	0.0223997),
('specifically',	0.30103),
('specification',	0.0377886),
('specify',	0.176091),
('specifying',	0.180387),
('speed',	0.30103),
('sphinx',	0.0377886),
('square',	0.30103),
('stable',	0.124939),
('staging',	0.30103),
('standard',	0.30103),
('standards',	0.0196872),
('star',	0.30103),
('start',	0.130682),
('started',	0.30103),
('starting',	0.30103),
('starts',	0.176091),
('state',	0.0579919),
('status',	0.0237782),
('stemmer',	0.0384937),
('stemming',	0.30103),
('step',	0.125487),
('stepbystep',	0.30103),
('steps',	0.000399531),
('still',	0.30103),
('storage',	0.176091),
('store',	0.09691),
('stored',	0.0560289),
('stores',	0.0352647),
('strategic',	0.30103),
('streamed',	0.30103),
('string',	0.0791812),
('strings',	0.102946),
('structure',	0.00252931),
('structures',	0.30103),
('style',	0.00683942),
('styles',	0.0512762),
('styling',	0.30103),
('subdirectory',	0.30103),
('subject',	0.0347621),
('submit',	0.176091),
('subset',	0.30103),
('substituted',	0.30103),
('subterm',	0.30103),
('subtype',	0.00340676),
('subtypes',	0.0322109),
('such',	0.0109526),
('sufficient',	0.30103),
('suggested',	0.30103),
('summarizes',	0.30103),
('summary',	0.0545088),
('supplied',	0.30103),
('support',	0.13267),
('supports',	0.30103),
('sure',	0.033211),
('sustainability',	0.30103),
('switch',	0.127058),
('switcher',	0.09691),
('sync',	0.0864771),
('synchronization',	0.0108913),
('synchronize',	0.0791812),
('synchronized',	0.30103),
('synchronizing',	0.30103),
('syslog',	0.30103),
('system',	0.00974223),
('systems',	0.30103),
('tab',	0.124939),
('table',	0.0265585),
('tables',	0.176091),
('tablestyle',	0.30103),
('tabs',	0.30103),
('tag',	0.190003),
('tagging',	0.30103),
('tags',	0.0365968),
('take',	0.176091),
('taken',	0.30103),
('takes',	0.176091),
('task',	0.0588466),
('tasks',	0.00455615),
('taxonomy',	0.00273808),
('team',	0.0377886),
('technically',	0.30103),
('technologies',	0.30103),
('technology',	0.176091),
('telephone',	0.151968),
('template',	0.30103),
('temporarily',	0.30103),
('temporary',	0.176091),
('term',	0.0323619),
('terms',	0.0204346),
('test',	0.09691),
('text',	0.00113841),
('than',	0.0396293),
('that',	0.00225298),
('the',	0.000218523),
('their',	0.0232901),
('them',	0.0241962),
('theme',	0.00284869),
('themes',	0.00612104),
('theming',	0.0410633),
('themselves',	0.30103),
('then',	0.0600977),
('there',	0.00908846),
('thereby',	0.30103),
('these',	0.0152112),
('they',	0.0226736),
('thirdparty',	0.176091),
('this',	0.00553756),
('three',	0.176091),
('throttle',	0.09691),
('through',	0.0738368),
('time',	0.0224476),
('timeout',	0.30103),
('times',	0.195673),
('timestamp',	0.30103),
('title',	0.00610755),
('together',	0.30103),
('toggle',	0.30103),
('tomatoes',	0.124939),
('tool',	0.30103),
('toolbar',	0.0103021),
('tooltip',	0.30103),
('top',	0.0800334),
('topic',	0.0124814),
('topics',	0.00293554),
('topleft',	0.30103),
('toplevel',	0.30103),
('topright',	0.30103),
('totally',	0.30103),
('track',	0.30103),
('tracked',	0.0222764),
('tracking',	0.00474644),
('tracks',	0.176091),
('traditional',	0.30103),
('transferred',	0.30103),
('transform',	0.30103),
('translatable',	0.124939),
('translate',	0.30103),
('translated',	0.0102192),
('translation',	0.0579919),
('translations',	0.0142404),
('transmission',	0.30103),
('transported',	0.30103),
('tray',	0.124939),
('triggers',	0.30103),
('troubleshooting',	0.00934003),
('true',	0.30103),
('trusted',	0.09691),
('try',	0.30103),
('trying',	0.176091),
('turn',	0.30103),
('turning',	0.176091),
('turns',	0.30103),
('twice',	0.30103),
('twig',	0.30103),
('twigfilebased',	0.30103),
('two',	0.0426965),
('twocolumn',	0.30103),
('type',	0.00156563),
('types',	0.00251886),
('typically',	0.124939),
('typing',	0.30103),
('uncacheable',	0.30103),
('uncheck',	0.0588626),
('unchecked',	0.30103),
('under',	0.0191323),
('underlying',	0.30103),
('understand',	0.176091),
('understandable',	0.30103),
('unformatted',	0.0467698),
('uniform',	0.30103),
('uninstall',	0.0113013),
('uninstalled',	0.0377886),
('uninstalling',	0.00590886),
('unique',	0.0992971),
('unlimited',	0.176091),
('unpacked',	0.30103),
('unpublished',	0.124939),
('unpublishing',	0.30103),
('until',	0.0517241),
('untrusted',	0.30103),
('unused',	0.0163904),
('upcoming',	0.30103),
('update',	0.0194147),
('updated',	0.0299632),
('updates',	0.0143266),
('updating',	0.0875392),
('upload',	0.09691),
('uploaded',	0.176091),
('upper',	0.176091),
('url',	0.00282977),
('urls',	0.00654752),
('use',	0.0047347),
('used',	0.0170506),
('useful',	0.30103),
('user',	0.000722423),
('userdefined',	0.30103),
('userinterface',	0.30103),
('username',	0.09691),
('users',	0.00428393),
('uses',	0.176091),
('using',	0.00235879),
('usually',	0.30103),
('uuid',	0.0762928),
('valid',	0.176091),
('value',	0.0334275),
('values',	0.0181907),
('variables',	0.0170333),
('variations',	0.30103),
('various',	0.181508),
('vary',	0.124939),
('vegetables',	0.30103),
('verification',	0.176091),
('verified',	0.30103),
('verify',	0.0207448),
('versatile',	0.30103),
('versions',	0.30103),
('vertical',	0.30103),
('very',	0.137029),
('via',	0.30103),
('videos',	0.30103),
('view',	0.00200207),
('viewed',	0.124939),
('viewer',	0.30103),
('viewing',	0.0137883),
('viewport',	0.176091),
('viewports',	0.30103),
('views',	0.0039232),
('visibility',	0.0413927),
('visible',	0.041999),
('visit',	0.0378247),
('visited',	0.0147233),
('visiting',	0.30103),
('visitors',	0.00814188),
('visits',	0.0211893),
('visual',	0.0511525),
('visually',	0.09691),
('vocabularies',	0.0676289),
('vocabulary',	0.0104654),
('w3c',	0.0401585),
('wait',	0.09691),
('waiting',	0.30103),
('walk',	0.183394),
('walked',	0.30103),
('walking',	0.30103),
('want',	0.0061777),
('warning',	0.09691),
('warnings',	0.30103),
('was',	0.0579919),
('way',	0.0450238),
('ways',	0.124939),
('web',	0.00419611),
('website',	0.0125891),
('week',	0.30103),
('weekly',	0.30103),
('weights',	0.0791812),
('well',	0.0684206),
('went',	0.30103),
('were',	0.0595965),
('wget',	0.09691),
('what',	0.000280323),
('when',	0.00661073),
('whenever',	0.30103),
('where',	0.015902),
('whether',	0.124939),
('which',	0.00475139),
('while',	0.0647376),
('white',	0.09691),
('who',	0.0024211),
('whose',	0.09691),
('why',	0.30103),
('widelyused',	0.30103),
('widget',	0.0149292),
('widgets',	0.0791812),
('width',	0.0119181),
('widths',	0.176091),
('will',	0.00442817),
('wish',	0.131957),
('with',	0.00250037),
('within',	0.0527979),
('without',	0.0791812),
('word',	0.0513646),
('words',	0.126931),
('work',	0.177783),
('workflow',	0.0546499),
('working',	0.00523858),
('would',	0.026441),
('wraps',	0.30103),
('write',	0.30103),
('writing',	0.30103),
('written',	0.176091),
('wwwexamplecom',	0.09691),
('wysiwyg',	0.09691),
('xml',	0.30103),
('yaml',	0.0541162),
('yamlformat',	0.30103),
('yet',	0.176091),
('yml',	0.30103),
('you',	0.00149631),
('your',	0.00100013),
('zone',	0.176091);

DROP TABLE IF EXISTS `semaphore`;
CREATE TABLE `semaphore` (
  `name` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Primary Key: Unique name.',
  `value` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'A value for the semaphore.',
  `expire` double NOT NULL COMMENT 'A Unix timestamp with microseconds indicating when the semaphore should expire.',
  PRIMARY KEY (`name`),
  KEY `value` (`value`),
  KEY `expire` (`expire`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Table for holding semaphores, locks, flags, etc. that…';


DROP TABLE IF EXISTS `sequences`;
CREATE TABLE `sequences` (
  `value` int unsigned NOT NULL AUTO_INCREMENT COMMENT 'The value of the sequence.',
  PRIMARY KEY (`value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores IDs.';


DROP TABLE IF EXISTS `sessions`;
CREATE TABLE `sessions` (
  `uid` int unsigned NOT NULL COMMENT 'The "users".uid corresponding to a session, or 0 for anonymous user.',
  `sid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'A session ID (hashed). The value is generated by Drupal''s session handlers.',
  `hostname` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The IP address that last used this session ID (sid).',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when this session last requested a page. Old records are purged by PHP automatically.',
  `session` longblob COMMENT 'The serialized contents of the user''s session, an array of name/value pairs that persists across page requests by this session ID. Drupal loads the user''s session from here   at the start of each request and saves it at the end.',
  PRIMARY KEY (`sid`),
  KEY `timestamp` (`timestamp`),
  KEY `uid` (`uid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Drupal''s session handlers read and write into the sessions…';

INSERT INTO `sessions` (`uid`, `sid`, `hostname`, `timestamp`, `session`) VALUES
(1,	'q5JTLFYDEzgGvV5ObDIDxztn3vebTL7-x9hxcDWSyLk',	'127.0.0.1',	1723018766,	'_sf2_meta|a:4:{s:1:\"u\";i:1723018773;s:1:\"c\";i:1722190534;s:1:\"l\";i:2000000;s:1:\"s\";s:43:\"OO8fhF09tKf2qSyXydfnnrA4VF7R73HuYbtglCGUTHU\";}_sf2_attributes|a:1:{s:3:\"uid\";s:1:\"1\";}');

DROP TABLE IF EXISTS `shortcut`;
CREATE TABLE `shortcut` (
  `id` int unsigned NOT NULL AUTO_INCREMENT,
  `shortcut_set` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `shortcut_field__uuid__value` (`uuid`),
  KEY `shortcut_field__shortcut_set__target_id` (`shortcut_set`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for shortcut entities.';

INSERT INTO `shortcut` (`id`, `shortcut_set`, `uuid`, `langcode`) VALUES
(1,	'default',	'08fe570b-9a18-4d77-8cb6-395e79826162',	'en'),
(2,	'default',	'da5a48a6-5ecf-42f8-b789-45d53cad7955',	'en');

DROP TABLE IF EXISTS `shortcut_field_data`;
CREATE TABLE `shortcut_field_data` (
  `id` int unsigned NOT NULL,
  `shortcut_set` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `title` varchar(255) DEFAULT NULL,
  `weight` int DEFAULT NULL,
  `link__uri` varchar(2048) DEFAULT NULL COMMENT 'The URI of the link.',
  `link__title` varchar(255) DEFAULT NULL COMMENT 'The link text.',
  `link__options` longblob COMMENT 'Serialized array of options for the link.',
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`id`,`langcode`),
  KEY `shortcut__id__default_langcode__langcode` (`id`,`default_langcode`,`langcode`),
  KEY `shortcut_field__shortcut_set__target_id` (`shortcut_set`),
  KEY `shortcut_field__link__uri` (`link__uri`(30))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for shortcut entities.';

INSERT INTO `shortcut_field_data` (`id`, `shortcut_set`, `langcode`, `title`, `weight`, `link__uri`, `link__title`, `link__options`, `default_langcode`) VALUES
(1,	'default',	'en',	'Add content',	-20,	'internal:/node/add',	NULL,	'a:0:{}',	1),
(2,	'default',	'en',	'All content',	-19,	'internal:/admin/content',	NULL,	'a:0:{}',	1);

DROP TABLE IF EXISTS `shortcut_set_users`;
CREATE TABLE `shortcut_set_users` (
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid for this set.',
  `set_name` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The "shortcut_set".set_name that will be displayed for this user.',
  PRIMARY KEY (`uid`),
  KEY `set_name` (`set_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maps users to shortcut sets.';


DROP TABLE IF EXISTS `taxonomy_index`;
CREATE TABLE `taxonomy_index` (
  `nid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "node".nid this record tracks.',
  `tid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The term ID.',
  `status` int NOT NULL DEFAULT '1' COMMENT 'Boolean indicating whether the node is published (visible to non-administrators).',
  `sticky` tinyint DEFAULT '0' COMMENT 'Boolean indicating whether the node is sticky.',
  `created` int NOT NULL DEFAULT '0' COMMENT 'The Unix timestamp when the node was created.',
  PRIMARY KEY (`nid`,`tid`),
  KEY `term_node` (`tid`,`status`,`sticky`,`created`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Maintains denormalized information about node/term…';


DROP TABLE IF EXISTS `taxonomy_term__parent`;
CREATE TABLE `taxonomy_term__parent` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `parent_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `revision_id` (`revision_id`),
  KEY `parent_target_id` (`parent_target_id`),
  KEY `bundle_delta_target_id` (`bundle`,`delta`,`parent_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for taxonomy_term field parent.';


DROP TABLE IF EXISTS `taxonomy_term_data`;
CREATE TABLE `taxonomy_term_data` (
  `tid` int unsigned NOT NULL AUTO_INCREMENT,
  `revision_id` int unsigned DEFAULT NULL,
  `vid` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`tid`),
  UNIQUE KEY `taxonomy_term_field__uuid__value` (`uuid`),
  UNIQUE KEY `taxonomy_term__revision_id` (`revision_id`),
  KEY `taxonomy_term_field__vid__target_id` (`vid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for taxonomy_term entities.';


DROP TABLE IF EXISTS `taxonomy_term_field_data`;
CREATE TABLE `taxonomy_term_field_data` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `vid` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `name` varchar(255) NOT NULL,
  `description__value` longtext,
  `description__format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `weight` int NOT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`tid`,`langcode`),
  KEY `taxonomy_term__id__default_langcode__langcode` (`tid`,`default_langcode`,`langcode`),
  KEY `taxonomy_term__revision_id` (`revision_id`),
  KEY `taxonomy_term_field__name` (`name`(191)),
  KEY `taxonomy_term__status_vid` (`status`,`vid`,`tid`),
  KEY `taxonomy_term__tree` (`vid`,`weight`,`name`(191)),
  KEY `taxonomy_term__vid_name` (`vid`,`name`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for taxonomy_term entities.';


DROP TABLE IF EXISTS `taxonomy_term_field_revision`;
CREATE TABLE `taxonomy_term_field_revision` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `status` tinyint NOT NULL,
  `name` varchar(255) DEFAULT NULL,
  `description__value` longtext,
  `description__format` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  `revision_translation_affected` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`,`langcode`),
  KEY `taxonomy_term__id__default_langcode__langcode` (`tid`,`default_langcode`,`langcode`),
  KEY `taxonomy_term_field__description__format` (`description__format`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision data table for taxonomy_term entities.';


DROP TABLE IF EXISTS `taxonomy_term_revision`;
CREATE TABLE `taxonomy_term_revision` (
  `tid` int unsigned NOT NULL,
  `revision_id` int unsigned NOT NULL AUTO_INCREMENT,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `revision_user` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `revision_created` int DEFAULT NULL,
  `revision_log_message` longtext,
  `revision_default` tinyint DEFAULT NULL,
  PRIMARY KEY (`revision_id`),
  KEY `taxonomy_term__tid` (`tid`),
  KEY `taxonomy_term_field__revision_user__target_id` (`revision_user`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The revision table for taxonomy_term entities.';


DROP TABLE IF EXISTS `taxonomy_term_revision__parent`;
CREATE TABLE `taxonomy_term_revision__parent` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `parent_target_id` int unsigned NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`revision_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `parent_target_id` (`parent_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Revision archive storage for taxonomy_term field parent.';


DROP TABLE IF EXISTS `user__roles`;
CREATE TABLE `user__roles` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `roles_target_id` varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `roles_target_id` (`roles_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for user field roles.';

INSERT INTO `user__roles` (`bundle`, `deleted`, `entity_id`, `revision_id`, `langcode`, `delta`, `roles_target_id`) VALUES
('user',	0,	1,	1,	'en',	0,	'administrator');

DROP TABLE IF EXISTS `user__user_picture`;
CREATE TABLE `user__user_picture` (
  `bundle` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The field instance bundle to which this row belongs, used when deleting a field instance',
  `deleted` tinyint NOT NULL DEFAULT '0' COMMENT 'A boolean indicating whether this data item has been deleted',
  `entity_id` int unsigned NOT NULL COMMENT 'The entity id this data is attached to',
  `revision_id` int unsigned NOT NULL COMMENT 'The entity revision id this data is attached to, which for an unversioned entity type is the same as the entity id',
  `langcode` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The language code for this data item.',
  `delta` int unsigned NOT NULL COMMENT 'The sequence number for this data item, used for multi-value fields',
  `user_picture_target_id` int unsigned NOT NULL COMMENT 'The ID of the file entity.',
  `user_picture_alt` varchar(512) DEFAULT NULL COMMENT 'Alternative image text, for the image''s ''alt'' attribute.',
  `user_picture_title` varchar(1024) DEFAULT NULL COMMENT 'Image title text, for the image''s ''title'' attribute.',
  `user_picture_width` int unsigned DEFAULT NULL COMMENT 'The width of the image in pixels.',
  `user_picture_height` int unsigned DEFAULT NULL COMMENT 'The height of the image in pixels.',
  PRIMARY KEY (`entity_id`,`deleted`,`delta`,`langcode`),
  KEY `bundle` (`bundle`),
  KEY `revision_id` (`revision_id`),
  KEY `user_picture_target_id` (`user_picture_target_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Data storage for user field user_picture.';


DROP TABLE IF EXISTS `users`;
CREATE TABLE `users` (
  `uid` int unsigned NOT NULL AUTO_INCREMENT,
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  PRIMARY KEY (`uid`),
  UNIQUE KEY `user_field__uuid__value` (`uuid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for user entities.';

INSERT INTO `users` (`uid`, `uuid`, `langcode`) VALUES
(0,	'ba24855a-352a-4ad7-99fc-d349ca6c0d1a',	'en'),
(1,	'eab086f7-e8c6-4f27-88d9-510b1bbfa845',	'en');

DROP TABLE IF EXISTS `users_data`;
CREATE TABLE `users_data` (
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid this record affects.',
  `module` varchar(50) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The name of the module declaring the variable.',
  `name` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'The identifier of the data.',
  `value` longblob COMMENT 'The value.',
  `serialized` tinyint unsigned DEFAULT '0' COMMENT 'Whether value is serialized.',
  PRIMARY KEY (`uid`,`module`,`name`),
  KEY `module` (`module`),
  KEY `name` (`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores module data as key/value pairs per user.';


DROP TABLE IF EXISTS `users_field_data`;
CREATE TABLE `users_field_data` (
  `uid` int unsigned NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `preferred_langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `preferred_admin_langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `name` varchar(60) NOT NULL,
  `pass` varchar(255) DEFAULT NULL,
  `mail` varchar(254) DEFAULT NULL,
  `timezone` varchar(32) DEFAULT NULL,
  `status` tinyint DEFAULT NULL,
  `created` int NOT NULL,
  `changed` int DEFAULT NULL,
  `access` int NOT NULL,
  `login` int DEFAULT NULL,
  `init` varchar(254) DEFAULT NULL,
  `default_langcode` tinyint NOT NULL,
  PRIMARY KEY (`uid`,`langcode`),
  UNIQUE KEY `user__name` (`name`,`langcode`),
  KEY `user__id__default_langcode__langcode` (`uid`,`default_langcode`,`langcode`),
  KEY `user_field__mail` (`mail`(191)),
  KEY `user_field__created` (`created`),
  KEY `user_field__access` (`access`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The data table for user entities.';

INSERT INTO `users_field_data` (`uid`, `langcode`, `preferred_langcode`, `preferred_admin_langcode`, `name`, `pass`, `mail`, `timezone`, `status`, `created`, `changed`, `access`, `login`, `init`, `default_langcode`) VALUES
(0,	'en',	'en',	NULL,	'',	NULL,	NULL,	NULL,	0,	1722184552,	1722184552,	0,	0,	NULL,	1),
(1,	'en',	'en',	NULL,	'admin',	'$2y$10$10bXcHgyRHO1BqBNcVbSuOT3uGlOBB.Ncc74fzg7bMj.ostm.zOtK',	'admin@example.com',	'Europe/Belgrade',	1,	1722184552,	1722190504,	1723018766,	1722190504,	'admin@example.com',	1);

DROP TABLE IF EXISTS `watchdog`;
CREATE TABLE `watchdog` (
  `wid` bigint NOT NULL AUTO_INCREMENT COMMENT 'Primary Key: Unique watchdog event ID.',
  `uid` int unsigned NOT NULL DEFAULT '0' COMMENT 'The "users".uid of the user who triggered the event.',
  `type` varchar(64) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Type of log message, for example "user" or "page not found."',
  `message` longtext NOT NULL COMMENT 'Text of log message to be passed into the t() function.',
  `variables` longblob NOT NULL COMMENT 'Serialized array of variables that match the message string and that is passed into the t() function.',
  `severity` tinyint unsigned NOT NULL DEFAULT '0' COMMENT 'The severity level of the event. ranges from 0 (Emergency) to 7 (Debug)',
  `link` text COMMENT 'Link to view the result of the event.',
  `location` text NOT NULL COMMENT 'URL of the origin of the event.',
  `referer` text COMMENT 'URL of referring page.',
  `hostname` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '' COMMENT 'Hostname of the user who triggered the event.',
  `timestamp` bigint NOT NULL DEFAULT '0' COMMENT 'Unix timestamp of when event occurred.',
  PRIMARY KEY (`wid`),
  KEY `type` (`type`),
  KEY `uid` (`uid`),
  KEY `severity` (`severity`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Table that contains logs of all system events.';


DROP TABLE IF EXISTS `webform`;
CREATE TABLE `webform` (
  `webform_id` varchar(32) NOT NULL COMMENT 'The webform id.',
  `next_serial` int unsigned NOT NULL DEFAULT '1' COMMENT 'The serial number to give to the next submission to this webform.',
  PRIMARY KEY (`webform_id`,`next_serial`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores all webform data.';

INSERT INTO `webform` (`webform_id`, `next_serial`) VALUES
('contact',	1);

DROP TABLE IF EXISTS `webform_submission`;
CREATE TABLE `webform_submission` (
  `sid` int NOT NULL AUTO_INCREMENT,
  `webform_id` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL COMMENT 'The ID of the target entity.',
  `uuid` varchar(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `langcode` varchar(12) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `serial` int DEFAULT NULL,
  `token` varchar(255) DEFAULT NULL,
  `uri` varchar(2000) DEFAULT NULL,
  `created` int DEFAULT NULL,
  `completed` int DEFAULT NULL,
  `changed` int DEFAULT NULL,
  `in_draft` tinyint DEFAULT NULL,
  `current_page` varchar(128) DEFAULT NULL,
  `remote_addr` varchar(128) DEFAULT NULL,
  `uid` int unsigned DEFAULT NULL COMMENT 'The ID of the target entity.',
  `entity_type` varchar(32) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `entity_id` varchar(255) DEFAULT NULL,
  `locked` tinyint DEFAULT NULL,
  `sticky` tinyint DEFAULT NULL,
  `notes` longtext,
  PRIMARY KEY (`sid`),
  UNIQUE KEY `webform_submission_field__uuid__value` (`uuid`),
  KEY `webform_submission_field__webform_id__target_id` (`webform_id`),
  KEY `webform_submission_field__uid__target_id` (`uid`),
  KEY `webform_submission_field__token` (`token`(191))
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='The base table for webform_submission entities.';


DROP TABLE IF EXISTS `webform_submission_data`;
CREATE TABLE `webform_submission_data` (
  `webform_id` varchar(32) NOT NULL COMMENT 'The webform id.',
  `sid` int unsigned NOT NULL COMMENT 'The unique identifier for this submission.',
  `name` varchar(128) NOT NULL COMMENT 'The name of the element.',
  `property` varchar(128) NOT NULL DEFAULT '' COMMENT 'The property of the element''s value.',
  `delta` int unsigned NOT NULL DEFAULT '0' COMMENT 'The delta of the element''s value.',
  `value` mediumtext NOT NULL COMMENT 'The element''s value.',
  PRIMARY KEY (`sid`,`name`,`property`,`delta`),
  KEY `webform_id` (`webform_id`),
  KEY `sid_webform_id` (`sid`,`webform_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='Stores all submitted data for webform submissions.';


-- 2024-08-08 06:02:11
